(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     89920,       2069]*)
(*NotebookOutlinePosition[    127131,       3063]*)
(*  CellTagsIndexPosition[    127087,       3059]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Legal Notice, Disclaimer, and Book Ordering Information:", \
"Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "(* Legal Notice, Disclaimer, and Book Ordering Information:\n\nLast \
Modified: FIO Jan 10, 2003\n\n",
  StyleBox["Mathematica For Physics: 2nd Edition",
    FontColor->RGBColor[1, 0, 0]],
  "\n\nRobert L. Zimmerman and Fredrick I. Olness\n\nWebSite:  \n",
  StyleBox["  www.physics.smu.edu/~olness\n  darkwing.uoregon.edu/~phys600/\n\
\n",
    FontColor->RGBColor[1, 0, 0]],
  "MathSource Number: 0206-862",
  StyleBox["\n",
    FontColor->RGBColor[1, 0, 0]],
  "\nISBN 0-201-53796-6\nFor ordering information, call 1-800-282-0693\n\
Addison-Wesley Publishing Company\n\nCommunication with the authors:\n\
Fredrick I. Olness:  olness@mail.physics.smu.edu\nRobert L. Zimmerman: \
bob@zim.uoregon.edu\n\nCopyright 2002, Addison-Wesley Publishing Company, \
Inc. The material in\nthis file may be distributed freely  so long as the \
content remains\nunchanged, and the copyright and  reference notices are \
included. The\npublisher grants permission for the noncommercial use of these \
programs\nand program segments.  All other uses require the prior written \
consent\nof the publisher.    \n\nAll rights are reserved with regard to the  \
material in the\n\"Mathematica For Physics\" text, and may not be reproduced, \
stored in a\nretrieval system, or transmitted,  in any form or by any means,\n\
electronic, mechanical, photocopying,  recording, or otherwise, without\nthe \
prior written permission  of the publisher. \n\nThe programs and applications \
presented in this book have been included\nfor  their instructional value. \
They have been tested with care but are\nnot  guaranteed for any particular \
purpose. The publisher does not\noffer any  warranties or representations, \
nor does it accept any\nliabilities with  respect to the programs or \
applications. \n\n *)\n"
}], "Input",
  Evaluatable->False,
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell["Java Sample", "Title",
  TextAlignment->Center,
  TextJustification->0,
  Background->RGBColor[0.990997, 0.983993, 0.949996]],

Cell[TextData[{
  "This sample generates a simple ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " graphic in a external Java window. \n\nThis Notebook requires JLink from \
Wolfram and Java from Sun. "
}], "Subsection",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["Travelling Wave Animation", "Section",
  TextAlignment->Center,
  TextJustification->0,
  FontColor->RGBColor[0, 0, 1]],

Cell[TextData[{
  "Implementation using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s New JLink Capability"
}], "Subsection",
  TextAlignment->Center,
  TextJustification->0,
  FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell["Some Basic Setup", "Section",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Off[General::"\<spell\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Off[General::"\<spell1\>"];\)\)}], "Input",
  Hyphenation->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell["Load JLink: available from Wolfram at www.wri.com", "Subsection",
  TextAlignment->Center,
  TextJustification->0],

Cell[BoxData[
    \(\(\(\ \)\(<< JLink`\)\)\)], "Input"],

Cell["Load Java: available from Sun at java.sun.com", "Subsection",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\ \ \)\(InstallJava[]\)\)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`LinkObject[
      "java -classpath \
\"/usr/local/math41/AddOns/Applications/JLink/JLink.jar\" \
com.wolfram.jlink.Install", 2, 2]\)], "Output"]
}, Open  ]],

Cell[BoxData[
    StyleBox[\(\(\ \)\( (*\ Turn\ off\ FrontEnd\ for\ rendering\ *) \)\),
      FontColor->RGBColor[0, 0, 1]]], "Input",
  TextAlignment->Center,
  TextJustification->0],

Cell[BoxData[
    \(\(UseFrontEndForRendering = False;\)\)], "Input"],

Cell[BoxData[
    StyleBox[\(\(\ \)\( (*\ Set\ up\ Drawing\ Area\ *) \)\),
      FontColor->RGBColor[0, 0, 1]]], "Input",
  TextAlignment->Center,
  TextJustification->0],

Cell[BoxData[
    RowBox[{\(createWindow[]\), ":=", 
      RowBox[{"Module", "[", 
        RowBox[{\({frame}\), ",", "\[IndentingNewLine]", 
          
          RowBox[{\(frame = 
              JavaNew["\<com.wolfram.jlink.MathFrame\>", "\<Vibrating \
String\>"]\), ";", 
            "\[IndentingNewLine]", \(drawArea = 
              JavaNew["\<com.wolfram.jlink.MathCanvas\>"]\), ";", 
            "\[IndentingNewLine]", 
            RowBox[{"drawArea", "@", 
              RowBox[{
                StyleBox["setUsesFE",
                  PageWidth->Infinity,
                  ShowSpecialCharacters->False], 
                StyleBox["[",
                  PageWidth->Infinity,
                  ShowSpecialCharacters->False], "UseFrontEndForRendering", 
                StyleBox["]",
                  PageWidth->Infinity,
                  ShowSpecialCharacters->False]}]}], 
            StyleBox[";",
              PageWidth->Infinity,
              ShowSpecialCharacters->False], 
            "\[IndentingNewLine]", \(drawArea@setSize[800, 600]\), ";", 
            StyleBox["\n",
              PageWidth->Infinity,
              ShowSpecialCharacters->False,
              FontFamily->"Courier New",
              FontSize->10], \(JavaBlock[
              frame@setLayout[
                  JavaNew["\<java.awt.BorderLayout\>"]]; \
\[IndentingNewLine]frame@
                add[drawArea, 
                  ReturnAsJavaObject[
                    BorderLayout`CENTER]]; \[IndentingNewLine]frame@
                pack[]; \[IndentingNewLine]frame@
                setSize[800, 600]; \[IndentingNewLine]frame@
                setLocation[100, 100]; \[IndentingNewLine]JavaShow[frame]]\), 
            ";", "\n", "frame"}]}], "\n", "]"}]}]], "Input"],

Cell[BoxData[
    \(\(\(\ \)\( (*We\ can\ wrap\ the\ whole\ thing\ in\ JavaBlock\ and\ be\ \
sure\ that\ all\ the\ objects\ will\ get\ released, \ 
      needed\ during\ event\ \(\(handling\)\(.\)\)*) \)\)\)], "Input",
  TextAlignment->Center,
  TextJustification->0],

Cell["Define the plot: drawWave", "Subsection",
  TextAlignment->Center,
  TextJustification->0],

Cell[BoxData[
    \(\(colors = \({red, green, blue} = {RGBColor[1, 0, 0], 
            RGBColor[0, 1, 0], RGBColor[0, 0, 1]}\);\)\)], "Input"],

Cell[BoxData[
    \(\(\(\ \ \)\(\(drawWave[c_, 
        t_]\)\(:=\)\(\ \
\)\(\[IndentingNewLine]\)\(Plot[\[IndentingNewLine]{Cos[
              2\ \[Pi]\ \((x - c\ t)\)], Cos[2\ \[Pi]\ \((x + c\ t)\)], 
            Cos[2\ \[Pi]\ \((x - c\ t)\)] + Cos[2\ \[Pi]\ \((x + c\ t)\)]}\  // 
          Evaluate, {\[IndentingNewLine]x, \(-2\)\ , 
          2}, \[IndentingNewLine]PlotStyle -> {blue, 
            green, {Thickness[0.004], 
              red}}, \[IndentingNewLine]PlotRange -> {\(-2\), 
            2}, \[IndentingNewLine]AspectRatio -> 
          Automatic, \[IndentingNewLine]PlotLabel -> "\<Travelling Wave\>", \
\[IndentingNewLine]DisplayFunction -> Identity]\)\(\ \ \)\)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\ \)\(Show[drawWave[0.5, 1], 
        DisplayFunction -> $DisplayFunction];\)\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95238 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.476191 0.238095 [
[.02381 .46369 -6 -9 ]
[.02381 .46369 6 0 ]
[.2619 .46369 -6 -9 ]
[.2619 .46369 6 0 ]
[.7381 .46369 -3 -9 ]
[.7381 .46369 3 0 ]
[.97619 .46369 -3 -9 ]
[.97619 .46369 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .11905 -24 -4.5 ]
[.4875 .11905 0 4.5 ]
[.4875 .2381 -12 -4.5 ]
[.4875 .2381 0 4.5 ]
[.4875 .35714 -24 -4.5 ]
[.4875 .35714 0 4.5 ]
[.4875 .59524 -18 -4.5 ]
[.4875 .59524 0 4.5 ]
[.4875 .71429 -6 -4.5 ]
[.4875 .71429 0 4.5 ]
[.4875 .83333 -18 -4.5 ]
[.4875 .83333 0 4.5 ]
[.4875 .95238 -6 -4.5 ]
[.4875 .95238 0 4.5 ]
[.5 .96488 -47 0 ]
[.5 .96488 47 10.125 ]
[ 0 0 0 0 ]
[ 1 .95238 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .47619 m
.02381 .48244 L
s
[(-2)] .02381 .46369 0 1 Mshowa
.2619 .47619 m
.2619 .48244 L
s
[(-1)] .2619 .46369 0 1 Mshowa
.7381 .47619 m
.7381 .48244 L
s
[(1)] .7381 .46369 0 1 Mshowa
.97619 .47619 m
.97619 .48244 L
s
[(2)] .97619 .46369 0 1 Mshowa
.125 Mabswid
.07143 .47619 m
.07143 .47994 L
s
.11905 .47619 m
.11905 .47994 L
s
.16667 .47619 m
.16667 .47994 L
s
.21429 .47619 m
.21429 .47994 L
s
.30952 .47619 m
.30952 .47994 L
s
.35714 .47619 m
.35714 .47994 L
s
.40476 .47619 m
.40476 .47994 L
s
.45238 .47619 m
.45238 .47994 L
s
.54762 .47619 m
.54762 .47994 L
s
.59524 .47619 m
.59524 .47994 L
s
.64286 .47619 m
.64286 .47994 L
s
.69048 .47619 m
.69048 .47994 L
s
.78571 .47619 m
.78571 .47994 L
s
.83333 .47619 m
.83333 .47994 L
s
.88095 .47619 m
.88095 .47994 L
s
.92857 .47619 m
.92857 .47994 L
s
.25 Mabswid
0 .47619 m
1 .47619 L
s
.5 0 m
.50625 0 L
s
[(-2)] .4875 0 1 0 Mshowa
.5 .11905 m
.50625 .11905 L
s
[(-1.5)] .4875 .11905 1 0 Mshowa
.5 .2381 m
.50625 .2381 L
s
[(-1)] .4875 .2381 1 0 Mshowa
.5 .35714 m
.50625 .35714 L
s
[(-0.5)] .4875 .35714 1 0 Mshowa
.5 .59524 m
.50625 .59524 L
s
[(0.5)] .4875 .59524 1 0 Mshowa
.5 .71429 m
.50625 .71429 L
s
[(1)] .4875 .71429 1 0 Mshowa
.5 .83333 m
.50625 .83333 L
s
[(1.5)] .4875 .83333 1 0 Mshowa
.5 .95238 m
.50625 .95238 L
s
[(2)] .4875 .95238 1 0 Mshowa
.125 Mabswid
.5 .02381 m
.50375 .02381 L
s
.5 .04762 m
.50375 .04762 L
s
.5 .07143 m
.50375 .07143 L
s
.5 .09524 m
.50375 .09524 L
s
.5 .14286 m
.50375 .14286 L
s
.5 .16667 m
.50375 .16667 L
s
.5 .19048 m
.50375 .19048 L
s
.5 .21429 m
.50375 .21429 L
s
.5 .2619 m
.50375 .2619 L
s
.5 .28571 m
.50375 .28571 L
s
.5 .30952 m
.50375 .30952 L
s
.5 .33333 m
.50375 .33333 L
s
.5 .38095 m
.50375 .38095 L
s
.5 .40476 m
.50375 .40476 L
s
.5 .42857 m
.50375 .42857 L
s
.5 .45238 m
.50375 .45238 L
s
.5 .5 m
.50375 .5 L
s
.5 .52381 m
.50375 .52381 L
s
.5 .54762 m
.50375 .54762 L
s
.5 .57143 m
.50375 .57143 L
s
.5 .61905 m
.50375 .61905 L
s
.5 .64286 m
.50375 .64286 L
s
.5 .66667 m
.50375 .66667 L
s
.5 .69048 m
.50375 .69048 L
s
.5 .7381 m
.50375 .7381 L
s
.5 .7619 m
.50375 .7619 L
s
.5 .78571 m
.50375 .78571 L
s
.5 .80952 m
.50375 .80952 L
s
.5 .85714 m
.50375 .85714 L
s
.5 .88095 m
.50375 .88095 L
s
.5 .90476 m
.50375 .90476 L
s
.5 .92857 m
.50375 .92857 L
s
.25 Mabswid
.5 0 m
.5 .95238 L
s
gsave
.5 .96488 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Travelling) show
129.000 11.562 moveto
(Wave) show
153.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .95238 L
0 .95238 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .2381 m
.02499 .23821 L
.02605 .23851 L
.02729 .2391 L
.02846 .23988 L
.03053 .24183 L
.03279 .24474 L
.03527 .2489 L
.0379 .25436 L
.04262 .26682 L
.05205 .30122 L
.06244 .35149 L
.08274 .47249 L
.09394 .54196 L
.10458 .6028 L
.11464 .65127 L
.11995 .6721 L
.12562 .69007 L
.12831 .69697 L
.13085 .70244 L
.13333 .70679 L
.1356 .70993 L
.13777 .71214 L
.13886 .71296 L
.14005 .71363 L
.14125 .71407 L
.14254 .71428 L
.14376 .71422 L
.14487 .71395 L
.14605 .71344 L
.14715 .71276 L
.14837 .71177 L
.14967 .71044 L
.15234 .70687 L
.15478 .7026 L
.15925 .69236 L
.16395 .67834 L
.17387 .63891 L
.18471 .58322 L
.20596 .45371 L
.22527 .34094 L
.23491 .29599 L
.23999 .27683 L
.24536 .26044 L
.25006 .24964 L
.25273 .24505 L
.25401 .24325 L
.25522 .24179 L
.25632 .24068 L
.25751 .23969 L
Mistroke
.2586 .239 L
.25961 .23853 L
.26081 .2382 L
.26189 .2381 L
.26314 .23822 L
.26432 .23858 L
.26549 .23916 L
.26674 .24003 L
.26899 .24224 L
.27167 .24595 L
.27411 .25034 L
.27942 .26307 L
.28444 .27896 L
.2933 .31523 L
.30292 .36448 L
.32234 .48195 L
.33266 .54571 L
.34376 .6085 L
.35435 .65798 L
.35898 .67539 L
.36405 .69099 L
.36637 .69688 L
.36886 .70226 L
.371 .70612 L
.37332 .70948 L
.37469 .71105 L
.37595 .71222 L
.37716 .71309 L
.37844 .71376 L
.37958 .71413 L
.38065 .71428 L
.38182 .71422 L
.38307 .71391 L
.38429 .71336 L
.38498 .71294 L
.38563 .71247 L
.38835 .70977 L
.3907 .70646 L
.39323 .70189 L
.399 .68779 L
.40429 .67054 L
.41408 .62893 L
.4244 .57418 L
.44435 .45192 L
.46248 .34558 L
.47187 .30072 L
.47682 .28126 L
.48207 .26426 L
.48473 .25716 L
.48767 .2506 L
Mistroke
.49037 .24575 L
.49283 .24234 L
.49405 .24103 L
.49537 .23987 L
.49609 .23936 L
.49676 .23896 L
.49745 .23864 L
.49809 .2384 L
.49934 .23813 L
.50047 .23811 L
.50169 .23833 L
.50301 .23885 L
.50425 .23959 L
.50538 .24049 L
.50793 .24329 L
.51029 .24682 L
.51252 .25098 L
.51752 .2631 L
.52296 .28049 L
.53391 .32723 L
.54403 .38154 L
.5643 .50612 L
.57422 .56625 L
.58332 .61606 L
.592 .65618 L
.5966 .6737 L
.6015 .68921 L
.60409 .69598 L
.60644 .70124 L
.60884 .7057 L
.61104 .70899 L
.61352 .71176 L
.61483 .71281 L
.6155 .71324 L
.61621 .71362 L
.61741 .71406 L
.61853 .71426 L
.61922 .71428 L
.61987 .71423 L
.62109 .71394 L
.62234 .71339 L
.62304 .71296 L
.62369 .7125 L
.62614 .71013 L
.62836 .70713 L
.63071 .7031 L
.6356 .69194 L
.64095 .67561 L
.65048 .63699 L
.65935 .59183 L
Mistroke
.69833 .35757 L
.70854 .3069 L
.71392 .28491 L
.71963 .26581 L
.72461 .25301 L
.72744 .24744 L
.7301 .24338 L
.73135 .24186 L
.73253 .24066 L
.73361 .23976 L
.73476 .23902 L
.736 .23846 L
.73715 .23817 L
.73786 .2381 L
.73852 .23811 L
.73977 .23833 L
.74093 .23876 L
.74217 .23947 L
.74335 .24038 L
.74442 .2414 L
.74704 .2447 L
.74952 .24884 L
.75446 .25996 L
.75984 .27622 L
.76943 .31495 L
.77831 .36003 L
.79855 .48203 L
.81756 .59578 L
.8264 .64015 L
.83572 .67723 L
.84059 .69194 L
.84317 .69829 L
.84593 .70394 L
.84847 .70808 L
.85078 .71094 L
.8519 .71201 L
.8531 .71294 L
.85425 .71359 L
.8553 .714 L
.85655 .71426 L
.85774 .71426 L
.8588 .71406 L
.85997 .71362 L
.86123 .7129 L
.86257 .71185 L
.86499 .7092 L
.86744 .70555 L
.86974 .70124 L
.87405 .69097 L
.87922 .67501 L
Mistroke
.88397 .65707 L
.89469 .60667 L
.91514 .48577 L
.93422 .36982 L
.94365 .32064 L
.95257 .28287 L
.9575 .26647 L
.9601 .25924 L
.96286 .25268 L
.96517 .24809 L
.96773 .24401 L
.96885 .24255 L
.97005 .24121 L
.97109 .24025 L
.97223 .2394 L
.97323 .23882 L
.97416 .23844 L
.97514 .23819 L
.97619 .2381 L
Mfstroke
0 1 0 r
.02381 .2381 m
.02499 .23821 L
.02605 .23851 L
.02729 .2391 L
.02846 .23988 L
.03053 .24183 L
.03279 .24474 L
.03527 .2489 L
.0379 .25436 L
.04262 .26682 L
.05205 .30122 L
.06244 .35149 L
.08274 .47249 L
.09394 .54196 L
.10458 .6028 L
.11464 .65127 L
.11995 .6721 L
.12562 .69007 L
.12831 .69697 L
.13085 .70244 L
.13333 .70679 L
.1356 .70993 L
.13777 .71214 L
.13886 .71296 L
.14005 .71363 L
.14125 .71407 L
.14254 .71428 L
.14376 .71422 L
.14487 .71395 L
.14605 .71344 L
.14715 .71276 L
.14837 .71177 L
.14967 .71044 L
.15234 .70687 L
.15478 .7026 L
.15925 .69236 L
.16395 .67834 L
.17387 .63891 L
.18471 .58322 L
.20596 .45371 L
.22527 .34094 L
.23491 .29599 L
.23999 .27683 L
.24536 .26044 L
.25006 .24964 L
.25273 .24505 L
.25401 .24325 L
.25522 .24179 L
.25632 .24068 L
.25751 .23969 L
Mistroke
.2586 .239 L
.25961 .23853 L
.26081 .2382 L
.26189 .2381 L
.26314 .23822 L
.26432 .23858 L
.26549 .23916 L
.26674 .24003 L
.26899 .24224 L
.27167 .24595 L
.27411 .25034 L
.27942 .26307 L
.28444 .27896 L
.2933 .31523 L
.30292 .36448 L
.32234 .48195 L
.33266 .54571 L
.34376 .6085 L
.35435 .65798 L
.35898 .67539 L
.36405 .69099 L
.36637 .69688 L
.36886 .70226 L
.371 .70612 L
.37332 .70948 L
.37469 .71105 L
.37595 .71222 L
.37716 .71309 L
.37844 .71376 L
.37958 .71413 L
.38065 .71428 L
.38182 .71422 L
.38307 .71391 L
.38429 .71336 L
.38498 .71294 L
.38563 .71247 L
.38835 .70977 L
.3907 .70646 L
.39323 .70189 L
.399 .68779 L
.40429 .67054 L
.41408 .62893 L
.4244 .57418 L
.44435 .45192 L
.46248 .34558 L
.47187 .30072 L
.47682 .28126 L
.48207 .26426 L
.48473 .25716 L
.48767 .2506 L
Mistroke
.49037 .24575 L
.49283 .24234 L
.49405 .24103 L
.49537 .23987 L
.49609 .23936 L
.49676 .23896 L
.49745 .23864 L
.49809 .2384 L
.49934 .23813 L
.50047 .23811 L
.50169 .23833 L
.50301 .23885 L
.50425 .23959 L
.50538 .24049 L
.50793 .24329 L
.51029 .24682 L
.51252 .25098 L
.51752 .2631 L
.52296 .28049 L
.53391 .32723 L
.54403 .38154 L
.5643 .50612 L
.57422 .56625 L
.58332 .61606 L
.592 .65618 L
.5966 .6737 L
.6015 .68921 L
.60409 .69598 L
.60644 .70124 L
.60884 .7057 L
.61104 .70899 L
.61352 .71176 L
.61483 .71281 L
.6155 .71324 L
.61621 .71362 L
.61741 .71406 L
.61853 .71426 L
.61922 .71428 L
.61987 .71423 L
.62109 .71394 L
.62234 .71339 L
.62304 .71296 L
.62369 .7125 L
.62614 .71013 L
.62836 .70713 L
.63071 .7031 L
.6356 .69194 L
.64095 .67561 L
.65048 .63699 L
.65935 .59183 L
Mistroke
.69833 .35757 L
.70854 .3069 L
.71392 .28491 L
.71963 .26581 L
.72461 .25301 L
.72744 .24744 L
.7301 .24338 L
.73135 .24186 L
.73253 .24066 L
.73361 .23976 L
.73476 .23902 L
.736 .23846 L
.73715 .23817 L
.73786 .2381 L
.73852 .23811 L
.73977 .23833 L
.74093 .23876 L
.74217 .23947 L
.74335 .24038 L
.74442 .2414 L
.74704 .2447 L
.74952 .24884 L
.75446 .25996 L
.75984 .27622 L
.76943 .31495 L
.77831 .36003 L
.79855 .48203 L
.81756 .59578 L
.8264 .64015 L
.83572 .67723 L
.84059 .69194 L
.84317 .69829 L
.84593 .70394 L
.84847 .70808 L
.85078 .71094 L
.8519 .71201 L
.8531 .71294 L
.85425 .71359 L
.8553 .714 L
.85655 .71426 L
.85774 .71426 L
.8588 .71406 L
.85997 .71362 L
.86123 .7129 L
.86257 .71185 L
.86499 .7092 L
.86744 .70555 L
.86974 .70124 L
.87405 .69097 L
.87922 .67501 L
Mistroke
.88397 .65707 L
.89469 .60667 L
.91514 .48577 L
.93422 .36982 L
.94365 .32064 L
.95257 .28287 L
.9575 .26647 L
.9601 .25924 L
.96286 .25268 L
.96517 .24809 L
.96773 .24401 L
.96885 .24255 L
.97005 .24121 L
.97109 .24025 L
.97223 .2394 L
.97323 .23882 L
.97416 .23844 L
.97514 .23819 L
.97619 .2381 L
Mfstroke
1 0 0 r
.004 w
.02381 0 m
.02499 .00023 L
.02605 .00084 L
.02729 .00201 L
.02846 .00358 L
.03053 .00747 L
.03279 .0133 L
.03527 .0216 L
.0379 .03253 L
.04262 .05746 L
.05205 .12625 L
.06244 .22679 L
.08274 .46878 L
.09394 .60772 L
.10458 .72941 L
.11464 .82634 L
.11995 .86801 L
.12562 .90395 L
.12831 .91774 L
.13085 .92869 L
.13333 .9374 L
.1356 .94368 L
.13777 .94809 L
.13886 .94973 L
.14005 .95108 L
.14125 .95195 L
.14254 .95236 L
.14376 .95225 L
.14487 .95171 L
.14605 .9507 L
.14715 .94933 L
.14837 .94736 L
.14967 .9447 L
.15234 .93755 L
.15478 .929 L
.15925 .90852 L
.16395 .88048 L
.17387 .80164 L
.18471 .69026 L
.20596 .43123 L
.22527 .20569 L
.23491 .1158 L
.23999 .07747 L
.24536 .04468 L
.25006 .02309 L
.25273 .0139 L
.25401 .01031 L
.25522 .00738 L
.25632 .00516 L
.25751 .00319 L
Mistroke
.2586 .00181 L
.25961 .00087 L
.26081 .0002 L
.26189 0 L
.26314 .00025 L
.26432 .00097 L
.26549 .00213 L
.26674 .00386 L
.26899 .0083 L
.27167 .01572 L
.27411 .02448 L
.27942 .04994 L
.28444 .08173 L
.2933 .15426 L
.30292 .25276 L
.32234 .48771 L
.33266 .61522 L
.34376 .74081 L
.35435 .83977 L
.35898 .87458 L
.36405 .90578 L
.36637 .91758 L
.36886 .92833 L
.371 .93606 L
.37332 .94276 L
.37469 .9459 L
.37595 .94825 L
.37716 .95 L
.37844 .95133 L
.37958 .95207 L
.38065 .95237 L
.38182 .95226 L
.38307 .95163 L
.38429 .95054 L
.38498 .94969 L
.38563 .94876 L
.38835 .94334 L
.3907 .93672 L
.39323 .9276 L
.399 .8994 L
.40429 .86489 L
.41408 .78168 L
.4244 .67216 L
.44435 .42766 L
.46248 .21496 L
.47187 .12525 L
.47682 .08633 L
.48207 .05234 L
.48473 .03813 L
.48767 .025 L
Mistroke
.49037 .01531 L
.49283 .00849 L
.49405 .00587 L
.49537 .00356 L
.49609 .00253 L
.49676 .00174 L
.49745 .00108 L
.49809 .00061 L
.49934 7e-05 L
.50047 4e-05 L
.50169 .00047 L
.50301 .0015 L
.50425 .00299 L
.50538 .0048 L
.50793 .01039 L
.51029 .01745 L
.51252 .02577 L
.51752 .05002 L
.52296 .08478 L
.53391 .17826 L
.54403 .28689 L
.5643 .53605 L
.57422 .65631 L
.58332 .75593 L
.592 .83617 L
.5966 .87121 L
.6015 .90222 L
.60409 .91577 L
.60644 .92629 L
.60884 .9352 L
.61104 .9418 L
.61352 .94733 L
.61483 .94943 L
.6155 .95029 L
.61621 .95105 L
.61741 .95194 L
.61853 .95234 L
.61922 .95238 L
.61987 .95227 L
.62109 .95169 L
.62234 .95058 L
.62304 .94973 L
.62369 .94881 L
.62614 .94407 L
.62836 .93806 L
.63071 .93001 L
.6356 .90769 L
.64095 .87504 L
.65048 .79778 L
.65935 .70747 L
Mistroke
.69833 .23895 L
.70854 .13761 L
.71392 .09363 L
.71963 .05543 L
.72461 .02983 L
.72744 .01869 L
.7301 .01056 L
.73135 .00753 L
.73253 .00513 L
.73361 .00334 L
.73476 .00185 L
.736 .00073 L
.73715 .00015 L
.73786 1e-05 L
.73852 3e-05 L
.73977 .00046 L
.74093 .00133 L
.74217 .00275 L
.74335 .00457 L
.74442 .00661 L
.74704 .0132 L
.74952 .0215 L
.75446 .04373 L
.75984 .07624 L
.76943 .15372 L
.77831 .24386 L
.79855 .48788 L
.81756 .71537 L
.8264 .80411 L
.83572 .87827 L
.84059 .90769 L
.84317 .92039 L
.84593 .93169 L
.84847 .93997 L
.85078 .94569 L
.8519 .94782 L
.8531 .94968 L
.85425 .95099 L
.8553 .95182 L
.85655 .95232 L
.85774 .95232 L
.8588 .95192 L
.85997 .95106 L
.86123 .94962 L
.86257 .9475 L
.86499 .94222 L
.86744 .93492 L
.86974 .9263 L
.87405 .90575 L
.87922 .87382 L
Mistroke
.88397 .83795 L
.89469 .73715 L
.91514 .49536 L
.93422 .26346 L
.94365 .16508 L
.95257 .08955 L
.9575 .05675 L
.9601 .04229 L
.96286 .02917 L
.96517 .01998 L
.96773 .01183 L
.96885 .00892 L
.97005 .00624 L
.97109 .00431 L
.97223 .0026 L
.97323 .00145 L
.97416 .00068 L
.97514 .00018 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{250, 238.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003j0000kR000`400?l00000o`00003onP3oool0
0?X0oooo003j0?ooo`00M03oool400000880oooo001d0?ooo`030000003oool0oooo08<0oooo000>
0?ooo`80o`00=@3oool20?l002h0oooo00<000000?ooo`3oool0103oool20?l000030000003oool0
oooo0340oooo0`3o000d0?ooo`80o`003`3oool00100oooo00<0o`000?ooo`3oool0<@3oool00`3o
0000oooo0?l0000W0?ooo`@00000103oool00`000000oooo0?ooo`020?ooo`030?l000000000o`00
03@0oooo00@0o`000?ooo`3o0000o`00<`3oool00`3o0000oooo0?ooo`0>0?ooo`00403oool00`3o
0000oooo0?ooo`0a0?ooo`040?l0003oool0oooo0?l002l0oooo00P000000?ooo`3oool0oooo0?l0
00000000oooo0?l00380oooo0P3o00020?ooo`030?l0003oool0oooo0300oooo00<0o`000?ooo`3o
ool03`3oool00140oooo00<0o`000?ooo`3oool0;`3oool01@3o0000oooo0?ooo`3oool0o`0002`0
oooo00@000000?ooo`3oool000000P3oool01@3o0000oooo0000003oool0o`000380oooo00D0o`00
0?ooo`3oool0oooo0?l0000b0?ooo`030?l0003oool0oooo00l0oooo000A0?ooo`030?l0003oool0
oooo02l0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0Z0?ooo`8000000`3oool0
0`3o0000oooo000000020?ooo`030?l0003oool0oooo02l0oooo00D0o`000?ooo`3oool0oooo0?l0
000b0?ooo`030?l0003oool0oooo00l0oooo000A0?ooo`030?l0003oool0oooo02l0oooo00<0o`00
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`0^0?ooo`030?l0003oool0oooo0080000000<0oooo
0?l0003oool0<03oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo02h0oooo00<0o`00
0?ooo`3oool0403oool00140oooo00<0o`000?ooo`3oool0;`3oool00`3o0000oooo0?ooo`020?oo
o`030?l0003oool0oooo02h0oooo00@0o`000?ooo`3oool000000P3oool00`3o0000oooo0?ooo`0^
0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0;P3oool00`3o0000oooo0?ooo`0@
0?ooo`004P3oool00`3o0000oooo0?ooo`0^0?ooo`030?l0003oool0oooo0080oooo00<0o`000?oo
o`3oool0;P3oool0103o0000oooo0?ooo`0000020?ooo`030?l0003oool0oooo02h0oooo00<0o`00
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`0^0?ooo`030?l0003oool0oooo0100oooo000B0?oo
o`030?l0003oool0oooo02d0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0^0?oo
o`040?l0003oool0oooo00000080oooo00<0o`000?ooo`3oool0;P3oool00`3o0000oooo0?ooo`04
0?ooo`030?l0003oool0oooo02d0oooo00<0o`000?ooo`3oool0403oool00180oooo00<0o`000?oo
o`3oool0;@3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo02d0oooo00@0o`000?oo
o`3oool000000`3oool00`3o0000oooo0?ooo`0]0?ooo`030?l0003oool0oooo00@0oooo00<0o`00
0?ooo`3oool0;03oool00`3o0000oooo0?ooo`0A0?ooo`004P3oool00`3o0000oooo0?ooo`0]0?oo
o`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0;@3oool0103o0000oooo0?ooo`000003
0?ooo`030?l0003oool0oooo02d0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0/
0?ooo`030?l0003oool0oooo0140oooo000C0?ooo`030?l0003oool0oooo02`0oooo00<0o`000?oo
o`3oool0103oool00`3o0000oooo0?ooo`0/0?ooo`040?l0003oool0oooo0?ooo`8000000P3oool0
0`3o0000oooo0?ooo`0/0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0;03oool0
0`3o0000oooo0?ooo`0A0?ooo`004`3oool00`3o0000oooo0?ooo`0/0?ooo`030?l0003oool0oooo
00@0oooo00<0o`000?ooo`3oool0;03oool01@3o0000oooo0?ooo`3oool0000000<0oooo00<0o`00
0?ooo`3oool0;03oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo02`0oooo00<0o`00
0?ooo`3oool04@3oool001<0oooo00<0o`000?ooo`3oool0:`3oool00`3o0000oooo0?ooo`050?oo
o`030?l0003oool0oooo02`0oooo00D0o`000?ooo`3oool0oooo000000030?ooo`030?l0003oool0
oooo02`0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0/0?ooo`030?l0003oool0
oooo0140oooo000C0?ooo`030?l0003oool0oooo02/0oooo00<0o`000?ooo`3oool01P3oool00`3o
0000oooo0?ooo`0[0?ooo`050?l0003oool0oooo0?ooo`000000103oool00`3o0000oooo0?ooo`0[
0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0;03oool00`3o0000oooo0?ooo`0A
0?ooo`004`3oool00`3o0000oooo0?ooo`0[0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?oo
o`3oool0:`3oool01@3o0000oooo0?ooo`3oool0000000@0oooo00<0o`000?ooo`3oool0:`3oool0
0`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo02/0oooo00<0o`000?ooo`3oool04@3oool0
01<0oooo00<0o`000?ooo`3oool0:`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo
02/0oooo00@0o`000?ooo`3oool0oooo0P0000030?ooo`030?l0003oool0oooo02/0oooo00<0o`00
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`0[0?ooo`030?l0003oool0oooo0140oooo000C0?oo
o`030?l0003oool0oooo02X0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0Z0?oo
o`030?l0003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0[0?oo
o`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool0:`3oool00`3o0000oooo0?ooo`0A0?oo
o`00503oool00`3o0000oooo0?ooo`0Y0?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3o
ool0:@3oool00`3o0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<0o`000?ooo`3o
ool0:@3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo02X0oooo00<0o`000?ooo`3o
ool04P3oool001@0oooo00<0o`000?ooo`3oool0:@3oool00`3o0000oooo0?ooo`080?ooo`030?l0
003oool0oooo02T0oooo00<0o`000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030?l0
003oool0oooo02T0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0Z0?ooo`030?l0
003oool0oooo0180oooo000D0?ooo`030?l0003oool0oooo02T0oooo00<0o`000?ooo`3oool0203o
ool00`3o0000oooo0?ooo`0Y0?ooo`030?l0003oool0oooo0080oooo00<000000?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`0Y0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0:P3o
ool00`3o0000oooo0?ooo`0B0?ooo`00503oool00`3o0000oooo0?ooo`0Y0?ooo`030?l0003oool0
oooo00P0oooo00<0o`000?ooo`3oool0:@3oool00`3o0000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00<0o`000?ooo`3oool0:@3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0
oooo02X0oooo00<0o`000?ooo`3oool04P3oool001@0oooo00<0o`000?ooo`3oool0:@3oool00`3o
0000oooo0?ooo`080?ooo`030?l0003oool0oooo02T0oooo00<0o`000?ooo`3oool00P3oool20000
00@0oooo00<0o`000?ooo`3oool0:@3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo
02X0oooo00<0o`000?ooo`3oool04P3oool001@0oooo00<0o`000?ooo`3oool0:03oool00`3o0000
oooo0?ooo`090?ooo`030?l0003oool0oooo02T0oooo00<0o`000?ooo`3oool00P3oool00`000000
oooo0?ooo`030?ooo`030?l0003oool0oooo02T0oooo00<0o`000?ooo`3oool0203oool00`3o0000
oooo0?ooo`0Y0?ooo`030?l0003oool0oooo0180oooo000D0?ooo`030?l0003oool0oooo02P0oooo
00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`0X0?ooo`030?l0003oool0oooo0080oooo
00<000000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0Y0?ooo`030?l0003oool0oooo00P0oooo
00<0o`000?ooo`3oool0:@3oool00`3o0000oooo0?ooo`0B0?ooo`00503oool00`3o0000oooo0?oo
o`0X0?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool06@3oool4000000<0oooo00<0
00000?ooo`3oool00P3oool2000000030?l0003oool0oooo00<0oooo00<000000?ooo`3oool0103o
ool00`3o0000oooo0?ooo`0W0?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool0:@3o
ool00`3o0000oooo0?ooo`0B0?ooo`005@3oool00`3o0000oooo0?ooo`0W0?ooo`030?l0003oool0
oooo00X0oooo00<0o`000?ooo`3oool06`3oool00`000000oooo0?ooo`090?ooo`030?l000000000
oooo00<0oooo00<000000?ooo`3oool0103oool00`3o0000oooo0?ooo`0W0?ooo`030?l0003oool0
oooo00T0oooo00<0o`000?ooo`3oool0:03oool00`3o0000oooo0?ooo`0C0?ooo`005@3oool00`3o
0000oooo0?ooo`0W0?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool06`3oool00`00
0000oooo0?ooo`090?ooo`030?l000000000oooo00<0oooo0`0000040?ooo`030?l0003oool0oooo
02L0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`0X0?ooo`030?l0003oool0oooo
01<0oooo000E0?ooo`030?l0003oool0oooo02L0oooo00<0o`000?ooo`3oool02P3oool00`3o0000
oooo0?ooo`0C0?ooo`@00000103oool00`000000oooo0?ooo`070?ooo`80000000<0o`000?ooo`3o
ool00`3oool00`000000oooo0?ooo`040?ooo`030?l0003oool0oooo02L0oooo00<0o`000?ooo`3o
ool02@3oool00`3o0000oooo0?ooo`0X0?ooo`030?l0003oool0oooo01<0oooo000E0?ooo`030?l0
003oool0oooo02L0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`0K0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3o00001@3oool00`000000oooo0?ooo`040?ooo`030?l0
003oool0oooo02L0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`0X0?ooo`030?l0
003oool0oooo01<0oooo000E0?ooo`030?l0003oool0oooo02L0oooo00<0o`000?ooo`3oool02P3o
ool00`3o0000oooo0?ooo`0I0?ooo`<000002@3oool00`000000oooo0?l000050?ooo`030000003o
ool0oooo00@0oooo00<0o`000?ooo`3oool09P3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003o
ool0oooo02P0oooo00<0o`000?ooo`3oool04`3oool001D0oooo00<0o`000?ooo`3oool09`3oool0
0`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo01/0oooo00<000000?ooo`3oool01`3oool2
000000030?l000000000oooo00<0oooo00<000000?ooo`3oool0103oool00`3o0000oooo0?ooo`0V
0?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool09`3oool00`3o0000oooo0?ooo`0C
0?ooo`005@3oool00`3o0000oooo0?ooo`0W0?ooo`030?l0003oool0oooo00/0oooo00<0o`000?oo
o`3oool09P3oool00`3o0000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<0o`000?oo
o`3oool09P3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo02L0oooo00<0o`000?oo
o`3oool04`3oool001D0oooo00<0o`000?ooo`3oool09P3oool00`3o0000oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo02H0oooo00<0o`000?ooo`3oool00`3oool2000000D0oooo00<0o`000?ooo`3o
ool09P3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo02L0oooo00<0o`000?ooo`3o
ool04`3oool001D0oooo00<0o`000?ooo`3oool09P3oool00`3o0000oooo0?ooo`0<0?ooo`030?l0
003oool0oooo02H0oooo00<0o`000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030?l0
003oool0oooo02H0oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?ooo`0V0?ooo`030?l0
003oool0oooo01@0oooo000F0?ooo`030?l0003oool0oooo02D0oooo00<0o`000?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0U0?ooo`030?l0003oool0oooo00@0oooo00<000000?ooo`3oool0103o
ool00`3o0000oooo0?ooo`0V0?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool09P3o
ool00`3o0000oooo0?ooo`0D0?ooo`005P3oool00`3o0000oooo0?ooo`0U0?ooo`030?l0003oool0
oooo00`0oooo00<0o`000?ooo`3oool09@3oool00`3o0000oooo0?ooo`040?ooo`030000003oool0
oooo00D0oooo00<0o`000?ooo`3oool09@3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0
oooo02H0oooo00<0o`000?ooo`3oool0503oool001H0oooo00<0o`000?ooo`3oool09@3oool00`3o
0000oooo0?ooo`0<0?ooo`030?l0003oool0oooo02D0oooo00<0o`000?ooo`3oool0103oool00`00
0000oooo0?ooo`050?ooo`030?l0003oool0oooo02D0oooo00<0o`000?ooo`3oool02`3oool00`3o
0000oooo0?ooo`0V0?ooo`030?l0003oool0oooo01@0oooo000F0?ooo`030?l0003oool0oooo02D0
oooo00<0o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`0U0?ooo`030?l0003oool0oooo00@0
oooo0P0000060?ooo`030?l0003oool0oooo02@0oooo00<0o`000?ooo`3oool0303oool00`3o0000
oooo0?ooo`0V0?ooo`030?l0003oool0oooo01@0oooo000F0?ooo`030?l0003oool0oooo02D0oooo
00<0o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`0U0?ooo`030?l0003oool0oooo00@0oooo
00<000000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0T0?ooo`030?l0003oool0oooo00`0oooo
00<0o`000?ooo`3oool09P3oool00`3o0000oooo0?ooo`0D0?ooo`005P3oool00`3o0000oooo0?oo
o`0U0?ooo`030?l0003oool0oooo00`0oooo00<0o`000?ooo`3oool09@3oool00`3o0000oooo0?oo
o`040?ooo`030000003oool0oooo00D0oooo00<0o`000?ooo`3oool0903oool00`3o0000oooo0?oo
o`0<0?ooo`030?l0003oool0oooo02H0oooo00<0o`000?ooo`3oool0503oool001H0oooo00<0o`00
0?ooo`3oool09@3oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003oool0oooo02@0oooo00<0o`00
0?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030?l0003oool0oooo02@0oooo00<0o`00
0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0U0?ooo`030?l0003oool0oooo01@0oooo000F0?oo
o`030?l0003oool0oooo02D0oooo00<0o`000?ooo`3oool03@3oool00`3o0000oooo0?ooo`0T0?oo
o`030?l0003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0T0?oo
o`030?l0003oool0oooo00d0oooo00<0o`000?ooo`3oool0903oool00`3o0000oooo0?ooo`0E0?oo
o`005P3oool00`3o0000oooo0?ooo`0T0?ooo`030?l0003oool0oooo00h0oooo00<0o`000?ooo`3o
ool0903oool00`3o0000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<0o`000?ooo`3o
ool0903oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003oool0oooo02@0oooo00<0o`000?ooo`3o
ool05@3oool001H0oooo00<0o`000?ooo`3oool0903oool00`3o0000oooo0?ooo`0>0?ooo`030?l0
003oool0oooo02@0oooo00<0o`000?ooo`3oool0103oool2000000H0oooo00<0o`000?ooo`3oool0
903oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003oool0oooo02@0oooo00<0o`000?ooo`3oool0
5@3oool001H0oooo00<0o`000?ooo`3oool0903oool00`3o0000oooo0?ooo`0>0?ooo`030?l0003o
ool0oooo02<0oooo00<0o`000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030?l0003o
ool0oooo02@0oooo00<0o`000?ooo`3oool03@3oool00`3o0000oooo0?ooo`0T0?ooo`030?l0003o
ool0oooo01D0oooo000F0?ooo`030?l0003oool0oooo02@0oooo00<0o`000?ooo`3oool03P3oool0
0`3o0000oooo0?ooo`0S0?ooo`030?l0003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`0T0?ooo`030?l0003oool0oooo00d0oooo00<0o`000?ooo`3oool0903oool0
0`3o0000oooo0?ooo`0E0?ooo`005`3oool00`3o0000oooo0?ooo`0S0?ooo`030?l0003oool0oooo
00h0oooo00<0o`000?ooo`3oool08`3oool00`3o0000oooo0?ooo`050?ooo`030000003oool0oooo
00D0oooo00<0o`000?ooo`3oool0903oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003oool0oooo
02@0oooo00<0o`000?ooo`3oool05@3oool001L0oooo00<0o`000?ooo`3oool08`3oool00`3o0000
oooo0?ooo`0>0?ooo`030?l0003oool0oooo02<0oooo00<0o`000?ooo`3oool01@3oool00`000000
oooo0?ooo`060?ooo`030?l0003oool0oooo02<0oooo00<0o`000?ooo`3oool03@3oool00`3o0000
oooo0?ooo`0T0?ooo`030?l0003oool0oooo01D0oooo000G0?ooo`030?l0003oool0oooo02<0oooo
00<0o`000?ooo`3oool03P3oool00`3o0000oooo0?ooo`0S0?ooo`030?l0003oool0oooo00D0oooo
0P0000070?ooo`030?l0003oool0oooo02<0oooo00<0o`000?ooo`3oool03@3oool00`3o0000oooo
0?ooo`0T0?ooo`030?l0003oool0oooo01D0oooo000G0?ooo`030?l0003oool0oooo02<0oooo00<0
o`000?ooo`3oool03P3oool00`3o0000oooo0?ooo`0S0?ooo`030?l0003oool0oooo00D0oooo00<0
00000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0R0?ooo`030?l0003oool0oooo00h0oooo00<0
o`000?ooo`3oool08`3oool00`3o0000oooo0?ooo`0F0?ooo`005`3oool00`3o0000oooo0?ooo`0S
0?ooo`030?l0003oool0oooo00h0oooo00<0o`000?ooo`3oool08`3oool00`3o0000oooo0?ooo`05
0?ooo`030000003oool0oooo00H0oooo00<0o`000?ooo`3oool08P3oool00`3o0000oooo0?ooo`0?
0?ooo`030?l0003oool0oooo0280oooo00<0o`000?ooo`3oool05P3oool001L0oooo00<0o`000?oo
o`3oool08`3oool00`3o0000oooo0?ooo`0>0?ooo`030?l0003oool0oooo02<0oooo00<0o`000?oo
o`3oool01@3oool00`000000oooo0?ooo`060?ooo`030?l0003oool0oooo0280oooo00<0o`000?oo
o`3oool03`3oool00`3o0000oooo0?ooo`0R0?ooo`030?l0003oool0oooo01H0oooo000G0?ooo`03
0?l0003oool0oooo0280oooo00<0o`000?ooo`3oool0403oool00`3o0000oooo0?ooo`0R0?ooo`04
0?l0000000000000000000@0oooo00<000000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0R0?oo
o`030?l0003oool0oooo00l0oooo00<0o`000?ooo`3oool08P3oool00`3o0000oooo0?ooo`0F0?oo
o`005`3oool00`3o0000oooo0?ooo`0R0?ooo`030?l0003oool0oooo0100oooo00<0o`000?ooo`3o
ool08P3oool00`3o0000oooo000000050?ooo`030000003oool0oooo00H0oooo00<0o`000?ooo`3o
ool08P3oool00`3o0000oooo0?ooo`0?0?ooo`030?l0003oool0oooo0280oooo00<0o`000?ooo`3o
ool05P3oool000h0oooo0`00o`060?ooo`030?l0003oool0oooo0280oooo00<0o`000?ooo`3oool0
1@3oool3003o00P0oooo00<0o`000?ooo`3oool08@3oool0103o0000oooo0?ooo`0000040?ooo`<0
0?l000<000000?ooo`3oool0103oool00`3o0000oooo0?ooo`0R0?ooo`030?l0003oool0oooo00D0
oooo0`00o`070?ooo`030?l0003oool0oooo0280oooo00<0o`000?ooo`3oool01@3oool2003o00l0
oooo000@0?ooo`800?l01@3oool00`3o0000oooo0?ooo`0R0?ooo`030?l0003oool0oooo00@0oooo
0P00o`020?ooo`03003o003oool0oooo00D0oooo00<0o`000?ooo`3oool0703oool4000000050?oo
o`3o0000oooo0?ooo`000000103oool01000o`0000000?ooo`00o`060?ooo`030?l0003oool0oooo
0280oooo00<0o`000?ooo`3oool0103oool2003o0080oooo00<00?l00?ooo`3oool0103oool00`3o
0000oooo0?ooo`0R0?ooo`030?l0003oool0oooo00@0oooo0P00o`0@0?ooo`004@3oool00`00o`00
oooo0?ooo`030?ooo`030?l0003oool0oooo0280oooo00<0o`000?ooo`3oool0103oool00`00o`00
oooo0?ooo`020?ooo`03003o003oool0oooo00@0oooo00<0o`000?ooo`3oool08@3oool0103o0000
oooo0?ooo`0000030?ooo`03003o003oool000000080oooo00<00?l00?ooo`3oool00`3oool00`3o
0000oooo0?ooo`0R0?ooo`030?l0003oool0oooo00@0oooo00<00?l00?ooo`3oool00P3oool00`00
o`00oooo0?ooo`030?ooo`030?l0003oool0oooo0280oooo00<0o`000?ooo`3oool00`3oool00`00
o`00oooo0?ooo`0@0?ooo`004@3oool00`00o`00oooo0?ooo`040?ooo`030?l0003oool0oooo0240
oooo00<0o`000?ooo`3oool0103oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo00@0
oooo00<0o`000?ooo`3oool08@3oool0103o000000000000000000020?ooo`04003o003oool0oooo
00000080oooo00<00?l00?ooo`3oool00`3oool00`3o0000oooo0?ooo`0R0?ooo`030?l0003oool0
oooo00<0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`030?ooo`030?l0003oool0
oooo0240oooo00<0o`000?ooo`3oool0103oool00`00o`00oooo0?ooo`0@0?ooo`004P3oool00`00
o`00oooo0?ooo`030?ooo`030?l0003oool0oooo0240oooo00<0o`000?ooo`3oool00`3oool00`00
o`00oooo0?ooo`030?ooo`03003o003oool0oooo00@0oooo00<0o`000?ooo`3oool08@3oool0103o
0000oooo0?ooo`0000020?ooo`04003o003oool0oooo00000080oooo00<00?l00?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`0R0?ooo`030?l0003oool0oooo00<0oooo00<00?l00?ooo`3oool0103o
ool00`00o`00oooo0?ooo`020?ooo`030?l0003oool0oooo0240oooo00<0o`000?ooo`3oool0103o
ool00`00o`00oooo0?ooo`0@0?ooo`004P3oool00`00o`00oooo0?ooo`030?ooo`030?l0003oool0
oooo0240oooo00<0o`000?ooo`3oool00`3oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0
oooo00<0oooo00<0o`000?ooo`3oool08@3oool00`3o0000oooo0?ooo`030?ooo`03003o003oool0
oooo008000000P3oool00`00o`00oooo0?ooo`030?ooo`030?l0003oool0oooo0240oooo00<0o`00
0?ooo`3oool00P3oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo0080oooo00<0o`00
0?ooo`3oool08@3oool00`3o0000oooo0?ooo`030?ooo`03003o003oool0oooo0140oooo000C0?oo
o`03003o003oool0oooo0080oooo00<0o`000?ooo`3oool08@3oool00`3o0000oooo0?ooo`030?oo
o`03003o003oool0oooo00@0oooo00<00?l00?ooo`3oool00`3oool00`3o0000oooo0?ooo`0Q0?oo
o`030?l0003oool0oooo0080oooo00D00?l00?ooo`3oool0oooo000000030?ooo`03003o003oool0
oooo00<0oooo00<0o`000?ooo`3oool08@3oool00`3o0000oooo0?ooo`020?ooo`03003o003oool0
oooo00D0oooo00<00?l00?ooo`3oool00P3oool00`3o0000oooo0?ooo`0Q0?ooo`030?l0003oool0
oooo00<0oooo00<00?l00?ooo`3oool04@3oool001<0oooo00<00?l00?ooo`3oool00P3oool00`3o
0000oooo0?ooo`0Q0?ooo`030?l0003oool0oooo0080oooo00<00?l00?ooo`3oool01P3oool00`00
o`00oooo0?ooo`020?ooo`030?l0003oool0oooo0240oooo00<0o`000?ooo`3oool00P3oool01@00
o`00oooo0?ooo`3oool0000000<0oooo00<00?l00?ooo`3oool00`3oool00`3o0000oooo0?ooo`0P
0?ooo`030?l0003oool0oooo00<0oooo00<00?l00?ooo`3oool01@3oool00`00o`00oooo0?ooo`03
0?ooo`030?l0003oool0oooo0200oooo00<0o`000?ooo`3oool00`3oool00`00o`00oooo0?ooo`0A
0?ooo`004`3oool00`00o`00oooo0?ooo`020?ooo`030?l0003oool0oooo0200oooo00<0o`000?oo
o`3oool00`3oool00`00o`00oooo0?ooo`060?ooo`03003o003oool0oooo0080oooo00<0o`000?oo
o`3oool08@3oool00`3o0000oooo0?ooo`020?ooo`05003o003oool0oooo0?ooo`000000103oool0
0`00o`00oooo0?ooo`020?ooo`030?l0003oool0oooo0200oooo00<0o`000?ooo`3oool00`3oool0
0`00o`00oooo0?ooo`060?ooo`03003o003oool0oooo0080oooo00<0o`000?ooo`3oool0803oool0
0`3o0000oooo0?ooo`030?ooo`03003o003oool0oooo0140oooo000D0?ooo`05003o003oool0oooo
0?ooo`3o00008P3oool00`3o0000oooo0?ooo`020?ooo`03003o003oool0oooo00P0oooo00D00?l0
0?ooo`3oool0oooo0?l0000S0?ooo`050?l0003oool0oooo0?ooo`00o`00103oool00`000000oooo
0?ooo`020?ooo`03003o003oool0oooo0080oooo00<0o`000?ooo`3oool0803oool00`3o0000oooo
0?ooo`020?ooo`03003o003oool0oooo00L0oooo00<00?l00?ooo`3oool00P3oool00`3o0000oooo
0?ooo`0P0?ooo`030?l0003oool0oooo0080oooo00<00?l00?ooo`3oool04P3oool001@0oooo00D0
0?l00?ooo`3oool0oooo0?l0000R0?ooo`030?l0003oool0oooo0080oooo00<00?l00?ooo`3oool0
203oool00`00o`00oooo0?ooo`020?ooo`030?l0003oool0oooo01l0oooo00<0o`000?ooo`3oool0
0P3oool00`00o`00oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00D00?l00?ooo`3oool0
oooo0?l0000R0?ooo`030?l0003oool0oooo0080oooo00<00?l00?ooo`3oool01`3oool00`00o`00
oooo0?ooo`020?ooo`030?l0003oool0oooo0200oooo00<0o`000?ooo`3oool00P3oool00`00o`00
oooo0?ooo`0B0?ooo`00503oool01@00o`00oooo0?ooo`3oool0o`000280oooo00<0o`000?ooo`3o
ool00P3oool00`00o`00oooo0?ooo`080?ooo`03003o003oool0oooo0080oooo00<0o`000?ooo`3o
ool07`3oool00`3o0000oooo0?ooo`020?ooo`03003o003oool0oooo0080oooo0P0000040?ooo`05
003o003oool0oooo0?ooo`3o00008P3oool00`3o0000oooo0?ooo`020?ooo`03003o003oool0oooo
00L0oooo00<00?l00?ooo`3oool00P3oool00`3o0000oooo0?ooo`0P0?ooo`030?l0003oool0oooo
0080oooo00<00?l00?ooo`3oool04P3oool001@0oooo00D00?l00?ooo`3oool0oooo0?l0000R0?oo
o`050?l0003oool0oooo0?ooo`00o`00303oool01@00o`00oooo0?ooo`3oool0o`000240oooo00<0
o`000?ooo`3oool00P3oool00`00o`00oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00D0
0?l00?ooo`3oool0oooo0?l0000R0?ooo`030?l0003oool0oooo0080oooo00<00?l00?ooo`3oool0
203oool01@00o`00oooo0?ooo`3oool0o`000280oooo00<0o`000?ooo`3oool00P3oool00`00o`00
oooo0?ooo`0B0?ooo`005@3oool01000o`00oooo0?ooo`3o000R0?ooo`050?l0003oool0oooo0?oo
o`00o`00303oool01@00o`00oooo0?ooo`3oool0o`000240oooo00D0o`000?ooo`3oool0oooo003o
00050?ooo`030000003oool0oooo00@0oooo00@00?l00?ooo`3oool0o`008P3oool01@3o0000oooo
0?ooo`3oool00?l000/0oooo00D00?l00?ooo`3oool0oooo0?l0000Q0?ooo`030?l0003oool0oooo
0080oooo00<00?l00?ooo`3oool04`3oool001D0oooo00D00?l00?ooo`3oool0oooo0?l0000Q0?oo
o`050?l0003oool0oooo0?ooo`00o`00303oool01@00o`00oooo0?ooo`3oool0o`000240oooo00D0
o`000?ooo`3oool0oooo003o00050?ooo`030000003oool0oooo00@0oooo00@00?l00?ooo`3oool0
o`008P3oool01@3o0000oooo0?ooo`3oool00?l000/0oooo00D00?l00?ooo`3oool0oooo0?l0000Q
0?ooo`030?l0003oool0oooo0080oooo00<00?l00?ooo`3oool04`3oool001D0oooo00D00?l00?oo
o`3oool0oooo0?l0000Q0?ooo`050?l0003oool0oooo0?ooo`00o`00303oool01@00o`00oooo0?oo
o`3oool0o`000240oooo00D0o`000?ooo`3oool0oooo003o00050?ooo`030000003oool0oooo00@0
oooo00@00?l00?ooo`3oool0o`008P3oool0103o0000oooo0?ooo`00o`0<0?ooo`05003o003oool0
oooo0?ooo`3o00008@3oool00`3o0000oooo0?ooo`020?ooo`03003o003oool0oooo01<0oooo000E
0?ooo`05003o003oool0oooo0?ooo`3o00008@3oool0103o0000oooo0?ooo`00o`0>0?ooo`04003o
003oool0oooo0?l00240oooo00D0o`000?ooo`3oool0oooo003o00050?ooo`8000001@3oool01000
o`00oooo0?ooo`3o000R0?ooo`040?l0003oool0oooo003o00d0oooo00@00?l00?ooo`3oool0o`00
8@3oool00`3o0000oooo0?ooo`020?ooo`03003o003oool0oooo01<0oooo000E0?ooo`05003o003o
ool0oooo0?ooo`3o00008@3oool0103o0000oooo0?ooo`00o`0>0?ooo`04003o003oool0oooo0?l0
0240oooo00@0o`000?ooo`3oool00?l01P3oool00`000000oooo0?ooo`040?ooo`05003o003oool0
oooo0?ooo`3o00008@3oool0103o0000oooo0?ooo`00o`0=0?ooo`04003o003oool0oooo0?l00240
oooo00D0o`000?ooo`3oool0oooo003o000F0?ooo`005P3oool01000o`00oooo0?ooo`3o000Q0?oo
o`040?l0003oool0oooo003o00h0oooo00@00?l00?ooo`3oool0o`008@3oool0103o0000oooo0?oo
o`00o`060?ooo`030000003oool0oooo00D0oooo00@00?l00?ooo`3oool0o`008@3oool0103o0000
oooo0?ooo`00o`0=0?ooo`05003o003oool0oooo0?ooo`3o0000803oool01@3o0000oooo0?ooo`3o
ool00?l001H0oooo000F0?ooo`04003o003oool0oooo0?l00200oooo00D0o`000?ooo`3oool0oooo
003o000>0?ooo`04003o003oool0oooo0?l00240oooo00@0o`000?ooo`3oool00?l01P3oool00`00
0000oooo0?ooo`050?ooo`04003o003oool0oooo0?l00200oooo00@0o`000?ooo`3oool00?l03P3o
ool01@00o`00oooo0?ooo`3oool0o`000200oooo00D0o`000?ooo`3oool0oooo003o000F0?ooo`00
5P3oool01000o`00oooo0?ooo`3o000P0?ooo`050?l0003oool0oooo0?ooo`00o`003P3oool01000
o`00oooo0?ooo`3o000P0?ooo`050?l0003oool0oooo0?ooo`00o`001P3oool00`000000oooo0?oo
o`050?ooo`04003o003oool0oooo0?l00200oooo00@0o`000?ooo`3oool00?l03P3oool01@00o`00
oooo0?ooo`3oool0o`000200oooo00D0o`000?ooo`3oool0oooo003o000F0?ooo`005P3oool01000
o`00oooo0?ooo`3o000P0?ooo`050?l0003oool0oooo0?ooo`00o`003`3oool00`00o`00oooo0?l0
000P0?ooo`050?l0003oool0oooo0?ooo`00o`001P3oool00`000000oooo0?ooo`050?ooo`04003o
003oool0oooo0?l00200oooo00@0o`000?ooo`3oool00?l03`3oool01000o`00oooo0?ooo`3o000P
0?ooo`040?l0003oool0oooo003o01L0oooo000F0?ooo`04003o003oool0oooo0?l00200oooo00@0
o`000?ooo`3oool00?l0403oool00`00o`00oooo0?l0000P0?ooo`050?l0003oool0oooo0?ooo`00
o`001P3oool2000000H0oooo00@00?l00?ooo`3oool0o`00803oool0103o0000oooo0?ooo`00o`0?
0?ooo`04003o003oool0oooo0?l00200oooo00@0o`000?ooo`3oool00?l05`3oool001H0oooo00@0
0?l00?ooo`3oool0o`00803oool0103o0000oooo0?ooo`00o`0@0?ooo`03003o003oool0o`000200
oooo00@0o`000?ooo`3oool00?l01`3oool00`000000oooo0?ooo`050?ooo`04003o003oool0oooo
0?l00200oooo00@0o`000?ooo`3oool00?l03`3oool01000o`00oooo0?ooo`3o000P0?ooo`040?l0
003oool0oooo003o01L0oooo000G0?ooo`03003o003oool0o`000200oooo00@0o`000?ooo`3oool0
0?l0403oool01000o`00oooo0?ooo`3o000O0?ooo`040?l0003oool0oooo003o00L0oooo00<00000
0?ooo`3oool01P3oool00`00o`00oooo0?l0000P0?ooo`040?l0003oool0oooo003o00l0oooo00@0
0?l00?ooo`3oool0o`00803oool0103o0000oooo0?ooo`00o`0G0?ooo`005`3oool00`00o`00oooo
0?l0000P0?ooo`040?l0003oool0oooo003o0100oooo00@00?l00?ooo`3oool0o`005`3oool20000
00@0oooo00<000000?ooo`3o00000P3oool00`00o`000000000000050?ooo`030000003oool0oooo
00H0oooo00<00?l00?ooo`3o0000803oool00`3o0000oooo003o000@0?ooo`04003o003oool0oooo
0?l00200oooo00<0o`000?ooo`00o`00603oool001L0oooo00@00?l00?ooo`3oool0o`007`3oool0
103o0000oooo0?ooo`00o`0@0?ooo`04003o003oool0oooo0?l001H0oooo00@000000?ooo`3oool0
00001@3oool0103o0000oooo0?ooo`00o`020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool01P3oool00`00o`00oooo0?l0000P0?ooo`030?l0003oool00?l00140oooo00<00?l00?oo
o`3o00007`3oool0103o0000oooo0?ooo`00o`0H0?ooo`005`3oool01000o`00oooo0?ooo`3o000O
0?ooo`030?l0003oool00?l00180oooo00<00?l00?ooo`3o00005P3oool010000000oooo0?ooo`00
00050?ooo`040?l0003oool0oooo003o0080oooo00<000000?ooo`3oool00P3oool3000000H0oooo
00<00?l00?ooo`3o0000803oool00`3o0000oooo003o000A0?ooo`03003o003oool0o`0001l0oooo
00@0o`000?ooo`3oool00?l0603oool001L0oooo00@00?l00?ooo`3oool0o`007`3oool00`3o0000
oooo003o000B0?ooo`03003o003oool0o`000100oooo100000020?ooo`040000003oool0oooo0000
00D0oooo00<0o`000?ooo`00o`000`0000050?ooo`030000003oool0oooo00H0oooo00<00?l00?oo
o`3o0000803oool00`3o0000oooo003o000A0?ooo`03003o003oool0o`0001l0oooo00@0o`000?oo
o`3oool00?l0603oool001P0oooo00<00?l00?ooo`3o00007P3oool0103o0000oooo0?ooo`00o`0B
0?ooo`03003o003oool0o`0001H0oooo00@000000?ooo`3oool000001@3oool0103o0000oooo003o
000000070?ooo`030000003oool0oooo00H0oooo00@00?l00?ooo`3oool0o`007`3oool00`3o0000
oooo003o000A0?ooo`03003o003oool0o`0001l0oooo00<0o`000?ooo`00o`006@3oool001P0oooo
00<00?l00?ooo`3o00007P3oool0103o0000oooo0?ooo`00o`0B0?ooo`03003o003oool0o`0001H0
oooo00@000000?ooo`3oool00000103oool01@3o0000oooo0?ooo`00o`00000000L0oooo00<00000
0?ooo`3oool01`3oool00`00o`00oooo0?l0000O0?ooo`030?l0003oool00?l00140oooo00@00?l0
0?ooo`3oool0o`007P3oool00`3o0000oooo003o000I0?ooo`00603oool00`00o`00oooo0?l0000N
0?ooo`040?l0003oool0oooo003o0180oooo00<00?l00?ooo`3o00005`3oool2000000D0oooo00@0
o`000?ooo`3oool00?l0100000040?ooo`030000003oool0oooo00L0oooo00<00?l00?ooo`3o0000
7P3oool00`3o0000oooo003o000C0?ooo`03003o003oool0o`0001h0oooo00<0o`000?ooo`00o`00
6@3oool001P0oooo00<00?l00?ooo`3o00007P3oool00`3o0000oooo003o000C0?ooo`03003o003o
ool0o`0001h0oooo00@0o`000?ooo`3oool00?l0203oool00`000000oooo0?ooo`070?ooo`03003o
003oool0o`0001h0oooo00<0o`000?ooo`00o`004`3oool00`00o`00oooo0?l0000N0?ooo`030?l0
003oool00?l001T0oooo000H0?ooo`03003o003oool0o`0001h0oooo00<0o`000?ooo`00o`00503o
ool00`00o`00o`000?ooo`0M0?ooo`030?l0003oool00?l000T0oooo0P0000080?ooo`03003o003o
ool0o`0001h0oooo00<0o`000?ooo`00o`004`3oool00`00o`00oooo0?l0000N0?ooo`030?l0003o
ool00?l001T0oooo000H0?ooo`03003o003oool0o`0001h0oooo00<0o`000?ooo`00o`00503oool0
0`00o`00o`000?ooo`0M0?ooo`030?l0003oool00?l000T0oooo00<000000?ooo`3oool01`3oool0
0`00o`00oooo0?l0000N0?ooo`030?l0003oool00?l001<0oooo00<00?l00?ooo`3o00007P3oool0
0`3o00000?l00?ooo`0I0?ooo`006@3oool00`00o`00o`000?ooo`0M0?ooo`030?l0003oool00?l0
01@0oooo00<00?l00?l0003oool07@3oool00`3o0000oooo003o00090?ooo`030000003oool0oooo
00L0oooo00<00?l00?ooo`3o00007P3oool00`3o0000oooo003o000C0?ooo`03003o003oool0o`00
01h0oooo00<0o`00003o003oool06@3oool001T0oooo00<00?l00?l0003oool07@3oool00`3o0000
oooo003o000D0?ooo`03003o003o0000oooo01d0oooo00<0o`000?ooo`00o`002@3oool00`000000
oooo0?ooo`080?ooo`03003o003o0000oooo01d0oooo00<0o`000?ooo`00o`004`3oool00`00o`00
oooo0?l0000N0?ooo`030?l00000o`00oooo01T0oooo000I0?ooo`03003o003oool0o`0001d0oooo
00<0o`000?ooo`00o`00503oool00`00o`00oooo0?l0000M0?ooo`030?l0003oool00?l000T0oooo
00<000000?ooo`3oool0203oool00`00o`00o`000?ooo`0M0?ooo`030?l00000o`00oooo01@0oooo
00<00?l00?l0003oool07@3oool00`3o00000?l00?ooo`0I0?ooo`006@3oool00`00o`00oooo0?l0
000M0?ooo`030?l00000o`00oooo01@0oooo00<00?l00?ooo`3o00007@3oool00`3o00000?l00?oo
o`090?ooo`8000002@3oool00`00o`00o`000?ooo`0M0?ooo`030?l00000o`00oooo01@0oooo00<0
0?l00?l0003oool07@3oool00`3o00000?l00?ooo`0I0?ooo`006@3oool00`00o`00oooo0?l0000L
0?ooo`030?l0003oool00?l001D0oooo00<00?l00?ooo`3o00007@3oool00`3o00000?l00?ooo`09
0?ooo`030000003oool0oooo00P0oooo00<00?l00?l0003oool07@3oool00`3o00000?l00?ooo`0D
0?ooo`03003o003o0000oooo01d0oooo00<0o`00003o003oool06@3oool001T0oooo00<00?l00?oo
o`3o0000703oool00`3o0000oooo003o000F0?ooo`03003o003o0000oooo01/0oooo00<0o`000?oo
o`00o`002P3oool00`000000oooo0?ooo`080?ooo`03003o003o0000oooo01d0oooo00<0o`00003o
003oool0503oool00`00o`00o`000?ooo`0L0?ooo`030?l0003oool00?l001X0oooo000J0?ooo`03
003o003o0000oooo01/0oooo00<0o`000?ooo`00o`005P3oool00`00o`00o`000?ooo`0K0?ooo`03
0?l0003oool00?l000X0oooo00<000000?ooo`3oool0203oool00`00o`00oooo0?l0000M0?ooo`03
0?l00000o`00oooo01@0oooo00<00?l00?ooo`3o0000703oool00`3o00000?l00?ooo`0J0?ooo`00
6P3oool00`00o`00o`000?ooo`0K0?ooo`030?l0003oool00?l001H0oooo00<00?l00?l0003oool0
6`3oool00`3o00000?l00?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<00?l00?l0003oool0
703oool00`3o00000?l00?ooo`0D0?ooo`03003o003oool0o`0001`0oooo00<0o`00003o003oool0
6P3oool001X0oooo00<00?l00?l0003oool06`3oool00`3o00000?l00?ooo`0F0?ooo`03003o003o
0000oooo01/0oooo00<0o`00003o003oool02P3oool00`000000oooo0?ooo`090?ooo`03003o003o
0000oooo01/0oooo00<0o`00003o003oool05P3oool00`00o`00o`000?ooo`0K0?ooo`030?l00000
o`00oooo01X0oooo000J0?ooo`03003o003o0000oooo01/0oooo00<0o`00003o003oool05P3oool0
0`00o`00o`000?ooo`0K0?ooo`030?l00000o`00oooo00X0oooo0P00000:0?ooo`03003o003o0000
oooo01/0oooo00<0o`00003o003oool05P3oool00`00o`00o`000?ooo`0K0?ooo`030?l00000o`00
oooo01X0oooo000?0?ooo`@000001`3oool00`00o`00o`000?ooo`0K0?ooo`030?l00000o`00oooo
00/0oooo100000070?ooo`03003o003o0000oooo01/0oooo00<0o`00003o003oool02P3oool00`00
0000oooo0?ooo`090?ooo`03003o003o0000oooo01/0oooo00<0o`00003o003oool0203oool40000
00X0oooo00<00?l00?l0003oool06`3oool00`3o00000?l00?ooo`080?ooo`@000003P3oool000l0
oooo00<000000?ooo`3oool02@3oool00`3o0000oooo0?ooo`0J0?ooo`030?l00000o`00oooo00d0
oooo00<000000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0J0?ooo`030?l00000o`00oooo00X0
oooo00<000000?ooo`3oool02@3oool00`00o`00o`000?ooo`0K0?ooo`030?l00000o`00oooo00X0
oooo00<000000?ooo`3oool02@3oool00`00o`00o`000?ooo`0K0?ooo`030?l00000o`00oooo00P0
oooo00<000000?ooo`3oool03`3oool00100oooo00<000000?ooo`3oool0203oool00`3o0000oooo
0?ooo`0J0?ooo`030?l00000o`00oooo00d0oooo00<000000?ooo`3oool01`3oool00`3o0000oooo
0?ooo`0J0?ooo`030?l0003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`00o`00o`00
0?ooo`0K0?ooo`030?l00000o`00oooo00X0oooo00<000000?ooo`3oool02@3oool00`00o`00o`00
0?ooo`0K0?ooo`030?l0003oool0oooo00T0oooo00<000000?ooo`3oool03P3oool000T0oooo1000
00040?ooo`030000003oool0oooo00L0oooo00<00?l00?l0003oool06P3oool00`3o0000oooo0?oo
o`050?ooo`@00000103oool00`000000oooo0?ooo`070?ooo`030?l0003oool0oooo01X0oooo00<0
o`000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030?l0003oool0oooo01X0oooo00<0
o`00003o003oool02P3oool00`000000oooo0?ooo`0:0?ooo`030?l0003oool0oooo01X0oooo00<0
o`000?ooo`3oool02P3oool00`000000oooo0?ooo`0=0?ooo`004P3oool00`000000oooo0?ooo`06
0?ooo`03003o003o0000oooo01X0oooo00<0o`000?ooo`3oool03@3oool00`000000oooo0?ooo`07
0?ooo`030?l0003oool0oooo01X0oooo00<0o`000?ooo`3oool02P3oool2000000/0oooo00<0o`00
0?ooo`3oool06P3oool00`3o0000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<0o`00
0?ooo`3oool06P3oool00`3o0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo000?0?oo
o`040000003oool0oooo000000P0oooo00<00?l00?l0003oool06P3oool00`3o0000oooo0?ooo`0;
0?ooo`<000002@3oool00`3o0000oooo0?ooo`0J0?ooo`030?l0003oool0oooo00X0oooo00<00000
0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0J0?ooo`030?l0003oool0oooo00P0oooo0`00000<
0?ooo`030?l0003oool0oooo01X0oooo00<0o`000?ooo`3oool0203oool010000000oooo0?ooo`00
000>0?ooo`00403oool2000000T0oooo00<00?l00?l0003oool06P3oool00`3o0000oooo0?ooo`0=
0?ooo`030000003oool0oooo00L0oooo00<00?l00?l0003oool06P3oool00`3o0000oooo0?ooo`0:
0?ooo`030000003oool0oooo00X0oooo00<0o`000?ooo`3oool06P3oool00`3o0000oooo0?ooo`0:
0?ooo`030000003oool0oooo00X0oooo00<0o`000?ooo`3oool06P3oool00`3o0000oooo0?ooo`09
0?ooo`8000003`3oool001`0oooo00<0o`000?ooo`3oool0603oool00`3o00000?l00?ooo`0H0?oo
o`03003o003o0000oooo01T0oooo00<0o`00003o003oool02`3oool00`000000oooo0?ooo`0:0?oo
o`03003o003o0000oooo01X0oooo00<0o`000?ooo`3oool05`3oool00`00o`00o`000?ooo`0J0?oo
o`030?l0003oool0oooo01X0oooo000L0?ooo`030?l0003oool0oooo01P0oooo00<0o`00003o003o
ool06@3oool00`3o0000oooo0?ooo`0H0?ooo`030?l0003oool0oooo00/0oooo00<000000?ooo`3o
ool02P3oool00`00o`00o`000?ooo`0J0?ooo`030?l0003oool0oooo01L0oooo00<00?l00?l0003o
ool06@3oool00`3o00000?l00?ooo`0K0?ooo`00703oool00`3o0000oooo0?ooo`0H0?ooo`030?l0
003oool0oooo01T0oooo00<0o`000?ooo`3oool0603oool00`3o0000oooo0?ooo`0;0?ooo`030000
003oool0oooo00/0oooo00<0o`000?ooo`3oool06@3oool00`3o0000oooo0?ooo`0H0?ooo`030?l0
003oool0oooo01P0oooo00<0o`000?ooo`3oool06`3oool000T0oooo4`0000000`3o000000000000
000H000000030?l000000000000001T0000000<0o`00000000000000600000000`3o000000000000
000I000000030?l000000000000001P0000000<0o`000000000000006@0000000`3o000000000000
000H000000030?l0000000000000018000002@3oool000h0oooo00<000000?ooo`3oool0203oool0
10000000oooo0?ooo`3o00070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3o
ool0103o0000oooo0?ooo`00000:0?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3oool0
o`001`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo00@0o`000?ooo`3o
ool000002P3oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo0?l000L0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`040?l0003oool0oooo000000X0oooo00<0
00000?ooo`3oool0203oool010000000oooo0?ooo`3o00070?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool01@3oool0103o0000oooo0?ooo`00000:0?ooo`030000003oool0oooo00d0
oooo000L0?ooo`030?l00000o`00oooo01P0oooo00<0o`000?ooo`3oool06@3oool00`3o0000oooo
0?ooo`0H0?ooo`030?l0003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`3o0000oooo
0?ooo`0H0?ooo`030?l0003oool0oooo01T0oooo00<0o`000?ooo`3oool0603oool00`3o0000oooo
0?ooo`0K0?ooo`00703oool00`3o00000?l00?ooo`0H0?ooo`030?l0003oool0oooo01T0oooo00<0
o`000?ooo`3oool0603oool00`3o0000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<0
o`000?ooo`3oool0603oool00`3o0000oooo0?ooo`0I0?ooo`030?l0003oool0oooo01P0oooo00<0
o`000?ooo`3oool06`3oool001d0oooo00<0o`000?ooo`3oool05`3oool00`3o0000oooo0?ooo`0I
0?ooo`030?l00000o`00oooo01P0oooo00<0o`000?ooo`3oool02`3oool00`000000oooo0?ooo`0;
0?ooo`030?l0003oool0oooo01P0oooo00<0o`000?ooo`3oool06@3oool00`3o0000oooo0?ooo`0H
0?ooo`030?l0003oool0oooo01/0oooo000M0?ooo`030?l0003oool0oooo01L0oooo00<0o`000?oo
o`3oool06@3oool00`3o00000?l00?ooo`0G0?ooo`03003o003o0000oooo00`0oooo0P00000<0?oo
o`030?l00000o`00oooo01P0oooo00<0o`000?ooo`3oool06@3oool00`3o00000?l00?ooo`0G0?oo
o`03003o003o0000oooo01`0oooo000M0?ooo`030?l0003oool0oooo01H0oooo00<00?l00?l0003o
ool06P3oool00`3o00000?l00?ooo`0G0?ooo`03003o003o0000oooo00`0oooo00<000000?ooo`3o
ool02`3oool00`3o00000?l00?ooo`0G0?ooo`03003o003o0000oooo01X0oooo00<0o`00003o003o
ool05`3oool00`00o`00o`000?ooo`0L0?ooo`007@3oool00`3o0000oooo0?ooo`0F0?ooo`03003o
003o0000oooo01X0oooo00<0o`00003o003oool05`3oool00`00o`00o`000?ooo`0<0?ooo`030000
003oool0oooo00/0oooo00<0o`00003o003oool05`3oool00`00o`00o`000?ooo`0J0?ooo`030?l0
0000o`00oooo01L0oooo00<00?l00?l0003oool0703oool001d0oooo00<0o`00003o003oool05P3o
ool00`00o`00o`000?ooo`0K0?ooo`030?l0003oool0oooo01H0oooo00<00?l00?l0003oool0303o
ool00`000000oooo0?ooo`0;0?ooo`030?l00000o`00oooo01L0oooo00<00?l00?l0003oool06P3o
ool00`3o00000?l00?ooo`0G0?ooo`03003o003o0000oooo01`0oooo000M0?ooo`030?l00000o`00
oooo01H0oooo00<00?l00?l0003oool06`3oool00`3o00000?l00?ooo`0F0?ooo`03003o003o0000
oooo00`0oooo00<000000?ooo`3oool0303oool00`3o0000oooo0?ooo`0F0?ooo`03003o003o0000
oooo01/0oooo00<0o`000?ooo`3oool05P3oool00`00o`00o`000?ooo`0L0?ooo`007@3oool00`3o
00000?l00?ooo`0F0?ooo`03003o003o0000oooo01/0oooo00<0o`00003o003oool05P3oool00`00
o`00o`000?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<0o`000?ooo`3oool05P3oool00`00
o`00o`000?ooo`0K0?ooo`030?l0003oool0oooo01H0oooo00<0o`000?ooo`3oool0703oool001d0
oooo00<0o`00003o003oool05P3oool00`00o`00o`000?ooo`0K0?ooo`030?l00000o`00oooo01H0
oooo00<0o`000?ooo`3oool0303oool2000000d0oooo00<0o`00003o003oool05P3oool00`00o`00
o`000?ooo`0K0?ooo`030?l00000o`00oooo01D0oooo00<00?l00?l0003oool07@3oool001d0oooo
00<0o`00003o003oool05P3oool00`3o0000oooo0?ooo`0K0?ooo`030?l00000o`00oooo01D0oooo
00<00?l00?l0003oool03@3oool00`000000oooo0?ooo`0<0?ooo`030?l00000o`00oooo01D0oooo
00<00?l00?l0003oool0703oool00`3o00000?l00?ooo`0E0?ooo`03003o003o0000oooo01d0oooo
000M0?ooo`030?l0003oool00?l001H0oooo00<0o`000?ooo`3oool06`3oool00`3o00000?l00?oo
o`0E0?ooo`03003o003o0000oooo00d0oooo00<000000?ooo`3oool0303oool00`3o00000?l00?oo
o`0E0?ooo`03003o003o0000oooo01`0oooo00<0o`00003o003oool05@3oool00`00o`00o`000?oo
o`0M0?ooo`007@3oool00`3o0000oooo003o000E0?ooo`03003o003o0000oooo01`0oooo00<0o`00
0?ooo`00o`005@3oool00`00o`00o`000?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<0o`00
003o003oool05@3oool00`00o`00o`000?ooo`0L0?ooo`030?l00000o`00oooo01D0oooo00<00?l0
0?l0003oool07@3oool001h0oooo00<0o`00003o003oool0503oool00`00o`00o`000?ooo`0L0?oo
o`030?l0003oool00?l001D0oooo00<00?l00?l0003oool03@3oool00`000000oooo0?ooo`0<0?oo
o`030?l00000o`00oooo01D0oooo00<00?l00?l0003oool0703oool00`3o00000?l00?ooo`0E0?oo
o`03003o003o0000oooo01d0oooo000N0?ooo`030?l00000o`00oooo01@0oooo00<00?l00?l0003o
ool0703oool00`3o0000oooo003o000E0?ooo`03003o003o0000oooo00d0oooo0P00000=0?ooo`03
0?l00000o`00oooo01D0oooo00<00?l00?l0003oool0703oool00`3o00000?l00?ooo`0E0?ooo`03
003o003o0000oooo01d0oooo000N0?ooo`030?l00000o`00oooo01@0oooo00<00?l00?l0003oool0
703oool00`3o0000oooo003o000E0?ooo`03003o003o0000oooo00d0oooo00<000000?ooo`3oool0
303oool00`3o0000oooo003o000E0?ooo`03003o003o0000oooo01`0oooo00<0o`00003o003oool0
503oool00`00o`00oooo0?l0000N0?ooo`007P3oool00`3o00000?l00?ooo`0D0?ooo`03003o003o
0000oooo01d0oooo00<0o`00003o003oool0503oool00`00o`00o`000?ooo`0=0?ooo`030000003o
ool0oooo00`0oooo00<0o`000?ooo`00o`00503oool00`00o`00oooo0?l0000M0?ooo`030?l0003o
ool00?l001@0oooo00<00?l00?ooo`3o00007P3oool001h0oooo00<0o`000?ooo`00o`00503oool0
0`00o`00o`000?ooo`0M0?ooo`030?l00000o`00oooo01<0oooo00<00?l00?ooo`3o00003P3oool0
0`000000oooo0?ooo`0<0?ooo`030?l0003oool00?l001@0oooo00<00?l00?ooo`3o00007@3oool0
0`3o0000oooo003o000D0?ooo`03003o003oool0o`0001h0oooo000N0?ooo`030?l0003oool00?l0
01@0oooo00<00?l00?l0003oool07@3oool00`3o0000oooo003o000C0?ooo`03003o003oool0o`00
00h0oooo00<000000?ooo`3oool0303oool00`3o0000oooo003o000D0?ooo`03003o003oool0o`00
01d0oooo00<0o`000?ooo`00o`00503oool00`00o`00oooo0?l0000N0?ooo`007P3oool00`3o0000
oooo003o000C0?ooo`03003o003oool0o`0001h0oooo00<0o`000?ooo`00o`004`3oool00`00o`00
oooo0?l0000>0?ooo`030000003oool0oooo00d0oooo00<0o`00003o003oool04`3oool00`00o`00
oooo0?l0000M0?ooo`030?l0003oool00?l001@0oooo00<00?l00?l0003oool07P3oool001h0oooo
00<0o`000?ooo`00o`004`3oool00`00o`00oooo0?l0000N0?ooo`030?l0003oool00?l001<0oooo
00<00?l00?ooo`3o00003P3oool2000000h0oooo00<0o`00003o003oool04`3oool00`00o`00oooo
0?l0000N0?ooo`030?l00000o`00oooo0180oooo00<00?l00?ooo`3o00007`3oool001h0oooo00<0
o`000?ooo`00o`004`3oool00`00o`00oooo0?l0000N0?ooo`030?l0003oool00?l001<0oooo00<0
0?l00?ooo`3o00003P3oool00`000000oooo0?ooo`0=0?ooo`030?l00000o`00oooo01<0oooo00<0
0?l00?ooo`3o00007P3oool00`3o00000?l00?ooo`0B0?ooo`03003o003oool0o`0001l0oooo000N
0?ooo`030?l0003oool00?l001<0oooo00<00?l00?ooo`3o00007P3oool00`3o0000oooo003o000C
0?ooo`03003o003oool0o`0000h0oooo00<000000?ooo`3oool03@3oool00`3o0000oooo003o000B
0?ooo`03003o003oool0o`0001l0oooo00<0o`000?ooo`00o`004P3oool00`00o`00oooo0?l0000O
0?ooo`007`3oool00`3o00000?l00?ooo`0B0?ooo`03003o003oool0o`0001h0oooo00<0o`000?oo
o`00o`004@3oool0100000000?l00?ooo`3o00020?ooo`030000003oool0oooo0080oooo0`000005
0?ooo`030000003oool0oooo00d0oooo00<0o`000?ooo`00o`004P3oool00`00o`00oooo0?l0000O
0?ooo`030?l0003oool00?l00180oooo00<00?l00?ooo`3o00007`3oool001l0oooo00<0o`000?oo
o`00o`004P3oool00`00o`00oooo0?l0000N0?ooo`030?l0003oool00?l00100oooo00D000000?oo
o`00o`0000000?l0000:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool0
0`3o0000oooo003o000B0?ooo`03003o003oool0o`0001l0oooo00<0o`000?ooo`00o`004P3oool0
0`00o`00oooo0?l0000O0?ooo`007`3oool00`3o0000oooo003o000A0?ooo`03003o003oool0o`00
01l0oooo00@0o`000?ooo`3oool00?l03`3oool01@000000oooo003o00000000o`0000X0oooo00<0
00000?ooo`3oool00P3oool3000000d0oooo00<0o`000?ooo`00o`004P3oool00`00o`00oooo0?l0
000O0?ooo`030?l0003oool00?l00180oooo00<00?l00?ooo`3o00007`3oool001l0oooo00<0o`00
0?ooo`00o`004@3oool00`00o`00oooo0?l0000P0?ooo`030?l0003oool00?l000l0oooo00D00000
0?ooo`00o`0000000?l000070?ooo`<000001@3oool00`000000oooo0?ooo`0=0?ooo`030?l0003o
ool00?l00180oooo00<00?l00?ooo`3o00007`3oool00`3o0000oooo003o000A0?ooo`04003o003o
ool0oooo0?l001l0oooo000O0?ooo`030?l0003oool00?l00140oooo00<00?l00?ooo`3o0000803o
ool00`3o0000oooo003o000?0?ooo`0500000000o`00oooo0000003o00001`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00d0oooo00<0o`000?ooo`00o`004@3oool01000o`00oooo
0?ooo`3o000O0?ooo`040?l0003oool0oooo003o0100oooo00@00?l00?ooo`3oool0o`007`3oool0
01l0oooo00<0o`000?ooo`00o`004@3oool00`00o`00oooo0?l0000P0?ooo`030?l0003oool00?l0
00l0oooo00D00000003o003oool000000?l000070?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool03@3oool0103o0000oooo0?ooo`00o`0@0?ooo`04003o003oool0oooo0?l001l0oooo
00@0o`000?ooo`3oool00?l0403oool01000o`00oooo0?ooo`3o000O0?ooo`007`3oool00`3o0000
oooo003o000@0?ooo`04003o003oool0oooo0?l00200oooo00<0o`000?ooo`00o`00403oool01000
o`0000000?ooo`3o00070?ooo`@00000103oool00`000000oooo0?ooo`0=0?ooo`040?l0003oool0
oooo003o0100oooo00@00?l00?ooo`3oool0o`007`3oool0103o0000oooo0?ooo`00o`0@0?ooo`04
003o003oool0oooo0?l001l0oooo000O0?ooo`040?l0003oool0oooo003o00l0oooo00@00?l00?oo
o`3oool0o`00803oool00`3o0000oooo003o000@0?ooo`04003o003oool0oooo0?l000l0oooo00<0
00000?ooo`3oool03@3oool0103o0000oooo0?ooo`00o`0@0?ooo`04003o003oool0oooo0?l001l0
oooo00@0o`000?ooo`3oool00?l0403oool01000o`00oooo0?ooo`3o000O0?ooo`007`3oool0103o
0000oooo0?ooo`00o`0?0?ooo`04003o003oool0oooo0?l00200oooo00@0o`000?ooo`3oool00?l0
3P3oool01@00o`00oooo0?ooo`3oool0o`0000l0oooo0P00000>0?ooo`040?l0003oool0oooo003o
0100oooo00@00?l00?ooo`3oool0o`007`3oool01@3o0000oooo0?ooo`3oool00?l000h0oooo00@0
0?l00?ooo`3oool0o`00803oool001l0oooo00@0o`000?ooo`3oool00?l03`3oool01000o`00oooo
0?ooo`3o000P0?ooo`040?l0003oool0oooo003o00h0oooo00D00?l00?ooo`3oool0oooo0?l0000?
0?ooo`030000003oool0oooo00d0oooo00@0o`000?ooo`3oool00?l0403oool01000o`00oooo0?oo
o`3o000O0?ooo`050?l0003oool0oooo0?ooo`00o`003P3oool01000o`00oooo0?ooo`3o000P0?oo
o`007`3oool0103o0000oooo0?ooo`00o`0>0?ooo`05003o003oool0oooo0?ooo`3o0000803oool0
103o0000oooo0?ooo`00o`0>0?ooo`05003o003oool0oooo0?ooo`3o00003`3oool00`000000oooo
0?ooo`0>0?ooo`040?l0003oool0oooo003o00h0oooo00D00?l00?ooo`3oool0oooo0?l0000O0?oo
o`050?l0003oool0oooo0?ooo`00o`003P3oool01000o`00oooo0?ooo`3o000P0?ooo`007`3oool0
103o0000oooo0?ooo`00o`0>0?ooo`05003o003oool0oooo0?ooo`3o0000803oool0103o0000oooo
0?ooo`00o`0>0?ooo`05003o003oool0oooo0?ooo`3o00003`3oool00`000000oooo0?ooo`0>0?oo
o`040?l0003oool0oooo003o00h0oooo00@00?l00?ooo`3oool0o`008@3oool0103o0000oooo0?oo
o`00o`0>0?ooo`04003o003oool0oooo0?l00200oooo000O0?ooo`040?l0003oool0oooo003o00h0
oooo00D00?l00?ooo`3oool0oooo0?l0000P0?ooo`050?l0003oool0oooo0?ooo`00o`003@3oool0
1@00o`00oooo0?ooo`3oool0o`0000l0oooo00<000000?ooo`3oool03P3oool0103o0000oooo0?oo
o`00o`0>0?ooo`04003o003oool0oooo0?l00240oooo00D0o`000?ooo`3oool0oooo003o000=0?oo
o`04003o003oool0oooo0?l00200oooo000P0?ooo`040?l0003oool0oooo003o00d0oooo00D00?l0
0?ooo`3oool0oooo0?l0000P0?ooo`050?l0003oool0oooo0?ooo`00o`00303oool00`00o`00oooo
0?ooo`020?ooo`030?l0003oool0oooo00d0oooo0P00000?0?ooo`040?l0003oool0oooo003o00h0
oooo00@00?l00?ooo`3oool0o`008@3oool01@3o0000oooo0?ooo`3oool00?l000d0oooo00@00?l0
0?ooo`3oool0o`00803oool00200oooo00@0o`000?ooo`3oool00?l03@3oool01@00o`00oooo0?oo
o`3oool0o`000200oooo00D0o`000?ooo`3oool0oooo003o000<0?ooo`05003o003oool0oooo0?oo
o`3o0000403oool00`000000oooo0?ooo`0>0?ooo`050?l0003oool0oooo0?ooo`00o`003@3oool0
1000o`00oooo0?ooo`3o000Q0?ooo`050?l0003oool0oooo0?ooo`00o`00303oool01@00o`00oooo
0?ooo`3oool0o`000200oooo000P0?ooo`040?l0003oool0oooo003o00`0oooo00<00?l00?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`0O0?ooo`040?l0003oool0oooo003o00`0oooo00D00?l00?oo
o`3oool0oooo0?l0000@0?ooo`030000003oool0oooo00h0oooo00D0o`000?ooo`3oool0oooo003o
000<0?ooo`05003o003oool0oooo0?ooo`3o00008@3oool01@3o0000oooo0?ooo`3oool00?l000`0
oooo00D00?l00?ooo`3oool0oooo0?l0000P0?ooo`00803oool0103o0000oooo0?ooo`00o`0<0?oo
o`03003o003oool0oooo0080oooo00<0o`000?ooo`3oool07`3oool01@3o0000oooo0?ooo`3oool0
0?l000/0oooo00D00?l00?ooo`3oool0oooo0?l0000@0?ooo`030000003oool0oooo00h0oooo00D0
o`000?ooo`3oool0oooo003o000<0?ooo`05003o003oool0oooo0?ooo`3o00008@3oool00`3o0000
oooo0?ooo`020?ooo`03003o003oool0oooo00T0oooo00D00?l00?ooo`3oool0oooo0?l0000P0?oo
o`00803oool01@3o0000oooo0?ooo`3oool00?l000/0oooo00D00?l00?ooo`3oool0oooo0?l0000R
0?ooo`050?l0003oool0oooo0?ooo`00o`002`3oool01@00o`00oooo0?ooo`3oool0o`000100oooo
00<000000?ooo`3oool03P3oool01@3o0000oooo0?ooo`3oool00?l000`0oooo00D00?l00?ooo`3o
ool0oooo0?l0000Q0?ooo`030?l0003oool0oooo0080oooo00<00?l00?ooo`3oool02@3oool01@00
o`00oooo0?ooo`3oool0o`000200oooo000P0?ooo`050?l0003oool0oooo0?ooo`00o`002`3oool0
1@00o`00oooo0?ooo`3oool0o`000280oooo00D0o`000?ooo`3oool0oooo003o000:0?ooo`03003o
003oool0oooo0080oooo00<0o`000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030?l0
003oool0oooo0080oooo00<00?l00?ooo`3oool02@3oool01@00o`00oooo0?ooo`3oool0o`000240
oooo00<0o`000?ooo`3oool00P3oool00`00o`00oooo0?ooo`090?ooo`05003o003oool0oooo0?oo
o`3o0000803oool00200oooo00<0o`000?ooo`3oool00P3oool00`00o`00oooo0?ooo`070?ooo`03
003o003oool0oooo0080oooo00<0o`000?ooo`3oool0803oool01@3o0000oooo0?ooo`3oool00?l0
00X0oooo00<00?l00?ooo`3oool00P3oool00`3o0000oooo0?ooo`0>0?ooo`8000003`3oool00`3o
0000oooo0?ooo`020?ooo`03003o003oool0oooo00P0oooo00<00?l00?ooo`3oool00P3oool00`3o
0000oooo0?ooo`0O0?ooo`030?l0003oool0oooo0080oooo00<00?l00?ooo`3oool0203oool01@00
o`00oooo0?ooo`3oool0o`000240oooo000P0?ooo`030?l0003oool0oooo0080oooo00<00?l00?oo
o`3oool01`3oool00`00o`00oooo0?ooo`020?ooo`030?l0003oool0oooo0200oooo00<0o`000?oo
o`3oool00P3oool00`00o`00oooo0?ooo`070?ooo`03003o003oool0oooo0080oooo00<0o`000?oo
o`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030?l0003oool0oooo00<0oooo00<00?l00?oo
o`3oool01`3oool00`00o`00oooo0?ooo`020?ooo`030?l0003oool0oooo01l0oooo00<0o`000?oo
o`3oool00`3oool00`00o`00oooo0?ooo`070?ooo`05003o003oool0oooo0?ooo`3o00008@3oool0
0200oooo00<0o`000?ooo`3oool00P3oool00`00o`00oooo0?ooo`070?ooo`03003o003oool0oooo
0080oooo00<0o`000?ooo`3oool0803oool00`3o0000oooo0?ooo`020?ooo`03003o003oool0oooo
00L0oooo00<00?l00?ooo`3oool00P3oool00`3o0000oooo0?ooo`0>0?ooo`030000003oool0oooo
00h0oooo00<0o`000?ooo`3oool00`3oool00`00o`00oooo0?ooo`070?ooo`03003o003oool0oooo
0080oooo00<0o`000?ooo`3oool07`3oool00`3o0000oooo0?ooo`030?ooo`03003o003oool0oooo
00L0oooo00D00?l00?ooo`3oool0oooo0?l0000Q0?ooo`00803oool00`3o0000oooo0?ooo`020?oo
o`03003o003oool0oooo00L0oooo00<00?l00?ooo`3oool00P3oool00`3o0000oooo0?ooo`0P0?oo
o`030?l0003oool0oooo0080oooo00<00?l00?ooo`3oool01P3oool00`00o`00oooo0?ooo`030?oo
o`030?l0003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`3o0000oooo0?ooo`020?oo
o`03003o003oool0oooo00L0oooo00<00?l00?ooo`3oool00P3oool00`3o0000oooo0?ooo`0O0?oo
o`030?l0003oool0oooo00<0oooo00<00?l00?ooo`3oool01P3oool00`00o`00oooo0?ooo`020?oo
o`030?l0003oool0oooo01l0oooo000P0?ooo`030?l0003oool0oooo00<0oooo00<00?l00?ooo`3o
ool01P3oool00`00o`00oooo0?ooo`020?ooo`030?l0003oool0oooo0200oooo00<0o`000?ooo`3o
ool00`3oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo00<0oooo00<0o`000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0?0?ooo`030?l0003oool0oooo00<0oooo00<00?l00?ooo`3o
ool01@3oool00`00o`00oooo0?ooo`020?ooo`030?l0003oool0oooo0200oooo00<0o`000?ooo`3o
ool0103oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo0080oooo00<0o`000?ooo`3o
ool07`3oool00200oooo00<0o`000?ooo`3oool00`3oool00`00o`00oooo0?ooo`050?ooo`03003o
003oool0oooo00<0oooo00<0o`000?ooo`3oool0803oool00`3o0000oooo0?ooo`030?ooo`03003o
003oool0oooo00D0oooo00<00?l00?ooo`3oool00`3oool00`3o0000oooo0?ooo`0>0?ooo`800000
403oool00`3o0000oooo0?ooo`030?ooo`03003o003oool0oooo00D0oooo00<00?l00?ooo`3oool0
0P3oool00`3o0000oooo0?ooo`0Q0?ooo`030?l0003oool0oooo00<0oooo00<00?l00?ooo`3oool0
103oool00`00o`00oooo0?ooo`030?ooo`030?l0003oool0oooo01l0oooo000P0?ooo`030?l0003o
ool0oooo00<0oooo00<00?l00?ooo`3oool01@3oool00`00o`00oooo0?ooo`030?ooo`030?l0003o
ool0oooo0200oooo00<0o`000?ooo`3oool00`3oool00`00o`00oooo0?ooo`050?ooo`03003o003o
ool0oooo0080oooo00<0o`000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030?l0003o
ool0oooo00<0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`030?ooo`030?l0003o
ool0oooo0240oooo00<0o`000?ooo`3oool00`3oool00`00o`00oooo0?ooo`040?ooo`03003o003o
ool0oooo00<0oooo00<0o`000?ooo`3oool07`3oool00200oooo00<0o`000?ooo`3oool0103oool0
0`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo00<0oooo00<0o`000?ooo`3oool0803oool0
0`3o0000oooo0?ooo`030?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<0o`000?ooo`3oool00`3oool0
0`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo00<0oooo00<0o`000?ooo`3oool08@3oool0
0`3o0000oooo0?ooo`030?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool0103oool0
0`3o0000oooo0?ooo`0O0?ooo`008@3oool00`3o0000oooo0?ooo`030?ooo`03003o003oool0oooo
00<0oooo00<00?l00?ooo`3oool0103oool00`3o0000oooo0?ooo`0P0?ooo`030?l0003oool0oooo
00@0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`030?ooo`030?l0003oool0oooo
00l0oooo00<000000?ooo`3oool03`3oool00`3o0000oooo0?ooo`040?ooo`03003o003oool0oooo
0080oooo00<00?l00?ooo`3oool0103oool00`3o0000oooo0?ooo`0Q0?ooo`030?l0003oool0oooo
00@0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`040?ooo`030?l0003oool0oooo
01l0oooo000Q0?ooo`030?l0003oool0oooo00@0oooo00D00?l00?ooo`3oool0oooo003o00070?oo
o`030?l0003oool0oooo0200oooo00<0o`000?ooo`3oool01@3oool01@00o`00oooo0?ooo`3oool0
0?l000H0oooo00<0o`000?ooo`3oool01`3oool4000000@0oooo00<000000?ooo`3oool03`3oool0
0`3o0000oooo0?ooo`040?ooo`800?l00`3oool00`00o`00oooo0?ooo`040?ooo`030?l0003oool0
oooo0240oooo00<0o`000?ooo`3oool01@3oool00`00o`00oooo0?ooo`02003o00H0oooo00<0o`00
0?ooo`3oool07`3oool00240oooo00<0o`000?ooo`3oool0103oool2003o00030?ooo`00o`00oooo
00H0oooo00<0o`000?ooo`3oool08P3oool00`3o0000oooo0?ooo`040?ooo`800?l000<0oooo003o
0000o`001P3oool00`3o0000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool03`3oool00`3o0000oooo0?ooo`050?ooo`@00?l01`3oool00`3o0000oooo0?ooo`0Q0?oo
o`030?l0003oool0oooo00D0oooo1000o`070?ooo`030?l0003oool0oooo01l0oooo000Q0?ooo`03
0?l0003oool0oooo00H0oooo00<00?l00?ooo`3oool01P3oool00`3o0000oooo0?ooo`0R0?ooo`03
0?l0003oool0oooo00D0oooo0P00o`080?ooo`030?l0003oool0oooo00T0oooo00<000000?ooo`3o
ool00`3oool3000000l0oooo00<0o`000?ooo`3oool01P3oool2003o00P0oooo00<0o`000?ooo`3o
ool08@3oool00`3o0000oooo0?ooo`060?ooo`800?l01`3oool00`3o0000oooo0?ooo`0P0?ooo`00
8@3oool00`3o0000oooo0?ooo`0?0?ooo`030?l0003oool0oooo0280oooo00<0o`000?ooo`3oool0
3`3oool00`3o0000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
3`3oool00`3o0000oooo0?ooo`0@0?ooo`030?l0003oool0oooo0240oooo00<0o`000?ooo`3oool0
3`3oool00`3o0000oooo0?ooo`0P0?ooo`008@3oool00`3o0000oooo0?ooo`0?0?ooo`030?l0003o
ool0oooo0280oooo00<0o`000?ooo`3oool03`3oool00`3o0000oooo0?ooo`090?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool03`3oool00`3o0000oooo0?ooo`0@0?ooo`030?l0003o
ool0oooo0240oooo00<0o`000?ooo`3oool03`3oool00`3o0000oooo0?ooo`0P0?ooo`008@3oool0
0`3o0000oooo0?ooo`0?0?ooo`030?l0003oool0oooo0280oooo00<0o`000?ooo`3oool03P3oool0
0`3o0000oooo0?ooo`080?ooo`<000001@3oool00`000000oooo0?ooo`0?0?ooo`030?l0003oool0
oooo0100oooo00<0o`000?ooo`3oool08@3oool00`3o0000oooo0?ooo`0?0?ooo`030?l0003oool0
oooo0200oooo000Q0?ooo`030?l0003oool0oooo00l0oooo00<0o`000?ooo`3oool08P3oool00`3o
0000oooo0?ooo`0>0?ooo`030?l0003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0@0?ooo`030?l0003oool0oooo00h0oooo00<0o`000?ooo`3oool08`3oool00`3o
0000oooo0?ooo`0>0?ooo`030?l0003oool0oooo0200oooo000Q0?ooo`030?l0003oool0oooo00l0
oooo00<0o`000?ooo`3oool08P3oool00`3o0000oooo0?ooo`0>0?ooo`030?l0003oool0oooo0100
oooo0P00000A0?ooo`030?l0003oool0oooo00h0oooo00<0o`000?ooo`3oool08`3oool00`3o0000
oooo0?ooo`0>0?ooo`030?l0003oool0oooo0200oooo000Q0?ooo`030?l0003oool0oooo00l0oooo
00<0o`000?ooo`3oool08P3oool00`3o0000oooo0?ooo`0>0?ooo`030?l0003oool0oooo0100oooo
00<000000?ooo`3oool0403oool00`3o0000oooo0?ooo`0>0?ooo`030?l0003oool0oooo02<0oooo
00<0o`000?ooo`3oool03P3oool00`3o0000oooo0?ooo`0P0?ooo`008@3oool00`3o0000oooo0?oo
o`0?0?ooo`030?l0003oool0oooo0280oooo00<0o`000?ooo`3oool03P3oool00`3o0000oooo0?oo
o`0@0?ooo`030000003oool0oooo0100oooo00<0o`000?ooo`3oool03P3oool00`3o0000oooo0?oo
o`0S0?ooo`030?l0003oool0oooo00h0oooo00<0o`000?ooo`3oool0803oool00240oooo00<0o`00
0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0S0?ooo`030?l0003oool0oooo00h0oooo00<0o`00
0?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030?l0003oool0oooo00h0oooo00<0o`00
0?ooo`3oool08`3oool00`3o0000oooo0?ooo`0>0?ooo`030?l0003oool0oooo0200oooo000R0?oo
o`030?l0003oool0oooo00d0oooo00<0o`000?ooo`3oool08`3oool00`3o0000oooo0?ooo`0>0?oo
o`030?l0003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`3o0000oooo0?ooo`0>0?oo
o`030?l0003oool0oooo02<0oooo00<0o`000?ooo`3oool03P3oool00`3o0000oooo0?ooo`0P0?oo
o`008P3oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003oool0oooo02@0oooo00<0o`000?ooo`3o
ool03@3oool00`3o0000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<0o`000?ooo`3o
ool03P3oool00`3o0000oooo0?ooo`0S0?ooo`030?l0003oool0oooo00h0oooo00<0o`000?ooo`3o
ool0803oool00280oooo00<0o`000?ooo`3oool03@3oool00`3o0000oooo0?ooo`0T0?ooo`030?l0
003oool0oooo00`0oooo00<0o`000?ooo`3oool04@3oool200000140oooo00<0o`000?ooo`3oool0
3P3oool00`3o0000oooo0?ooo`0T0?ooo`030?l0003oool0oooo00`0oooo00<0o`000?ooo`3oool0
8@3oool00280oooo00<0o`000?ooo`3oool03@3oool00`3o0000oooo0?ooo`0T0?ooo`030?l0003o
ool0oooo00`0oooo00<0o`000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030?l0003o
ool0oooo00h0oooo00<0o`000?ooo`3oool0903oool00`3o0000oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo0240oooo000R0?ooo`030?l0003oool0oooo00d0oooo00<0o`000?ooo`3oool0903oool0
0`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0oooo0140oooo00<000000?ooo`3oool0403oool0
0`3o0000oooo0?ooo`0>0?ooo`030?l0003oool0oooo02@0oooo00<0o`000?ooo`3oool0303oool0
0`3o0000oooo0?ooo`0Q0?ooo`008P3oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003oool0oooo
02@0oooo00<0o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`0A0?ooo`030000003oool0oooo
0140oooo00<0o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`0U0?ooo`030?l0003oool0oooo
00`0oooo00<0o`000?ooo`3oool08@3oool00280oooo00<0o`000?ooo`3oool03@3oool00`3o0000
oooo0?ooo`0T0?ooo`030?l0003oool0oooo00`0oooo00<0o`000?ooo`3oool04@3oool00`000000
oooo0?ooo`0A0?ooo`030?l0003oool0oooo00`0oooo00<0o`000?ooo`3oool09@3oool00`3o0000
oooo0?ooo`0<0?ooo`030?l0003oool0oooo0240oooo000R0?ooo`030?l0003oool0oooo00`0oooo
00<0o`000?ooo`3oool09@3oool00`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0oooo0140oooo
0P00000B0?ooo`030?l0003oool0oooo00`0oooo00<0o`000?ooo`3oool09@3oool00`3o0000oooo
0?ooo`0<0?ooo`030?l0003oool0oooo0240oooo000R0?ooo`030?l0003oool0oooo00`0oooo00<0
o`000?ooo`3oool09@3oool00`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0oooo0140oooo00<0
00000?ooo`3oool04@3oool00`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0oooo02H0oooo00<0
o`000?ooo`3oool02`3oool00`3o0000oooo0?ooo`0Q0?ooo`008P3oool00`3o0000oooo0?ooo`0<
0?ooo`030?l0003oool0oooo02H0oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?ooo`0A
0?ooo`030000003oool0oooo0140oooo00<0o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`0V
0?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool08@3oool00280oooo00<0o`000?oo
o`3oool0303oool00`3o0000oooo0?ooo`0V0?ooo`030?l0003oool0oooo00/0oooo00<0o`000?oo
o`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030?l0003oool0oooo00`0oooo00<0o`000?oo
o`3oool09P3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo0240oooo000S0?ooo`03
0?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool09P3oool00`3o0000oooo0?ooo`0:0?ooo`03
0?l0003oool0oooo0180oooo00<000000?ooo`3oool04@3oool00`3o0000oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo02H0oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?ooo`0Q0?ooo`00
8`3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo02H0oooo00<0o`000?ooo`3oool0
2P3oool00`3o0000oooo0?ooo`0B0?ooo`030000003oool0oooo0140oooo00<0o`000?ooo`3oool0
303oool00`3o0000oooo0?ooo`0V0?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool0
8@3oool002<0oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?ooo`0V0?ooo`030?l0003o
ool0oooo00X0oooo00<0o`000?ooo`3oool04P3oool200000180oooo00<0o`000?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0V0?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool08@3o
ool002<0oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?ooo`0V0?ooo`030?l0003oool0
oooo00X0oooo00<0o`000?ooo`3oool04P3oool00`000000oooo0?ooo`0A0?ooo`030?l0003oool0
oooo00`0oooo00<0o`000?ooo`3oool09P3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0
oooo0280oooo000S0?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool09P3oool00`3o
0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo0180oooo00<000000?ooo`3oool04P3oool00`3o
0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo02L0oooo00<0o`000?ooo`3oool02P3oool00`3o
0000oooo0?ooo`0R0?ooo`008`3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo02L0
oooo00<0o`000?ooo`3oool02P3oool00`3o0000000000000002000000<0oooo00<000000?ooo`3o
ool00P3oool3000000D0oooo00<000000?ooo`3oool04P3oool00`3o0000oooo0?ooo`0:0?ooo`03
0?l0003oool0oooo02P0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`0R0?ooo`00
8`3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo02P0oooo00<0o`000?ooo`3oool0
2@3oool0103o0000oooo0?ooo`00000<0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool04P3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo02P0oooo00<0o`000?ooo`3o
ool02@3oool00`3o0000oooo0?ooo`0R0?ooo`008`3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0
003oool0oooo02P0oooo00<0o`000?ooo`3oool02@3oool0103o0000oooo0?ooo`00000<0?ooo`03
0000003oool0oooo0080oooo0`00000B0?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3o
ool0:03oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo0280oooo000T0?ooo`030?l0
003oool0oooo00T0oooo00<0o`000?ooo`3oool0:03oool00`3o0000oooo0?ooo`090?ooo`040?l0
003oool0oooo000000T0oooo0`0000050?ooo`030000003oool0oooo0180oooo00<0o`000?ooo`3o
ool02P3oool00`3o0000oooo0?ooo`0X0?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3o
ool08P3oool002@0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`0X0?ooo`030?l0
003oool0oooo00T0oooo00@0o`000?ooo`3oool000002@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0180oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`0X0?ooo`03
0?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool08P3oool002@0oooo00<0o`000?ooo`3oool0
2@3oool00`3o0000oooo0?ooo`0X0?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`000000
0P0000090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04P3oool00`3o0000oooo
0?ooo`0:0?ooo`030?l0003oool0oooo02P0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo
0?ooo`0R0?ooo`00903oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo02P0oooo00<0
o`000?ooo`3oool0203oool01@3o0000oooo0?ooo`3oool0000000T0oooo100000040?ooo`030000
003oool0oooo01<0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`0X0?ooo`030?l0
003oool0oooo00T0oooo00<0o`000?ooo`3oool08P3oool002@0oooo00<0o`000?ooo`3oool02@3o
ool00`3o0000oooo0?ooo`0X0?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool04`3o
ool00`000000oooo0?ooo`0C0?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool0:03o
ool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo0280oooo000U0?ooo`030?l0003oool0
oooo00P0oooo00<0o`000?ooo`3oool0:03oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0
oooo01<0oooo0P00000D0?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool0:P3oool0
0`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo02<0oooo000U0?ooo`030?l0003oool0oooo
00L0oooo00<0o`000?ooo`3oool0:P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo
01<0oooo00<000000?ooo`3oool04`3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo
02X0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0S0?ooo`009@3oool00`3o0000
oooo0?ooo`070?ooo`030?l0003oool0oooo02X0oooo00<0o`000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<0o`000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`0Z0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool08`3oool002D0oooo
00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0Z0?ooo`030?l0003oool0oooo00L0oooo
00<0o`000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030?l0003oool0oooo00L0oooo
00<0o`000?ooo`3oool0:P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo02<0oooo
000U0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0:P3oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo01<0oooo00<000000?ooo`3oool0503oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo02X0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`0S0?ooo`009@3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo02X0oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`0C0?ooo`8000005@3oool00`3o0000oooo0?ooo`07
0?ooo`030?l0003oool0oooo02X0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0S
0?ooo`009@3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo02X0oooo00<0o`000?oo
o`3oool01P3oool00`3o0000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<0o`000?oo
o`3oool01`3oool00`3o0000oooo0?ooo`0Z0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?oo
o`3oool0903oool002H0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0Z0?ooo`03
0?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool0503oool00`000000oooo0?ooo`0E0?ooo`03
0?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool0:P3oool00`3o0000oooo0?ooo`060?ooo`03
0?l0003oool0oooo02@0oooo000V0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool0
:`3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo01@0oooo00<000000?ooo`3oool0
5@3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo02`0oooo00<0o`000?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`0T0?ooo`009P3oool00`3o0000oooo0?ooo`050?ooo`030?l0003o
ool0oooo02`0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0D0?ooo`030000003o
ool0oooo01D0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0/0?ooo`030?l0003o
ool0oooo00D0oooo00<0o`000?ooo`3oool0903oool002H0oooo00<0o`000?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`0/0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0503oool0
0`000000oooo0?ooo`0E0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0;03oool0
0`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo02D0oooo000V0?ooo`030?l0003oool0oooo
00D0oooo00<0o`000?ooo`3oool0;03oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo
01@0oooo0P00000F0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0;03oool00`3o
0000oooo0?ooo`040?ooo`030?l0003oool0oooo02D0oooo000V0?ooo`030?l0003oool0oooo00D0
oooo00<0o`000?ooo`3oool0;03oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo01@0
oooo00<000000?ooo`3oool05@3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo02`0
oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0U0?ooo`009`3oool00`3o0000oooo
0?ooo`040?ooo`030?l0003oool0oooo02`0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo
0?ooo`0E0?ooo`030000003oool0oooo01D0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo
0?ooo`0]0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool09@3oool002L0oooo00<0
o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0]0?ooo`030?l0003oool0oooo00@0oooo00<0
o`000?ooo`3oool05@3oool00`000000oooo0?ooo`0E0?ooo`030?l0003oool0oooo00@0oooo00<0
o`000?ooo`3oool0;@3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo02H0oooo000W
0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0;P3oool00`3o0000oooo0?ooo`03
0?ooo`030?l0003oool0oooo01D0oooo00<000000?ooo`3oool05P3oool00`3o0000oooo0?ooo`02
0?ooo`030?l0003oool0oooo02h0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0V
0?ooo`009`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo02h0oooo00<0o`000?oo
o`3oool00`3oool00`3o0000oooo0?ooo`0E0?ooo`8000005`3oool00`3o0000oooo0?ooo`020?oo
o`030?l0003oool0oooo02l0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0V0?oo
o`009`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo02h0oooo00<0o`000?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`0E0?ooo`030000003oool0oooo01H0oooo00<0o`000?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`0_0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3o
ool09P3oool002P0oooo00D0o`000?ooo`3oool0oooo0?l0000b0?ooo`050?l0003oool0oooo0?oo
o`3o0000603oool00`000000oooo0?ooo`0F0?ooo`030?l0003oool0oooo0080oooo00<0o`000?oo
o`3oool0;`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo02H0oooo000X0?ooo`05
0?l0003oool0oooo0?ooo`3o0000<P3oool01@3o0000oooo0?ooo`3oool0o`000100oooo10000004
0?ooo`030000003oool0oooo01L0oooo00D0o`000?ooo`3oool0oooo0?l0000b0?ooo`040?l0003o
ool0oooo0?l002T0oooo000X0?ooo`040?l0003oool0oooo0?l003<0oooo00D0o`000?ooo`3oool0
oooo0?l0000@0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool05`3oool0103o0000
oooo0?ooo`3o000c0?ooo`040?l0003oool0oooo0?l002T0oooo000Y0?ooo`<0o`00=03oool30?l0
0180oooo00<000000?ooo`3oool0103oool3000001P0oooo0`3o000d0?ooo`<0o`00:@3oool007H0
oooo00<000000?ooo`3oool0P@3oool007L0oooo00<000000?ooo`3oool0P03oool007@0oooo00@0
00000?ooo`3oool00000PP3oool007D0oooo0P0000230?ooo`00QP3oool300000740oooo00290?oo
o`030000003oool0oooo06h0oooo001@0?ooo`<000000`3oool4000000<0oooo0P0000000`3oool0
00000?ooo`020?ooo`030000003oool0oooo0080oooo0`0000020?ooo`D0000000<0oooo00000000
00000`0000000`3oool0000000000006000000030?ooo`00000000000080oooo0`0000080?ooo`03
0000003oool0000000@0oooo0P0000000`3oool000000?ooo`020?ooo`030000003oool0oooo0080
oooo0`00001B0?ooo`00D@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool000000`3oool00`000000oooo000000020?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?oo
o`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`030000003oool000000080oooo00<0
00000?ooo`3oool0D`3oool00540oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03
0?ooo`<000000`3oool00`000000oooo000000020?ooo`<000001@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool01@3oool01@000000oooo0000003oool0000000<0
oooo0`0000030?ooo`030000003oool000000080oooo0`00001C0?ooo`00D@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool000000`3oool00`000000
oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo00D0oooo00D000000?ooo`000000oooo000000050?ooo`040000003o
ool0oooo000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`1@0?ooo`00C`3o
ool01@000000oooo0000003oool000000080oooo00<000000?ooo`0000000P0000020?ooo`800000
0P3oool200000080oooo0P0000020?ooo`8000001@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0080oooo0P0000020?ooo`040000003oool00000000000@0oooo0P0000000`3oool0
00000?ooo`050?ooo`050000003oool0oooo0?ooo`0000000`3oool200000080oooo0P0000020?oo
o`8000000P3oool2000005<0oooo001?0?ooo`D00000703oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo01L0oooo0`000000103oool0000000000000001S0?ooo`00K`3oool2000000@0
oooo0P0000050?ooo`030000003oool0oooo07/0oooo0000\
\>"],
  ImageRangeCache->{{{0, 249}, {237.062, 0}} -> {-2.27289, -2.08201, \
0.0182188, 0.0182188}}]
}, Open  ]],

Cell[BoxData[
    \(\(\(\ \)\(c = 0.25;\)\)\)], "Input"],

Cell[BoxData[
    \(\(\(\ \)\(times = Range[0, 10, c];\)\)\)], "Input"],

Cell["Setup the animation", "Subsection",
  TextAlignment->Center,
  TextJustification->0],

Cell[BoxData[
    \(\(LoadJavaClass["\<java.lang.Thread\>"];\)\)], "Input"],

Cell[BoxData[
    \(\(\(\ \)\(AnimationPlot[c_, 
        t_List] := \[IndentingNewLine]JavaBlock[\[IndentingNewLine]Block[{frm}\
, \[IndentingNewLine]frm = 
            createWindow[]; \[IndentingNewLine]Map[\((obj = 
                  drawWave[c, #]; \[IndentingNewLine]drawArea@
                  setMathCommand["\<obj\>"]; \[IndentingNewLine]drawArea@
                  repaintNow[]; \[IndentingNewLine]Thread`sleep[10];)\) &, 
            t\ ]\[IndentingNewLine]]\[IndentingNewLine]]\)\)\)], "Input"],

Cell["Draw in a Java window", "Subsection",
  TextAlignment->Center,
  TextJustification->0],

Cell[BoxData[
    \(\(\(\ \)\(AnimationPlot[c, times];\)\)\)], "Input"]
}, Open  ]]
},
FrontEndVersion->"4.1 for X",
ScreenRectangle->{{0, 1024}, {0, 768}},
WindowToolbars->"EditBar",
CellGrouping->Manual,
WindowSize->{804, 636},
WindowMargins->{{97, Automatic}, {Automatic, 22}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of all cells in \
a given style.  Make modifications to any definition using commands in the \
Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->7,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageHeaderLines->{True, True},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellBracketOptions->{"Color"->RGBColor[0, 0, 0.466667]},
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Header Graphic (to be pasted in)", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["HeaderCell"],
    ShowCellBracket->False,
    CellMargins->{{0, 0}, {0, 0}},
    Evaluatable->False,
    PageBreakBelow->False,
    ImageSize->{350, 24},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    StyleMenuListing->None],
  
  Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005N000061000`40O003h00OJgoo00Ikog?NJia[
W7>LNmh4Ool00gOoJg]c_@05Ool01GOoJke[NfnLOmh0g7oo001YOol047?oDeU6DTV]CHa1cSIc?YAJ
mgNmOomSW56<@NlfLe[g0Woo00U_oe<HBLi=JdG>=U8nU5lGMmh0fWoo001XOol00f_NH:El0005O000
16R4=Li2eVIB0g`000EXHcHaKke__FAS00El0004H:D^4DjDMmkIOol006Moo`03Nomh07`000Ql0003
>Q1l07`000=l0003CLeO_G`000Ql0003<Q1JmWoo0=Qoo`0000MVNFIjHWYVNV9jIWYRN@02IWX0269i
IWYVNV9jIWYRNFIjHWX2IWX00f9iIWYRNP02IWX2HWX2IWX00f9iHWYVN@02IWX01F9jIWYVNFIjHWX0
0VIj01=RNVIjHWYVNV9jIWUVNVIiHWYVNVIiHWYVNV9jIWYRNVIjIWURNP02IWX01F9iHWYVNVIjHWX0
0VIj00ERNFIjHWYVNFIj009RNP06IWUVNVIjHWYVNV9j0VIj00=RNVIjIWT00V9j0VIj00ARNVIjIWUR
NP9VNP03HWYVNF9j009VNP03HWYNgW@000]l0003O21l07`0009l0003CM9d0G`000Ql0009L00MKeHF
J[]VVfZjJY]V^fZj009Z^`03J]]Z^f[K009Zf`03K]]ZnfkK009^n`03K_a^nfkl009^o004Kaa^o6lL
La`3Ka`05W<mLaac?7<lLaac?G<lLcec?7LmLeac?GLlLeec?G=MMeecGGMMLeegGG=M0WMM0gMm00Eg
GGMnMgegOWMm00=gOP0=NiigOGMnNiigOWNNNiigOGNNNiigWW^NMkh017^N00Ek_W^NNiik_W^O00Ik
_P0>Nkmo_W^oNmik_gnoNmio_g_OOmmkgWnoOmmkg`Aog`03NmmoggoO009og`03OomoggoO065oo`00
00<d43P@>1000SP@00Hd4CP@=10h43PA=102>1001C@@>10h43P@=1000SP@00<d43P@=1000cP@00ld
43P@>14h43@@>10d43P@=14h43@@>10d43P@=1000SP@00Ld43P@=14h43@@>10d4@02>10013@@>10d
43P@0S@@00<h43@@>1000SP@00Td43P@>10d43PA>10d43P@=1000cP@00Ld43P@=10h43@@>10d4002
>1001C@@>10h43P@=1000SP@00@d43P@>10d408h4006=10h43@@>10d4CP?1G`000<l:TQ>O00017`0
00I41W`0O01l05`W?2h5O0000f`2O01l0003O0001B@692dlDT1a?7800T2B00A0Td2bA;=4/`94d`03
A?A8m4Sd00995003CAE9=DdD009=E@03DEIAME5e009AMP05DIIEUUFFEIME]P02EKL015WGEMMIeeGG
15Wh00aN65XHGQQN65hhGQQN>F8hHUUR>69IGUT3HUT0369iHWYVNF9jIWUVNV:IIYYVNVJJI[YZVP9V
^P06J[]Z^V[KJ[]ZffkK0f[K00=Znf[lK_/00Vkk0VlL00=_6flLK_`00W<L00A_?7<lKaac?09c?@09
Leac?G<mLeagGG=MMeegOG=M00=gO@07MiigOGNMMiikWGNNNih00W^n00AkWW^nNkik_`9k_P06Nmmo
gW_OOmikggoOEWoo0002A=<01DBcA=A4ddCCA;<014CC00]4/dCCA==4e4CCA;=4ddBcA=A4ddBc00=4
d`06A;=4e4CCA;=4ddCD0TCC00=4/dCCA=<00TCC00=4/dCDB;<00TCC00E4]4CCA;=4ddCD00A4d`06
A;=4ddCDA==4/dCD0dCC00E4e4CCA==4ddBd00=4d`03A;=4ddSD0094d`03A;=4e4CC00=4d`03A=A4
ddBc0094d`03A=A4ddBc0094d`03A=A4ddBd00A4d`0>A=A4ddBcA=A0e5B_O05d0g@SN05TB3Cg:?QP
9@Al0006:6X`eEB?B;8`nW0S17`000</JRciF8h017`000EL8b3>BAA=5Ddd009==@03DEE=EU5E00=A
MP9EUP0=DIIEUeFgEKII]eGGFMMEeeggFOMIf5hHFOP00ehH00MN>5hIGSQN>68iHUUN>@03HUT01f9i
IUURNFIjHWYVVFIj00AVVP09IY]V^VZJI[]Z^VZkI[]ZfVZj00EZf`07K_]ZnfkLJ_]^nfklK_/00Vkl
00I_6flLKaa^o7<LKc`2La`00flmLaa_?@02Lc`2Lcd02WMLLeecGGMMLeegGG=mMeegOGMM0WMm00Qg
OWNMMgigWWMmNiigWGNN0g^N00=k_W^NMkl017^n00Qo_g_NNkikggoNNmmogWoo0WoO00=ooWoOOol0
EGoo0002A;<0142B?54lDSab0TBc0210Td2BA;=4/cab@58lLCaB?790LSab@994/d2c@58lLT1b@990
LSab@74lDTBBA;=0Tcab@54lLT1bA;=0TSaA0Sab0T2B01LlLT1a?590LSab@590LT2B?790DT2BA;=4
/T1bA;=4Td1b?74lDT1b?78lLD1b0094/`09@78lLSaA@790Tcab@54lLT1b0094/`05@990DSab?590
TP02A;<013ab?34lDSaA0T2B014lDT1b@9=4/d2B?790LSaA@9=0e3SF>?LlecSF?=I8/dAY00El0005
;;50e42d@=@he`04O00017006914dcCi17`000Id01b^A?===DTECC@2CCD01E5ECEEAEE5fDGD00U5f
0UFF00aE]UFgEKII]eGGFKQEeeWhFOMIn5ggFOP4GQP2GST2HSP6HUT01fIjHUUVNF9jIWURVVIi009V
VP05JYYVVfJjJYYV^`02J[X00fZkJ]]Z^P03J]/02fkKJ]]^nf[KK_]Zo6kkJaa^o6kkK_`00VlL00Uc
6flLLaa_?7<lLaa_?G<lLcd00W<l0W<m00=gG7<mLed00W=M01EgGG=MMgecOGMnMgegOWMmNgigOGNN
MiekOW^NMiikWGNnNiik_W^NNkl00W^n00Qo_W_NNkmogg^nNmmogg_O0WoO00AoogoOOomogeEoo`00
02i4/d2BEKMZ^ehHJ[Y8ld1cCEEEUT1bA==VVV9IFMQRFFIiGSUVNUFF@79AMVJJFMMVNU5fGQQRFEWH
IYYAUT1bDGIZ^UWhGSUR>CaBGQQVVUWGIWYEUUVgIWYIf0=RF@0>IYYE]ddeIYYRFEWG@794m5Vg?59=
EFJJGQUN60=RF@0:HSTlLTBcIYYIn68iGQQ=EFZjFOP2HST06D2C@99I]fJjFMQRNEgh?98h46JJMii^
fflLB?AAUVIjIYYAMT1bEGIVVUWGIYYEUT2B00=4/`03A=@leFA800El0006>6/le4RdA==0]3cE17`0
00EH0b2>A;@lmg0T00Al00046:e954dECA@3CCD07deEDEEAEU5eDEIAUUFFDIIEUeFfEIME]eGGFKME
eeWgFMMImeghFOQJ65hGGOQN65hiGQQR>5iIHSUNF68i00=RF@08HWYVFF9iHWYRNFIjIYUVNP=VVP03
I[YVVVJk009Z^P05I[]Z^fJjJ]]Z^`05J]/01FkkJ]a^nfkkK_`00Vkk00=_76kkKa`00flL00Ec76lL
Laac?6lL009c?00=Leec?7=LLcecG7<mLeegGG=MMgegGGMnMed00gMm00IgOWMmMiekOWNNMid3Nih0
0gNNNiik_P02Nkh027^oNkik_goNNkikggnnNml2Oml017_nOmmoogoOEWoo0000?DBc@9=956JJOomE
]dBc?75Mn7oo=110TUFgLceoog<mB?Aoof9IA==0TdCCGQUoogMm@998m7MmOomN64CD@998m5FgOomo
gdSd@79956[LOomVVTBcA?=^o7ooHSU==E5EEIIooddeK_]oodBc@79==Goo>114ddde009oo`07A;=^
o7oOA==4/d2BBCD00Woo00=8m4BcDIH00Woo00U954BB@9=8lehIOomgGDCC>1000Woo00i8e42BHUUo
oe5FOomRFDCC@9=4dehIOomkWT2c0dBc00A4ddBc?=I/A`Al0007>4L<S3b@A;A4/dCC?=H017`000EL
8QR=@;8ln7@R00Al00048<i4m4dEBA@2CCD014eECCE=EE5e0U5f015AME5fEIIAUUFGEKII]UFgEMMI
]eWHFOMIf5WgGQQMn5XH009N6004HQQN>EhHGST2HST00eiIHSURF@02HUT0269jIWURNVIiHWYVVVJI
IWX4IYX01fZjIY]V^VZjJ[]ZffZj009Zf`0EJ[]ZffkKJ_]ZffkkJ_a^g6kkK_a_76kkKaa^o7<KKaac
76llLaa_?6lM009c?00BLcec?7<mLcagGG=MMeegG7=MMeecGGMmMeegOG=nMgegOWNM0WMn00UgWG]n
NiigWG^NMiikWWNnNih01G^n00]k_g_OOmikggnnNmmoogoONmmoogoO05Ioo`0002]4/dCC@98d47^n
>150/caAHSUooeFF?790DT2BOomEUS@@DEERNS`aA;<lDE5EOom4dd1b?59=5GooA==0LTBc@;<d3goo
Ka`h44CC@78lDGooDGHlDP02@780?7ooCEDlDD2C>35AMG<m>15_73`a?79EUWooIWTh<CP@Lceogc@@
>11gOCPA@;=4/c@?OomZVSPA@;<d47ooMcdd44BcA==0Tc0?OomR>3@@FMMoocPa@790/SPAGQQ^fd2b
IYXl<DCC?55AEGooA;=0LTBc?=DX/@8PSP0378m0SGPT00Al0003:4L/STCC0094/`03>=Ml07`000=l
000316/PSR2a00Al0006K00TdDdEBAA==Ddd0Tde00Y=EE5FCEEAEU5eDGIEUU6FEIME]P=E]`9Ie`06
EMMIeeWgGOQIn5Wg0ehH015N>EhHGSQR>EiHHSURFEiIHUURNF9IIWURFVIiHWYVNVIi00EVVP09J[YV
VfZjJ[YZ^fJkJ[YZ^fJk009Zf`0<K_]Zff[KK_]ZffkkJ_]^o6[kK_a_76lK16lL00=c76llLa`00W<l
00Qc?G<lLcecG7<mLeec?G=L0g=M029gOG=MMgegOGMMMgegOWMmMiigOG^NMiegWW^NMiikWW^nMiik
_g^nNkmk_WnoNkikggoNNkiogg_OOmikggoOOomogUMoo`0001m0/dBcA=<lDV[KEII0Tc`aK_aoogoO
?350TT1bOomVVSaA>35k_SaB?34`46ZkOolh4D2c@;90TWooFMLlLP02A;<013PaNgioocPA0TBc038h
4GooIYXlDDBc>11oofIj?554/dSd?790TSaALce0TcaAHUYoogMn@78h<FZkOolh<CaBIWUMn3P@>154
/gooEKI0LTBc?35c?Goo>114ddBcA=<h47ooMgh`3gMMOold44CC0TBc01<lDE6G?35kWSaB?34`46Zk
Oolh4DBc?=EXB6PSG09L8VP106`@[`04O0001f0188m4/dCCA;<leVa600Al0003J08dAg0000Al000;
D2@hlddECAA95DTdDCE==E5ECEEAE@02DGH04U6FDGIEUU6FEIME]UFgFKIEeeVhFMMImeWHFOMN65Wh
GQMJ609N6006GSUN>68iHSUNF68i169I00ERNVIiHWUVNF:J009VNP03IYUVVVJK009VVP05J[YV^fZj
I[YZ^`03J]/016ZjJ]]ZffkK0V[K00I^nfklK_]ZnfklKa/2K_`00flKKaac7002Ka`01W<LKcac76lm
Kcac?09c?@0<LcagG7=MMeecGGMMLeegGGMmLeegOGMn0WMm00agOWMmMiikOG^NNiegWW^NMkikWW^n
Nih4Nkh01g^oOkikgg_OOkmkgW_O00=og`03Oomoggoo05Eoo`0000Q4ddBcA;=0TUFFJ_]0DCPA0Woo
04AIefJJ?54h4GooLa`l<D1bEIIooflLLaaoogoO>114ddBc>15oof9J?554ddBc?55Z^goo<0llLT1b
=0moogMM>354/cPAOom^o30??55gGCaAA;=0LVIjEIHd47^NOom8m6kk=11R>Goo>354TSaBOom_77<L
Niiood2c@994/caAHWYoocPA0dBc00Ph4GMnOol`3WMnOolh4D2c0TBc00e0ddBB?79EUWooKaac77oo
Nmlh442c?=Id9004O0000g0RK09l0003O0000f@1;;54e002A;<00d3DB;9l000:O0001BR_BAE=54TE
CA@00dde0TeE00MAMU5EDGIAMUFFDIIEU`02EKH2EKL04EWGEMMImeWHFOMMn5WgGOQJ65hIGQQN>5hH
HSUN>5hiHST01F9I00QVNV9iIWYRNVIiIWYRVFIj0fJJ00UV^VZkIYYZ^fZjJ]YZ^fZjJ[/00V[K00a^
ff[KJ_]^nf[KK_aZnfklKa]^o6kkLa`4Ka`01g<LKcec76llLaac?7<m009c?005Leec?G=MLeecG002
Led00gMmMeegO@03Mgd037MnMgekWWMmMiigOGNNNiigWW^NMiikWP=k_P0?Nkmk_WnnNkikgWnoNmik
ggnoOomoggooNmmoogoO05Eoo`000dBc00=0/d1bMgh00SPa015oogMM<0moocaB>11oog^o>354/cPa
Okm0LSQAOomZfc`a0094/`0:=11oogMM>354/dCC?59In7ooGOP2HUT0<eWhOomoocPAA;<h<G=MOomV
NW^oNkhh4DBc@99=EF[K<0ioog<m<0ikOSPaEGIood2B@;<l<F[KFMLh<FlLOolh4DBcA=<lLUWGOom0
TT2CA==4/caAIYYoob`>K_aoocP@A;=4d`02A;<0342cA;<h<GoO@78hDGooK]/l<DCC@;A0d`Yl0008
@6/le4BcA;=4dd2c>=M/A`Ul000>D4Lm5DceBAA=54TECCA==DeECCEAEDeEDGIAM@9AMP9EUP05DIMI
]eFfFMME]`02FML015WgFOQImeWh0UhH00UMmehHGQQN>EhHHUUR>5hiGUT00f9I00MRNF9IIUYRNFIj
HWYVN@04IYX01fJjJYYV^VZkI[YV^fZj009Zf`05J[YZff[KJ]]^f`02J]/04FkkJ_]^o6kkJ_]^o6lL
K_]_77;lKaac76llLaa_77<mKc`00W<l0W<m01]c?7=MMcecG7MMLeegGG=MLgegGWMMMgegOWMmMiig
OW^MMiekWWNNNiikWG^NNkigWW^nNil00W^n00ek_g^nNmik_g_NOmmogW_OOmmogWoOOomog`1FOol0
000OA;=0/dCCA;<lDG<LA9=4dgooIWTd46IJIYX`3goOOolh44Bc@79N>E6F>11ooeWG?594ddBc?35g
OWoo>1000TBc02M0LU5EOomIeddeDII8m6klOolh44Bc?55Z^gooA==N67oo?550/dBc@79^o3P@OomR
FC`aDIIRFD2COom9541cA;94/fkl;0ioog^n>1400TBc00E0LTdeOom==D2B0094/`0:?79Mn7oo=11A
MWooA;=0TTBcA=<2A;<024CC@79R>E6F>11ooeWG?782A;<00ccFE8il0007O0001E1Y>=I4]4BcA=<0
0dBc00<dmfa7O0001W`000QHAcTHB?A954SdBAE=54dd0Tde00]=EE5FDEEAMTefEGIAUUFFDIME]UFF
009E]`08FMMEeeWGFMQIeeWhGOQIm`=N6003GSUR65hh009N>@03HUQR>F9I00=RF@07IWYRNVIiHWYV
NFJJIWX00VJJ00YZVVJJIYYVVfJjJ[]Z^VJkJ[YV^`9Zf`0<J[]^nf[KJ]]^nf[kK]a^nf[kK_a_76kk
0VlL00Q_6g<LKaac76lLLca_?7<L0W<m00]c?7MLLcacGG=LLcecGGMMLeegOGMM009gO@03LgegOGMn
009gO@06MgikWWMnNiegWW^N0WNN015k_W^NNkik_g^nOkikgWnoNmmo_W_ONkmogWooNmmoogoO05Mo
o`0001m4/dCCA;=0/d1bGQQEeddeOomE]caB>31ooc@?KaaoocPAA;=0/dBbK_a=5GooB?A0TT2CA;<l
<FZkOolh4@02A;<0:42B@9=ooe6F?350TS`aFMMoocaBA;<lDEhHOold43P@Lce8m42BA;<lDF9JFMMo
oe5f@78h<G<lA==ooeFG?994/caBJ_]4TgooJ[/lDD2B0TBc00@lLWooFOQ0DP94/`08?79=EGooBA@d
47ooJ[/h<@A4/`0??590/T1bK_a=5GooB?A0LTBcA==4/ccFA;=TB7@S009l000:M0=PJ42d?=I4/dCC
A;=0/dBcA=<2A;<02CSGC;1XAg`1O01h0FA6A;4m5`03B?@00dTDCAA95@02CCD02deECCE=EE5FDGEA
MU6EEGIAUUFFEIL00UFf00YI]eGGFKMIeeWgFOQImeWhGOQJ60=N6005GSUR>5hiHUUN>@06HUT01fIi
HWYVNF9jIYUVNVJI009VVP0:IY]Z^VJkJYYV^VZkJ[YZffZjJ[/4J]/016kkJ]]^nf[k0Vkl00A^nfkl
Kaa^n`E_7004Lcac77<lKc`2Lc`2Lcd01W=MMcecGG=MLeacG@9gG@03LgegGGMm009gO@9gOP0:Mgeg
WWMmMiikWW^MMiik_W^NMih3Nkh01W^oNkik_W_NOkikg`9ogP06NmmoggoOOmmoog_OEWoo0005A;<0
34CCIWYR>GooB?A0TT1bHUUIn5ghOollD@94/`0T?59IegooOolh44SdDCDlLCabGQQoocaA@;=0LTde
>35oof9J?554/d2BDEEoodTD@98lTUEfOom9541c@990LTSDA==0TdCC0Woo02Q0TT2C@99EUVIjOomI
md1AA;=0TTBcMgeooeFg?35EUcaA@;<h47ooIYXlDD2cA;=8m41bOomIecP@GQQooc`a@794/d2bA;=Z
fd1B?79Ie`9oo`03=10lLT2B00=4/`03@=@leCSG008leP05>?LleD2dA;=0d`03A;<00dCCA;=0/`02
A;<023cD?=HheccF??LleTCeA=<3B?@014dDBAE==DdD0Tde01E=EE5ECEEAMU5EDGIAUUFFDIME]UFG
EKMIeUFgFMMEeeWhFMMIn5hHFOL00ehH00AN>5hHGSUN>09R>@03GUQRFF9I009RF@06IWYRNV9IHWYV
VFIj16JJ00YV^VJJJYYV^VZkJ[YV^fZkJ]]Z^P=Zf`05K]]Zff[KJ]]^o002K_/00f[lKa]^n`02Ka`0
17;lKaac?6lL0W<L00A_?7<MLcac?@9c?004LcecG7LmLe`2Med01g=mMeegGGMmMeegOGMn009gO@06
MiigOGNNNgekWWNN0W^N00AgWW^nNkikW`=k_P04Okmk_W_ONkh2Nml01GoONmioggooOmh0Egoo0000
1d2cA==4/dCCA;<h<FZj009oo`09?350/dBc?35gGEWgOom8e42B0094/`0M=11oogoo>10lLWooB=@d
44BcOom4/cPAA==ogbP=OomgGC0@A;<lLSPAOomI]cPA@78h<GooDGHh4002>34017oo@;=4TR`>0Woo
00Pl<D2cA;<h4G<LOomVNS@@0TBc02Hh4G<LOom4dc`aJ_]c7C@?<0moog^N=10d3gNNEIHX3GooIWXd
430?NkioocPa?58l<E5fOolh<DBc>11oog^NCEEooe5f@994/dCC0dBc00E0ddBcA;=4/dCC00=4/`0<
A==4/dBcA;=4ddBcA==4/dCCA;=0/dBd0TCC00i8e4SdA?=8m4TDCAA954TeCCEA=DeEDEEAEU5e0U5f
00EEMU6FEIIE]eFf009E]`03FMMEeeWG009Im`9In003GOQJ65hH009N6006GSUN668iGSQRFF8i0V9I
00URNF9IIUURNFIjHWUVNV:IIWX016JJ00MV^VJKJ[YV^VZkJ[YZ^`06J]/00fkkJ]]^n`02J_/01Fkl
K_]^o6lLK_/00VlL00ec76lLLca_76llLca_?7<mLcac?G=MLcac?@03Led00g=LMeecG@03Mgd02gMn
MgegOGNNMgegWW^NMgigWG^NMih00W^N00AgWW^NNkik_`=k_P05Ommk_WoONmio_`02Oml01GooNmmo
ggooOml0EGoo0002A;<0442cA;=4/d1bCCEoogoO>114/dCC?79E]goOOom953ab0TBc00llDFZkNihh
DCaBHUUoofIjK_]oog^NHWUoog^nGQP00Woo00A^o4CCCAEgO@9oo`03HYU95GMM009oo`07J[YZ^goo
Oolh44SdK_`00Woo00Dh4DBcA;=0TTTD009oo`0<J]]4ddBc@990/goo?350/cPAOomk_VIj0Woo00ER
FG=MOom4/fkK009oo`0DJ]]4/c@?KaaooehHFOQoogoO?554/caAJYYcGE5fOomE]T1bA==0/`94/`0:
@==4/dBc@;=4ddBc@;=4/dCC@;<2A;<0143CA;=4/d2c0TBc00e0ddBcA==4/dSCA==4m4SdBAA<m4TD
CAE==002CCD3CED2DGH02E6EDGIEUU6GEIIE]UGGEKMEe`02FML03eWHFOQImeghFOMN65XHGQQN>EhH
HSUN>F9IGSQN>@02HUT01VIIHUURNFIjHWYRN@9VNP03IYUVNVZJ00=VVP0?J[YVVfZjI[YZ^f[KI[YZ
^f[KJ[]ZnfkKJ]]^nf[K009^o007J_]^nfklKa]^o6lLKa/00VlL00Ec76llLaa_?G<L009c?007Lcec
?7LmLeec?7=MMe`00W=M00EgOG=NMgegGGMm009gOP0>MgegOW^MMgigWG^NMiikWG^NMkikWW^nNkmo
_P9k_P07Nkmk_W_ONkiogg_NNml00goO00=oogoOOol0EGoo00002TBcA==4/dBc@;90TehhOomkWSPa
0dBc00Dd47ooOomc7D2B0094/`0V@;=0/TdD@9=4/d2BDGI8ldCD>354ddSdBAAA=E5f@;=0TUWG@;=8
m5FF?558deFGB==EUSaaA;=E]eEfCEE4TT2CA==E]dCCA;=0/P=4/`04@794ddSdEKL2A;<05dCC@798
m4BbA;=0TU5EBAA8m3ab?59=54BcDGI4/eFg@794/eVgA;=0/c`aA;800UhH00Y4/cPaA;=4dd2c@998
m3aAB?A0LP=4/`05A==4/dBcA;=4d`03A;<01DCCA;=4/dBcA=<00dBc00=4ddBcA;<014Bc00A4ddCD
B=A8l`98m003BAA95DdD00===@03CEEAEU5E009AMP0=EGIAMU6FEIIE]eFFFKME]UVgEMQIeeWgFML0
0UWh00=J65ghGQP00UhH00AN>EhhHSQR>@9RF@0;GUURFF9IHUUVFV9iIWUVNV9iIWYRVP03IYX026Jj
JYYV^fZjI[]Z^VZkJ[X2J]/02FZkJ]]Zff[KK_]ZffkkJ_]^n`02K_`01VlLK_a_6fklKaac709_700;
Laac?7<LKcac?G<lLcec?7<mLeagG@02Led2Med017=MMgegGG=n0gMm00agOW]mMgigWGNNNiekWWNN
NkikWWNnNih2Nkh03G^oOkik_W^nNmmogW^oOmmogWoONmmooWoO05Moo`000TBc00U4ddBc@79cGG<L
J[]In41bA=<00TBc00M0LUFFK_aV^W^NB?A0/`02A;<02T2CA;=4/dBc@790TdBbA;=0TdBC0T2B00i0
TdBB@9=0TTBCA;=0TTBc@9=0TT2c@994Td2C0T2B00M0LT2cA;=4/d2BA990/`03A;<01DCCA;=0TT2C
@98014Bc00M0/dBcA;=4/d2B@9=0TP02A;<0242BA9=0TT2c@794/T2C@983A;<0142c@790LT2c1DBc
00=4TdBc@;<00dBc00E4ddBcA;=4/dCC00=4/`05A==4/dBcA;=4d`03A;<01DCCA;=4/dBcA=<00TBc
00I4ddBcA?=4ddSdB=@2BA@02TdDBAE==4deCEE==E5ECEEAME5F0U6F00AEUUFGEIIE]P9E]`09EMMI
eeWGFMMIn5ggFOQMn5XH009N600BGSUN65hHGSURFEhiHSURFF8iHWURFVIiHUURNV9iIYYVNVIi16JJ
00UVVfZJI[]Z^VJjJ]YZ^f[JJ[/00f[K00Y^ff[KJ]]ZnfkkK_aZnfkkK_a^n`9_700EL_a_76lLLaa_
?7<MKcac7G<lLcec?7=MLcacGG<mLeegGG=LLeegOG=M00AgO@08MiigOGMnMiekWWMnNiigWP9kWP05
MiikWW^nNkik_`03Nkh027oONmik_goONmiogg_OOol2Oml00gooOmmoo`1DOol000E4/`04?54lDSaA
@783A;<01TCCA;=0LSaA?58lD@A4/`05A==4/dBcA;=4d`03A;<01DCCA;=4/dBcA=<00dBc00E4ddBc
A;=4/dCC00=4/`05A==4/dBcA;=4d`03A;<01DCCA;=4/dBcA=<00dBc00E4ddBcA;=4/dCC00=4/`05
A==4/dBcA;=4d`03A;<01DCCA;=4/dBcA=<00dBc00E4ddBcA;=4/dCC00=4/`05A==4/dBcA;=4d`03
A;<01DCCA;=4/dBcA=<00dBc00E4ddBcA;=4/dCC00=4/`05A==4/dBcA;=4d`03A;<01DCCA;=4/dSD
A?<014Sd00===DdDBCD00Tde00M=EE5EDEE=MU5eDGIEMP02DIH035FgEIME]UVgFMMEeeWGFMQImeWh
GOQIm`AN6006GSUN>5hhHSURF5iI169I00MRNVIjHWUVNV9iIYYVNP04IYX01VJjJY]Z^VJkJ[YV^`9Z
^`0@J]YZff[KK]]ZffkkJ]]^nf[lK]]^o6[lK_]_76klKa/2Ka`01W<LKaac76llLca_?09c?007Lcec
?7=MLcacGGLlLgd00WMM00=cGGMmMed00gMm0WMn00MgWGMnMgekWGNNNiigW@02Nih00gNnNiik_`03
Nkh01gnoNkikggoNNmmogg_N009og`9oo`03Ommoogoo05Aoo`000814/dCDA;=4e4BcA=A4/dCDA;=4
e4BcA=A4/dCDA;=4e4BcA=A4/dCDA;=4e4BcA=A4/dCDA;=4e4BcA=A4/dCDA;=4e4BcA=A4/dCDA;=4
e4BcA=A4/dCDA;=4e4BcA=A4/dCDA;=4e4BcA=A4/dCDA;=4e4BcA=A4/dCDA;=4e4BcA=A4/dCDA;=4
e4BcA=A4/dCDA;=4e4BcA=A4/dCDA;=4e4BcA=A4/dCDA;=4e4BcA=A4/dCDA;=4e4BcA=A4/dCDA;=4
e4BcA=A4/dCDA;=4e4BcA=A4/dCDA;=4e4BcA=A4/dCDA;=4e4BcA=A4/dCDA;=4e4BcA=A4/dSD0TCC
00A8e4SdB?E9509=5008BAE==E4eCEEAEDeEDGIEMP9AMP08DIIEUUFGEKII]UFgFMMEe`9Ie`05FOMM
meWhGOQJ6003GQP01V8iGSQN>F8iHUUN>@=RF@06IUURNFIJHWUVNV:I0VIj00UVVFJJIYYZVVJjIYYV
^VJkJ[X00VZk00=ZfV[KJ[/00f[K01A^nf[KK_aZffkkK_a[6fkkK_a_6flLLaa_77<LKaac?6llLaa_
77<l0W<m00Ac?7<mMcac?@EcG@0@MgegGGMmMeigOGMnMgegWGMnMiikWWNNNiikWG^NMkh2Nih3Nkh0
2G_OOkik_W_NNkmogW^oOmikg`02Oml00gooOmmog`1FOol0008/3P04<0h/3R`><0h2;0h0130>;0h/
3S0>0R`>00@`3R`>;0h`3P8/3P04<0h/3R`><0h2;0h0130>;0h/3S0>0R`>00@`3R`>;0h`3P8/3P04
<0h/3R`><0h2;0h0130>;0h/3S0>0R`>00@`3R`>;0h`3P8/3P04<0h/3R`><0h2;0h0130>;0h/3S0>
0R`>00@`3R`>;0h`3P8/3P04<0h/3R`><0h2;0h0130>;0h/3S0>0R`>00@`3R`>;0h`3P8/3P04<0h/
3R`><0h2;0h0130>;0h/3S0>0R`>00@`3R`>;0h`3P8/3P04<0h/3R`><0h2;0h0130>;0h/3S0>0R`>
00@`3R`>;0h`3P8/3P05<0l`3S0?<0ld3`03=102>103>342?5400cab@790TP02@9800dBc@;=4d`02
A=<2B?@3BA@04TddBCE==DeDCEEAEDeeDEIAME6FDGIEUU6FEKIE]eFfEKMIeP9Ee`07FMMImeWgFOQI
meghFQP015hH0ehh00AR>EiHHUUNF@=RF@9RN@05IWURNVJIIWYVV@03IYX3I[X016ZkI[YZ^f[J0V[K
00YZfV[KJ_]^nf[kK_]^o6lKK_a_6`=_700KLca_?7<LKcac?G<lLeac?7=MLeacGGMmLeegOG=mMgec
OGMnMiegOGNNNiigWG^nMiik_WNn009k_P07Nmik_goNNmikggoOOoh0Dgoo0000

\
\>"], "Graphics",
    ShowCellBracket->False,
    CellMargins->{{0, 0}, {Inherited, 0}},
    Evaluatable->False,
    ImageSize->{350, 24},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    ShowCellBracket->False,
    CellMargins->{{60, 0}, {0, 5}},
    PageBreakBelow->False,
    LineSpacing->{0, 37},
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontSize->36,
    FontTracking->"Plain",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{9, 0}, {0, 0}},
    FontSize->24,
    FontTracking->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    ShowCellBracket->False,
    CellMargins->{{60, 0}, {0, 5}},
    PageBreakBelow->False,
    LineSpacing->{1, 0},
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{9, 0}, {0, 0}},
    ParagraphIndent->-85,
    FontSize->16]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    ShowCellBracket->False,
    CellMargins->{{60, 4}, {30, 10}},
    PageBreakBelow->False,
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->12,
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{9, 10}, {50, 10}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellFrame->{{6, 0}, {0, 1}},
    CellDingbat->None,
    CellMargins->{{44, 0}, {10, 35}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->{{8, 4}, {0, 4}},
    LineSpacing->{0, 22},
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->20,
    FontWeight->"Bold",
    FontColor->RGBColor[0.410163, 0.128908, 0.121096]],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{9, 0}, {2, 50}},
    CellFrameMargins->{{5, 4}, {0, 4}},
    FontSize->14,
    FontTracking->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellFrame->{{0, 0}, {0, 1}},
    CellMargins->{{60, 0}, {8, 10}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {6, 40}},
    FontSize->12]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellDingbat->None,
    CellMargins->{{60, Inherited}, {8, 12}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellDingbat->None,
    CellMargins->{{22, 0}, {4, 20}},
    FontSize->11]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{60, 20}, {10, 5}},
    LineSpacing->{1, 0},
    ParagraphSpacing->{0, 12},
    FontFamily->"Times New Roman",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{9, 0}, {4, 4}},
    ParagraphSpacing->{0, 6}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Commentary"],
    CellMargins->{{60, 20}, {2, 8}},
    TextJustification->0,
    LineSpacing->{1, 1},
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Commentary", "Printout"],
    CellMargins->{{9, 0}, {4, 4}},
    LineSpacing->{1, 3},
    FontFamily->"Times New Roman"]
  }, Open  ]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output to the \
kernel.  Be careful when modifying, renaming, or removing these styles, \
because the front end associates special meanings with these style names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellFrame->True,
    CellMargins->{{60, 20}, {0, 0}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    CellFrameColor->RGBColor[0.6, 0.2, 0],
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    Background->RGBColor[0.996109, 0.976577, 0.906264]],
  
  Cell[StyleData["Input", "Printout"],
    CellFrame->True,
    CellMargins->{{37, 0}, {6, 6}}]
  }, Open  ]],
  
  Cell[StyleData["InlineInput"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{60, 20}, {15, 0}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    CellFrameColor->RGBColor[0, 0.500008, 0.6],
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Printout"],
    CellFrame->False,
    CellMargins->{{37, 0}, {6, 2}},
    Background->GrayLevel[1]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{60, 20}, {0, 0}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellFrameColor->RGBColor[0, 0.6, 0.6],
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageSize->{250, 250}],
  
  Cell[StyleData["Graphics", "Printout"],
    CellFrame->False,
    CellMargins->{{37, 0}, {6, 2}},
    ImageSize->{250, 250},
    ImageMargins->{{28, Inherited}, {Inherited, 0}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{72, 20}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{44, Inherited}, {Inherited, Inherited}},
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{72, 20}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{44, Inherited}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontTracking->"Extended",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayText"],
    CellFrame->0.5,
    CellMargins->{{60, 20}, {15, 5}},
    LineSpacing->{0, 12},
    ParagraphSpacing->{0, 6},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold",
    FontSlant->"Plain",
    Background->RGBColor[1, 1, 0.8]],
  
  Cell[StyleData["DisplayText", "Printout"],
    CellMargins->{{9, 0}, {4, 4}},
    ParagraphSpacing->{0, 6},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{60, Inherited}, {0, 0}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    ShowCellLabel->False,
    CellFrameColor->RGBColor[0, 0.6, 0.6],
    CounterIncrements->"Graphics",
    ImageSize->{250, 250},
    Background->RGBColor[1, 0.900008, 0.900008]],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellFrame->False,
    CellMargins->{{37, Inherited}, {6, 2}},
    ImageSize->{250, 250},
    ImageMargins->{{28, Inherited}, {Inherited, 0}}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->6],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Bold"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard ButtonFunctions, for use \
in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext ButtonBoxes.  The \
\"Hyperlink\" style is for links within the same Notebook, or between \
Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line help \
system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder objects in \
palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->PrimaryPlaceholder,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles of most \
cells.  If a cell's FormatType matches the name of one of the styles defined \
below, then that style is applied between the cell's style and its own \
options. This is particularly true of Input and Output.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{0.6, 1},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an inline cell \
within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 116, 2, 48, "Subsubsection"],
Cell[1846, 56, 1876, 32, 661, "Input",
  Evaluatable->False]
}, Closed]],
Cell[3737, 91, 131, 3, 58, "Title"],
Cell[3871, 96, 279, 8, 96, "Subsection"],

Cell[CellGroupData[{
Cell[4175, 108, 125, 3, 72, "Section"],
Cell[4303, 113, 221, 8, 50, "Subsection"],

Cell[CellGroupData[{
Cell[4549, 125, 105, 3, 72, "Section",
  Evaluatable->False],
Cell[4657, 130, 180, 4, 47, "Input"]
}, Open  ]],
Cell[4852, 137, 120, 2, 50, "Subsection"],
Cell[4975, 141, 56, 1, 31, "Input"],
Cell[5034, 144, 116, 2, 50, "Subsection"],

Cell[CellGroupData[{
Cell[5175, 150, 62, 1, 31, "Input"],
Cell[5240, 153, 181, 4, 31, "Output"]
}, Open  ]],
Cell[5436, 160, 183, 4, 31, "Input"],
Cell[5622, 166, 69, 1, 31, "Input"],
Cell[5694, 169, 170, 4, 31, "Input"],
Cell[5867, 175, 1755, 40, 223, "Input"],
Cell[7625, 217, 267, 5, 47, "Input"],
Cell[7895, 224, 96, 2, 50, "Subsection"],
Cell[7994, 228, 142, 2, 31, "Input"],
Cell[8139, 232, 697, 12, 159, "Input"],

Cell[CellGroupData[{
Cell[8861, 248, 116, 2, 31, "Input"],
Cell[8980, 252, 79932, 1783, 239, 14762, 974, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[88927, 2038, 56, 1, 31, "Input"],
Cell[88986, 2041, 71, 1, 31, "Input"],
Cell[89060, 2044, 90, 2, 50, "Subsection"],
Cell[89153, 2048, 75, 1, 31, "Input"],
Cell[89231, 2051, 504, 8, 175, "Input"],
Cell[89738, 2061, 92, 2, 50, "Subsection"],
Cell[89833, 2065, 71, 1, 31, "Input"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

