(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     68700,       2141]*)
(*NotebookOutlinePosition[     69688,       2172]*)
(*  CellTagsIndexPosition[     69644,       2168]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Legal Notice, Disclaimer, and Book Ordering Information:", \
"Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "(* Legal Notice, Disclaimer, and Book Ordering Information:\n\nLast \
Modified: FIO June 8, 2002\n\n",
  StyleBox["Mathematica For Physics: 2nd Edition",
    FontColor->RGBColor[1, 0, 0]],
  "\n\nRobert L. Zimmerman and Fredrick I. Olness\n",
  "\nWebSite:  \n",
  StyleBox["  www.physics.smu.edu/~olness\n  darkwing.uoregon.edu/~phys600/\n\
\n",
    FontColor->RGBColor[1, 0, 0]],
  "MathSource Number: 0206-862",
  StyleBox["\n",
    FontColor->RGBColor[1, 0, 0]],
  "\nISBN 0-201-53796-6\nFor ordering information, call 1-800-282-0693\n\
Addison-Wesley Publishing Company\n",
  "\nCommunication with the authors:\nFredrick I. Olness:  \
olness@mail.physics.smu.edu\nRobert L. Zimmerman: bob@zim.uoregon.edu\n\n\
Copyright 2002, Addison-Wesley Publishing Company, Inc. The material in\nthis \
file may be distributed freely  so long as the content remains\nunchanged, \
and the copyright and  reference notices are included. The\npublisher grants \
permission for the noncommercial use of these programs\nand program segments. \
 All other uses require the prior written consent\nof the publisher.    \n\n\
All rights are reserved with regard to the  material in the\n\"Mathematica \
For Physics\" text, and may not be reproduced, stored in a\nretrieval system, \
or transmitted,  in any form or by any means,\nelectronic, mechanical, \
photocopying,  recording, or otherwise, without\nthe prior written permission \
 of the publisher. \n\nThe programs and applications presented in this book \
have been included\nfor  their instructional value. They have been tested \
with care but are\nnot  guaranteed for any particular purpose. The publisher \
does not\noffer any  warranties or representations, nor does it accept any\n\
liabilities with  respect to the programs or applications. \n\n *)\n"
}], "Input",
  Evaluatable->False,
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[TextData[{
  "Contains correction on:        \n2nd Edition:Chpt.10,Problem 10.2.4 p.613: \
Time it takes to fall into a black hole (FIO, 19 Apr 2004)  \n      Part b. \
",
  StyleBox["change rule is not detined correctly. \n      \n2",
    FontSlant->"Italic"],
  "nd Edition:Chpt.10,Problem 10.3.3. p.634: The Expansion Age for the \
Friedman-Robertson-Walker models  (FIO, 19 Apr 2004)  \n      ",
  " In[215]:=  Need to take part [[1,1]] of solution instead of [[2,1]]. "
}], "SmallText",
  FontColor->RGBColor[1, 0, 0]],

Cell["10. Relativity and Cosmology", "Title",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["10.1 Introduction    ", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Off[General::spell ];  
Off[General::spell1];\
\>", "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  "10.2 Special Relativity ",
  StyleBox[" ",
    FontColor->RGBColor[0, 0, 1]]
}], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Overview of Special Relativity  ", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Problem 1:  Decay of a particle  ", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Remarks and outline", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Clear["\<Global`*\>"];\)\)], "Input"],

Cell[BoxData[
    \(\(momRule = \[IndentingNewLine]{p1\  \[Rule] 
            m1 {1, 0, 0, 0}, \ \[IndentingNewLine]\ 
          p2\  \[Rule] 
            m2\ \[Gamma]2 {1, 0, 0, \(-v2\)}, \[IndentingNewLine]p3\  \[Rule] 
            m3\ \ \[Gamma]3 {1, 0, 0, v3}};\)\)], "Input"],

Cell[BoxData[
    \(\(\(conRule = {p3 \[Rule] p1 - p2}\ ;\)\(\ \ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\[Eta] = DiagonalMatrix[{1, \(-1\), \(-1\), \(-1\)}];\)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"eq1", "=", " ", 
      RowBox[{
        RowBox[{\(\(m3\^2 == p3 . \[Eta] . p3 /. conRule\) /. momRule\), "/.",
           
          RowBox[{"{", 
            RowBox[{"v2", "\[Rule]", 
              FormBox[\(\@\(1 - 1\/\[Gamma]2\^2\)\),
                "TraditionalForm"]}], "}"}]}], " ", "//", 
        "ExpandAll"}]}]], "Input"],

Cell[BoxData[
    \(sol = \ \(Solve[eq1, \[Gamma]2\ \ ] // Simplify\) // Flatten\)], "Input"],

Cell[BoxData[
    \(\(\(\ \)\(FullSimplify[m2\ \ \[Gamma]2\ \  - m2 /. sol]\)\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 2:  Two-particle collision  ", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Clear["\<Global`*\>"];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection"],

Cell[BoxData[{
    \(\(pL1 = {E1, p1, 0, 0};\)\ \), "\[IndentingNewLine]", 
    \(\(pL2 = {m2, 0, 0, 0};\)\)}], "Input"],

Cell[BoxData[
    \(pLT = pL1 + pL2\)], "Input"],

Cell[BoxData[{
    \(\(pCM1 = {ECM1, kCM1, 0, 0};\)\), "\[IndentingNewLine]", 
    \(\(pCM2 = {ECM2, \(-kCM1\), 0, 0};\)\)}], "Input"],

Cell[BoxData[
    \(pCMT = pCM1 + pCM2\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection"],

Cell[BoxData[
    \(\(\[Eta] = DiagonalMatrix[{1, \(-1\), \(-1\), \(-1\)}];\)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(eq1 = pLT . \[Eta] . pLT \[Equal] pCMT . \[Eta] . pCMT\)], "Input"],

Cell[BoxData[
    \(\(eq2 = ECM1 + ECM2 \[Equal] m3 + m4;\)\)], "Input"],

Cell[BoxData[
    RowBox[{\({eq3, eq4}\), "=", 
      RowBox[{"{", 
        RowBox[{\(E1 \[Equal] T1 + m1\), ",", 
          RowBox[{"p1", "\[Equal]", 
            FormBox[\(\@\(E1\^2 - m1\^2\)\),
              "TraditionalForm"]}]}], "}"}]}]], "Input"],

Cell[BoxData[
    \(sol = \(Solve[{eq1, eq2, eq3, eq4}, {T1}, {E1, p1, ECM1}] // Flatten\) // 
        Simplify\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 3:  Compton scattering ", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Clear["\<Global`*\>"];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{"p1", "=", 
          RowBox[{
            FormBox[\(h\/\[Lambda]0\),
              "TraditionalForm"], " ", \({1, 0, 0, 1}\)}]}], ";"}], 
      " "}], "\[IndentingNewLine]", \(p2 = m\ {1, 0, 0, 0};\)}], "Input"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"p3", "=", 
        RowBox[{
          FormBox[\(h\/\[Lambda]1\),
            "TraditionalForm"], \({1, Sin[\[Theta]1], 0, 
            Cos[\[Theta]1]}\)}]}], 
      ";"}], "\[IndentingNewLine]", \(p4 = 
        m\ \[Gamma]f {1, \(-vf\)\ Sin[\[Theta]2], 0, 
            vf\ Cos[\[Theta]2]};\)}], "Input"],

Cell[BoxData[
    \(\(\[Eta] = DiagonalMatrix[{1, \(-1\), \(-1\), \(-1\)}];\)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(eq1 = \((\(m\^2 \[Equal] \((p1 + p2 - p3)\) . \[Eta] . \((p1 + p2 - 
                    p3)\) // Simplify\) // ExpandAll)\)\)], "Input"],

Cell[BoxData[
    \(lamRule = \(\(\(Solve[\ eq1\ , \ \[Lambda]1\ ]\)[\([1, 
            1]\)]\)\(\ \)\(//\)\(ExpandAll\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(\[Lambda]1\  - \[Lambda]0 /. 
        lamRule\)\(//\)\(Collect[#, {m, h}] &\)\(\ \)\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection"],

Cell[BoxData[
    \(\(\(\((eq2 = p1 + p2 \[Equal] p3 + p4 // Thread)\) // 
      ColumnForm\)\(\[IndentingNewLine]\)
    \(\ \)\)\)], "Input"],

Cell[BoxData[
    \(eq3 = \(\(Solve[{eq2[\([1]\)]}, \[Gamma]f\ \ ] // 
          Flatten\)\(//\)\(Simplify\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(\ \)\(\((\(\((\ \ \(m \((\[Gamma]f - 1)\)\  /. lamRule\) /. eq3 // 
                  Factor)\)\  /. lamRule\)\  /. \[Lambda]0 \[Rule] 
              h/m\ temp\  // Factor)\) /. 
      temp \[Rule] \ \[Lambda]0\ m/h\)\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection"],

Cell[BoxData[
    \(eq4 = eq2[\([{2, 4}]\)]\)], "Input"],

Cell[BoxData[
    \(eq5 = \(\(Eliminate[\ 
          eq2[\([{2, 
                4}]\)], \ \ \[Gamma]f\ ]\)\(//\)\(Simplify\)\(\ \)\)\)], \
"Input"],

Cell[BoxData[
    \(eq6 = \ 
      eq5 /. lamRule\  // ExpandAll[#, Trig \[Rule] True] &\)], "Input"],

Cell[BoxData[
    \(\(\(\(\(Solve[
              eq6 /. {\ 
                  Sin[\[Theta]2] \[Rule] 
                    tan[\[Theta]2]\ Cos[\[Theta]2]}\ , \ \ tan[\[Theta]2]]\)[\
\([1, 1]\)]\  /. tan\  \[Rule] Tan\) /. \ \ Rule \[Rule] 
          Equal\)\(\ \)\(//\)\(Simplify\)\(\ \)\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 4:  Moving mirror and generalized Snell's law  ", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Clear["\<Global`*\>"];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection"],

Cell[BoxData[
    \(Ki = \[Nu]i {1, Cos[\[Theta]i], Sin[\[Theta]i], 0}; 
    Kr = \[Nu]r {1, \(-Cos[\[Theta]r]\), Sin[\[Theta]r], 0};\)], "Input"],

Cell[BoxData[
    \(Kmi = \[Nu]m {1, Cos[\[Theta]m], Sin[\[Theta]m], 0}; 
    Kmr = \[Nu]m {1, \(-Cos[\[Theta]m]\), Sin[\[Theta]m], 0};\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"boostx", "=", 
        FormBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"\[Gamma]", \(\(-v\)\ \[Gamma]\), "0", "0"},
                {\(\(-v\)\ \[Gamma]\), "\[Gamma]", "0", "0"},
                {"0", "0", "1", "0"},
                {"0", "0", "0", "1"}
                }], "\[NoBreak]", ")"}],
          "TraditionalForm"]}], ";"}]], "Input"],

Cell[BoxData[
    \(\(\((eq1 = \((Ki \[Equal] boostx . Kmi)\) // 
            Thread)\)\(//\)\(ColumnForm\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(\((eq2 = \((Kr \[Equal] boostx . Kmr)\) // Thread)\)\  // 
      ColumnForm\)], "Input"],

Cell[BoxData[
    \(sol1 = \(\(Solve[{eq1, eq2} // Flatten, \ \[Nu]i\ , {Cos[\[Theta]r], 
            Sin[\[Theta]r], Cos[\[Theta]m], 
            Sin[\[Theta]m], \[Nu]m}]\)\(//\)\(Flatten\)\(\ \)\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection"],

Cell[BoxData[{
    \(\(\(eq3 = 
        Eliminate[{eq1, 
                  eq2\ \ , \ \ \[Nu]r \[NotEqual] 0, \[Nu]i \[NotEqual] 
                    0\ \ , \ v \[NotEqual] 0, v \[NotEqual] \(-1\)\ \ , 
                  v \[NotEqual] 1\ } /. sol1 // Flatten, {Cos[\[Theta]m], 
              Sin[\[Theta]m], \[Gamma]\ \ }]\  // 
          Map[Simplify\ , #] &\ ;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\ \(\(eq3\)\(\ \)\(//\)\(ColumnForm\)\(\ \ \)\)\)}], "Input"],

Cell[BoxData[
    \(eq4 = \(\(Solve[\ eq3[\([2]\)]\ , v\ ]\  // Simplify\) // 
          PowerExpand\)\  // Simplify\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        FormBox[\(\(1 - v\)\/\(v + 1\)\),
          "TraditionalForm"], "\[Equal]", 
        RowBox[{"(", 
          RowBox[{
            FormBox[\(\(1 - v\)\/\(v + 1\)\),
              "TraditionalForm"], "/.", \(eq4[\([2]\)]\)}], ")"}]}], "//", 
      "Simplify"}]], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Problem 5:  One-dimensional motion of a relativistic particle with \
constant acceleration  \
\>", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Clear[\"Global`*\"];", "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection"],

Cell[BoxData[
    RowBox[{"eqMotion", "=", 
      RowBox[{
        RowBox[{"D", "[", 
          RowBox[{
            FractionBox[\(\(x'\)[t]\), 
              FormBox[
                SqrtBox[
                  RowBox[{"1", "-", 
                    SuperscriptBox[
                      RowBox[{
                        SuperscriptBox["x", "\[Prime]",
                          MultilineFunction->None], "(", "t", ")"}], "2"]}]],
                "TraditionalForm"]], ",", "t"}], "]"}], "\[Equal]", 
        "g"}]}]], "Input"],

Cell[BoxData[
    \(\(\(\ \)\(eq1\  = \ \(\(\(\(DSolve[{eqMotion\ } // Flatten\ , x[t], t] // 
              Simplify\) // PowerExpand\) // 
          Simplify\)\(\ \)\(//\)\(Flatten\)\(\ \)\)\)\)\)], "Input"],

Cell[BoxData[
    \(\(\(\ \ \)\(\(\(\(\(eqMotion /. D[eq1[\([#]\)], t]\) /. 
                D[eq1[\([#]\)], {t, 2}] &\) /@ {1, 2}\  // Simplify\) // 
        PowerExpand\)\(\ \)\(//\)\(Simplify\)\(\ \ \)\)\)\)], "Input"],

Cell[BoxData[
    \(eq2 = x[t] /. eq1[\([1]\)]\)], "Input"],

Cell[BoxData[
    \(initialConditions = {\((\ eq2)\) \[Equal] x0, \((D[eq2, t])\) \[Equal] 
              v0} /. t \[Rule] 0 // PowerExpand\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"gamRule", "=", 
        FormBox[\({1 - v0\^2 \[Rule] 1\/\[Gamma]\^2, 
            v0\^2 - 1 \[Rule] \(-\(1\/\[Gamma]\^2\)\)}\),
          "TraditionalForm"]}], ";"}]], "Input"],

Cell[BoxData[
    \(\(\(\ \)\(eq3 = \(\(\((\((Solve[initialConditions, {C[1], C[2]}]\ \  // 
                  Simplify)\) // PowerExpand)\) /. 
          gamRule\)\(\ \)\(//\)\(PowerExpand\)\(\ \)\)\)\)\)], "Input"],

Cell[BoxData[
    \(crule = eq3[\([1]\)]\)], "Input"],

Cell[BoxData[
    \(xsol = \ \ \(\(eq2 /. crule\)\(//\)\(Simplify\)\(\ \ \)\)\)], "Input"],

Cell[BoxData[
    RowBox[{"nonRelResult", " ", "=", 
      RowBox[{
        RowBox[{"Series", "[", 
          RowBox[{
            RowBox[{"(", " ", 
              RowBox[{"xsol", "/.", 
                RowBox[{"\[Gamma]", "\[Rule]", 
                  FormBox[\(1\/\@\(1 - v0\^2\)\),
                    "TraditionalForm"]}]}], ")"}], " ", ",", 
            "   ", \({g, 0, 1}\), ",", \({v0, 0, 1}\)}], "]"}], "//", 
        "Normal", "  "}]}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{"values", "=", 
        RowBox[{"{", 
          
          RowBox[{\(x0 \[Rule] 0\), ",", \(v0 \[Rule] 1/2\), 
            ",", \(g \[Rule] \(-0.1\)\), ",", 
            RowBox[{"\[Gamma]", "\[Rule]", 
              FormBox[\(1\/\@\(1 - v0\^2\)\),
                "TraditionalForm"]}]}], "}"}]}], ";"}]], "Input"],

Cell[BoxData[
    \(\(text = {Text[\ 
            StyleForm["\<Relativistic\>", FontFamily -> "\<Times-Bold\>", 
              FontSize \[Rule] 10\ ], {10, 1.2}], 
          Text[\ StyleForm["\<non-relaltivistic \>", 
              FontFamily -> "\<Times-Bold\>", FontSize \[Rule] 10\ ], {8, \ 
              0.2}]\ };\)\)], "Input"],

Cell[BoxData[
    \(\(\(Plot[{\ xsol, nonRelResult} //. values // 
          Evaluate, \[IndentingNewLine]{t, 0, 
          12}, \[IndentingNewLine]GridLines \[Rule] 
          Automatic, \[IndentingNewLine]AxesLabel \[Rule] {"\<t\>", "\<x\>"}, 
        PlotStyle \[Rule] {{Thickness[0.01]}, {Dashing[{0.06, 0.1}], 
              Thickness[
                0.001]}}, \[IndentingNewLine]Epilog \[Rule] \ \ text\ ];\)\(\ \
\ \)\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Problem 6: Two-dimensional motion of a relativistic particle in a \
uniform electric field  \
\>", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Clear["\<Global`*\>"];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection"],

Cell[BoxData[
    \(\(pVec[t_] = {px[t], py[t], pz[t]};\)\)], "Input"],

Cell[BoxData[
    \(eqMotion = \(\(\(pVec'\)[t] \[Equal] {0, \ e\ E0, 
            0}\)\(//\)\(Thread\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(\(initial = {px[0] \[Equal] px0, py[0] \[Equal] 0, 
          pz[0] \[Equal] 0};\)\)], "Input"],

Cell[BoxData[
    \(momRule = \(DSolve[eqMotion~Join~initial, {px[t], py[t], pz[t]}, 
          t]\)[\([1]\)]\)], "Input"],

Cell[BoxData[
    \(\[Gamma]Rule = \(m\ \[Gamma] \[Equal] 
            Sqrt[pVec[t] . pVec[t] + m\^2 /. momRule] // 
          Solve[#, \[Gamma]] &\) // Flatten\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection"],

Cell[BoxData[
    \(\(\(\ \ \ \)\(eq1 = \ \ \ \ \ \ \ \ \ \(pVec[t] \[Equal] 
              m\ \[Gamma] {\(x'\)[t], \(y'\)[t], \(z'\)[t]} /. 
            momRule\) /. \[Gamma]Rule // Thread\)\)\)], "Input"],

Cell[BoxData[
    \(\(initial = {x[0] \[Equal] 0, y[0] \[Equal] 0, 
          z[0] \[Equal] 0};\)\)], "Input"],

Cell[BoxData[{
    \(\(\(path = 
        DSolve[{eq1, initial} // Flatten, {x[t], y[t], z[t]}, t] // 
          Flatten;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(path // ColumnForm\)}], "Input"],

Cell[BoxData[
    \(\(values = {m \[Rule] 1, e \[Rule] 1, E0 \[Rule] 0.1, 
          px0 \[Rule] 0.1};\)\)], "Input"],

Cell[BoxData[
    \(\(\(\ \)\(Plot[\({x[t], y[t]} /. path\) //. values // 
          Evaluate, \[IndentingNewLine]{t, 0, 
          5}, \[IndentingNewLine]GridLines \[Rule] Automatic, 
        PlotStyle \[Rule] {\ Thickness[0.01]\ , \ Dashing[{0.06, 0.1}]\ }, 
        AxesLabel \[Rule] {"\<t\>", "\<y or x\>"}\ ];\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(\(relXY = {x[t], y[t]} /. path;\)\)], "Input"],

Cell[BoxData[
    \(\(\(\ \)\(nonrelXY = \((\(\(Map[Series[#, {t, 0, 2}] &, 
                  relXY] /. {px0^2 \[Rule] 0} // PowerExpand\) // Simplify\) // 
          Normal)\)\)\)\)], "Input"],

Cell[BoxData[
    \(\(Plot[{relXY[\([1]\)], \ nonrelXY[\([1]\)]} /. values // 
          Evaluate, \[IndentingNewLine]{t, 0, 
          30}, \[IndentingNewLine]GridLines \[Rule] Automatic, 
        PlotStyle \[Rule] {\ Thickness[0.01]\ , Dashing[{0.06, 0.1}]\ }, 
        AxesLabel \[Rule] {"\<t\>", "\<x\>"}\ ];\)\)], "Input"],

Cell[BoxData[
    \(\(Plot[{relXY[\([2]\)], \ nonrelXY[\([2]\)]} /. values // 
          Evaluate, \[IndentingNewLine]{t, 0, 
          30}, \[IndentingNewLine]GridLines \[Rule] Automatic, 
        PlotStyle \[Rule] {\ Thickness[0.01]\ , \ Dashing[{0.06, 0.1}\ ]\ }, 
        AxesLabel \[Rule] {"\<t\>", "\<y\>"}\ ];\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[TextData[{
  "10.3 General Relativity      ",
  StyleBox[" ",
    FontColor->RGBColor[0, 0, 1]]
}], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Overview of General Relativity", "Subsection"],

Cell[CellGroupData[{

Cell["Problem 1: Killing vectors and Spherical Symmetry    ", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Clear["\<Global`*\>"];\)\)], "Input"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"g\[Mu]\[Nu]", "=", 
        RowBox[{"DiagonalMatrix", "[", 
          
          FormBox[\({g00(r), 
              g11(r), \(-r\^2\), \(-r\^2\)\ \(\(sin\^2\)(\[Theta])\)}\),
            "TraditionalForm"], "]"}]}], 
      ";"}], "\[IndentingNewLine]", \(g\[Mu]\[Nu] // MatrixForm\)}], "Input"],

Cell[CellGroupData[{

Cell["Remarks and outline", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(killingEq[ContraV_, g_, \[CapitalGamma]_, 
          x_: {t, r, \[Theta], \[Phi]}] := \[IndentingNewLine]Module[{temp1, 
            temp2, temp3, temp4}, \[IndentingNewLine]temp1 = 
            g . ContraV; \[IndentingNewLine]temp2 = 
            Outer[D, temp1, x] - 
              temp1 . \[CapitalGamma]; \[IndentingNewLine]temp3 = 
            temp2 + Transpose[
                temp2]; \[IndentingNewLine]temp4 = \(\((temp3 // 
                      Flatten)\) \[Equal] 0 // Thread\)\  // 
              Simplify; \[IndentingNewLine]Complement[
            Select[temp4, 
              FreeQ[#, True &\ ]\ ]\ ]\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    \(\(christ[met_, 
          var_: {t, r, \[Theta], \[Phi]}]\  := \[IndentingNewLine]Module[{\ 
            temp1, imet, result}, \[IndentingNewLine]temp1 = 
            Outer[D, met, var]\ ; \[IndentingNewLine]imet = 
            Inverse[met] // Simplify; \[IndentingNewLine]result = 
            1/2 \((\ Transpose[imet . temp1, {1, 3, 2}]\  + \ \ \ Transpose[
                    imet . temp1, {1, 2, 3}]\ \  - \ \ \ \ imet . 
                    Transpose[
                      temp1, {3, 2, 1}]\ )\); \[IndentingNewLine]Return[
            result]];\)\)], "Input"]
}, Closed]],

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection"],

Cell[BoxData[{
    \(\(kt = {1, 0, 0, 0};\)\), "\[IndentingNewLine]", 
    \(\(kz = {0, 0, 0, \(-1\)};\)\), "\[IndentingNewLine]", 
    \(\(kx = {0, 
          0, \(-Sin[\[Phi]]\), \(-Cos[\[Phi]]\) 
            Cot[\[Theta]]};\)\ \ \), "\[IndentingNewLine]", 
    \(\(ky = {0, 0, 
          Cos[\[Phi]], \(-Sin[\[Phi]]\) Cot[\[Theta]]};\)\)}], "Input"],

Cell["\[CapitalGamma]=christ[g\[Mu]\[Nu]]  ", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\[CapitalGamma]\)], "Input"],

Cell[BoxData[
    \(\((\(killingEq[#, g\[Mu]\[Nu], \[CapitalGamma]] &\) /@ {kt, kz, kx, 
            ky}\  // Simplify)\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection"],

Cell[BoxData[
    \(\(velocity = {\(t'\)[s], \(r'\)[s], \(\[Theta]'\)[s], \(\[Phi]'\)[
            s]};\)\)], "Input"],

Cell[BoxData[{
    \(\(\(kconst = {\[IndentingNewLine]en \[Equal] 
            g\[Mu]\[Nu] . velocity . kt, \[IndentingNewLine]jx \[Equal] 
            g\[Mu]\[Nu] . velocity . kx, \[IndentingNewLine]jy \[Equal] 
            g\[Mu]\[Nu] . velocity . ky, \[IndentingNewLine]jz \[Equal] 
            g\[Mu]\[Nu] . velocity . kz};\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(kconst // ColumnForm\)}], "Input"],

Cell[BoxData[
    \(\(Solve[kconst[\([{\ 1, 4}]\)], {\(t'\)[s], \(\[Phi]'\)[s]}] // 
        Flatten\) // ColumnForm\)], "Input"],

Cell[BoxData[
    \(\(\(Solve[kconst[\([{\ 2, 3}]\)], \(\[Theta]'\)[s], \(\[Phi]'\)[s]\ ] // 
        Flatten\)\(//\)\(Simplify\)\(\ \)\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 2: Schwarzschild solution  ", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Clear["\<Global`*\>"];\)\)], "Input"],

Cell[BoxData[
    RowBox[{" ", 
      RowBox[{
        RowBox[{"g\[Mu]\[Nu]", "=", 
          RowBox[{"DiagonalMatrix", "[", 
            
            FormBox[\({g00(r), 
                g11(r), \(-r\^2\), \(-r\^2\)\ \(\(sin\^2\)(\[Theta])\)}\),
              "TraditionalForm"], "]"}]}], ";"}]}]], "Input"],

Cell[CellGroupData[{

Cell["Remarks and outline", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(christ[met_, 
          var_: {t, r, \[Theta], \[Phi]}]\  := \[IndentingNewLine]Module[{\ 
            temp1, imet}, \ \[IndentingNewLine]temp1 = 
            Outer[D, met, var]\ ; \[IndentingNewLine]imet = 
            Inverse[met] // Simplify; \[IndentingNewLine]1/2 \((\ 
              Transpose[imet . temp1, {1, 3, 2}]\  + \ \ \ Transpose[
                  imet . temp1, {1, 2, 3}]\ \  - \ \ \ \ imet . 
                  Transpose[
                    temp1, {3, 2, 1}]\ )\)\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    \(curvR[christ_, 
        var_: {t, 
            r, \[Theta], \[Phi]}] := \[IndentingNewLine]Module[{temp1}, \
\[IndentingNewLine]temp1 = 
          Outer[D, christ, 
            var]; \[IndentingNewLine]\((Transpose[
              Outer[D, christ, var], {1, 2, 4, 3}] - 
            Transpose[Outer[D, christ, var], {1, 2, 3, 4}] + 
            Transpose[Inner[Times, christ, christ, Plus, 2], {1, 3, 4, 2}] - 
            Transpose[
              Inner[Times, christ, christ, Plus, 2], {1, 4, 3, 
                2}])\)\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(einstein[curv_, 
        met_] := \[IndentingNewLine]Module[{dem, temp1, temp2, i, j, 
          s}, \[IndentingNewLine]dem = 
          Length[met]; \[IndentingNewLine]temp1 = 
          Simplify[
            ExpandAll[
              Table[Sum[curv[\([s, i, s, j]\)], {s, dem}], \ \ \ {i, 
                  dem}, {j, dem}]]]; \[IndentingNewLine]temp2 = 
          Simplify[
            ExpandAll[
              Sum[\(Inverse[met]\)[\([j, i]\)] curv[\([s, i, s, j]\)], {s, 
                  dem}, {i, dem}, {j, dem}]]]; \[IndentingNewLine]Simplify[
          ExpandAll[
            Table[temp1[\([i, j]\)] - \((1/2)\) met[\([i, j]\)] temp2, {i, 
                dem}, {j, dem}]]]]\)], "Input"]
}, Closed]],

Cell["Solution", "Subsubsection"],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection"],

Cell[BoxData[
    \(\(\(\ \)\(\(\[CapitalGamma]\)\(\ \)\(=\)\(christ[
        g\[Mu]\[Nu], {t, r, \[Theta], \[Phi]}]\)\(\ \ \ \)\)\)\)], "Input"],

Cell[BoxData[
    \(\(R = 
        curvR[\[CapitalGamma], {t, r, \[Theta], \[Phi]}] // 
          Simplify\ ;\)\)], "Input"],

Cell[BoxData[
    \(\(G\[Mu]\[Nu] = einstein[R, g\[Mu]\[Nu]];\)\)], "Input"],

Cell[BoxData[{
    \(\(\({eqGtt, eqGrr, eqG\[Theta]\[Theta], 
          eqG\[Phi]\[Phi]} = \ \(\(MapAt[Flatten, G\[Mu]\[Nu] \[Equal] 0, 1] // 
              Thread\) // Select[#1, FreeQ[#, True] &] &\)\  // 
          Simplify\ ;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \({eqGtt, eqGrr, eqG\[Theta]\[Theta], eqG\[Phi]\[Phi]}\  // 
      ColumnForm\)}], "Input"],

Cell[BoxData[{
    \(\(\(vacuumeq = \((\ \({\ eqGtt, eqGrr} // 
                Solve[#, {\(g11'\)[r], \(g00'\)[r]}] &\) // Flatten)\) /. 
          Rule \[Rule] Equal;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(vacuumeq // ColumnForm\)}], "Input"],

Cell["sol=DSolve[vacuumeq,{g11[r],g00[r]},r]// Simplify//Flatten ", "Input"],

Cell[BoxData[
    RowBox[{"bdcond", "=", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{\(C[1]\), "\[Rule]", 
            RowBox[{"Log", "[", 
              FormBox[\(c\^2\/\(2\ G\ M\)\),
                "TraditionalForm"], "]"}]}], ",", 
          RowBox[{\(C[2]\), "\[Rule]", " ", 
            FormBox[\(\(2\ G\ M\)\/c\^2\),
              "TraditionalForm"]}]}], "}"}]}]], "Input"],

Cell[BoxData[
    \(\((\(\(g\[Mu]\[Nu] /. sol\) /. bdcond\) /. G \[Rule] temp\ c\^2\ r\  // 
          Simplify)\) /. temp \[Rule] G\/\(r\ c\^2\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection"],

Cell[BoxData[
    \(\(data = {{7.35\ *10\^25\ \ g, 
              1.738\ *10\^8\ \ \ cm}, \ \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \
\ \ {5.977\ *10\^27\ \ g, 
              6.378\ *10\^8\ \ cm}, \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \
{Mo, 6.9598\ *10\^10\ \ \ \ cm}, \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ {Mo\
\ , 1.738\ *10\^10\ \ cm}, \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ {Mo\ , 
              10\^6\ \ cm\ }} /. \[IndentingNewLine]Mo \[Rule] \ 
            1.989\ *\(10\^33\) g\ \ ;\)\)], "Input"],

Cell[BoxData[{
    \(\(names = {Moon, Earth, Sun, "\<white dwarf\>"\ , 
          neutron\ star};\)\), "\[IndentingNewLine]", 
    \(\ TableForm[data, TableHeadings \[Rule] {names, \ {\ Mass, \ Radius}}] /. 
      cm \[Rule] \(\(10\^\(-5\)\)\(\ \)\(km\)\(\ \)\)\)}], "Input"],

Cell[BoxData[
    \(\(constants = {c \[Rule] 3.0*\ \(10\^10\) cm/sec\ , \ 
          G \[Rule] 7.425\ *\(10\^\(-29\)\) \(c\^2\ cm\)\/g};\)\)], "Input"],

Cell[BoxData[
    RowBox[{\(Ratio[{M_, r_}]\), " ", ":=", 
      RowBox[{
        FormBox[\(\(2\ G\ M\)\/\(c\^2\ r\)\),
          "TraditionalForm"], "//.", "constants"}]}]], "Input"],

Cell[BoxData[
    \(Transpose[{names, \(Ratio[#] &\) /@ data\ }]\  // TableForm\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 3: Geodesics for the Schwarzschild metric   ", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Clear["\<Global`*\>"];\)\)], "Input"],

Cell[CellGroupData[{

Cell["Remarks and outline", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(geodesic[met_, var_, 
        parameter_:  s] := \[IndentingNewLine]Module[{met1, temp1, vel1, 
          var1}, \[IndentingNewLine]vel1 = 
          D[Through[var[parameter]], parameter]; \[IndentingNewLine]var1 = 
          Through[var[parameter]]; \[IndentingNewLine]met1 = 
          met /. Thread[
              var \[Rule] 
                Through[
                  var[parameter]]]; \[IndentingNewLine]temp1 = \((D[
                    met1 . vel1, 
                    parameter] - \((\(1/2\ D[met1, #] . vel1 . vel1 &\) /@ 
                      var1)\) \[Equal] {0, 0, 0, 0})\) // Thread]\)], "Input"]
}, Closed]],

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection"],

Cell[BoxData[
    RowBox[{"g\[Mu]\[Nu]", "=", 
      RowBox[{"DiagonalMatrix", "[", 
        FormBox[\({g00(r), 
            g11(r), \(-r\^2\), \(-r\^2\)\ \(\(sin\^2\)(\[Theta])\)}\),
          "TraditionalForm"], "]"}]}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"comp", "=", 
        FormBox[\({g00 \[Rule] \((1 - \(2\ m\)\/#1 &)\), 
            g11 \[Rule] \((\(-\(1\/\(1 - \(2\ m\)\/#1\)\)\) &)\)}\),
          "TraditionalForm"]}], ";"}]], "Input"],

Cell[BoxData[
    \(\(\(\ \)\(eq1 = 
        geodesic[g\[Mu]\[Nu]\ , {t, r, \[Theta], \[Phi]}] // 
          Simplify\ ;\)\)\)], "Input"],

Cell[BoxData[{
    \(\(\(eq2 = \(\(\((Solve[
                      eq1, {\(t''\)[s], \(r''\)[s], \(\[Theta]''\)[
                          s], \(\[Phi]''\)[s]}] // Flatten)\) /. 
                comp\) /. \[Theta] \[Rule] \((\[Pi]/2 &)\)\) /. 
            Rule \[Rule] Equal\  // Simplify;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\ \(\(eq2\)\(//\)\(ColumnForm\)\(\ \ \)\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection"],

Cell[BoxData[
    \(eq3 = \ \(DSolve[eq2[\([1]\)]\ , r[s], s]\)[\([1, 
            1]\)]\  /. \(\(Rule\)\(\[Rule]\)\(Equal\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    RowBox[{"trule", "=", " ", 
      RowBox[{
        RowBox[{\(\(Solve[eq3, \(t'\)[s]]\)[\([1, 1]\)]\), "/.", 
          RowBox[{\(C[1]\), "\[Rule]", 
            RowBox[{
              FormBox[\(-\(1\/\(2\ m\)\)\),
                "TraditionalForm"], "  ", \(Log[En]\)}]}]}], "//", "Flatten", 
        " "}]}]], "Input"],

Cell[BoxData[
    RowBox[{"\[Phi]rule", "=", 
      RowBox[{\((\(DSolve[eq2[\([4]\)]\ , r[s], s]\)[\([1, 1]\)]\  /. 
              Rule \[Rule] 
                Equal // \(Solve[#, \(\[Phi]'\)[s]]\)[\([1, 1]\)] &\ )\), "/.",
         
        RowBox[{\(C[1]\), "\[Rule]", 
          FormBox[\(\@h\),
            "TraditionalForm"]}]}]}]], "Input"],

Cell[BoxData[
    \(eq4\  = \(eq2[\([2]\)] /. trule\) /. \[Phi]rule // Simplify\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection"],

Cell[BoxData[
    \(\(vel = {\(t'\)[s], \(r'\)[s], 0, \(\[Phi]'\)[s]};\)\)], "Input"],

Cell[BoxData[
    \(\(met = \((\(\(\(g\[Mu]\[Nu] /. comp\) /. \[Theta] \[Rule] \[Pi]\/2\) /. 
              r \[Rule] r[s]\) /. \[Theta] \[Rule] \[Theta][
                s])\)\ ;\)\)], "Input"],

Cell[BoxData[
    \(eq5 = 1 \[Equal] \(\(\(vel . met\) . vel\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(eq6 = \(eq5 /. trule\) /. \[Phi]rule\  // Simplify\)], "Input"],

Cell[BoxData[
    \(\(r'\)[s]\^2 /. \(Solve[eq6, \(r'\)[s]]\)[\([1]\)] // 
      Simplify\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 4: Time it takes to fall into a black hole     ", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Clear["\<Global`*\>"];\)\)], "Input"],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{"eq1", "=", 
        FormBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{
                SuperscriptBox["r", "\[Prime]",
                  MultilineFunction->None], "(", "s", ")"}], "2"], 
            "==", \(En\^2 + \(2\ m\)\/\(r(s)\) - 
              h\^2\/\(r(s)\)\^2 + \(2\ h\^2\ m\)\/\(r(s)\)\^3 - 1\)}],
          "TraditionalForm"]}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{"eq2", "=", 
      RowBox[{
        RowBox[{\(\(Solve[eq1, \(r'\)[s]]\  /. h \[Rule] 0\)\  /. 
            Rule \[Rule] Equal\), " ", "/.", 
          FormBox[\(\@x_ \[RuleDelayed] \@Simplify[x]\),
            "TraditionalForm"]}], "//", "Flatten", " "}]}]], "Input"],

Cell[BoxData[
    \(eq3 = eq2[\([1]\)]\)], "Input"],

Cell[BoxData[
    \(eq4 = \(0 \[Equal] eq3[\([2]\)] /. s \[Rule] 0\) /. 
        r[0] \[Rule] r0\)], "Input"],

Cell[BoxData[
    \(rprimerule = \ \(\(Solve[{eq3, eq4}, {\(r'\)[s], En}]\)[\([2]\)]\ \ \  // 
          Simplify\) // ExpandAll\)], "Input"],

Cell[BoxData[
    RowBox[{"radialeq", "=", 
      RowBox[{
        RowBox[{\(rprimerule[\([1]\)]\), "/.", 
          FormBox[\(\@x_ \[RuleDelayed] \@Factor[x]\),
            "TraditionalForm"]}], "//", "PowerExpand"}]}]], "Input"],

Cell[BoxData[
    \(Stime = \(\(Integrate[\ 
          1\/\(r'\)[s] /. rprimerule, {r[s], r0\ , 
            r\ }, \[IndentingNewLine]Assumptions \[Rule] {\ \ r0\  > r\  > 
                0}]\)\(//\)\(Apart\)\(\ \ \)\)\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(Stime /. r \[Rule] 0\), "/.", 
        RowBox[{"m", "\[Rule]", " ", 
          FormBox[\(\(G\ M\)\/c\^2\),
            "TraditionalForm"]}]}], "//", "PowerExpand"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{"trule", "=", 
        RowBox[{\(\(t'\)[s]\), "\[Rule]", 
          FormBox[\(En\/\(1 - \(2\ m\)\/\(r(s)\)\)\),
            "TraditionalForm"]}]}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{"eq5", "=", 
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{
                      FormBox[
                        FractionBox[
                          RowBox[{
                            SuperscriptBox["r", "\[Prime]",
                              MultilineFunction->None], "(", "s", ")"}], 
                          RowBox[{
                            SuperscriptBox["t", "\[Prime]",
                              MultilineFunction->None], "(", "s", ")"}]],
                        "TraditionalForm"], "/.", "trule"}], "/.", 
                    "rprimerule"}], "/.", \(r[s] \[Rule] r[t]\)}], ")"}], 
              "  ", "/.", " ", 
              FormBox[\(x_\^n_ \[RuleDelayed] Factor[Together[x]]\^n\),
                "TraditionalForm"]}], " ", "//", "PowerExpand"}], " ", "//", 
          "Expand"}], " ", "//", "Simplify"}]}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["(*",
        FontColor->RGBColor[1, 0, 0]], 
      StyleBox[" ",
        FontColor->RGBColor[1, 0, 0]], 
      StyleBox[
        RowBox[{
          
          RowBox[{\(Incorrect\ \(version : \ \[IndentingNewLine]change\)\), 
            "=", " ", 
            FormBox[
              RowBox[{"{", 
                RowBox[{\(r(t) \[Rule] r0\ \(\(cos\^2\)(x)\)\), ",", 
                  RowBox[{
                    RowBox[{
                      SuperscriptBox["r", "\[Prime]",
                        MultilineFunction->None], "(", "x", ")"}], 
                    "\[Rule]", \(\(-2\)\ r0\ \(cos(x)\)\ \(sin(x)\)\)}]}], 
                "}"}],
              "TraditionalForm"]}], ";"}],
        FontColor->RGBColor[1, 0, 0]], 
      StyleBox["\[IndentingNewLine]",
        FontColor->RGBColor[1, 0, 0]], 
      StyleBox["*)",
        FontColor->RGBColor[1, 0, 0]]}]], "Input"],

Cell[BoxData[
    StyleBox[
      RowBox[{
        RowBox[{"change", "=", " ", 
          FormBox[
            RowBox[{"{", 
              RowBox[{\(r[t] \[Rule] r0\ Cos[x]^2\), ",", 
                RowBox[{
                  RowBox[{
                    SuperscriptBox["r", "\[Prime]",
                      MultilineFunction->None], "[", "x", "]"}], 
                  "\[Rule]", \(\(-2\)\ r0\ Cos[x]\ Sin[x]\)}]}], "}"}],
            "TraditionalForm"]}], ";"}],
      FontColor->RGBColor[1, 0, 0]]], "Input"],

Cell[BoxData[
    \(eq6 = \ \(\(\((1\/eq5\ \ \(r'\)[x] /. change)\) // 
          Simplify\)\(//\)\(PowerExpand\)\(\ \ \ \)\)\)], "Input"],

Cell[BoxData[
    RowBox[{"Ttime", "=", 
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"Integrate", "[", "  ", 
                  RowBox[{"eq6", " ", ",", 
                    RowBox[{"{", 
                      RowBox[{"x", ",", "0", ",", 
                        FormBox[\(\(cos\^\(-1\)\)(\@\(r\/r0\))\),
                          "TraditionalForm"]}], " ", "}"}]}], "  ", "]"}], 
                "/.", \({2\ m - r0 \[Rule] \(-temp1\)\ }\)}], "//", 
              "PowerExpand"}], ")"}], "/.", \(temp1 \[Rule] r0 - 2\ m\)}], 
        " ", "//", "Simplify", " "}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection"],

Cell[BoxData[
    \(\(value = {m \[Rule] 1, r0 \[Rule] 8};\)\)], "Input"],

Cell[BoxData[{
    \(\(\(pt1 = 
        Plot[Evaluate[\((Ttime /. value)\)], {r, 2, 8}, 
          DisplayFunction \[Rule] Identity];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(pt2 = 
        Plot[Evaluate[Stime /. value], {r, 0, 8}, 
          DisplayFunction \[Rule] Identity];\)\)}], "Input"],

Cell[BoxData[
    \(\(text = {Line[{{2, 0}, {2, 
                  40}}], \[IndentingNewLine]\[IndentingNewLine]\ 
            Text[\ StyleForm["\<Proper Time\>", 
                FontFamily -> "\<Times-Bold\>", FontSize \[Rule] 10\ ], {1.2, 
                22}], \[IndentingNewLine]\ \[IndentingNewLine]Text[\ 
              StyleForm["\<Coordinate Time\>", 
                FontFamily -> "\<Times-Bold\>", FontSize \[Rule] 10\ ], {4.5, 
                30}], \[IndentingNewLine]\ \[IndentingNewLine]Text[\ 
              StyleForm["\<r=2m\>", FontFamily -> "\<Times-Bold\>", 
                FontSize \[Rule] 10\ ], {2.6, 
                10}]\ \[IndentingNewLine]\[IndentingNewLine]} // 
          Graphics;\)\)], "Input"],

Cell[BoxData[
    \(\(Show[{pt1, pt2, \ 
          text}, \[IndentingNewLine]AxesLabel \[Rule] {"\<Distance\>", \
"\<Time\>"}, 
        DisplayFunction \[Rule] $DisplayFunction, \
\[IndentingNewLine]PlotRange \[Rule] {0, 40}];\)\)], "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Problem 5: Circular geodesics for the Schwarzschild metric   \
\>", \
"Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Clear["\<Global`*\>"];\)\)], "Input"],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"teq", "=", 
      RowBox[{
        FormBox[
          RowBox[{
            RowBox[{
              SuperscriptBox["t", "\[Prime]",
                MultilineFunction->None], "(", "s", ")"}], 
            "==", \(En\/\(1 - \(2\ m\)\/\(r(s)\)\)\)}],
          "TraditionalForm"], "/.", \(r[s]\  \[Rule] r0\)}]}]], "Input"],

Cell[BoxData[
    RowBox[{" ", 
      RowBox[{"\[Phi]eq", "=", " ", 
        RowBox[{
          FormBox[
            RowBox[{
              RowBox[{
                SuperscriptBox["\[Phi]", "\[Prime]",
                  MultilineFunction->None], "(", "s", ")"}], 
              "==", \(h\/\(r(s)\)\^2\)}],
            "TraditionalForm"], "/.", \(r[s]\  \[Rule] r0\)}]}]}]], "Input"],

Cell[BoxData[
    RowBox[{" ", 
      RowBox[{"acc", "=", 
        RowBox[{
          RowBox[{\(\(r''\)[s]\), " ", "\[Equal]", " ", 
            FormBox[
              FractionBox[
                RowBox[{
                  RowBox[{"m", " ", 
                    RowBox[{"(", 
                      RowBox[{\(En\^2\), "-", 
                        SuperscriptBox[
                          RowBox[{
                            SuperscriptBox["r", "\[Prime]",
                              MultilineFunction->None], "(", "s", ")"}], 
                          "2"]}], ")"}], " ", \(\(r(s)\)\^3\)}], 
                  "-", \(h\^2\ \(r(s)\)\^2\), 
                  "+", \(4\ h\^2\ m\ \((r(s) - m)\)\)}], \(\((2\ m - 
                      r(s))\)\ \(r(s)\)\^4\)],
              "TraditionalForm"]}], 
          "/.", \(r\  \[Rule] \((r0 &)\)\)}]}]}]], "Input"],

Cell[BoxData[
    RowBox[{"vel", "=", " ", 
      RowBox[{
        FormBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{
                SuperscriptBox["r", "\[Prime]",
                  MultilineFunction->None], "(", "s", ")"}], "2"], 
            "==", \(En\^2 + \(2\ m\)\/\(r(s)\) - 
              h\^2\/\(r(s)\)\^2 + \(2\ h\^2\ m\)\/\(r(s)\)\^3 - 1\)}],
          "TraditionalForm"], " ", 
        "/.", \(r\  \[Rule] \((r0 &)\)\)}]}]], "Input"],

Cell[BoxData[
    RowBox[{"eq2", "=", " ", 
      RowBox[{\((\(Solve[{acc, vel}, {En, \ h}\ ] // Simplify\)\  // 
            PowerExpand)\), "/.", 
        RowBox[{"{", 
          
          FormBox[\(1\/\@\(3\ m - r0\) \[Rule] \(-\(\[ImaginaryI]\/\@\(r0 - 3\
\ m\)\)\)\),
            "TraditionalForm"], "}"}]}]}]], "Input"],

Cell[BoxData[
    \(Enhrule = eq2[\([4]\)]\)], "Input"],

Cell[BoxData[
    \(sol = \(DSolve[{\ teq, \[Phi]eq, 
                t[0] \[Equal] 0, \[Phi][0] \[Equal] 0}, {t[s], \[Phi]\ [s]}, 
              s] /. Enhrule // Flatten\) // Simplify\)], "Input"],

Cell[BoxData[
    \(\(\(\ \)\(\(s\)\(/.\)\(\(Solve[\((\[Phi][s] /. sol)\)\  \[Equal] 
            2\ \[Pi], s]\)[\([1, 1]\)]\)\(\ \)\)\)\)], "Input"],

Cell[BoxData[
    \(\(\(\ \)\(\(Period\)\(/.\)\(\(Solve[\ {Period \[Equal] 
                t[s\ ], \[Phi][s] \[Equal] 2\ \[Pi]\ } /. sol, Period, 
          s]\)[\([1, 1]\)]\)\(\ \)\)\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 6: Precession of the Perihelion ", "Subsection"],

Cell[BoxData[
    \(\(Clear["\<Global`*\>"];\)\)], "Input"],

Cell["Solution", "Subsubsection"],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{"eq1", "=", 
        FormBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{
                SuperscriptBox["r", "\[Prime]",
                  MultilineFunction->None], "(", "s", ")"}], "2"], 
            "==", \(En\^2 + \(2\ m\)\/\(r(s)\) - 
              h\^2\/\(r(s)\)\^2 + \(2\ h\^2\ m\)\/\(r(s)\)\^3 - 1\)}],
          "TraditionalForm"]}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"change", "=", 
        FormBox[
          RowBox[{"{", 
            RowBox[{
              RowBox[{
                RowBox[{
                  SuperscriptBox["r", "\[Prime]",
                    MultilineFunction->None], "(", "s", ")"}], "\[Rule]", 
                FractionBox[
                  RowBox[{"h", " ", 
                    RowBox[{
                      SuperscriptBox["r", "\[Prime]",
                        MultilineFunction->None], "(", "\[Phi]", 
                      ")"}]}], \(\(r(\[Phi])\)\^2\)]}], 
              ",", \(r(s) \[Rule] r(\[Phi])\)}], "}"}],
          "TraditionalForm"]}], ";"}]], "Input"],

Cell[BoxData[
    \(eq2 = eq1 /. change\)], "Input"],

Cell[BoxData[
    \(eq3 = eq2 /. {r \[Rule] \((1/u[#] &)\)}\)], "Input"],

Cell[BoxData[
    \(uEq = \((D[
                eq3, \[Phi]] // \(Solve[#, \(\(u'\)'\)[\[Phi]]]\)[\([1, 
                    1]\)] &)\) /. Rule \[Rule] Equal // ExpandAll\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b  ", "Subsubsection"],

Cell[BoxData[
    \(\(pertu = {u\  -> \((u0 + du[#] &)\)};\)\)], "Input"],

Cell[BoxData[
    \(\(\(\ \)\(\(uEq /. pertu\)\(//\)\(ExpandAll\)\(\ \)\)\)\)], "Input"],

Cell[BoxData[
    \(eq4 = \ \((uEq /. pertu // ExpandAll)\)\  /. 
        du[\[Phi]]^2 \[Rule] 0\)], "Input"],

Cell[BoxData[
    \(eq5 = \(eq4 /. \(\(du'\)'\)[\[Phi]] \[Rule] 0\) /. 
          du[\[Phi]] \[Rule] 0 // Simplify\)], "Input"],

Cell[BoxData[
    \(eq6 = \(\(\(Solve[{eq5, eq4}, \(\(du'\)'\)[\[Phi]]]\)[\([1, 
                  1]\)] /. {6\ m\ u0 -> 1 - \[Gamma]\^2}\) /. Rule -> Equal // 
          ExpandAll\) // Simplify\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"\[Gamma]rule", "=", "  ", 
        FormBox[\(\[Gamma] \[Rule] \@\(1 - 6\ m\ u0\)\),
          "TraditionalForm"]}], ";"}]], "Input"],

Cell[BoxData[
    \(\(\(dusol\)\(=\)\(\(DSolve[{eq6\ \ , du[0] == e\ u0, \(du'\)[0] == 0}, 
          du[\[Phi]], \[Phi]]\)[\([1, 1]\)]\)\(\ \ \)\)\)], "Input"],

Cell[BoxData[
    \(uSol = \(\(u0 + du[\[Phi]]\)\(/.\)\(dusol\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"u0rule", "=", " ", 
        FormBox[\(u0 \[Rule] 1\/\(a\ \((1 - e\^2)\)\)\),
          "TraditionalForm"]}], ";"}]], "Input"],

Cell[BoxData[
    \(\(\(r == \((1/\ uSol\ \ )\) /. 
        u0rule\)\(\ \ \)\(//\)\(Simplify\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(\ \)\(eq7 = \ 2\ \[Pi]/\[Gamma]\  - \ 2\ \[Pi];\)\)\)], "Input"],

Cell[BoxData[
    RowBox[{\((\((\(eq7 /. \[Gamma]rule\) /. u0rule)\) + O[m]^2 // Normal)\), 
      "/.", 
      FormBox[\(m \[Rule] \(G\ M\)\/c\^2\),
        "TraditionalForm"]}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"\[CapitalDelta]", "=", 
        FormBox[\(\(6\ G\ M\ \[Pi]\)\/\(a\ c\^2\ \((1 - e\^2)\)\)\),
          "TraditionalForm"]}], ";"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c   ", "Subsubsection"],

Cell[BoxData[
    RowBox[{" ", 
      RowBox[{
        RowBox[{"const", "=", 
          RowBox[{"{", 
            RowBox[{\(M\  \[Rule] 1.989\ *10\^33\ \ gm\), ",", " ", 
              RowBox[{"G", " ", "->", " ", 
                RowBox[{"7.42426", " ", "*", " ", \(10\^\(-29\)\), " ", 
                  FormBox[\(\(c\^2\ cm\)\/gm\),
                    "TraditionalForm"]}]}]}], "}"}]}], ";"}], " "}]], "Input"],

Cell[BoxData[
    \(\(\(mercury\  = {\ a \[Rule] 0.3871\ AU, \ 
          AU -> 1.495985*\ 10\^13\ cm, \ \ e -> 
            0.20561421\ };\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(\(radTosec = \ 360*\ 60\ *60\ /\((2\ \[Pi])\)\ ;\)\)], "Input"],

Cell[BoxData[
    \(\(\(Mnumber = \ \ \ 100\/0.24085;\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(\(\[CapitalDelta]\ \((radTosec)\) \((\ Mnumber)\) /. const\) //. 
        mercury\)\(//\)\(NumberForm[#, 4] &\)\(\ \ \ \)\)\)], "Input"],

Cell[BoxData[
    \(\(venus = {\ a \[Rule] 108.2\ \ *10\^11\ cm, 
          e \[Rule] 0.007};\)\)], "Input"],

Cell[BoxData[
    \(\(\(\ \ \)\(Vnumber = 100\/0.62\ \ ;\)\)\)], "Input"],

Cell[BoxData[
    \(\(\(\ \ \)\(\(\[CapitalDelta]\ \((radTosec)\) \((\ Vnumber)\) /. 
          const\) //. venus // NumberForm[#, 2] &\)\)\)], "Input"],

Cell[BoxData[
    \(\(earth = {\ \ a \[Rule] 149.6\ *\ 10\^11\ cm\ , 
          e \[Rule] 0.017};\)\)], "Input"],

Cell[BoxData[
    \(\(\[CapitalDelta]\ \((radTosec\ )\) \((100)\) /. const\) //. earth // 
      NumberForm[#, 2] &\)], "Input"]
}, Closed]]
}, Closed]],

Cell[TextData[{
  "10.4 Cosmology     ",
  StyleBox[" ",
    FontColor->RGBColor[0, 0, 1]]
}], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Overview of Friedmann, Robertson, and Walker Cosmology  ", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
Problem  1: Field equations for Friedmann-Robertson-Walker \
cosmology   \
\>", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Clear["\<Global`*\>"];\)\)], "Input"],

Cell[CellGroupData[{

Cell["Remarks and outline", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(christ[g\[Mu]\[Nu]_, 
          var_: {t, r, \[Theta], \[Phi]}]\  := \[IndentingNewLine]Module[{\ 
            temp1, imet}, \[IndentingNewLine]temp1 = \ 
            Outer[D, g\[Mu]\[Nu], var]\ ; \[IndentingNewLine]imet = \ 
            Inverse[g\[Mu]\[Nu]] // Simplify; \[IndentingNewLine]\ \ 1/2 \((\ 
              Transpose[imet . temp1, {1, 3, 2}]\  + 
                Transpose[imet . temp1, {1, 2, 3}]\ \  - \ 
                imet . Transpose[
                    temp1, {3, 2, 1}]\ )\)\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    \(curvR[\[CapitalGamma]_, 
        var_: {t, r, \[Theta], \[Phi]}] := \[IndentingNewLine]Module[{temp1}, 
        temp1 = Outer[D, \[CapitalGamma], 
            var]; \[IndentingNewLine]\((Transpose[
              Outer[D, \[CapitalGamma], var], {1, 2, 4, 
                3}] - \[IndentingNewLine]Transpose[
              Outer[D, \[CapitalGamma], var], {1, 2, 3, 
                4}] + \[IndentingNewLine]Transpose[
              Inner[Times, \[CapitalGamma], \[CapitalGamma], Plus, 2], {1, 3, 
                4, 2}] - \[IndentingNewLine]Transpose[
              Inner[Times, \[CapitalGamma], \[CapitalGamma], Plus, 2], {1, 4, 
                3, 2}])\)\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(einstein[curv_, 
        g\[Mu]\[Nu]_] := \[IndentingNewLine]Module[{dem, temp1, temp2, i, j, 
          s}, dem = Length[g\[Mu]\[Nu]]; \[IndentingNewLine]temp1 = 
          Simplify[
            ExpandAll[
              Table[Sum[curv[\([s, i, s, j]\)], {s, dem}], {i, dem}, {j, 
                  dem}]]]; \[IndentingNewLine]temp2 = 
          Simplify[
            ExpandAll[
              Sum[\(Inverse[g\[Mu]\[Nu]]\)[\([j, i]\)] 
                  curv[\([s, i, s, j]\)], {s, dem}, {i, dem}, {j, 
                  dem}]]]; \[IndentingNewLine]Simplify[
          ExpandAll[
            Table[temp1[\([i, j]\)] - \((1/2)\) g\[Mu]\[Nu][\([i, j]\)] 
                  temp2, {i, dem}, {j, dem}]]]]\)], "Input"]
}, Closed]],

Cell["Solution ", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{"g\[Mu]\[Nu]", "=", 
        RowBox[{"DiagonalMatrix", "[", 
          
          FormBox[\({1, \(-\(\(R(t)\)\^2\/\(1 - 
                      k\ r\^2\)\)\), \(-r\^2\)\ \(R(t)\)\^2, \(-r\^2\)\ \
\(R(t)\)\^2\ \(\(sin\^2\)(\[Theta])\)}\),
            "TraditionalForm"], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
    \(\(\[CapitalGamma] = christ[g\[Mu]\[Nu]];\)\)], "Input"],

Cell[BoxData[
    \(\(\(R\[Alpha]\[Beta]\[Gamma]\[Delta] = 
        curvR[\[CapitalGamma]] // Simplify;\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(G\[Mu]\[Nu] = 
      einstein[R\[Alpha]\[Beta]\[Gamma]\[Delta], g\[Mu]\[Nu]]\)], "Input"],

Cell[BoxData[{
    \(\(vel = {1, 0, 0, 
          0};\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*Contravariant\ four - 
        velocity*) \), "\[IndentingNewLine]", 
    \(\(covel = g\[Mu]\[Nu] . {1, 0, 0, 0};\) (*Covariant\ four - 
        velocity*) \)}], "Input"],

Cell[BoxData[
    \(\(T = 
        Table[\((\[Rho][t] + P[t])\) covel[\([i]\)] covel[\([j]\)] - 
              g\[Mu]\[Nu][\([i, j]\)] P[t], {i, 4}, {j, 4}] // 
          Simplify;\)\)], "Input"],

Cell[BoxData[
    \(\((eq1 = \(\(Map[Flatten, 
                  G\[Mu]\[Nu] \[Equal] 
                    8\ \[Pi]\ G\ T + \[Lambda]\ g\[Mu]\[Nu]] // Thread\) // 
              Select[#1, FreeQ[#, True] &] &\)\  // Simplify\ )\) // 
      ColumnForm\)], "Input"],

Cell[BoxData[
    \(\((fieldeq = \(\(Solve[
                    eq1 /. \(R'\)[t] \[Rule] Sqrt[x], {\(R''\)[t], 
                      x}]\)[\([1]\)] /. x \[Rule] \(R'\)[t]^2\) /. 
              Rule \[Rule] Equal // ExpandAll)\) // ColumnForm\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection"],

Cell[BoxData[
    \(conT = 
      Table[\((\[Rho][t] + P[t])\) 
            vel[\([i]\)]\ vel[\([j]\)] - \(Inverse[g\[Mu]\[Nu]]\)[\([i, 
                j]\)]\ P[t], {i, 4}, {j, 4}]\)], "Input"],

Cell[BoxData[
    \(coder[{2, U, U}, conT_, christ_, var_]\  := \n\t
      Outer[D, conT, var] + \ \t\n\t
        Transpose[
          Inner[Times, christ, conT, Plus, 2], {1, 3, 2}] + \ \ Transpose[
          Inner[Times, christ, Transpose[conT, {2, 1}], Plus, 2], {2, 3, 
            1}]\)], "Input"],

Cell[BoxData[
    \(\(eq2 = 
        coder[{2, U, U}, conT, \[CapitalGamma], {t, r, \[Theta], \[Phi]}] // 
          Simplify\ ;\)\)], "Input"],

Cell[BoxData[
    \(\(\(eq3\)\(=\)\(Table[
        Sum[eq2[\([i, s, s]\)], {s, 1, 4}], {i, 1, 4}]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(eq4 = eq3[\([1]\)] \[Equal] 0\)], "Input"],

Cell[BoxData[
    \(\(eqstate = {P[t] \[Rule] \[Alpha]\ \[Rho][t]};\)\)], "Input"],

Cell[BoxData[
    \(eq5 = \(\(DSolve[{eq4 /. eqstate, R[to] \[Equal] Ro}, R[t], t]\)[\([1, 
                1]\)] /. {\[Rho][to] \[Rule] \[Rho]o, Rule \[Rule] Equal} // 
          Simplify\) // PowerExpand\)], "Input"],

Cell[BoxData[
    \(\[Rho]rule = \(\(Solve[eq5, \[Rho][t]]\)[\([1, 1]\)] // PowerExpand\) // 
        Simplify\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection"],

Cell["\<\
 fieldeq/.\[Rho]rule/.eqstate/.\[Alpha]->0//
                           ExpandAll  //ColumnForm\
\>", "Input",
  AspectRatioFixed->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Problem  2: Zero-pressure (Dust) Cosmological Models    ",
  StyleBox["  ",
    FontColor->RGBColor[0, 0, 1]]
}], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Remarks and outline", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Clear["\<Global`*\>"];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"eq1", "=", 
        FormBox[
          RowBox[{
            RowBox[{
              SuperscriptBox["R", "\[Prime]\[Prime]",
                MultilineFunction->None], "(", "t", ")"}], 
            "==", \(1\/3\ \[Lambda]\ \(R(
                  t)\) - \(4\ G\ \[Pi]\ Ro\^3\ \[Rho]o\)\/\(3\ \
\(R(t)\)\^2\)\)}],
          "TraditionalForm"]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"eq2", "=", 
        FormBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{
                SuperscriptBox["R", "\[Prime]",
                  MultilineFunction->None], "(", "t", ")"}], "2"], 
            "==", \(\(8\ G\ \[Pi]\ \[Rho]o\ Ro\^3\)\/\(3\ \(R(t)\)\) + 
              1\/3\ \[Lambda]\ \(R(t)\)\^2 - k\)}],
          "TraditionalForm"]}], ";"}]}], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"parameterrule", "=", 
        FormBox[
          RowBox[{"{", 
            RowBox[{\(R(to) \[Rule] Ro\), ",", 
              RowBox[{
                RowBox[{
                  SuperscriptBox["R", "\[Prime]",
                    MultilineFunction->None], "(", "to", ")"}], 
                "\[Rule]", \(Ho\ Ro\)}], ",", 
              RowBox[{
                RowBox[{
                  SuperscriptBox["R", "\[Prime]\[Prime]",
                    MultilineFunction->None], "(", "to", ")"}], 
                "\[Rule]", \(\(-Ho\^2\)\ qo\ Ro\)}], 
              ",", \(\[Rho]o \[Rule] \(3\ Ho\^2\ \[Sigma]\)\/\(4\ G\ \
\[Pi]\)\), ",", \(\[Lambda] \[Rule] 3\ Ho\^2\ \[CapitalGamma]\)}], "}"}],
          "TraditionalForm"]}], ";"}]], "Input"],

Cell[BoxData[
    \(qrule = \(Solve[\({eq1, eq2} /. t \[Rule] to\) /. parameterrule, {qo, 
              k}] // Flatten\) // Simplify\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection"],

Cell[BoxData[
    \(\(change = {\(R'\)[t] \[Rule] \(X'\)[t]\ Ro, 
          R[t] \[Rule] X[t]\ Ro};\)\)], "Input"],

Cell[BoxData[
    \(\((\(\(eq2 /. parameterrule\) /. qrule\) /. change // 
        Solve[#, \(X'\)[t]] &)\)\)], "Input"],

Cell[BoxData[
    \(eq3 = {\(X'\)[t] \[Rule] 
          Ho\ \((1 - \[CapitalGamma] - 
                  2\ \[Sigma] + \((2\ \[Sigma])\)/
                    X[t] + \[CapitalGamma]\ X[t]^2)\)^\((1/2)\)}\)], "Input"],

Cell[BoxData[
    \(\(\(integrand\)\(=\)\((\(1/\(X'\)[t] /. 
            eq3\) /. {\[CapitalGamma] \[Rule] 0, 
            Ho \[Rule] 1, \[Sigma] \[Rule] qo}\ \ )\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(eq4 = 
      Integrate[\ integrand, {X[t], 0, 1}\ , 
          GenerateConditions \[Rule] False\ ] // Simplify\)], "Input"],

Cell[BoxData[
    \(eq4 = Integrate[\ integrand, {X[t], 0, 1}\ \ ] // Simplify\)], "Input"],

Cell[BoxData[
    \(Clear[ageo]\)], "Input"],

Cell[BoxData[{
    \(\(ageo[q1_]\  := \ 
        eq4[\([2]\)] /. qo \[Rule] q1 // Chop;\)\), "\[IndentingNewLine]", 
    \(ageo[1/2] = 2/3; \ ageo[ .5] = 2/3;\), "\[IndentingNewLine]", 
    \(ageo[0] = 1; geo[ .0] = 1;\)}], "Input"],

Cell[BoxData[
    \(\(label = {PointSize[ .03], Point[{ .5, ageo[ .5]}], 
          Text[\ StyleForm["\<k=0, Flat\>", FontFamily -> "\<Times-Bold\>", 
              FontSize \[Rule] 10\ ], { .9,  .67}], 
          Text[\ StyleForm["\<k=1, Closed\>", FontFamily -> "\<Times-Bold\>", 
              FontSize \[Rule] 10\ ], {1.4,  .58}], 
          Text[\ StyleForm["\<k=-1, Open\>", FontFamily -> "\<Times-Bold\>", 
              FontSize \[Rule] 10\ ], { .5,  .82}]};\)\)], "Input"],

Cell[BoxData[
    \(\(\(\ \)\(ageplot[Ho_] := 
        Plot[ageo[qo], {qo,  .00001, 2}, Frame \[Rule] True, 
          PlotLabel \[Rule] "\<Age for \[CapitalGamma]=0\>", 
          FrameLabel \[Rule] {"\<10^-29 gm/cc\>", "\<  \>", \
"\<\[CurlyRho]o\>", "\< \>"}, 
          FrameTicks \[Rule] \((1/10 
                   Round[\ 
                    10\ {{0, {1/2,  .000196\ Ho^2}, {1, 
                            2* .000196\ Ho^2}, {1.5, 
                            3* .000196\ Ho^2}}, {{ .5,  .5*9.78*\((100/
                                  Ho)\)}, { .6,  .6*9.78*\((100/
                                  Ho)\)}, { .7,  .7*9.78*\((100/
                                  Ho)\)}, { .8,  .8*9.78*\((100/
                                  Ho)\)}, { .9,  .9*9.78*\((100/Ho)\)}, {1, 
                            1*9.78*\((100/Ho)\)}}}\ \ ] // N)\), 
          GridLines \[Rule] Automatic, Epilog \[Rule] label];\)\)\)], "Input"],

Cell[BoxData[
    \(\(ageplot[70];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection"],

Cell[BoxData[
    \(\(\(ageL[
        q1_, \[Sigma]1_]\)\(:=\)\(NIntegrate[\(\(\(\(\(1/\(X'\)[t] /. eq3\) /. 
                  Ho \[Rule] 1\) /. \[CapitalGamma] \[Rule] \[Sigma]1 - q1\) /. 
              qo \[Rule] q1\) /. \[Sigma] \[Rule] \[Sigma]1\) /. 
          X[t] \[Rule] x, {x, 0, 1}]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(\(agetable[Ho_] := 
        1/100  Round[
              100  Table[\ 
                  9.78*\((100/Ho)\)\ ageL[q, sigma]\ , {q, 0, 
                    2,  .5}, {sigma, 0, 2.5,  .5}]] // N;\)\)], "Input"],

Cell[BoxData[
    \(TableForm[agetable[70], TableSpacing \[Rule] {1}, 
      TableHeadings \[Rule] {{"\<qo=0\>", "\<qo=.5\>", "\<qo=1\>", \
"\<qo=1.5\>", "\<qo=2\>"}, {"\<\[Sigma]o=0\>", "\<.5\>", "\<1\>", "\<1.5\>", \
"\<2\>", "\<2.5\>"}}]\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Problem  3: The Expansion and Age for the ",
  "Friedmann",
  "-Robertson-Walker models    ",
  StyleBox[" ",
    FontColor->RGBColor[0, 0, 1]]
}], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Remarks and outline", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Clear["\<Global`*\>"];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{"eq1", "=", 
        FormBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{
                SuperscriptBox["R", "\[Prime]",
                  MultilineFunction->None], "(", "t", ")"}], "2"], 
            "==", \(\(Ho\^2\ Ro\^3\)\/\(R(t)\)\)}],
          "TraditionalForm"]}], ";"}]], "Input"],

Cell[BoxData[
    \(eq2 = 
      t \[Equal] Integrate[Sqrt[1/eq1[\([2]\)]], R[t]] // 
        PowerExpand\)], "Input"],

Cell[BoxData[
    \(eq2[\([2]\)] /. R[t] \[Rule] Ro\)], "Input"],

Cell[BoxData[
    \(scale0 = \(Solve[eq2, R[t]]\)[\([2, 1]\)] /. 
        Rule \[Rule] Equal\)], "Input"],

Cell[BoxData[
    \(\(Plot[
        Evaluate[scale0[\([2]\)] /. {Ho \[Rule] 1, Ro \[Rule] 1}], {t, 0, 1}, 
        Frame \[Rule] True, 
        FrameTicks \[Rule] {{{0, "\<0\>"}, {1/3, "\<1/(3Ho)\>"}, {2/
                  3, "\<Now \>"}, {1, "\<1/Ho\>"}}, {0, {1/
                  2, "\< Ro/2 \>"}, {1, "\<Ro\>"}}}, 
        Epilog \[Rule] \(Graphics[{PointSize[ .03], 
                Point[{2/3, 1}]}]\)[\([1]\)]];\)\)], "Input"],

Cell[BoxData[
    \(\(Plot[
        Evaluate[scale0[\([2]\)] /. {Ho \[Rule] 1, Ro \[Rule] 1}], {t, 0, 1}, 
        Frame \[Rule] True, PlotLabel \[Rule] scale0, 
        FrameTicks \[Rule] {{{0, "\<0\>"}, {1/3, "\<1/(3Ho)\>"}, {2/
                  3, "\<Now \>"}, {1, "\<1/Ho\>"}}, {0, {1/
                  2, "\< Ro/2 \>"}, {1, "\<Ro\>"}}}, 
        Epilog \[Rule] \(Graphics[{PointSize[ .03], 
                Point[{2/3, 1}]}]\)[\([1]\)]];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection"],

Cell[BoxData[
    \(\(eq3 = \(R'\)[t]^2 \[Equal] \(-1\) + 
            2\ qo\ Ho^2\ Ro^3/\((R[t])\);\)\)], "Input"],

Cell[BoxData[
    \(\(Rorule = Ro \[Rule] 1/Ho\ Sqrt[1/\((2\ qo - 1)\)];\)\)], "Input"],

Cell[BoxData[
    \(eq4 = eq3 /. Rorule // PowerExpand\)], "Input"],

Cell[BoxData[
    \(\(change = 
        R \[Rule] \((\((2\ qo/\((Ho \((2  qo - 1)\)^\((3/2)\))\) 
                  Sin[x[#]]^2)\) &)\);\)\)], "Input"],

Cell[BoxData[
    \(scale1 = \(R[x] /. change\) /. x[x] \[Rule] x // PowerExpand\)], "Input"],

Cell[BoxData[
    \(eq5 = \(\(Solve[eq4 /. change, \(x'\)[t]]\)[\([2]\)] // Simplify\) // 
        PowerExpand\)], "Input"],

Cell[BoxData[
    \(\(\(time1\)\(=\)\(Integrate[\((1/\(x'\)[t] /. eq5)\), {x[t], 0, 
          x}]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(xage = \(\(Solve[Ro \[Equal] scale1, x]\)[\([2]\)] /. Rorule // 
          ExpandAll\) // PowerExpand\)], "Input"],

Cell[BoxData[
    \(age1 = \(time1 /. xage // ExpandAll\) // Simplify\)], "Input"],

Cell[BoxData[
    \(\(value = {qo \[Rule] 1, Ho \[Rule] 1};\)\)], "Input"],

Cell[BoxData[
    \(\(\(label = {PointSize[ .03], \ 
          Text[\ StyleForm[
              1/100\ \ Round[100 \((\(time1 /. xage\) /. value\ \ )\)\ ] // 
                N\ \ , FontFamily -> "\<Times-Bold\>", 
              FontSize \[Rule] 10\ ], {2.6, 1}], \[IndentingNewLine]\ 
          Text[\ StyleForm["\<age/Ho =\>"\ \ , 
              FontFamily -> "\<Times-Bold\>", FontSize \[Rule] 10\ ], {1.4, 
              1}], \[IndentingNewLine]Point[{\(time1 /. x \[Rule] \[Pi]/2\) /. 
                value, \(scale1 /. x \[Rule] \[Pi]/2\) /. value}], 
          Point[{\(time1 /. xage\) /. value, \(scale1 /. xage\) /. 
                value}]};\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(\(ParametricPlot[Evaluate[{time1, scale1} /. value], {x, 0, \[Pi]}, 
        Frame \[Rule] True, PlotLabel \[Rule] "\<Closed Model, qo=1 \>", 
        FrameTicks \[Rule] {{{0, "\<0\>"}, {age1 /. value // 
                  N, "\<age\>"}, {3\ age1 /. value // 
                  N, "\<3* age\>"}, {\(time1 /. value\) /. 
                  x \[Rule] \[Pi]/2, "\<Max\>"}, {9\ age1 /. value // 
                  N, "\<9* age\>"}}, {0, 1/2, {1, "\<Ro\>"}, 1.5, 2}}, 
        Epilog \[Rule] label];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection"],

Cell[" eq6=R'[t]^2 == 1+ 2 qo Ho^2 Ro^3/(R[t]); ", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Rorule = Ro \[Rule] 1/Ho\ Sqrt[1/\((1 - 2\ qo)\)];\)\)], "Input"],

Cell[BoxData[
    \(eq7 = eq6 /. Rorule // PowerExpand\)], "Input"],

Cell[BoxData[
    \(\(change = 
        R \[Rule] \((\((2\ qo/\((Ho \((1 - 2\ qo)\)^\((3/2)\))\) 
                  Sinh[x[#]]^2)\) &)\);\)\)], "Input"],

Cell[BoxData[
    \(scale2 = \(R[x] /. change\) /. x[x] \[Rule] x // PowerExpand\)], "Input"],

Cell[BoxData[
    \(eq8 = \(\(Solve[eq7 /. change, \(x'\)[t]]\)[\([2]\)] // Simplify\) // 
        PowerExpand\)], "Input"],

Cell[BoxData[
    \(time2 = Integrate[\((1/\(x'\)[t] /. eq8)\), {x[t], 0, x}]\)], "Input"],

Cell[BoxData[
    \(xage = \(\(Solve[Ro \[Equal] scale2, x]\)[\([2]\)] /. Rorule // 
          PowerExpand\) // Simplify\)], "Input"],

Cell[BoxData[
    \(age2 = time2 /. xage\)], "Input"],

Cell[BoxData[
    \(\(value = {qo \[Rule]  .02, Ho \[Rule] 1};\)\)], "Input"],

Cell[BoxData[
    \(\(label = {PointSize[ .03], \[IndentingNewLine]\ 
          Text[\ StyleForm["\<age/Ho = \>"\ \ , 
              FontFamily -> "\<Times-Bold\>", 
              FontSize \[Rule] 10\ ], {\(1.5\ time2 /. xage\) /. 
                value, \(scale2 /. xage\) /. value}], \[IndentingNewLine]\ 
          Text[\ StyleForm[
              1/100\ \ Round[100 \((\(time2 /. xage\) /. value\ \ )\)\ ] // 
                N\ \ , FontFamily -> "\<Times-Bold\>", 
              FontSize \[Rule] 10\ ], {\(1.9\ time2 /. xage\) /. 
                value, \(scale2 /. xage\) /. value}], 
          Point[{\(time2 /. xage\) /. value, \(scale2 /. xage\) /. 
                value}]};\)\)], "Input"],

Cell[BoxData[
    \(\(ParametricPlot[Evaluate[{time2, scale2} /. value], {x, 0, 3}, 
        Frame \[Rule] True, PlotLabel \[Rule] "\<Open Model, qo=.02\>", 
        FrameTicks \[Rule] {{{0, "\< 0\>"}, { .5\ age1 /. value // 
                  N, "\<age/2\>"}, {age1 /. value // 
                  N, "\<age\>"}, {2  age1 /. value // 
                  N, "\<2age\>"}, {3/2\ age1 /. value // 
                  N, "\<3/2 age\>"}}, {0, 1/2, {1, "\<Ro\>"}, 1.5, 2}}, 
        Epilog \[Rule] label];\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["10.5 Exercises ", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Exercise 1 Lorentz boosts ", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Exercise 2 Radioactive decay of moving Nucleus ", "Subsubsection"],

Cell["Exercise 3 Schwarzschild solution  ", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Exercise 4 Potential analysis for timelike geodesics  ", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Exercise 5 Schwarzschild solution in null coordinates    ", \
"Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Exercise 6 Null geodesics for the Schwarzschild metric", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Exercise 7 Mercury's Anomalous Precession and Modification of \
Newton's Gravity \
\>", "Subsubsection"],

Cell["Exercise 8 Cosmological Force and Mercury ", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]]
},
FrontEndVersion->"4.1 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
WindowToolbars->"EditBar",
CellGrouping->Manual,
WindowSize->{898, 893},
WindowMargins->{{24, Automatic}, {Automatic, 40}},
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"PaperSize"->{612, 792},
"PaperOrientation"->"Portrait",
"PostScriptOutputFile":>FrontEnd`FileName[{$RootDirectory, "home", "olness", \
"zim", "2002", "ch10"}, "ch10.nb.ps", CharacterEncoding -> "ISO8859-1"],
"Magnification"->1},
Magnification->1
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 116, 2, 42, "Subsubsection"],
Cell[1846, 56, 1886, 33, 657, "Input",
  Evaluatable->False]
}, Closed]],
Cell[3747, 92, 528, 10, 102, "SmallText"],
Cell[4278, 104, 93, 2, 114, "Title",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[4396, 110, 88, 2, 60, "Section",
  Evaluatable->False],
Cell[4487, 114, 96, 4, 42, "Input"]
}, Closed]],
Cell[4598, 121, 158, 6, 40, "Section",
  Evaluatable->False],
Cell[4759, 129, 102, 2, 45, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[4886, 135, 103, 2, 45, "Subsection",
  Evaluatable->False],
Cell[4992, 139, 92, 2, 42, "Subsubsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[5109, 145, 81, 2, 28, "Subsubsection",
  Evaluatable->False],
Cell[5193, 149, 59, 1, 27, "Input"],
Cell[5255, 152, 280, 5, 75, "Input"],
Cell[5538, 159, 82, 1, 27, "Input"],
Cell[5623, 162, 116, 2, 27, "Input"],
Cell[5742, 166, 358, 9, 62, "Input"],
Cell[6103, 177, 93, 1, 24, "Input"],
Cell[6199, 180, 92, 1, 24, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[6340, 187, 106, 2, 29, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[6471, 193, 81, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[6555, 197, 59, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[6651, 203, 31, 0, 42, "Subsubsection"],
Cell[6685, 205, 120, 2, 43, "Input"],
Cell[6808, 209, 48, 1, 27, "Input"],
Cell[6859, 212, 134, 2, 40, "Input"],
Cell[6996, 216, 51, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[7084, 222, 31, 0, 42, "Subsubsection"],
Cell[7118, 224, 116, 2, 27, "Input"],
Cell[7237, 228, 87, 1, 27, "Input"],
Cell[7327, 231, 72, 1, 24, "Input"],
Cell[7402, 234, 253, 6, 37, "Input"],
Cell[7658, 242, 124, 2, 24, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[7831, 250, 101, 2, 29, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[7957, 256, 81, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[8041, 260, 59, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[8137, 266, 31, 0, 42, "Subsubsection"],
Cell[8171, 268, 271, 7, 61, "Input"],
Cell[8445, 277, 346, 9, 61, "Input"],
Cell[8794, 288, 116, 2, 27, "Input"],
Cell[8913, 292, 157, 2, 31, "Input"],
Cell[9073, 296, 141, 2, 24, "Input"],
Cell[9217, 300, 122, 2, 24, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[9376, 307, 31, 0, 42, "Subsubsection"],
Cell[9410, 309, 142, 3, 43, "Input"],
Cell[9555, 314, 129, 2, 24, "Input"],
Cell[9687, 318, 256, 4, 24, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[9980, 327, 31, 0, 42, "Subsubsection"],
Cell[10014, 329, 56, 1, 27, "Input"],
Cell[10073, 332, 148, 4, 24, "Input"],
Cell[10224, 338, 101, 2, 24, "Input"],
Cell[10328, 342, 301, 6, 24, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[10678, 354, 125, 2, 29, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[10828, 360, 81, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[10912, 364, 59, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[11008, 370, 31, 0, 42, "Subsubsection"],
Cell[11042, 372, 146, 2, 27, "Input"],
Cell[11191, 376, 148, 2, 27, "Input"],
Cell[11342, 380, 409, 10, 81, "Input"],
Cell[11754, 392, 128, 2, 27, "Input"],
Cell[11885, 396, 108, 2, 24, "Input"],
Cell[11996, 400, 211, 3, 24, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[12244, 408, 31, 0, 42, "Subsubsection"],
Cell[12278, 410, 489, 9, 59, "Input"],
Cell[12770, 421, 129, 2, 24, "Input"],
Cell[12902, 425, 319, 9, 41, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[13270, 440, 170, 5, 29, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[13465, 449, 81, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[13549, 453, 63, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[13649, 459, 31, 0, 42, "Subsubsection"],
Cell[13683, 461, 526, 14, 49, "Input"],
Cell[14212, 477, 209, 3, 24, "Input"],
Cell[14424, 482, 221, 3, 24, "Input"],
Cell[14648, 487, 59, 1, 24, "Input"],
Cell[14710, 490, 152, 2, 24, "Input"],
Cell[14865, 494, 218, 5, 43, "Input"],
Cell[15086, 501, 216, 3, 27, "Input"],
Cell[15305, 506, 53, 1, 24, "Input"],
Cell[15361, 509, 90, 1, 24, "Input"],
Cell[15454, 512, 455, 11, 47, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[15946, 528, 31, 0, 42, "Subsubsection"],
Cell[15980, 530, 354, 9, 49, "Input"],
Cell[16337, 541, 333, 6, 43, "Input"],
Cell[16673, 549, 440, 8, 91, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[17162, 563, 170, 5, 29, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[17357, 572, 81, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[17441, 576, 59, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[17537, 582, 31, 0, 42, "Subsubsection"],
Cell[17571, 584, 70, 1, 27, "Input"],
Cell[17644, 587, 124, 2, 27, "Input"],
Cell[17771, 591, 115, 2, 24, "Input"],
Cell[17889, 595, 122, 2, 27, "Input"],
Cell[18014, 599, 173, 3, 28, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[18224, 607, 31, 0, 42, "Subsubsection"],
Cell[18258, 609, 206, 3, 27, "Input"],
Cell[18467, 614, 110, 2, 24, "Input"],
Cell[18580, 618, 218, 5, 59, "Input"],
Cell[18801, 625, 117, 2, 24, "Input"],
Cell[18921, 629, 337, 5, 59, "Input"],
Cell[19261, 636, 66, 1, 24, "Input"],
Cell[19330, 639, 194, 3, 27, "Input"],
Cell[19527, 644, 327, 5, 56, "Input"],
Cell[19857, 651, 331, 5, 56, "Input"]
}, Closed]]
}, Closed]],
Cell[20215, 660, 163, 6, 40, "Section",
  Evaluatable->False],
Cell[20381, 668, 52, 0, 45, "Subsection"],

Cell[CellGroupData[{
Cell[20458, 672, 123, 2, 45, "Subsection",
  Evaluatable->False],
Cell[20584, 676, 59, 1, 27, "Input"],
Cell[20646, 679, 336, 8, 48, "Input"],

Cell[CellGroupData[{
Cell[21007, 691, 92, 2, 28, "Subsubsection",
  Evaluatable->False],
Cell[21102, 695, 674, 12, 139, "Input"],
Cell[21779, 709, 587, 10, 107, "Input"]
}, Closed]],
Cell[22381, 722, 81, 2, 42, "Subsubsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[22487, 728, 31, 0, 42, "Subsubsection"],
Cell[22521, 730, 352, 7, 75, "Input"],
Cell[22876, 739, 80, 1, 27, "Input"],
Cell[22959, 742, 48, 1, 24, "Input"],
Cell[23010, 745, 134, 2, 24, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[23181, 752, 31, 0, 42, "Subsubsection"],
Cell[23215, 754, 118, 2, 27, "Input"],
Cell[23336, 758, 427, 7, 123, "Input"],
Cell[23766, 767, 129, 2, 24, "Input"],
Cell[23898, 771, 150, 2, 24, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[24097, 779, 105, 2, 29, "Subsection",
  Evaluatable->False],
Cell[24205, 783, 59, 1, 27, "Input"],
Cell[24267, 786, 307, 8, 31, "Input"],

Cell[CellGroupData[{
Cell[24599, 798, 92, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[24694, 802, 539, 9, 107, "Input"],
Cell[25236, 813, 572, 12, 107, "Input"],
Cell[25811, 827, 715, 15, 107, "Input"]
}, Closed]],
Cell[26541, 845, 33, 0, 42, "Subsubsection"],

Cell[CellGroupData[{
Cell[26599, 849, 31, 0, 42, "Subsubsection"],
Cell[26633, 851, 145, 2, 27, "Input"],
Cell[26781, 855, 124, 3, 24, "Input"],
Cell[26908, 860, 76, 1, 27, "Input"],
Cell[26987, 863, 384, 7, 59, "Input"],
Cell[27374, 872, 270, 5, 56, "Input"],
Cell[27647, 879, 76, 0, 24, "Input"],
Cell[27726, 881, 392, 10, 43, "Input"],
Cell[28121, 893, 158, 2, 40, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[28316, 900, 31, 0, 42, "Subsubsection"],
Cell[28350, 902, 510, 8, 129, "Input"],
Cell[28863, 912, 275, 4, 45, "Input"],
Cell[29141, 918, 151, 2, 46, "Input"],
Cell[29295, 922, 183, 4, 44, "Input"],
Cell[29481, 928, 92, 1, 27, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[29622, 935, 122, 2, 29, "Subsection",
  Evaluatable->False],
Cell[29747, 939, 59, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[29831, 944, 92, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[29926, 948, 632, 12, 107, "Input"]
}, Closed]],
Cell[30573, 963, 81, 2, 42, "Subsubsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[30679, 969, 31, 0, 42, "Subsubsection"],
Cell[30713, 971, 232, 5, 31, "Input"],
Cell[30948, 978, 230, 5, 56, "Input"],
Cell[31181, 985, 137, 3, 27, "Input"],
Cell[31321, 990, 410, 7, 59, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[31768, 1002, 31, 0, 42, "Subsubsection"],
Cell[31802, 1004, 145, 2, 27, "Input"],
Cell[31950, 1008, 337, 8, 41, "Input"],
Cell[32290, 1018, 347, 8, 28, "Input"],
Cell[32640, 1028, 92, 1, 24, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[32769, 1034, 31, 0, 42, "Subsubsection"],
Cell[32803, 1036, 85, 1, 27, "Input"],
Cell[32891, 1039, 194, 3, 40, "Input"],
Cell[33088, 1044, 83, 1, 27, "Input"],
Cell[33174, 1047, 83, 1, 24, "Input"],
Cell[33260, 1050, 102, 2, 26, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[33411, 1058, 125, 2, 29, "Subsection",
  Evaluatable->False],
Cell[33539, 1062, 81, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[33623, 1066, 59, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[33707, 1071, 31, 0, 42, "Subsubsection"],
Cell[33741, 1073, 426, 11, 48, "Input"],
Cell[34170, 1086, 293, 6, 31, "Input"],
Cell[34466, 1094, 51, 1, 27, "Input"],
Cell[34520, 1097, 109, 2, 27, "Input"],
Cell[34632, 1101, 141, 2, 27, "Input"],
Cell[34776, 1105, 230, 5, 31, "Input"],
Cell[35009, 1112, 232, 4, 66, "Input"],
Cell[35244, 1118, 218, 5, 42, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[35499, 1128, 31, 0, 42, "Subsubsection"],
Cell[35533, 1130, 205, 5, 54, "Input"],
Cell[35741, 1137, 1009, 23, 45, "Input"],
Cell[36753, 1162, 920, 25, 60, "Input"],
Cell[37676, 1189, 513, 13, 27, "Input"],
Cell[38192, 1204, 138, 2, 47, "Input"],
Cell[38333, 1208, 655, 15, 53, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[39025, 1228, 31, 0, 42, "Subsubsection"],
Cell[39059, 1230, 73, 1, 27, "Input"],
Cell[39135, 1233, 319, 7, 59, "Input"],
Cell[39457, 1242, 726, 12, 155, "Input"],
Cell[40186, 1256, 241, 5, 59, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[40476, 1267, 141, 5, 29, "Subsection",
  Evaluatable->False],
Cell[40620, 1274, 59, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[40704, 1279, 81, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[40788, 1283, 345, 9, 54, "Input"],
Cell[41136, 1294, 382, 10, 42, "Input"],
Cell[41521, 1306, 859, 20, 45, "Input"],
Cell[42383, 1328, 474, 12, 45, "Input"],
Cell[42860, 1342, 326, 8, 46, "Input"],
Cell[43189, 1352, 55, 1, 24, "Input"],
Cell[43247, 1355, 197, 3, 24, "Input"],
Cell[43447, 1360, 149, 2, 24, "Input"],
Cell[43599, 1364, 199, 3, 24, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[43847, 1373, 62, 0, 29, "Subsection"],
Cell[43912, 1375, 59, 1, 27, "Input"],
Cell[43974, 1378, 33, 0, 42, "Subsubsection"],

Cell[CellGroupData[{
Cell[44032, 1382, 31, 0, 42, "Subsubsection"],
Cell[44066, 1384, 426, 11, 48, "Input"],
Cell[44495, 1397, 668, 17, 45, "Input"],
Cell[45166, 1416, 52, 1, 27, "Input"],
Cell[45221, 1419, 72, 1, 24, "Input"],
Cell[45296, 1422, 183, 3, 24, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[45516, 1430, 33, 0, 42, "Subsubsection"],
Cell[45552, 1432, 73, 1, 27, "Input"],
Cell[45628, 1435, 88, 1, 27, "Input"],
Cell[45719, 1438, 109, 2, 24, "Input"],
Cell[45831, 1442, 127, 2, 24, "Input"],
Cell[45961, 1446, 207, 3, 28, "Input"],
Cell[46171, 1451, 174, 4, 28, "Input"],
Cell[46348, 1457, 160, 2, 27, "Input"],
Cell[46511, 1461, 84, 1, 24, "Input"],
Cell[46598, 1464, 167, 4, 43, "Input"],
Cell[46768, 1470, 115, 2, 27, "Input"],
Cell[46886, 1474, 88, 1, 24, "Input"],
Cell[46977, 1477, 189, 4, 42, "Input"],
Cell[47169, 1483, 183, 4, 43, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[47389, 1492, 34, 0, 42, "Subsubsection"],
Cell[47426, 1494, 414, 9, 49, "Input"],
Cell[47843, 1505, 162, 3, 31, "Input"],
Cell[48008, 1510, 83, 1, 27, "Input"],
Cell[48094, 1513, 76, 1, 44, "Input"],
Cell[48173, 1516, 160, 2, 27, "Input"],
Cell[48336, 1520, 108, 2, 28, "Input"],
Cell[48447, 1524, 73, 1, 44, "Input"],
Cell[48523, 1527, 152, 2, 27, "Input"],
Cell[48678, 1531, 112, 2, 28, "Input"],
Cell[48793, 1535, 128, 2, 27, "Input"]
}, Closed]]
}, Closed]],
Cell[48948, 1541, 153, 6, 40, "Section",
  Evaluatable->False],
Cell[49104, 1549, 126, 2, 45, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[49255, 1555, 151, 5, 45, "Subsection",
  Evaluatable->False],
Cell[49409, 1562, 59, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[49493, 1567, 92, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[49588, 1571, 553, 9, 107, "Input"],
Cell[50144, 1582, 707, 12, 123, "Input"],
Cell[50854, 1596, 732, 15, 91, "Input"]
}, Closed]],
Cell[51601, 1614, 82, 2, 42, "Subsubsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[51708, 1620, 31, 0, 42, "Subsubsection"],
Cell[51742, 1622, 335, 8, 46, "Input"],
Cell[52080, 1632, 75, 1, 27, "Input"],
Cell[52158, 1635, 126, 2, 27, "Input"],
Cell[52287, 1639, 109, 2, 27, "Input"],
Cell[52399, 1643, 258, 5, 40, "Input"],
Cell[52660, 1650, 195, 4, 27, "Input"],
Cell[52858, 1656, 263, 5, 27, "Input"],
Cell[53124, 1663, 255, 4, 24, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[53416, 1672, 31, 0, 42, "Subsubsection"],
Cell[53450, 1674, 194, 4, 27, "Input"],
Cell[53647, 1680, 302, 6, 72, "Input"],
Cell[53952, 1688, 143, 3, 27, "Input"],
Cell[54098, 1693, 120, 2, 27, "Input"],
Cell[54221, 1697, 62, 1, 24, "Input"],
Cell[54286, 1700, 82, 1, 24, "Input"],
Cell[54371, 1703, 218, 3, 27, "Input"],
Cell[54592, 1708, 123, 2, 24, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[54752, 1715, 31, 0, 42, "Subsubsection"],
Cell[54786, 1717, 146, 4, 42, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[54981, 1727, 194, 6, 29, "Subsection",
  Evaluatable->False],
Cell[55178, 1735, 92, 2, 42, "Subsubsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[55295, 1741, 81, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[55379, 1745, 59, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[55475, 1751, 31, 0, 42, "Subsubsection"],
Cell[55509, 1753, 831, 22, 89, "Input"],
Cell[56343, 1777, 781, 18, 46, "Input"],
Cell[57127, 1797, 146, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[57310, 1804, 31, 0, 42, "Subsubsection"],
Cell[57344, 1806, 114, 2, 27, "Input"],
Cell[57461, 1810, 120, 2, 27, "Input"],
Cell[57584, 1814, 214, 4, 27, "Input"],
Cell[57801, 1820, 185, 3, 27, "Input"],
Cell[57989, 1825, 143, 3, 27, "Input"],
Cell[58135, 1830, 91, 1, 27, "Input"],
Cell[58229, 1833, 44, 1, 27, "Input"],
Cell[58276, 1836, 232, 4, 59, "Input"],
Cell[58511, 1842, 481, 7, 59, "Input"],
Cell[58995, 1851, 929, 16, 107, "Input"],
Cell[59927, 1869, 49, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[60013, 1875, 31, 0, 42, "Subsubsection"],
Cell[60047, 1877, 316, 5, 27, "Input"],
Cell[60366, 1884, 225, 5, 27, "Input"],
Cell[60594, 1891, 253, 4, 43, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[60896, 1901, 228, 8, 29, "Subsection",
  Evaluatable->False],
Cell[61127, 1911, 92, 2, 42, "Subsubsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[61244, 1917, 81, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[61328, 1921, 59, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[61424, 1927, 31, 0, 42, "Subsubsection"],
Cell[61458, 1929, 357, 10, 48, "Input"],
Cell[61818, 1941, 118, 3, 27, "Input"],
Cell[61939, 1946, 64, 1, 27, "Input"],
Cell[62006, 1949, 105, 2, 27, "Input"],
Cell[62114, 1953, 433, 8, 59, "Input"],
Cell[62550, 1963, 459, 8, 59, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[63046, 1976, 31, 0, 42, "Subsubsection"],
Cell[63080, 1978, 115, 2, 27, "Input"],
Cell[63198, 1982, 87, 1, 27, "Input"],
Cell[63288, 1985, 67, 1, 27, "Input"],
Cell[63358, 1988, 151, 3, 27, "Input"],
Cell[63512, 1993, 93, 1, 27, "Input"],
Cell[63608, 1996, 123, 2, 27, "Input"],
Cell[63734, 2000, 121, 2, 27, "Input"],
Cell[63858, 2004, 134, 2, 27, "Input"],
Cell[63995, 2008, 82, 1, 27, "Input"],
Cell[64080, 2011, 74, 1, 27, "Input"],
Cell[64157, 2014, 674, 11, 75, "Input"],
Cell[64834, 2027, 528, 8, 59, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[65399, 2040, 31, 0, 42, "Subsubsection"],
Cell[65433, 2042, 85, 1, 27, "Input"],
Cell[65521, 2045, 87, 1, 27, "Input"],
Cell[65611, 2048, 67, 1, 27, "Input"],
Cell[65681, 2051, 152, 3, 27, "Input"],
Cell[65836, 2056, 93, 1, 27, "Input"],
Cell[65932, 2059, 123, 2, 27, "Input"],
Cell[66058, 2063, 90, 1, 27, "Input"],
Cell[66151, 2066, 133, 2, 27, "Input"],
Cell[66287, 2070, 53, 1, 27, "Input"],
Cell[66343, 2073, 77, 1, 27, "Input"],
Cell[66423, 2076, 698, 12, 75, "Input"],
Cell[67124, 2090, 511, 8, 59, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[67684, 2104, 82, 2, 40, "Section",
  Evaluatable->False],
Cell[67769, 2108, 99, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[67871, 2112, 72, 0, 28, "Subsubsection"],
Cell[67946, 2114, 108, 2, 28, "Subsubsection",
  Evaluatable->False],
Cell[68057, 2118, 127, 2, 28, "Subsubsection",
  Evaluatable->False],
Cell[68187, 2122, 132, 3, 28, "Subsubsection",
  Evaluatable->False],
Cell[68322, 2127, 127, 2, 28, "Subsubsection",
  Evaluatable->False],
Cell[68452, 2131, 114, 3, 28, "Subsubsection"],
Cell[68569, 2136, 115, 2, 28, "Subsubsection",
  Evaluatable->False]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

