(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     70112,       2367]*)
(*NotebookOutlinePosition[     72658,       2430]*)
(*  CellTagsIndexPosition[     72557,       2423]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Legal Notice, Disclaimer, and Book Ordering Information:", \
"Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "(* Legal Notice, Disclaimer, and Book Ordering Information:\n\nLast \
Modified: FIO June 8, 2002\n\n",
  StyleBox["Mathematica For Physics: 2nd Edition",
    FontColor->RGBColor[1, 0, 0]],
  "\n\nRobert L. Zimmerman and Fredrick I. Olness\n",
  "\nWebSite:  \n",
  StyleBox["  www.physics.smu.edu/~olness\n  darkwing.uoregon.edu/~phys600/\n\
\n",
    FontColor->RGBColor[1, 0, 0]],
  "MathSource Number: 0206-862",
  StyleBox["\n",
    FontColor->RGBColor[1, 0, 0]],
  "\nISBN 0-201-53796-6\nFor ordering information, call 1-800-282-0693\n\
Addison-Wesley Publishing Company\n",
  "\nCommunication with the authors:\nFredrick I. Olness:  \
olness@mail.physics.smu.edu\nRobert L. Zimmerman: bob@zim.uoregon.edu\n\n\
Copyright 2002, Addison-Wesley Publishing Company, Inc. The material in\nthis \
file may be distributed freely  so long as the content remains\nunchanged, \
and the copyright and  reference notices are included. The\npublisher grants \
permission for the noncommercial use of these programs\nand program segments. \
 All other uses require the prior written consent\nof the publisher.    \n\n\
All rights are reserved with regard to the  material in the\n\"Mathematica \
For Physics\" text, and may not be reproduced, stored in a\nretrieval system, \
or transmitted,  in any form or by any means,\nelectronic, mechanical, \
photocopying,  recording, or otherwise, without\nthe prior written permission \
 of the publisher. \n\nThe programs and applications presented in this book \
have been included\nfor  their instructional value. They have been tested \
with care but are\nnot  guaranteed for any particular purpose. The publisher \
does not\noffer any  warranties or representations, nor does it accept any\n\
liabilities with  respect to the programs or applications. \n\n *)\n"
}], "Input",
  Evaluatable->False,
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell["2. GENERAL PHYSICS", "Title",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["2.1  Introduction  ", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Off[General::spell1];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Off[General::spell];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  "2.2 Newtonian Mechanics in Inertial Frames ",
  StyleBox[" ",
    FontColor->RGBColor[1, 0, 0]]
}], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Overview of Newtonian Mechanics in Inertial Frames", "Subsection"],

Cell[CellGroupData[{

Cell["Problem 1: Escape Velocity  ", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Remarks and Outline", "Subsubsection"],

Cell[CellGroupData[{

Cell[TextData["Solution"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Clear[\"Global`*\"];", "Input",
  AspectRatioFixed->True],

Cell["\<\
T= (1/2) m v^2;     
U= -G M m/r;
energy=T+U\
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(sol = \(Solve[energy \[Equal] 0, v]\)[\([2]\)]\)], "Input"],

Cell[" Needs[\"Miscellaneous`PhysicalConstants`\"];", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(?Miscellaneous`PhysicalConstants`*\ \ \ \ \ (*\ output\ suppressed\ \
*)\)\)], "Input",
  Evaluatable->False],

Cell[BoxData[
    \(\(values = {G \[Rule] 
            GravitationalConstant, \[IndentingNewLine]r \[Rule] 
            EarthRadius, \[IndentingNewLine]M \[Rule] 
            EarthMass, \[IndentingNewLine]Newton \[Rule] 
            Kilogram\ Meter/Second^2};\)\)], "Input"],

Cell[BoxData[
    \(v0 = \(v /. sol\) //. values\  // PowerExpand\)], "Input"],

Cell[BoxData[
    \(\(Needs["\<Miscellaneous`Units`\>"];\)\)], "Input"],

Cell[BoxData[
    \(\(?Convert\)\)], "Input"],

Cell["Convert[v0,Kilo Meter/Second]", "Input",
  AspectRatioFixed->True],

Cell["Convert[v0,Mile/Second]", "Input",
  AspectRatioFixed->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 2: Projectile in a Uniform Gravitional Field  ", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Remarks and Outline ", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Solution"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Clear[\"Global`*\"];", "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection"],

Cell["eq1 ={m x''[t]==0, m z''[t]==-m g };", "Input",
  AspectRatioFixed->True],

Cell["initial1={x[0]==0, x[t1]==x1,z[0]==0, z[t1]==z1};", "Input",
  AspectRatioFixed->True],

Cell["dsol1=DSolve[Join[eq1,initial1], {x[t],z[t]},t] //Flatten", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Map[Collect[#, t] &, dsol1, {2}]\)], "Input"],

Cell[BoxData[
    \(Map[collect[#, t] &, dsol1, {2}]\)], "Input"],

Cell[BoxData[
    \(\(values1 = {x1 \[Rule] 300, z1 \[Rule] 0, g \[Rule] 9.8};\)\)], "Input"],

Cell["coord1[t_,t1_]= {x[t],z[t]} /.dsol1 /.values1", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(points[t1_]\  := Table[coord1[t, t1], {t, 0, t1, 0.5}]\)], "Input"],

Cell[BoxData[
    \(plot1[t1_] := 
      ListPlot[\ 
        points[t1] // 
          Evaluate, \[IndentingNewLine]PlotStyle \[Rule] {Hue[0.8], 
            PointSize[0.02]}, \[IndentingNewLine]GridLines \[Rule] 
          Automatic, \[IndentingNewLine]DisplayFunction \[Rule] 
          Identity]\)], "Input"],

Cell[BoxData[
    \(\(Show[{plot1[5], plot1[10], 
          plot1[15]}, \[IndentingNewLine]Epilog -> {\[IndentingNewLine]Text["\
\<t1= 5\>", coord1[\ \ 5/2, \ \ 5], 
              TextStyle \[Rule] {FontWeight \[Rule] "\<Bold\>"}]\ , \
\[IndentingNewLine]Text["\<t1=10\>", coord1[10/2, 10], 
              TextStyle \[Rule] {FontWeight \[Rule] "\<Bold\>"}], \
\[IndentingNewLine]Text["\<t1=15\>", coord1[15/2, 15], 
              TextStyle \[Rule] {FontWeight \[Rule] "\<Bold\>"}]}\ , \
\[IndentingNewLine]DisplayFunction -> $DisplayFunction\ \ , \
\[IndentingNewLine]PlotRange \[Rule] All];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection"],

Cell["\<\
initial2={x[0]==0 ,x'[0]==v0 Cos[\[Theta]], z[0]==0, z'[0]==v0 Sin[\
\[Theta]]};\
\>", "Input",
  AspectRatioFixed->True],

Cell["dsol2=DSolve[Join[eq1,initial2],{x,z},t] //Flatten", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(eq2 = \ \ \(z'\)[t] \[Equal] 0 /. dsol2\)], "Input"],

Cell[BoxData[
    \(\(\(\ \)\(\(z'\)[t] \[Equal] 0 /. dsol1\)\)\)], "Input"],

Cell["tsol= Solve[eq2,t] //Flatten", "Input",
  AspectRatioFixed->True],

Cell["{x[t],z[t]} /.dsol2 /.tsol //Simplify", "Input",
  AspectRatioFixed->True],

Cell["values2 = {g->9.8, v0->100};", "Input",
  AspectRatioFixed->True],

Cell["\<\
coord2[t_,\[Theta]_]= {x[t],z[t]} /.dsol2 /.values2\
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(plot2[\[Theta]_] := 
      ListPlot[\ 
        Table[coord2[t, \[Theta]], {t, 0, 20, 1/2}] // 
          Evaluate, \[IndentingNewLine]PlotStyle \[Rule] {Hue[ .8], 
            PointSize[0.02]}, \[IndentingNewLine]GridLines \[Rule] 
          Automatic, \[IndentingNewLine]DisplayFunction \[Rule] 
          Identity]\)], "Input"],

Cell[BoxData[
    \(\(Show[\ \ \(plot2[#] &\)\  /@ \ {\[Pi]/8, \ 2\ \[Pi]/8, \ 
            3\ \[Pi]/
                8}, \[IndentingNewLine]Epilog -> \ {\[IndentingNewLine]Text["\
\<\[Theta]= \[Pi]/8\>", \ coord2[5, \ \ \ \[Pi]/8]\ , 
              TextStyle \[Rule] {FontWeight \[Rule] "\<Bold\>"}], 
            Text["\<\[Theta]=2\[Pi]/8\>", \ coord2[5, 2  \[Pi]/8]\ , 
              TextStyle \[Rule] {FontWeight \[Rule] "\<Bold\>"}], \
\[IndentingNewLine]Text["\<\[Theta]=3\[Pi]/8\>", \ coord2[5, 3  \[Pi]/8]\ , 
              TextStyle \[Rule] {FontWeight \[Rule] "\<Bold\>"}]}, 
        PlotRange \[Rule] {{0, 1000}, {0, 
              500}}, \[IndentingNewLine]DisplayFunction -> $DisplayFunction, \
\[IndentingNewLine]FrameLabel \[Rule] {"\<x[t]\>", "\<z[t]\>"}\
\[IndentingNewLine]];\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[BoxData[
    \(eq3 = \ coord2[t, \[Theta]] \[Equal] {xMax, 0}\  // Thread\)], "Input"],

Cell[BoxData[
    \(sol3 = \ Solve[eq3, {t, xMax}]\)], "Input"],

Cell[BoxData[
    \(xMax = xMax\  /. sol3\  // Last\)], "Input"],

Cell[BoxData[
    \(\[Theta]\/\[Pi]\  /. 
        Solve[\ D[xMax, \[Theta]] \[Equal] 0\ , \[Theta]]\  // 
      Rationalize\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 3: Reflecting Trajectories ", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection"],

Cell["Clear[\"Global`*\"];", "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\({xEq, yEq} = {x[t] == x0 + \ vx0\ t\  + \ 1\/2\ ax\ t\^2, 
          y[t] == y0 + \ vy0\ t\  + \ 
              1\/2\ ay\ t\^2};\)\), "\[IndentingNewLine]", 
    \(\(\(rules = {vy0\  \[Rule] \ 0, \ ax \[Rule] 0, \ 
          ay \[Rule] \(-g\)};\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \({xEq, yEq} = {xEq, yEq}\  /. rules\)}], "Input"],

Cell[BoxData[
    \(ySol = \ DSolve[yEq, y, t]\  // Flatten\)], "Input"],

Cell[BoxData[
    \(xSol = \ DSolve[xEq, x, t]\  // Flatten\)], "Input"],

Cell[BoxData[
    \(position[
        t_] := \(If[\ t < tWall, {\(+x[t]\), y[t]}, {\(-x[t]\), y[t]}] /. 
          ySol\)\  /. xSol\)], "Input"],

Cell[BoxData[
    \(tWall = \ 
      t\  /. \(Solve[x[t] \[Equal] 0\  /. xSol, t]\)[\([1]\)]\)], "Input"],

Cell[BoxData[
    \(values = {x0 \[Rule] \(-100\), g \[Rule] 9.8, \ 
        y0 \[Rule] 100}\)], "Input"],

Cell[BoxData[
    \(\(plot[v_] := 
        ParametricPlot[\(position[t]\  //. values\)\  /. {vx0 \[Rule] v}\  // 
            Evaluate, {t, 0, 5}, 
          DisplayFunction \[Rule] Identity];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[\ 
        Table[plot[v], {v, 5, 50, 
            5}], \[IndentingNewLine]DisplayFunction \[Rule] $DisplayFunction, \
\[IndentingNewLine]PlotRange \[Rule] {{\(-125\), 0}, {0, 
              100}}, \[IndentingNewLine]Epilog \[Rule] {Thickness[0.02], 
            Hue[1.0], 
            Line[{{0, 0}, {0, 100}}]}\[IndentingNewLine]];\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Problem 4: Falling Projectile with Linear Air Resistance Drag\
\>", \
"Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Remarks and Outline ", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Clear[\"Global`*\"];", "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection"],

Cell[BoxData[
    \(\(eq1 = \ {m\ \(z''\)[t] \[Equal] \(-m\)\ g - 
              b\ \(z'\)[t]};\)\)], "Input"],

Cell[BoxData[
    \(\(initial = {z[0] \[Equal] z0, \(z'\)[0] \[Equal] 0};\)\)], "Input"],

Cell[BoxData[
    \(z[t_] = \(\(z[t] /. DSolve[\ Join[eq1, initial], {z}, t]\  // 
          First\)\(//\)\(Simplify\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(v[t_] = \(z'\)[t]\  // Simplify\)], "Input"],

Cell[BoxData[
    \(vTerminal = 
      Limit[v[t]\  /. {t \[Rule] \[Tau]\ m/
                  b}, \[Tau] \[Rule] \[Infinity]]\)], "Input"],

Cell[BoxData[
    \({zff, \ vff} = Limit[{z[t], v[t]}, b \[Rule] 0]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection"],

Cell[BoxData[
    \(\(values = {g \[Rule] 9.8, m \[Rule] 1, z0 \[Rule] 0};\)\)], "Input"],

Cell[BoxData[
    \(pointZ[b_, t_] = {t, z[t]} /. values\)], "Input"],

Cell[BoxData[
    \(pointZ[0, t_] = {t, zff} /. values\)], "Input"],

Cell[BoxData[
    \(\(plotZ[b_, hue_] := 
        ParametricPlot[\ 
          pointZ[b, t]\ , {t, 0, 
            10}, \[IndentingNewLine]PlotStyle \[Rule] {Hue[hue], 
              Thickness[0.008]}, \[IndentingNewLine]DisplayFunction \[Rule] 
            Identity\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    \(\(part1 = 
        Show[\ Table[\ plotZ[b, b/2], {b, 0, 1, 1/2}], 
          DisplayFunction \[Rule] $DisplayFunction\[IndentingNewLine]];\)\)], \
"Input"],

Cell[BoxData[
    \(\(textZ = {\[IndentingNewLine]Text[
              FontForm["\<b=0  \>", {"\<Times-Bold\>", 12}], 
              pointZ[0, 7]\ ], \[IndentingNewLine]Text[
              FontForm["\<b=1/2\>", {"\<Times-Bold\>", 12}], 
              pointZ[0.5, 7]], \[IndentingNewLine]Text[
              FontForm["\<b=1  \>", {"\<Times-Bold\>", 12}], 
              pointZ[1, 7]]\[IndentingNewLine]}\  // Graphics;\)\)], "Input"],

Cell[BoxData[
    \(\(Show[{part1, textZ}, \[IndentingNewLine]Frame \[Rule] 
          True, \[IndentingNewLine]GridLines \[Rule] 
          Automatic, \[IndentingNewLine]FrameLabel \[Rule] {"\<time\>", \
"\<height\>", "\<Effect of Air Resistance\>", "\< \>"}, \
\[IndentingNewLine]RotateLabel \[Rule] 
          False, \[IndentingNewLine]DisplayFunction \[Rule] $DisplayFunction\
\[IndentingNewLine]];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection"],

Cell[BoxData[
    \(pointV[b_, t_] = {t, v[t]} /. values\)], "Input"],

Cell[BoxData[
    \(pointV[0, t_] = {t, vff} /. values\)], "Input"],

Cell[BoxData[
    \(\(plotV[b_, hue_] := 
        ParametricPlot[\ 
          pointV[b, t]\ , {t, 0, 
            10}, \[IndentingNewLine]PlotStyle \[Rule] {Hue[hue], 
              Thickness[0.008]}, \[IndentingNewLine]DisplayFunction \[Rule] 
            Identity\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    \(\(part2 = 
        Show[\ Table[\ plotV[b, b/2], {b, 0, 1, 1/2}], 
          DisplayFunction \[Rule] $DisplayFunction\[IndentingNewLine]];\)\)], \
"Input"],

Cell[BoxData[
    \(\(textV = {\[IndentingNewLine]Text[
              FontForm["\<b=0  \>", {"\<Times-Bold\>", 12}], 
              pointV[0, 7]\ ], \[IndentingNewLine]Text[
              FontForm["\<b=1/2\>", {"\<Times-Bold\>", 12}], 
              pointV[0.5, 7]], \[IndentingNewLine]Text[
              FontForm["\<b=1  \>", {"\<Times-Bold\>", 12}], 
              pointV[1, 7]]\[IndentingNewLine]}\  // Graphics;\)\)], "Input"],

Cell[BoxData[
    \(\(Show[{part2, textV}, \[IndentingNewLine]Frame \[Rule] 
          True, \[IndentingNewLine]GridLines \[Rule] 
          Automatic, \[IndentingNewLine]FrameLabel \[Rule] {"\<time\>", \
"\<speed\>", "\<Effect of Air Resistance\>", "\< \>"}, \
\[IndentingNewLine]RotateLabel \[Rule] 
          False, \[IndentingNewLine]DisplayFunction \[Rule] $DisplayFunction\
\[IndentingNewLine]];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part d", "Subsubsection"],

Cell["<<Statistics`NormalDistribution`", "Input",
  CellTags->"S6.9.1"],

Cell[BoxData[{
    \(\(\(gaussian := \ 
      Random[NormalDistribution[1, 0.1]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Table[gaussian, {i, 10}]\)}], "Input"],

Cell[BoxData[{
    \(\(\(data = \ \(Table[{t, z[t] gaussian}, {t, 0, 40, 1}]\  /. 
            values\)\  /. {b \[Rule] 1/2};\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(listplot = 
        ListPlot[data, PlotStyle \[Rule] {PointSize[0.03]}];\)\)}], "Input"],

Cell[BoxData[
    \(<< Statistics`NonlinearFit`\)], "Input"],

Cell[BoxData[
    \(\(?NonlinearFit\)\)], "Input",
  Evaluatable->False],

Cell[BoxData[
    \(fit = 
      NonlinearFit[data, 
        a1 + a2\ t\  + a3\ Exp[\(-a4\)\ t], {t}, {a1, a2, a3, 
          a4}\ ]\)], "Input"],

Cell[BoxData[
    \(\(fitPlot = \ 
        Plot[\({fit, z[t]} /. values\)\  /. {b \[Rule] 1/2}\  // 
            Evaluate, {t, 0, 40}, 
          PlotStyle \[Rule] {{RGBColor[0, 0, 1]}, {RGBColor[1, 0, 0], 
                Thickness[0.008]}}];\)\)], "Input"],

Cell[BoxData[
    \(\(Plot[\(fit/z[t] /. values\)\  /. {b \[Rule] 1/2}\  // Evaluate, {t, 
          0, 40}];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[listplot, 
        fitPlot, \[IndentingNewLine]GridLines \[Rule] 
          Automatic, \[IndentingNewLine]Frame \[Rule] 
          True, \[IndentingNewLine]FrameLabel \[Rule] {"\<time\>", \
"\<height\>", "\<Experimental Data\>", "\<\>"}, \
\[IndentingNewLine]RotateLabel \[Rule] 
          False\[IndentingNewLine]];\)\)], "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Problem 5: Falling Projectile with Quadratic Air Resistance \
Drag\
\>", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Remarks and Outline ", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Clear[\"Global`*\"];", "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection"],

Cell[BoxData[
    \(\(eq1[
          sign_] = \ {m\ \(z''\)[t] \[Equal] \(-m\)\ g - \ 
              sign\ b\ \(z'\)[t]\^2};\)\)], "Input"],

Cell[BoxData[
    \(dsolUp = \ \(DSolve[\ Join[eq1[\(+1\)], {\(z'\)[0] \[Equal] vz0}], {z}, 
            t]\  // First\)\ \  // Simplify\)], "Input"],

Cell[BoxData[
    RowBox[{"c2sol", "=", " ", 
      RowBox[{
        RowBox[{
          RowBox[{"Solve", "[", 
            RowBox[{\(z[0] \[Equal] z0\  /. dsolUp\), ",", 
              FormBox[
                RowBox[{" ", 
                  SubscriptBox[
                    TagBox["c",
                      C], "2"]}],
                "TraditionalForm"]}], "]"}], " ", "//", "First"}], "  ", "//",
         "Simplify"}]}]], "Input"],

Cell[BoxData[
    \(\(dsolUp = dsolUp\  /. c2sol;\)\)], "Input"],

Cell[BoxData[
    \({zUp, 
        vUp} = \ \(\({z[t], \(z'\)[t]}\  /. 
          dsolUp\)\(\ \ \)\(//\)\(FullSimplify\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \({zUp0, vUp0} = Limit[{zUp, vUp}, b \[Rule] 0]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection"],

Cell[BoxData[
    \(dsolDown = \ \(DSolve[\ 
            Join[eq1[\(-1\)], {\(z'\)[timeTop] \[Equal] 0}], {z}, t]\  // 
          First\)\ \  // Simplify\)], "Input"],

Cell[BoxData[
    RowBox[{"c2sol", "=", " ", 
      RowBox[{
        RowBox[{
          RowBox[{"Solve", "[", 
            RowBox[{\(z[timeTop] \[Equal] zMax\  /. dsolDown\), ",", 
              FormBox[
                RowBox[{" ", 
                  SubscriptBox[
                    TagBox["c",
                      C], "2"]}],
                "TraditionalForm"]}], "]"}], " ", "//", "First"}], "  ", "//",
         "Simplify"}]}]], "Input"],

Cell[BoxData[
    \(\(dsolDown = dsolDown\  /. c2sol;\)\)], "Input"],

Cell[BoxData[
    \({zDown, 
        vDown} = \ \(\({z[t], \(z'\)[t]}\  /. 
          dsolDown\)\(\ \)\(//\)\(FullSimplify\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \({zDown0, vDown0} = \ Limit[{zDown, vDown}, b \[Rule] 0]\)], "Input"]
}, Closed]],

Cell[BoxData[
    \(vTerminal = \ 
      Limit[\ vDown /. {t \[Rule] \(\@m\ \[Tau]\)\/\(\@b\ \@g\)}, \[Tau] \
\[Rule] \[Infinity]]\)], "Input"],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection"],

Cell[BoxData[
    \(\(values = {g \[Rule] 9.8, m \[Rule] 1, z0 \[Rule] 0, \ 
          b \[Rule] 0.1, \ vz0 \[Rule] \(+20\)};\)\)], "Input"],

Cell[BoxData[
    \(timeTop = 
      t\  /. \ Solve[vUp \[Equal] 0\  /. values, t]\  // First\)], "Input"],

Cell[BoxData[
    \(zMax = \(zUp /. values\)\  /. {t \[Rule] timeTop}\)], "Input"],

Cell[BoxData[{
    \(zFull[
        tIn_] := \(If[tIn < timeTop, \ zUp, zDown]\  /. 
          values\)\  /. {t \[Rule] tIn}\), "\[IndentingNewLine]", 
    \(vFull[
        tIn_] := \(If[tIn < timeTop, \ vUp, vDown]\  /. 
          values\)\  /. {t \[Rule] tIn}\)}], "Input"],

Cell[BoxData[{
    \(zFull0[
        tIn_] := \(zUp0 /. 
          values\)\  /. {t \[Rule] tIn}\), "\[IndentingNewLine]", 
    \(vFull0[tIn_] := \(vUp0 /. values\)\  /. {t \[Rule] tIn}\)}], "Input"],

Cell[BoxData[
    \(\(Plot[{zFull[t], zFull0[t]}\ , {t, 0, 
          7}, \[IndentingNewLine]PlotStyle \[Rule] {{Thickness[
                0.008]}, {}}];\)\)], "Input"],

Cell[BoxData[
    \(\(Plot[{vFull[t], vFull0[t]}\ , {t, 0, 
          7}, \[IndentingNewLine]PlotStyle \[Rule] {{Thickness[
                0.008]}, {}}];\)\)], "Input"],

Cell[BoxData[
    \({vFull[100], vTerminal\ } /. values\)], "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 6: Rocket with varying Mass   ", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Remarks and Outline ", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution       ", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Clear[\"Global`*\"];", "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection"],

Cell["\<\
p[t   ]=  m[t] v;
p[t+\[Delta]t]= (m[t]-\[Delta]m)(v+\[Delta]v) + (+\[Delta]m)(v-ve); \
\>", \
"Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(\[Delta]v = \(x''\)[t]\ \[Delta]t;\)\), "\[IndentingNewLine]", 
    \(\(\[Delta]m = \(-\(m'\)[t]\)\ \ \ \[Delta]t;\)\)}], "Input"],

Cell["\<\
\[Delta]p =(p[t+\[Delta]t] - p[t])//ExpandAll    \
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(eq1 = \(-m[t]\)\ g \[Equal] \[Delta]p/\[Delta]t\  // 
        ExpandAll\)], "Input"],

Cell[BoxData[
    \(eq1 = eq1 /. \ \(\(\[Delta]t\)\(\[Rule]\)\(0\)\(\ \)\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Part ",
  StyleBox["b",
    FontWeight->"Plain"]
}], "Subsubsection"],

Cell[BoxData[
    \(dsol1 = 
      DSolve[{\(m'\)[t] \[Equal] \(-\[CapitalDelta]m\), m[0] \[Equal] m0}, m, 
          t] // Flatten\)], "Input"],

Cell[BoxData[
    \(eq2 = eq1 /. dsol1 // Simplify\)], "Input"],

Cell[BoxData[
    \(eq3 = \((\(Solve[eq2, \(x''\)[t]] // First\)\  // 
            First)\) /. \(\(Rule\)\(\[Rule]\)\(Equal\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(position = \(x[t] /. 
            DSolve[{eq3, x[0] \[Equal] 0, \(x'\)[0] \[Equal] 0}, x, t] // 
          First\) // FullSimplify\)], "Input"],

Cell[BoxData[
    \(speed = \ D[position, t] // Simplify\)], "Input"],

Cell["\<\
height= Limit[position,t->m0/\[CapitalDelta]m]    \
\>", "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Part ",
  StyleBox["c",
    FontWeight->"Plain"]
}], "Subsubsection"],

Cell[BoxData[
    \(\(values = {m0 \[Rule] 100, \[CapitalDelta]m \[Rule] 10, 
          g \[Rule] 9.8};\)\)], "Input"],

Cell[BoxData[
    \(tf = \((m0/\[CapitalDelta]m)\) /. values\)], "Input"],

Cell[BoxData[
    \(plot1[
        veIn_] := \[IndentingNewLine]ParametricPlot[\({position, speed} /. 
              values\) /. {ve \[Rule] veIn}\  // 
          Evaluate, \[IndentingNewLine]{t, 0, 
          tf}, \[IndentingNewLine]PlotStyle \[Rule] 
          Thickness[ .010], \[IndentingNewLine]DisplayFunction \[Rule] 
          Identity\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(\(elevation[
          ve_] = \[IndentingNewLine]{Thickness[0.004], Hue[0.8], 
              Line[{{height, 0}, {height, 10000}}]} /. values // 
          Graphics;\)\)], "Input"],

Cell[BoxData[
    \(\(Show[
        Table[{elevation[ve], plot1[ve]}, {ve, 100, 400, 
            100}], \[IndentingNewLine]Frame \[Rule] 
          True, \[IndentingNewLine]FrameLabel \[Rule] {"\<position\>", \
"\<speed\>", "\<\>", "\< \>"}, \[IndentingNewLine]RotateLabel \[Rule] 
          False, \[IndentingNewLine]PlotRange \[Rule] {{0, 4000}, {0, 
              4000}}, \[IndentingNewLine]DisplayFunction \[Rule] \
$DisplayFunction\[IndentingNewLine]];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Part ",
  StyleBox["d",
    FontWeight->"Plain"]
}], "Subsubsection"],

Cell[BoxData[{
    \(\(initial = {x[0] \[Rule] 0, \(x'\)[0] \[Rule] 
            0};\)\), "\[IndentingNewLine]", 
    \(\(order = 6;\)\)}], "Input"],

Cell[BoxData[
    \(eq4 = \ \(\(Series[eq3[\([1]\)] - eq3[\([2]\)], {t, 0, order}] /. 
          initial\)\(//\)\(Simplify\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(variables = 
      Table[D[x[t], {t, n}], {n, 0, order + 1}] /. {t \[Rule] 0}\)], "Input"],

Cell[BoxData[
    \(sol1 = \(Solve[eq4 \[Equal] 0, variables]\)[\([1]\)]\)], "Input"],

Cell[BoxData[
    \(series1 = \(\((x[t] + O[t]^order)\)\  /. sol1\) /. initial // 
        ExpandAll\)], "Input"],

Cell[BoxData[
    \(\(term[
          n_] = \(t\^\(n + 1\)\ ve\ \((\[CapitalDelta]m\/m0)\)\^n\)\/\(n\ \
\((n + 1)\)\);\)\)], "Input"],

Cell["\<\
series2= -(1/2) g t^2 + Sum[term[n],{n,1,order-2}];

series1==series2 //Normal //ExpandAll\
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(exact2 = \ \(-\((1/2)\)\)\ g\ t^2\  + \ 
          Sum[term[n], {n, 1, \[Infinity]}]\  // \ FullSimplify\)], "Input"],

Cell[BoxData[
    \(\((\(\(\((position == exact2\ )\)\[IndentingNewLine] // 
            MapAll[Together, #] &\)\ \[IndentingNewLine] // 
          PowerExpand\)\[IndentingNewLine] // \ 
        FullSimplify\[IndentingNewLine])\)\)], "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 7: Keplerian Orbits", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Remarks and Outline ", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection"],

Cell["Clear[\"Global`*\"];", "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection"],

Cell[BoxData[{
    RowBox[{\( (*\ \ \ \ \ \ \ \ \ \ \
mass\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ axes\ \ \ \ \ \ period\ \ \ \[Epsilon]\ \ \
\ \ *) \), "\[IndentingNewLine]", 
      RowBox[{
        RowBox[{"Mercury", "  ", "=", 
          
          StyleBox[\({3.300*10^23, \ \ \ 0.5791*10^11, \ \ \ \ 0.241, \ 
              0.206}\),
            FontFamily->"Courier"]}], 
        StyleBox[";",
          FontFamily->"Courier"]}]}], "\[IndentingNewLine]", 
    StyleBox[\(Venus\ \ \ \ \ \  = {4.870*10^24, \ \ \ 1.0821*10^11, \ \ \ \ \
0.615, \ 0.007};\),
      FontFamily->"Courier"], "\[IndentingNewLine]", 
    StyleBox[\(Earth\ \ \ \ \ \  = {5.974*10^24, \ \ \ 1.4960*10^11, \ \ \ \ \
1.000, \ 0.017};\),
      FontFamily->"Courier"], "\[IndentingNewLine]", 
    StyleBox[\(Mars\ \ \ \ \ \ \ \  = {6.419*10^23, \ \ \ 2.2794*10^11, \ \ \ \
\ 1.881, \ 0.093};\),
      FontFamily->"Courier"], "\[IndentingNewLine]", 
    StyleBox[\(Jupiter\  = {18.99*10^26, \ \ \ 7.7840*10^11, \ \ 11.860, \ 
            0.048};\),
      FontFamily->"Courier"], "\[IndentingNewLine]", 
    StyleBox[\(Saturn\ \ \  = {5.680*10^26, \ 14.2700*10^11, \ \ 29.420, \ 
            0.054};\),
      FontFamily->"Courier"], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox["Uranus",
          FontFamily->"Courier"], 
        StyleBox["   ",
          FontFamily->"Courier"], 
        StyleBox["=",
          FontFamily->"Courier"], 
        RowBox[{
          StyleBox["{",
            FontFamily->"Courier"], 
          StyleBox[\(8.680*10^25, \ 28.7100*10^11, \ \ 83.750, \ 0.047\),
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["}",
            FontFamily->"Courier"]}]}], 
      StyleBox[";",
        FontFamily->"Courier"]}], "\[IndentingNewLine]", 
    StyleBox[\(Neptune\  = {10.20*10^25, \ 44.9800*10^11, 163.700, \ 
            0.009};\),
      FontFamily->"Courier"], "\[IndentingNewLine]", 
    StyleBox[\(Pluto\ \ \ \ \  = {1.270*10^22, \ \ 59.5060*10^11, 248.000, \ 
            0.249};\),
      FontFamily->"Courier"]}], "Input"],

Cell[BoxData[
    \(\(data = {Mercury, Venus, Earth, Mars, Jupiter, Saturn, Uranus, 
          Neptune, Pluto};\)\)], "Input"],

Cell[BoxData[
    \(\(names = {"\<Mercury\>", "\<Venus\>", "\<Earth\>", "\<Mars\>", \
"\<Jupiter\>", "\<Saturn\>", "\<Uranus\>", "\<Neptune\>", "\<Pluto\>"};\)\)], \
"Input"],

Cell[BoxData[
    \(TableForm[data, 
      TableHeadings \[Rule] {names, {"\<Mass\>", "\<Axes\>", "\<Period\>", \
"\<\[Epsilon]\>"}}]\)], "Input"],

Cell[BoxData[
    \(\({mass, axes, period, \ \[Epsilon]} = Transpose[data];\)\)], "Input"],

Cell[BoxData[
    \(period\)], "Input"],

Cell["\<\
<<Miscellaneous`Units`
<<Miscellaneous`PhysicalConstants`\
\>", "Input",
  CellTags->"S5.65.1"],

Cell[BoxData[{
    \(\ \(values = {\[IndentingNewLine]year2sec \[Rule] 
            Convert[Year, Second], \ \[IndentingNewLine]G \[Rule] 
            GravitationalConstant, \ \[IndentingNewLine]Newton\  \[Rule] \ 
            Kilogram\ Meter/Second\^2, \[IndentingNewLine]AstronomicalUnit -> 
            Convert[AstronomicalUnit, Meter]};\)\), "\[IndentingNewLine]", 
    \(values\  // TableForm\)}], "Input"],

Cell[BoxData[
    \(kepler = \(\(4\ a\^3\ \[Pi]\^2\)\/\(T\^2\ G\)\  /. {a \[Rule] 
              axes\ *\ Meter, T \[Rule] \ period\ *\ year2sec}\)\ \  //. 
        values\)], "Input"],

Cell[BoxData[
    \(solarMass = 1.99\ *\ \(10\^30\) Kilogram; 
    TableForm[kepler\/solarMass, TableHeadings \[Rule] {names}] // 
      PaddedForm[#, {4, 3}] &\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b ", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(r = \(\(a\ \((1 - e\^2)\)\)\/\((1 + e\ Cos[\ \[Theta]])\)\  /. {a \
\[Rule] axes\ *\ Meter, T \[Rule] \ period\ *\ year2sec, \ 
            e \[Rule] \[Epsilon]}\)\ \  //. values\)], "Input"],

Cell[BoxData[
    \(points = 
      Outer[#1\ *\ #2 &, 
          r\/AstronomicalUnit\ , {Cos[\[Theta]], Sin[\[Theta]]}]\  /. 
        values\)], "Input"],

Cell[BoxData[
    \(\(plot1 = 
        ParametricPlot[\ 
          points[\([{1, 2, 3, 4}]\)]\  // Evaluate, {\[Theta], 0, 2\ \[Pi]}, 
          PlotRange \[Rule] All, AspectRatio \[Rule] 1];\)\)], "Input"],

Cell[BoxData[
    \(\(plot2 = 
        ParametricPlot[\ 
          points[\([{5, 6, 7, 8, 9}]\)]\  // Evaluate, {\[Theta], 0, 
            2\ \[Pi]}, PlotRange \[Rule] All, 
          AspectRatio \[Rule] 1];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[GraphicsArray[{plot1, plot2}]];\)\)], "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell["2.3 Newtonian Mechanics in Rotating Frames ", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Overview of Newtonian Mechanics in Rotating Frames", "Subsection"],

Cell[CellGroupData[{

Cell["\<\
Problem 1:  Projectile Motion as Measured by an Observer on Earth  \
\
\>", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Remarks and Outline", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Clear[\"Global`*\"];", "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Part a ", "Subsubsection"],

Cell[BoxData[{
    \(\(r[t_] = {x[t], y[t], z[t]};\)\), "\[IndentingNewLine]", 
    \(\(\[Omega][t_] = {\(-\[Omega]0\)\ Sin[\[Theta]], 
          0, \[Omega]0\ Cos[\[Theta]]};\)\)}], "Input"],

Cell[BoxData[
    \(fTransverse = \ \(-\ \ \ \ m\)\ Cross[\(\[Omega]'\)[t], 
          r[t]]\)], "Input"],

Cell[BoxData[
    \(fCoriolis = \ \ \ \(-\ \ \ 2\)\ m\ Cross[\[Omega][t], \ \(r'\)[
            t]]\)], "Input"],

Cell[BoxData[
    \(fCentrifugal = \ \(-m\)\ Cross[\ \[Omega][t], \ 
            Cross[\[Omega][t], r[t]]\ ]\  // Simplify\)], "Input"],

Cell[BoxData[
    \(\(fInertial = \ {0, 0, \(-m\)\ g};\)\)], "Input"],

Cell[BoxData[
    \(eq1 = 
      m\ \ \(r''\)[t] - fInertial\  - fTransverse - fCoriolis - 
        fCentrifugal\)], "Input"],

Cell[BoxData[
    \(initialRule = \ 
      Thread\  /@ \ {r[0] \[Rule] \ 0, \(r'\)[0] \[Rule] \ {1, 0, 0}}\  // 
        Flatten\)], "Input"],

Cell[BoxData[
    \(\(nOrder = 0;\)\)], "Input"],

Cell[BoxData[
    \(eq2 = \ \((\ \(\(Series[eq1/m, {t, 0, nOrder}] \[Equal] 
                  0\ \[IndentingNewLine] /. initialRule // Normal\)\  // 
            Thread\)\  // Simplify\ )\)\)], "Input"],

Cell[BoxData[
    \(vars = \ \[IndentingNewLine]\(\(Table[
            D[{x[t], y[t], z[t]}, {t, i}], {i, 2, nOrder + 2}] /. 
          t \[Rule] 0\)\(\ \)\(//\)\(Flatten\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(\ \)\(sol = \ Solve[eq2\ , vars]\  // First\)\)\)], "Input"],

Cell[BoxData[
    \(point[
        t_, \[Theta]_] = \[IndentingNewLine]\(Series[\ 
              r[t], {t, 0, nOrder + 2}]\  /. sol\)\  /. initialRule // 
        Normal\)], "Input"],

Cell[BoxData[
    RowBox[{\(plot[\[Theta]_]\), ":=", 
      RowBox[{"ParametricPlot", "[", 
        RowBox[{
          
          FormBox[\(\(\ \)\(\(point[
                    t, \[Theta]]\)[\([{1, 2}]\)] /. {\[Omega]0 \[Rule] 1, 
                  g \[Rule] 9.8}\  // Evaluate\)\),
            "TraditionalForm"], ",", "\[IndentingNewLine]", \({t, 0, 20}\), 
          ",", "\[IndentingNewLine]", \(PlotStyle -> {\ Thickness[0.016]}\), 
          ",", "\[IndentingNewLine]", \(AxesLabel \[Rule] {"\<x,South\>", \
"\<y,East\>"}\), ",", 
          "\[IndentingNewLine]", \(PlotRange \[Rule] {{0, 
                20}, {\(+200\), \(-200\)}}\), ",", 
          "\[IndentingNewLine]", \(Ticks \[Rule] False\), " ", ",", 
          "\[IndentingNewLine]", " ", \(DisplayFunction -> Identity\)}], 
        "]"}], " "}]], "Input"],

Cell[BoxData[
    \(\(\({plot[\[Pi]/4], plot[3  \[Pi]/4]}\  // GraphicsArray\)\  // 
        Show;\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection"],

Cell[BoxData[
    \(initial = \ 
      Thread\  /@ \ {r[0] == 0, \(r'\)[0] == {vx0, 0, 0}}\  // 
        Flatten\)], "Input"],

Cell[BoxData[
    \(eqNorth = 
      Join[Thread[eq1 \[Equal] 0], 
          initial]\  /. \(\(\[Theta]\)\(\[Rule]\)\(0\)\(\ \ \)\)\)], "Input"],

Cell[BoxData[
    \(solNorth = \ \(DSolve[eqNorth, {x[t], y[t], z[t]}, t]\  // First\) // 
        FullSimplify\)], "Input"],

Cell[BoxData[
    \(\(values = {g \[Rule] 9.8, z0 \[Rule] 500, vx0 \[Rule] 1};\)\)], "Input"],

Cell[BoxData[
    \(pointNorth[t_, \[Omega]0_] = \(r[t] /. solNorth\)\  /. 
        values\)], "Input"],

Cell[BoxData[
    \(\(plot1 = 
        ParametricPlot3D[
          pointNorth[t, 0] // Evaluate, \[IndentingNewLine]{t, 0, 
            10}, \[IndentingNewLine]BoxRatios \[Rule] {1, 1, 
              1}];\)\)], "Input"],

Cell[BoxData[
    \(\(plot2 = 
        ParametricPlot3D[
          Join[pointNorth[t, 0.01], {Thickness[ .02]}\ ] // Evaluate, {t, 0, 
            10}, \[IndentingNewLine]BoxRatios \[Rule] {1, 1, 
              1}];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[\ {plot1, 
          plot2}, \[IndentingNewLine]FaceGrids -> {{0, 1, 0}, {\(-1\), 0, 
              0}}, \[IndentingNewLine]BoxRatios -> {1, 1, 
            1}, \[IndentingNewLine]ViewPoint -> {1.5, \(-1.0\), 
            0.7}, \[IndentingNewLine]AxesLabel -> {"\<x-south\>", "\<west\>", \
"\<z-vertical\>"}\[IndentingNewLine]];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection"],

Cell[BoxData[
    \(eqEquator = 
      Join[Thread[eq1 \[Equal] 0], 
          initial]\  /. \[Theta] \[Rule] \(\(\[Pi]/2\)\(\ \ \)\)\)], "Input"],

Cell[BoxData[
    \(solEquator = \ \(DSolve[eqEquator, {x[t], y[t], z[t]}, t]\  // First\) // 
        FullSimplify\)], "Input"],

Cell[BoxData[
    \(pointEquator[t_, \[Omega]0_] = \(r[t] /. solEquator\) /. 
        values\)], "Input"],

Cell[BoxData[
    \(pointEquator[t_, 0] = \ 
      Limit[pointEquator[t, \[Omega]0], \[Omega]0 \[Rule] 0]\)], "Input"],

Cell[BoxData[
    \(\(plotEquator[\[Omega]0_, 
          style_] := \[IndentingNewLine]ParametricPlot3D[\[IndentingNewLine]\
Join[\ pointEquator[t, \[Omega]0], {style}]\  /. values\  // 
            Evaluate, \[IndentingNewLine]{t, 0, 
            10}, \[IndentingNewLine]BoxRatios \[Rule] {1, 1, 
              1}, \[IndentingNewLine]DisplayFunction \[Rule] 
            Identity];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[\ \[IndentingNewLine]{\ 
          plotEquator[
            0\ \ \ \ \ , {Thickness[0.02], 
              Hue[0.6]}], \[IndentingNewLine]plotEquator[
            0.01, {Thickness[0.01], 
              Hue[0.4]}]\ }, \[IndentingNewLine]FaceGrids -> {{0, \(-1\), 
              0}, \ {\(-1\), 0, 0}}, \[IndentingNewLine]BoxRatios -> {1, 1, 
            1}, \[IndentingNewLine]ViewPoint -> {1, 0.7, 
            0.7}, \[IndentingNewLine]AxesLabel -> {"\<x-South\>", \
"\<y-East\>", "\<z-Up\>"}, \[IndentingNewLine]DisplayFunction -> \
$DisplayFunction\ \ ];\)\)], "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 2:  Foucault Pendulum    ", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Remarks and Outline", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Clear[\"Global`*\"];", "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection"],

Cell[BoxData[{
    \(\(r[t_] = {x[t], y[t], z[t]};\)\), "\[IndentingNewLine]", 
    \(\(\[Omega][t_] = {\(-\[Omega]0\)\ Sin[\[Theta]], 
          0, \[Omega]0\ Cos[\[Theta]]};\)\)}], "Input"],

Cell[BoxData[
    \(fTransverse = \ \(-\ \ \ \ m\)\ Cross[\(\[Omega]'\)[t], 
          r[t]]\)], "Input"],

Cell[BoxData[
    \(fCoriolis = \ \ \ \(-\ \ \ 2\)\ m\ Cross[\[Omega][t], \ \(r'\)[
            t]]\)], "Input"],

Cell[BoxData[
    \(fCentrifugal = \ \(-m\)\ Cross[\ \[Omega][t], \ 
            Cross[\[Omega][t], r[t]]\ ]\  // Simplify\)], "Input"],

Cell[BoxData[{
    \(\(fGravity = {0, 0, \(-m\)\ g};\)\), "\[IndentingNewLine]", 
    \(\(fTension = 
        tension \((\ {0, 0, 1} - r[t]/L\ )\);\)\), "\[IndentingNewLine]", 
    \(fInertial = fGravity + fTension\)}], "Input"],

Cell[BoxData[
    \(eq1 = 
      0 \[Equal] 
          m\ \ \(r''\)[t] - fInertial\  - fTransverse - fCoriolis - 
            fCentrifugal\  // Thread\)], "Input"],

Cell[BoxData[
    \(initialRule = \ 
      Thread\  /@ \ {r[0] \[Rule] 0, \(r'\)[0] \[Rule] {1, 0, 0}}\  // 
        Flatten\)], "Input"],

Cell[BoxData[
    \(zSol = DSolve[{z[t] \[Equal] 0}, z, t]\  // First\)], "Input"],

Cell[BoxData[
    \(eq2 = \ \(eq1 /. {\[Omega]0\^2 -> 0, \ Sin[\[Theta]] \[Rule] 0}\)\  /. 
        zSol\)], "Input"],

Cell[BoxData[
    \(eq3 = \ 
      Solve[eq2, {\(x''\)[t], \(y''\)[t]}, 
            tension]\  /. {Rule\  \[Rule] \ Equal}\  // First\)], "Input"],

Cell[BoxData[
    \(eq4 = \ eq3 /. {\ g \[Rule] \ \[Omega]\^2\ L}\  // Simplify\)], "Input"],

Cell[BoxData[
    \(\(\(DSolve[eq4, {x, y}, t];\)\(\ \ \)\( (*\ 
      Not\ Displayed\ *) \)\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection"],

Cell[BoxData[
    \(imEq = \ \ I\ eq4[\([2]\)] // Thread[#, Equal] &\)], "Input"],

Cell[BoxData[
    \(\(\(reEq\)\(=\)\(\ \)\(eq4[\([1]\)]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(eq5 = \ \(reEq\  + \ imEq // Thread[#, Equal] &\)\  // 
        Simplify\)], "Input"],

Cell[BoxData[
    \(eq6 = \ 
      eq5\  /. \(DSolve[u[t] \[Equal] x[t] + I\ y[t], x, t]\)[\([1]\)]\  // 
        Simplify\)], "Input"],

Cell[BoxData[
    \(\(initial = {u[0] \[Equal] I\ y0, \(u'\)[0] \[Equal] 0};\)\)], "Input"],

Cell[BoxData[
    \(dsol = DSolve[Join[{eq6}, initial], {u[t]}, t]\  // First\)], "Input"],

Cell[BoxData[
    \(uSol = \((\ \(\(\(u[t]\ \[IndentingNewLine] /. 
                  dsol\)\ \[IndentingNewLine] /. \ \[Omega]0^2 \[Rule] 
                  0\[IndentingNewLine] // PowerExpand\)\[IndentingNewLine] // 
            ExpToTrig\)\ \ \[IndentingNewLine] // ExpandAll\ )\)\)], "Input"],

Cell[BoxData[
    \(x = \ \(reSol = \ 
        uSol /. {Complex[a_, b_] \[RuleDelayed] a}\)\)], "Input"],

Cell[BoxData[
    \(y = \ \(imSol = \ \((uSol - \ reSol)\)/I\  // Simplify\)\)], "Input"],

Cell[BoxData[
    \(\(point = {x, y};\)\)], "Input"],

Cell[BoxData[
    \(\(point /. {\[Omega]0\/\[Omega] \[Rule] 0}\  // FullSimplify\) // 
      TableForm\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection"],

Cell[BoxData[
    \(\(values = {\[Omega] \[Rule] Sqrt[g/L], \ L \[Rule] 1, \ 
          g \[Rule] 9.8, \ \[Omega]0 \[Rule] 1/10, \ 
          y0 \[Rule] 1};\)\)], "Input"],

Cell[BoxData[
    \(\(plot[\[Theta]in_, 
          options_: {}] := \[IndentingNewLine]ParametricPlot[\ \(point\ \  //. 
                values\) /. {\[Theta] \[Rule] \[Theta]in} // 
            Evaluate, \[IndentingNewLine]{t, 0, 
            10}, \[IndentingNewLine]Ticks \[Rule] 
            False, \[IndentingNewLine]PlotStyle \[Rule] {options}, \
\[IndentingNewLine]PlotRange \[Rule] {{\(-1\), 1}, {\(-1\), 1}}, 
          AxesLabel \[Rule] {"\<x-axis, south\>", "\<y-axis, east\>"}];\)\)], \
"Input"],

Cell[BoxData[
    \(\(plot[0];\)\)], "Input"],

Cell[BoxData[
    \(\(plot[\[Pi]];\)\)], "Input"],

Cell[BoxData[
    \(\(plot[\[Pi]/2, Thickness[0.02]];\)\)], "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell["2.4 Electricity and Magnetism ", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[" Overview of Electricity and Magnetism    ", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Problem 1: Charged Disk   ", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Remarks and Outline", "Subsubsection"],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection"],

Cell["Clear[\"Global`*\"];", "Input"],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection"],

Cell[BoxData[
    \(\(dV = k  dq\/\@\(z\^2 + r\^2\);\)\)], "Input"],

Cell[BoxData[
    \(\(dq = 2\ \[Pi]\ \ r\ dr\ \[Sigma];\)\)], "Input"],

Cell[BoxData[
    \(dV\/dr\)], "Input"],

Cell[BoxData[
    \(diskPotential = 
      Integrate[dV\/dr, {r, 0, R}]\ \  // PowerExpand\)], "Input"],

Cell["Needs[\"Calculus`VectorAnalysis`\"];", "Input"],

Cell[BoxData[
    \(Edisk = \(-Grad[diskPotential, Cartesian[x, y, z]]\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection"],

Cell[BoxData[
    \(Eplane = Limit[Edisk, R \[Rule] \[Infinity]]\)], "Input"]
}, Closed]]
}, Closed]],

Cell[BoxData[
    \(Eplane\  /. {k \[Rule] 1\/\(4  \[Pi]\ \[Epsilon]\_0\)}\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 2: Uniformly Charged Sphere ", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Remarks and Outline", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Clear[\"Global`*\"];", "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection"],

Cell[BoxData[
    \(\(eq1 = {\[IndentingNewLine]4\ \[Pi]\ r\^2\ Eoutside \[Equal] 
            qTotal\ \ \ \ \ \  (*\ 
            r > R\ *) , \[IndentingNewLine]4\ \[Pi]\ r\^2\ Einside \[Equal] 
            qEnclosed\  (*\ r < R\ *) };\)\)], "Input"],

Cell[BoxData[{
    \(\(qTotal = \(\(4  \[Pi]\ R\^3\)\/\(\(3\)\(\ \)\)\) \[Rho];\)\), "\
\[IndentingNewLine]", 
    \(\(qEnclosed = \(\(4  \[Pi]\ r\^3\)\/3\) \[Rho];\)\)}], "Input"],

Cell[BoxData[
    \(sol = Solve[eq1, {Einside, Eoutside}]\  // First\)], "Input"],

Cell[BoxData[
    \(eField[rr_, 
        RR_:  1, \[Rho]\[Rho]_:  
          1] := \ \(If[\ rr \[LessEqual] RR, \ Einside, Eoutside] /. 
          sol\) /. {r \[Rule] rr, 
          R \[Rule] RR, \[Rho] \[Rule] \[Rho]\[Rho]}\)], "Input"],

Cell[BoxData[
    \(\(p1 = Plot[eField[r], {r, 10\^\(-6\), 3}];\)\)], "Input"],

Cell[BoxData[{
    \(\(medium1 = {Hue[ .2], 
          Polygon[{{1,  .51}, {1, 0}, {3, 
                0}, {3,  .51}}]};\)\), "\[IndentingNewLine]", 
    \(\(medium2 = {Hue[ .5], 
          Polygon[{{0,  .51}, {0, 0}, {1, 0}, {1,  .51}}]};\)\)}], "Input"],

Cell[BoxData[
    \(\(Show[\[IndentingNewLine]{Graphics[{\[IndentingNewLine]medium1, \
\[IndentingNewLine]medium2, \[IndentingNewLine]Text["\<Inside \>", {0.5, 
                  0.4}], \[IndentingNewLine]Text["\<Outside\>", {2.0, 
                  0.4}]}], \[IndentingNewLine]p1\[IndentingNewLine]}, \
\[IndentingNewLine]AxesLabel \[Rule] {"\<Distance \>", "\<Electric Field\>"}, \
\[IndentingNewLine]Axes \[Rule] True];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection"],

Cell[BoxData[
    \(vOut[r_, 
        R_] = \(-Integrate[Eoutside /. sol, {r, \[Infinity], r}]\)\)], "Input"],

Cell[BoxData[
    \(vIn[r_, R_] = \((vOut[R, R] - Integrate[Einside /. sol, {r, R, r}])\) // 
        Simplify\)], "Input"],

Cell[TextData[{
  "The potential for all  ",
  StyleBox["r",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is   "
}], "Special5",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["v[r_,R_]:= If[r<R,vIn[r,R],vOut[r,R]]; ", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(p2 = 
        Plot[v[r, 1] /. \[Rho] \[Rule] 1, {r, 10\^\(-6\), 3}];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[{\[IndentingNewLine]Graphics[{\[IndentingNewLine]medium1, \
\[IndentingNewLine]medium2, \[IndentingNewLine]Text["\<Inside \>", {0.5, 
                  0.3}], \[IndentingNewLine]Text["\<Outside\>", {2.0, 
                  0.3}]}], \[IndentingNewLine]p2\[IndentingNewLine]}, \
\[IndentingNewLine]AxesLabel \[Rule] {"\<Distance \>", "\<Potential \
Field\>"}, \[IndentingNewLine]Axes \[Rule] 
          True\[IndentingNewLine]];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection"],

Cell[BoxData[
    \(vv[x_, y_, z_:  0, 
        R_:  1, \[Rho]\[Rho]_:  1] := \[IndentingNewLine]\(\(If[r < R, 
          vIn[r, R] // Evaluate, 
          vOut[r, R] // 
            Evaluate]\)\(\ \)\(/.\)\({r -> \@\(x\^2 + y\^2 + z\^2\), \[Rho] \
\[Rule] \[Rho]\[Rho]}\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(\(vPlot = 
        ContourPlot[
          vv[x, y]\ , {x, \(-2\), 2}, {y, \(-2\), 
            2}, \[IndentingNewLine]PlotPoints \[Rule] 
            30, \[IndentingNewLine]ColorFunction \[Rule] 
            Hue, \[IndentingNewLine]ContourSmoothing \[Rule] 
            True, \[IndentingNewLine]DisplayFunction \[Rule] 
            Identity];\)\)], "Input"],

Cell[TextData[{
  StyleBox[" ",
    FontColor->RGBColor[1, 0, 0]],
  "Needs[\"Graphics`PlotField`\"];"
}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(ePlot = 
        PlotGradientField[\(-vv[x, y]\), {x, \(-2\), 2}, {y, \(-2\), 
            2}, \[IndentingNewLine]ScaleFunction \[Rule] \((1 &)\), \
\[IndentingNewLine]DisplayFunction \[Rule] Identity];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[{vPlot, ePlot}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part d", "Subsubsection"],

Cell[BoxData[
    \(\(Needs["\<Graphics`PlotField3D`\>"];\)\)], "Input"],

Cell[BoxData[
    \(\(ePlot3D = 
        PlotGradientField3D[\[IndentingNewLine]\(-vv[x, y, z]\), {x, 0, 
            2}, {y, 0, 2}, {z, 0, 2}, \[IndentingNewLine]VectorHeads \[Rule] 
            True, \ \[IndentingNewLine]ScaleFunction \[Rule] \((1 &)\), \
\[IndentingNewLine]DisplayFunction \[Rule] Identity];\)\)], "Input"],

Cell[BoxData[
    \(point[r_, R_:  1] := {r\ Sin[\[Theta]]\ Cos[\[CurlyPhi]], 
        r\ Sin[\[Theta]]\ Sin[\[CurlyPhi]], r\ Cos[\[Theta]]}\)], "Input"],

Cell[BoxData[
    \(potPlot3D[
        r_] := \[IndentingNewLine]ParametricPlot3D[\[IndentingNewLine]point[
            r] // Evaluate, {\[Theta], 0, \[Pi]/2}, {\[CurlyPhi], 
          0, \[Pi]/2}, \[IndentingNewLine]PlotPoints \[Rule] 
          12, \[IndentingNewLine]DisplayFunction \[Rule] Identity]\)], "Input"],

Cell[BoxData[
    \(\(Show[\[IndentingNewLine]ePlot3D, \[IndentingNewLine]Table[
          potPlot3D[r], {r, 1/2, 2, 
            1/2}], \[IndentingNewLine]PlotRange \[Rule] {0, 
            1}, \[IndentingNewLine]DisplayFunction \[Rule] $DisplayFunction];\
\)\)], "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 3: Electric Dipole    ", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Remarks and Outline", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution:", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Clear[\"Global`*\"];", "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection"],

Cell[BoxData[
    \(monopole[q_, p0_: {0, 0, 0}, p1_: {x, y, z}] := 
      q\/\@\(\((p0 - p1)\) . \((p0 - p1)\)\)\)], "Input"],

Cell[BoxData[
    \(dipole = \((monopole[\(-q\), {0, 0, \(-d\)/2}] + 
          monopole[\(+q\), {0, 0, \(+d\)/2}])\)\)], "Input"],

Cell[BoxData[
    \(\(ContourPlot[
        dipole /. {q \[Rule] 1, d \[Rule] 1, y \[Rule] 0}\  // 
          Evaluate, \[IndentingNewLine]{x, \(-2\), 2}, {z, \(-2\), 
          2}, \[IndentingNewLine]PlotPoints \[Rule] 
          45, \[IndentingNewLine]Contours \[Rule] 
          21, \[IndentingNewLine]ColorFunction \[Rule] 
          Hue, \[IndentingNewLine]Axes \[Rule] 
          True, \[IndentingNewLine]AxesLabel \[Rule] {"\<x-axis\>", "\<z-axis\
\>"}];\)\)], "Input"],

Cell[BoxData[
    \(\(Needs["\<Graphics`PlotField3D`\>"];\)\)], "Input"],

Cell[BoxData[
    \(\(plot = \[IndentingNewLine]PlotGradientField3D[\(-dipole\) /. {q \
\[Rule] 1, d \[Rule] 1}\  // Evaluate, \[IndentingNewLine]{x, \(-0.5\), 
            0.5}, {y, \(-0.5\), 0.5}, {z, \(-1.0\), 
            1.0}, \[IndentingNewLine]PlotPoints \[Rule] 
            6, \[IndentingNewLine]ColorFunction \[Rule] 
            Hue, \[IndentingNewLine]VectorHeads \[Rule] 
            True, \ \[IndentingNewLine]ScaleFunction \[Rule] \((1 &)\), \
\[IndentingNewLine]BoxRatios \[Rule] {1, 1, 
              2}\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[plot, ViewPoint -> {0, 3, 0}\ ];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection"],

Cell[BoxData[
    \(\(Needs["\<Calculus`VectorAnalysis`\>"];\)\)], "Input"],

Cell[BoxData[
    \(x2rRule = 
      Thread[{x, y, z} \[Rule] 
          CoordinatesToCartesian[{r, \[Theta], \[CurlyPhi]}, 
            Spherical]]\)], "Input"],

Cell[BoxData[
    \(potential = dipole /. x2rRule // Simplify\)], "Input"],

Cell[BoxData[
    \(dipoleR = \(Series[potential, {r, \[Infinity], 2}] // Normal\) // 
        Simplify\)], "Input"],

Cell[BoxData[
    \(eField = \(-Grad[dipoleR, 
          Spherical[r, \[Theta], \[CurlyPhi]]]\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection"],

Cell[BoxData[
    \(\(rotDipole[\[Theta]_] = \((\ \ monopole[\(+1\), 
              1/2 {\(+Sin[\[Theta]]\), 0, \(+Cos[\[Theta]]\)}] + 
            monopole[\(-1\), 
              1/2 {\(-Sin[\[Theta]]\), 
                  0, \(-Cos[\[Theta]]\)}]\ )\);\)\)], "Input"],

Cell[BoxData[{
    \(\(frames = 1;\)\), "\[IndentingNewLine]", 
    \(Do[\[IndentingNewLine]PlotGradientField[\[IndentingNewLine]\(-rotDipole[\
\[Theta]]\) /. {y \[Rule] 0}, \[IndentingNewLine]{x, \(-2\), 2}, {z, \(-2\), 
          2}, \[IndentingNewLine]PlotPoints \[Rule] 
          14, \[IndentingNewLine]VectorHeads \[Rule] 
          True, \ \[IndentingNewLine]ScaleFunction \[Rule] \((1 &)\)]\
\[IndentingNewLine], {\[Theta], 2\ \[Pi]/frames, 2\ \[Pi], 
        2\ \[Pi]/frames}]\)}], "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Problem 4: Magnetic Vector Potential for a Long Straight Wire\
\>", \
"Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Remarks and Outline", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Clear[\"Global`*\"];", "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection"],

Cell[BoxData[
    \(\(\(Az[r_]\)\(=\)\(Integrate[
        I0\/\@\(z\^2 + r\^2\), {z, \(-L\), L}]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(A[x_, y_, z_] = {0, 0, Az[\@\(x\^2 + y\^2\)]}\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection"],

Cell[BoxData[{
    \(\(\(Needs["\<Calculus`VectorAnalysis`\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(B[x_, y_, z_] = 
      Curl[A[x, y, z], Cartesian[x, y, z]] // Simplify\)}], "Input"],

Cell[BoxData[
    \(B\[Infinity][x_, y_, z_] = 
      Limit[B[x, y, z], L \[Rule] \[Infinity]]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection"],

Cell[BoxData[
    \(\(Needs["\<Graphics`PlotField3D`\>"];\)\)], "Input"],

Cell[BoxData[
    \(\(p1 = 
        PlotVectorField3D[\[IndentingNewLine]B\[Infinity][x, y, z] /. 
            I0 \[Rule] 1, \[IndentingNewLine]{x, \(-1\), 1}, {y, \(-1\), 
            1}, {z, \(-1\), 1}, \[IndentingNewLine]PlotPoints \[Rule] 
            6, \[IndentingNewLine]VectorHeads \[Rule] 
            True, \[IndentingNewLine]ViewPoint \[Rule] {1, 1, 
              3}, \[IndentingNewLine]ColorFunction \[Rule] 
            Hue, \ \[IndentingNewLine]ScaleFunction \[Rule] \((1 &)\), \
\[IndentingNewLine]ViewPoint \[Rule] {2, 2, 
              16}\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[{
    \(\(\(Needs["\<Graphics`PlotField`\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PlotVectorField[\[IndentingNewLine]\(B\[Infinity][x, y, 
              z]\)[\([{1, 2}]\)] /. 
          I0 \[Rule] 1, \[IndentingNewLine]{x, \(-3\), 3}, {y, \(-3\), 
          3}, \[IndentingNewLine]PlotPoints \[Rule] 
          20, \[IndentingNewLine]VectorHeads \[Rule] 
          True, \[IndentingNewLine]ColorFunction \[Rule] 
          Hue, \ \[IndentingNewLine]ScaleFunction \[Rule] \((1 &)\)\
\[IndentingNewLine]];\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part d", "Subsubsection"],

Cell[BoxData[
    \(\(\(Acylind[r_]\)\(=\)\({0, 0, Az[r]}\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(Bcylind[r_] = \ 
      Curl[Acylind[r], Cylindrical[r, \[Theta], z]] // 
        Limit[#, L \[Rule] \[Infinity]] &\)], "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Problem 5: Motion of a Charged Particle in a Uniform B Field  \
\
\>", "Subsection"],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection"],

Cell["Clear[\"Global`*\"];", "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection"],

Cell[BoxData[{
    \(\(acceleration = {\(x''\)[t], \(y''\)[t], \(z''\)[
            t]};\)\), "\[IndentingNewLine]", 
    \(\(velocity = {\(x'\)[t], \(y'\)[t], \(z'\)[
            t]};\)\), "\[IndentingNewLine]", 
    \(\(magneticField = {0, 0, B};\)\)}], "Input"],

Cell[BoxData[
    \(eq1 = \(\(acceleration == 
          q/m\ \ Cross[velocity, 
              magneticField]\)\(//\)\(Thread\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(eq1 = eq1 /. {B \[Rule] m/q\ \ \[Omega]}\)], "Input"],

Cell[BoxData[
    \(\(initial = {\[IndentingNewLine]x[0] \[Equal] 0, \(x'\)[0] \[Equal] 
            v0x, \[IndentingNewLine]y[0] \[Equal] 0, \(y'\)[0] \[Equal] 
            v0y, \[IndentingNewLine]z[0] \[Equal] 0, \(z'\)[0] \[Equal] 
            v0z};\)\)], "Input"],

Cell[BoxData[
    \(dsol = \ \(DSolve[Join[{eq1, initial}], {x[t], y[t], z[t]}, t]\  // 
          Flatten\) // FullSimplify\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection"],

Cell[BoxData[
    \(\(values = {B \[Rule] m/q\ \ \[Omega], \ \[Omega] \[Rule] 1, 
          v0x \[Rule] 1, v0y \[Rule] 1, v0z \[Rule] 1/10\ };\)\)], "Input"],

Cell[BoxData[
    \(\(plot1 = \ 
        ParametricPlot3D[\({x[t], y[t], z[t], {Thickness[0.02]}} /. dsol\) /. 
              values\  // Evaluate, \[IndentingNewLine]{t, 0, 
            8  \[Pi]}, \[IndentingNewLine]PlotPoints \[Rule] 
            100\ ];\)\)], "Input"],

Cell[BoxData[{
    \(\(\(Needs["\<Graphics`PlotField3D`\>"]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\ \(plot2 = 
        PlotVectorField3D[\ {0, 0, 1} // 
            Evaluate, \[IndentingNewLine]{x, \(-2\), 2}, {y, \(-2\), 2}, {z, 
            0, 2}, \[IndentingNewLine]VectorHeads \[Rule] 
            True\ , \[IndentingNewLine]PlotPoints \[Rule] 
            4\[IndentingNewLine]];\)\)}], "Input"],

Cell[BoxData[
    \(\(\(\ \)\(Show[plot1, plot2];\)\)\)], "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Problem 6: Motion of a Charged Particle in a Uniform B Field and \
Time Varying E Field \
\>", "Subsection"],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection"],

Cell["Clear[\"Global`*\"];", "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(F = {Fx, Fy, Fz};\)\ \), "\[IndentingNewLine]", 
    \(\(r = {x[t], y[t], z[t]};\)\ \), "\[IndentingNewLine]", 
    \(\(EF = {Ex, Ey, Ez};\)\ \), "\[IndentingNewLine]", 
    \(BF = {Bx, By, Bz}; \ v = D[r, t]\)}], "Input"],

Cell[BoxData[
    \(F = q\ EF + q\ Cross[v, BF]\)], "Input"],

Cell[BoxData[{
    \(\(eq1 = \ 
        F - m\ D[r, {t, 2}] \[Equal] 0\  // 
          Thread;\)\), "\[IndentingNewLine]", 
    \(eq1\  // ColumnForm\)}], "Input"],

Cell[BoxData[
    \(\(initial = {\[IndentingNewLine]x[0] \[Equal] 0, \(x'\)[0] \[Equal] 
            0, \[IndentingNewLine]y[0] \[Equal] 0, \(y'\)[0] \[Equal] 
            0, \[IndentingNewLine]z[0] \[Equal] 0, \(z'\)[0] \[Equal] 
            0};\)\)], "Input"],

Cell[BoxData[
    \(fields = \ 
      Thread\  /@ \ {BF \[Rule] {0, 0, m\ \[Omega]0/q}, 
            EF \[Rule] {E0\ \ Cos[\[Omega]\ t\ ], 0, 0}}\  // 
        Flatten\)], "Input"],

Cell[BoxData[
    \(eqs = Join[eq1, initial] /. fields\)], "Input"],

Cell[BoxData[
    \(dsol = \(DSolve[eqs, {x[t], y[t], z[t]}, t]\  // Flatten\) // 
        FullSimplify\)], "Input"],

Cell[BoxData[
    \(\(values = {m \[Rule] 1, E0 \[Rule] 1, \[Omega]0 \[Rule] 1, \ 
          q \[Rule] \ 1\ };\)\)], "Input"],

Cell[BoxData[
    \(point[t_, \[Omega]_] = \({x[t], y[t], z[t]}\  /. dsol\)\  /. 
        values\)], "Input"],

Cell[BoxData[
    \(point[t_, 1] = 
      Limit[\ point[t, \[Omega]], \[Omega] \[Rule] 1]\)], "Input"],

Cell[BoxData[
    \(point[t_, 0] = 
      Limit[\ point[t, \[Omega]], \[Omega] \[Rule] 0]\)], "Input"],

Cell[BoxData[
    \(\(plot[\[Omega]_\ ] := 
        ParametricPlot[\ \(point[t, \[Omega]]\)[\([{1, 2}]\)]\  // 
            Evaluate, {t, 0, 
            20\ \[Pi]\ \ \ }, \[IndentingNewLine]PlotLabel \[Rule] \[Omega], \
\[IndentingNewLine]Ticks \[Rule] 
            None, \[IndentingNewLine]DisplayFunction \[Rule] 
            Identity];\)\)], "Input"],

Cell[BoxData[
    \(\(table = Table[\ plot[\[Omega]], {\[Omega], 0, 4, 1/3}];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[GraphicsArray[Partition[table, 3]]];\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[TextData[{
  "2.5 Modern Physics",
  StyleBox[" ",
    FontColor->RGBColor[1, 0, 0]]
}], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Problem 1:  Carbon Dating", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Clear[\"Global`*\"];", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(\(\ \)\(n[t_] = n0\ Exp[\(-a\)\ t]\)\)\)], "Input"],

Cell[BoxData[
    \(eq1 = \ 1/2\ n[0] \[Equal] \ n[\ 5750]\)], "Input"],

Cell[BoxData[
    \(aSol = \ Solve[eq1, a]\  // Flatten\)], "Input"],

Cell[BoxData[
    \(\(\(\ \)\(n[t_] = n[t]\  /. aSol\)\)\)], "Input"],

Cell[BoxData[
    \(eq2 = Eliminate[{n1 \[Equal] n[t], \ ratio == n1/n0}, n0]\)], "Input"],

Cell[BoxData[
    \(ageRule = Solve[eq2, t]\  // First\)], "Input"],

Cell[BoxData[
    \(time[ratio_] = \ t\  /. ageRule\)], "Input"],

Cell[BoxData[
    \(\(data = \ 
        Table[\ {ratio, \ time[ratio]}, {ratio, 0, 1, 1/10}]\  // 
          N;\)\)], "Input"],

Cell[BoxData[
    \(TableForm[\ data\ , \[IndentingNewLine]\ 
        TableHeadings -> {{}, {"\<Fraction Left\>"\ , "\<Age(yrs)\>"}}, \
\[IndentingNewLine]TableAlignments \[Rule] {Right, 
            Bottom}\[IndentingNewLine]]\  // 
      PaddedForm[#, {6, 1}] &\)], "Input"],

Cell[BoxData[{
    \(\(\(t0 = 5750;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Plot[\ 
        n[t]/n0, {t, 0, 5\ t0}, \[IndentingNewLine]AspectRatio \[Rule] 
          1, \[IndentingNewLine]Background \[Rule] 
          Hue[0.2, 0.5, 
            1], \[IndentingNewLine]Ticks \[Rule] {Range[0, 5\ t0, t0], 
            Table[1/2^i, {i, 0, 
                3}]}, \[IndentingNewLine]AxesLabel \[Rule] {"\<Age(yrs)\>", "\
\<ratio=n1/n0\>"}, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[0.02], 
            Hue[0.9]}, \[IndentingNewLine]GridLines \[Rule] {Range[0, 5\ t0, 
              t0], Table[
              1/2^i, {i, 0, 5}]}\[IndentingNewLine]];\)\)}], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 2:  Stable Isotopes", "Subsection"],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection"],

Cell["Clear[\"Global`*\"];", "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection"],

Cell[BoxData[
    \(Needs["\<Miscellaneous`ChemicalElements`\>"]\)], "Input"],

Cell[BoxData[
    \(Remove[Global`Mercury]\)], "Input"],

Cell[BoxData[
    \(\(?Miscellaneous`ChemicalElements`*\ \ \ \ \ \ (*\ Output\ not\ shown\ \
*)\)\)], "Input",
  Evaluatable->False],

Cell[BoxData[
    \({Elements[\([26]\)], \ ElementAbbreviations[\([26]\)]}\)], "Input"],

Cell[BoxData[
    \(StableIsotopes[Fe]\)], "Input"],

Cell[BoxData[
    \(Length[Elements]\)], "Input"],

Cell[BoxData[
    \(StableIsotopes[Fe] - 26\)], "Input"],

Cell[BoxData[
    \(StableIsotopes[Fe]*0 + 26\)], "Input"],

Cell[BoxData[{
    \(neutrons[n_] := \ 
      StableIsotopes[ElementAbbreviations[\([n]\)]\ ]\ \ \ \ \ \  - 
        n\), "\[IndentingNewLine]", 
    \(protons[\ \ n_] := \ 
      StableIsotopes[ElementAbbreviations[\([n]\)]\ ]*0\  + n\)}], "Input"],

Cell[BoxData[{
    \(\(\(pairs[n_] := 
      Transpose[{protons[n], neutrons[n]}]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(pairs[26]\)}], "Input"],

Cell[BoxData[
    \(\(ListPlot[
        pairs[26]\  // Evaluate, \[IndentingNewLine]PlotStyle \[Rule] 
          PointSize[
            0.03], \[IndentingNewLine]AxesLabel \[Rule] {"\<proton\>", \
"\<neutron\>"}, \[IndentingNewLine]PlotLabel \[Rule] "\<Iron (Fe)\>"\
\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    \(\(data = \ 
        Table[\ pairs[i], {i, Length[Elements]}]\  // 
          Flatten[#, 1] &;\)\)], "Input"],

Cell[BoxData[
    \(\(plot1 = 
        ListPlot[
          data, \[IndentingNewLine]PlotStyle \[Rule] 
            PointSize[
              0.015], \[IndentingNewLine]AxesLabel \[Rule] {"\<proton\>", \
"\<neutron\>"}, \[IndentingNewLine]PlotLabel \[Rule] "\<All Elements\>", \
\[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]DisplayFunction \[Rule] $DisplayFunction, \
\[IndentingNewLine]Epilog \[Rule] 
            Line[{{0, 0}, {100, 100}}]\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[plot1, PlotRange \[Rule] {{20, 30}, {20, 40}}];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection"],

Cell[BoxData[
    \(Select[
      data\ , \((OddQ[#[\([1]\)]]\  && \ OddQ[#[\([2]\)]])\) &]\)], "Input"],

Cell[BoxData[
    \(Select[data\ , \((OddQ[#[\([1]\)]]\  && \ OddQ[#[\([2]\)]])\) &]\  // 
      Length\)], "Input"],

Cell[BoxData[
    \(Select[data\ , \((EvenQ[#[\([1]\)]]\  && \ EvenQ[#[\([2]\)]])\) &]\  // 
      Length\)], "Input"],

Cell[BoxData[
    \(\(\(\ \ \)\(Length[
      Cases[data, {x_, y_\ } /; OddQ[y]\  && \ \ EvenQ[x]]\ ]\)\)\)], "Input"],

Cell[BoxData[
    \(\(\(\ \)\(Length[
      Cases[data, {x_, y_\ } /; EvenQ[y]\  && \ \ OddQ[x]]\ ]\)\)\)], "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 3: The Bohr Atom ", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Remarks and Outline", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Clear[\"Global`*\"];", "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection"],

Cell[BoxData[{
    \(\(coulomb = k\ \ \(Z\ e\^2\)\/r\^2;\)\), "\n", 
    \(\(force = m\ a;\)\), "\[IndentingNewLine]", 
    \(\(\(a = v\^2\/r;\)\(\n\)
    \)\), "\n", 
    \(eq1 = coulomb \[Equal] force\)}], "Input"],

Cell["angularMomentum = m v r;", "Input",
  AspectRatioFixed->True],

Cell["eq2=  angularMomentum == n \[HBar]", "Input",
  AspectRatioFixed->True],

Cell["rule1=Solve[{eq1,eq2},{v,r}] //First", "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(kineticEnergy = 1\/2\ m\ v\^2;\)\), "\n", 
    \(\(potentialEnergy = \(-\ k\) \(\(\ \)\(Z\ e\^2\)\)\/r;\)\), "\n", 
    \(totalEnergy = kineticEnergy + potentialEnergy\)}], "Input"],

Cell["energy[n_]= totalEnergy /.rule1 //Simplify", "Input",
  AspectRatioFixed->True],

Cell["Needs[\"Miscellaneous`PhysicalConstants`\"];", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(values = {\[IndentingNewLine]e \[Rule] 
            ElectronCharge, \[IndentingNewLine]m \[Rule] 
            ElectronMass, \[IndentingNewLine]k \[Rule] 
            1/\((4\ \[Pi]\ \[Epsilon]0)\), \[IndentingNewLine]\[Epsilon]0 \
\[Rule] VacuumPermittivity, \[IndentingNewLine]\[HBar] \[Rule] 
            PlanckConstantReduced, \[IndentingNewLine]Z \[Rule] 
            1};\)\)], "Input"],

Cell[BoxData[
    \(\(Needs["\<Miscellaneous`Units`\>"];\)\)], "Input"],

Cell["energyEV[n_]:= Convert[energy[n] //.values,ElectronVolt];", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(energyEV[1]\  // NumberForm[#, 3] &\)], "Input"],

Cell[BoxData[
    \(\(Plot[
        Table[\ energyEV[n]\/ElectronVolt, {n, 10}]\  // 
          Evaluate, \[IndentingNewLine]{x, 0, 
          1}, \[IndentingNewLine]PlotRange \[Rule] 
          All, \[IndentingNewLine]Axes \[Rule] {False, True}];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection"],

Cell[BoxData[
    \(eq3 = \[HBar]\ \[Omega] \[Equal] energy[n\_i] - energy[n\_f]\)], "Input"],

Cell[BoxData[
    \(\(Solve[eq3, \[Omega]]\  // First\)\  // Simplify\)], "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 4:  Relativistic Collision", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Remarks and Outline", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution:", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Clear[\"Global`*\"];", "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(p1 = m1\ \[Gamma]1\ {1, 0, 0, \[Beta]1};\)\), "\[IndentingNewLine]", 
    \(\(p2 = m2\ {1, 0, 0, 0};\)\)}], "Input"],

Cell[BoxData[
    \(\(p3 = m3\ \[Gamma]3\ {1, 0, 0, \[Beta]3};\)\)], "Input"],

Cell[BoxData[
    \(eq1 = p1 + p2 \[Equal] p3 // Thread\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"eq2", "=", " ", 
        FormBox[\({\[Gamma]3\^2 == 1\/\(1 - \[Beta]3\^2\), \[Gamma]1\^2 == 
              1\/\(1 - \[Beta]1\^2\)}\),
          "TraditionalForm"]}], ";"}]], "Input"],

Cell[BoxData[
    \(eq3 = Join[{eq1, eq2\ \ }]\  // Flatten\)], "Input"],

Cell[BoxData[
    \(sol = \(\(\(Solve[\ 
            eq3, {\[Beta]3, 
              m3\ }, {\[Gamma]3\ }\ ]\)[\([2]\)]\)\(//\)\(Simplify\)\(\ \
\)\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["2.6 Exercises ", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Exercise 1: Exploding Projectiles", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Exercise 2: Intersecting Trajectories (Shoot the Monkey)", \
"Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Exercise 3: Principle of Galilean Invariance", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Exercise 4: Elastic Collision", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Exercise 5: Projectile and Earth's Rotation", "Subsubsection"],

Cell["Exercise 6: Projectile Thrown up an Incline Plane", "Subsubsection"],

Cell["\<\
Exercise 7: Falling Object with Air Resistance as Observed  from \
the Rotating Earth\
\>", "Subsubsection"],

Cell["Exercise 8: Projectile Thrown up with Air Resistance", "Subsubsection"],

Cell["Exercise 9: Quadrupole ", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Exercise 10: Motion of a Charged Particle", "Subsubsection"],

Cell[TextData[{
  "Exercise 11:  ",
  Cell[BoxData[
      \(B\&\[RightVector]\)]],
  "  Field of a Spinning Disk   "
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]]
},
FrontEndVersion->"4.1 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
AutoGeneratedPackage->Automatic,
WindowToolbars->"EditBar",
CellGrouping->Manual,
WindowSize->{824, 688},
WindowMargins->{{0, Automatic}, {Automatic, 4}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowSelection->True,
ShowCellLabel->True,
ShowCellTags->False,
SpellingDictionaries->{"CorrectWords"->{
  "sol", "xf", "tf", "zf", "values1", "coord1", "discretept", "plot1", "tf.", 
    "initial2", "dsol2", "eq2", "tsol", "values2", "coord2", "plot2", "xo", 
    "posx", "eq1", "terminalv", "vsol", "zff", "vff", "vb", "zb", "vs.", 
    "coordz", "plotz", "blist", "text", "coordv", "plotv", "blistv", "textv", 
    "zb.", "dataPoint", "data", "dataplot", "fit", "ii.", "vup", "zup", 
    "Crule", "ttop", "eqdown", "c2rule", "c1rule", "vdown", "zdown", "tl", 
    "ve", "pf", "dv", "dp", "g", "svars", "series1", "term", "series2", 
    "exact2", "which", "position", "ven", "jup", "ura", "nep", "plu", "yrs", 
    "Kepler's", "mer", "Tosec", "kepler", "rlist", "pt1", "points", 
    "noninertial", "plot", "expsol", "fgravity", "ftension", "acc", "eq", 
    "hpconst", "appeqMotion", "appeq", "tmax.", "ptpend", "dq", "dV", 
    "diskPotential", "Edisk", "Eplane", "and", "Gaussis", "Eoutside", 
    "Einside", "totalCharge", "where", "medium1", "potoutside", "potinside", 
    "potential", "p2", "pot", "we", "potPlot", "ePlot", "ePlot3D", "point", 
    "potPlot3D", "p1", "Acylind", "Bcylind", "vel", "eqmotion", "solz", 
    "initial", "solxy", "Fy", "Fz", "Ey", "Ez", "Bx", "Bz", "qsol", 
    "fourierdata", "eq3", "freqrule", "current", "values", "ni", "nf", "px", 
    "py", "pz", "p3", "dsol1"}},
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
Magnification->1
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "S6.9.1"->{
    Cell[16334, 519, 71, 1, 27, "Input",
      CellTags->"S6.9.1"]},
  "S5.65.1"->{
    Cell[29727, 985, 105, 4, 42, "Input",
      CellTags->"S5.65.1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"S6.9.1", 72377, 2413},
  {"S5.65.1", 72461, 2416}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 116, 2, 42, "Subsubsection"],
Cell[1846, 56, 1886, 33, 657, "Input",
  Evaluatable->False]
}, Closed]],
Cell[3747, 92, 83, 2, 78, "Title",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[3855, 98, 86, 2, 60, "Section",
  Evaluatable->False],
Cell[3944, 102, 124, 2, 43, "Input"]
}, Closed]],
Cell[4083, 107, 177, 6, 40, "Section",
  Evaluatable->False],
Cell[4263, 115, 72, 0, 45, "Subsection"],

Cell[CellGroupData[{
Cell[4360, 119, 98, 2, 45, "Subsection",
  Evaluatable->False],
Cell[4461, 123, 44, 0, 42, "Subsubsection"],

Cell[CellGroupData[{
Cell[4530, 127, 91, 2, 28, "Subsubsection",
  Evaluatable->False],
Cell[4624, 131, 63, 1, 27, "Input"],
Cell[4690, 134, 95, 5, 57, "Input"],
Cell[4788, 141, 79, 1, 27, "Input"],
Cell[4870, 144, 88, 1, 27, "Input"],
Cell[4961, 147, 131, 3, 27, "Input",
  Evaluatable->False],
Cell[5095, 152, 274, 5, 75, "Input"],
Cell[5372, 159, 78, 1, 27, "Input"],
Cell[5453, 162, 71, 1, 27, "Input"],
Cell[5527, 165, 45, 1, 27, "Input"],
Cell[5575, 168, 72, 1, 27, "Input"],
Cell[5650, 171, 66, 1, 27, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[5765, 178, 124, 2, 29, "Subsection",
  Evaluatable->False],
Cell[5892, 182, 93, 2, 42, "Subsubsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[6010, 188, 91, 2, 28, "Subsubsection",
  Evaluatable->False],
Cell[6104, 192, 63, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[6192, 197, 31, 0, 42, "Subsubsection"],
Cell[6226, 199, 79, 1, 27, "Input"],
Cell[6308, 202, 92, 1, 27, "Input"],
Cell[6403, 205, 100, 1, 27, "Input"],
Cell[6506, 208, 65, 1, 27, "Input"],
Cell[6574, 211, 65, 1, 27, "Input"],
Cell[6642, 214, 93, 1, 27, "Input"],
Cell[6738, 217, 88, 1, 27, "Input"],
Cell[6829, 220, 87, 1, 27, "Input"],
Cell[6919, 223, 310, 7, 75, "Input"],
Cell[7232, 232, 606, 10, 123, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[7875, 247, 31, 0, 42, "Subsubsection"],
Cell[7909, 249, 131, 4, 27, "Input"],
Cell[8043, 255, 93, 1, 27, "Input"],
Cell[8139, 258, 72, 1, 27, "Input"],
Cell[8214, 261, 76, 1, 27, "Input"],
Cell[8293, 264, 71, 1, 27, "Input"],
Cell[8367, 267, 80, 1, 27, "Input"],
Cell[8450, 270, 71, 1, 27, "Input"],
Cell[8524, 273, 102, 3, 27, "Input"],
Cell[8629, 278, 349, 7, 75, "Input"],
Cell[8981, 287, 808, 13, 139, "Input"]
}, Closed]]
}, Closed]],
Cell[9816, 304, 91, 1, 27, "Input"],
Cell[9910, 307, 63, 1, 27, "Input"],
Cell[9976, 310, 64, 1, 27, "Input"],
Cell[10043, 313, 136, 3, 42, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[10216, 321, 105, 2, 29, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[10346, 327, 33, 0, 42, "Subsubsection"],
Cell[10382, 329, 63, 1, 27, "Input"],
Cell[10448, 332, 381, 7, 94, "Input"],
Cell[10832, 341, 72, 1, 27, "Input"],
Cell[10907, 344, 72, 1, 27, "Input"],
Cell[10982, 347, 144, 3, 27, "Input"],
Cell[11129, 352, 105, 2, 27, "Input"],
Cell[11237, 356, 105, 2, 27, "Input"],
Cell[11345, 360, 207, 4, 27, "Input"],
Cell[11555, 366, 373, 7, 91, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[11977, 379, 141, 5, 29, "Subsection",
  Evaluatable->False],
Cell[12121, 386, 93, 2, 42, "Subsubsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[12239, 392, 81, 2, 28, "Subsubsection",
  Evaluatable->False],
Cell[12323, 396, 63, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[12411, 401, 31, 0, 42, "Subsubsection"],
Cell[12445, 403, 110, 2, 27, "Input"],
Cell[12558, 407, 88, 1, 27, "Input"],
Cell[12649, 410, 139, 2, 27, "Input"],
Cell[12791, 414, 64, 1, 27, "Input"],
Cell[12858, 417, 139, 3, 27, "Input"],
Cell[13000, 422, 80, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[13117, 428, 31, 0, 42, "Subsubsection"],
Cell[13151, 430, 89, 1, 27, "Input"],
Cell[13243, 433, 69, 1, 27, "Input"],
Cell[13315, 436, 67, 1, 27, "Input"],
Cell[13385, 439, 301, 6, 75, "Input"],
Cell[13689, 447, 175, 4, 43, "Input"],
Cell[13867, 453, 431, 7, 91, "Input"],
Cell[14301, 462, 417, 7, 123, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[14755, 474, 31, 0, 42, "Subsubsection"],
Cell[14789, 476, 69, 1, 27, "Input"],
Cell[14861, 479, 67, 1, 27, "Input"],
Cell[14931, 482, 301, 6, 75, "Input"],
Cell[15235, 490, 175, 4, 43, "Input"],
Cell[15413, 496, 431, 7, 91, "Input"],
Cell[15847, 505, 416, 7, 123, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[16300, 517, 31, 0, 42, "Subsubsection"],
Cell[16334, 519, 71, 1, 27, "Input",
  CellTags->"S6.9.1"],
Cell[16408, 522, 184, 4, 59, "Input"],
Cell[16595, 528, 281, 5, 59, "Input"],
Cell[16879, 535, 60, 1, 27, "Input"],
Cell[16942, 538, 72, 2, 27, "Input",
  Evaluatable->False],
Cell[17017, 542, 145, 4, 27, "Input"],
Cell[17165, 548, 258, 5, 43, "Input"],
Cell[17426, 555, 124, 2, 27, "Input"],
Cell[17553, 559, 358, 7, 107, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[17972, 573, 144, 5, 29, "Subsection",
  Evaluatable->False],
Cell[18119, 580, 93, 2, 42, "Subsubsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[18237, 586, 81, 2, 28, "Subsubsection",
  Evaluatable->False],
Cell[18321, 590, 63, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[18409, 595, 31, 0, 42, "Subsubsection"],
Cell[18443, 597, 139, 3, 31, "Input"],
Cell[18585, 602, 149, 2, 27, "Input"],
Cell[18737, 606, 435, 12, 27, "Input"],
Cell[19175, 620, 64, 1, 27, "Input"],
Cell[19242, 623, 141, 3, 27, "Input"],
Cell[19386, 628, 78, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[19501, 634, 31, 0, 42, "Subsubsection"],
Cell[19535, 636, 166, 3, 27, "Input"],
Cell[19704, 641, 445, 12, 27, "Input"],
Cell[20152, 655, 68, 1, 27, "Input"],
Cell[20223, 658, 145, 3, 27, "Input"],
Cell[20371, 663, 88, 1, 27, "Input"]
}, Closed]],
Cell[20474, 667, 143, 3, 55, "Input"],

Cell[CellGroupData[{
Cell[20642, 674, 31, 0, 42, "Subsubsection"],
Cell[20676, 676, 140, 2, 27, "Input"],
Cell[20819, 680, 106, 2, 27, "Input"],
Cell[20928, 684, 82, 1, 27, "Input"],
Cell[21013, 687, 275, 6, 43, "Input"],
Cell[21291, 695, 199, 4, 43, "Input"],
Cell[21493, 701, 169, 3, 43, "Input"],
Cell[21665, 706, 169, 3, 43, "Input"],
Cell[21837, 711, 68, 1, 27, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[21966, 719, 108, 2, 29, "Subsection",
  Evaluatable->False],
Cell[22077, 723, 93, 2, 42, "Subsubsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[22195, 729, 88, 2, 28, "Subsubsection",
  Evaluatable->False],
Cell[22286, 733, 63, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[22374, 738, 31, 0, 42, "Subsubsection"],
Cell[22408, 740, 139, 5, 42, "Input"],
Cell[22550, 747, 153, 2, 43, "Input"],
Cell[22706, 751, 100, 3, 27, "Input"],
Cell[22809, 756, 104, 2, 27, "Input"],
Cell[22916, 760, 87, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[23040, 766, 88, 4, 42, "Subsubsection"],
Cell[23131, 772, 144, 3, 27, "Input"],
Cell[23278, 777, 63, 1, 27, "Input"],
Cell[23344, 780, 146, 2, 27, "Input"],
Cell[23493, 784, 163, 3, 27, "Input"],
Cell[23659, 789, 69, 1, 27, "Input"],
Cell[23731, 792, 101, 3, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[23869, 800, 88, 4, 42, "Subsubsection"],
Cell[23960, 806, 118, 2, 27, "Input"],
Cell[24081, 810, 73, 1, 27, "Input"],
Cell[24157, 813, 376, 7, 107, "Input"],
Cell[24536, 822, 199, 4, 43, "Input"],
Cell[24738, 828, 473, 8, 123, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[25248, 841, 88, 4, 42, "Subsubsection"],
Cell[25339, 847, 148, 3, 43, "Input"],
Cell[25490, 852, 145, 2, 27, "Input"],
Cell[25638, 856, 110, 2, 27, "Input"],
Cell[25751, 860, 85, 1, 27, "Input"],
Cell[25839, 863, 113, 2, 27, "Input"],
Cell[25955, 867, 133, 3, 52, "Input"],
Cell[26091, 872, 141, 5, 57, "Input"],
Cell[26235, 879, 137, 2, 27, "Input"],
Cell[26375, 883, 242, 4, 91, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[26678, 894, 97, 2, 29, "Subsection",
  Evaluatable->False],
Cell[26778, 898, 93, 2, 42, "Subsubsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[26896, 904, 33, 0, 28, "Subsubsection"],
Cell[26932, 906, 63, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[27020, 911, 31, 0, 42, "Subsubsection"],
Cell[27054, 913, 2080, 50, 171, "Input"],
Cell[29137, 965, 126, 2, 27, "Input"],
Cell[29266, 969, 174, 3, 27, "Input"],
Cell[29443, 974, 146, 3, 27, "Input"],
Cell[29592, 979, 90, 1, 27, "Input"],
Cell[29685, 982, 39, 1, 27, "Input"],
Cell[29727, 985, 105, 4, 42, "Input",
  CellTags->"S5.65.1"],
Cell[29835, 991, 411, 6, 116, "Input"],
Cell[30249, 999, 184, 3, 46, "Input"],
Cell[30436, 1004, 173, 3, 44, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[30646, 1012, 80, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[30729, 1016, 211, 3, 48, "Input"],
Cell[30943, 1021, 154, 4, 41, "Input"],
Cell[31100, 1027, 206, 4, 27, "Input"],
Cell[31309, 1033, 222, 5, 27, "Input"],
Cell[31534, 1040, 73, 1, 27, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],
Cell[31646, 1046, 110, 2, 40, "Section",
  Evaluatable->False],
Cell[31759, 1050, 72, 0, 45, "Subsection"],

Cell[CellGroupData[{
Cell[31856, 1054, 147, 5, 45, "Subsection",
  Evaluatable->False],
Cell[32006, 1061, 92, 2, 42, "Subsubsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[32123, 1067, 81, 2, 28, "Subsubsection",
  Evaluatable->False],
Cell[32207, 1071, 63, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[32295, 1076, 32, 0, 42, "Subsubsection"],
Cell[32330, 1078, 191, 3, 43, "Input"],
Cell[32524, 1083, 105, 2, 27, "Input"],
Cell[32632, 1087, 112, 2, 27, "Input"],
Cell[32747, 1091, 135, 2, 27, "Input"],
Cell[32885, 1095, 69, 1, 27, "Input"],
Cell[32957, 1098, 125, 3, 27, "Input"],
Cell[33085, 1103, 141, 3, 27, "Input"],
Cell[33229, 1108, 48, 1, 27, "Input"],
Cell[33280, 1111, 203, 3, 43, "Input"],
Cell[33486, 1116, 193, 3, 43, "Input"],
Cell[33682, 1121, 84, 1, 27, "Input"],
Cell[33769, 1124, 182, 4, 43, "Input"],
Cell[33954, 1130, 823, 16, 123, "Input"],
Cell[34780, 1148, 113, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[34930, 1155, 31, 0, 42, "Subsubsection"],
Cell[34964, 1157, 125, 3, 27, "Input"],
Cell[35092, 1162, 144, 3, 27, "Input"],
Cell[35239, 1167, 124, 2, 27, "Input"],
Cell[35366, 1171, 93, 1, 27, "Input"],
Cell[35462, 1174, 103, 2, 27, "Input"],
Cell[35568, 1178, 219, 5, 59, "Input"],
Cell[35790, 1185, 230, 5, 43, "Input"],
Cell[36023, 1192, 370, 6, 107, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[36430, 1203, 31, 0, 42, "Subsubsection"],
Cell[36464, 1205, 146, 3, 27, "Input"],
Cell[36613, 1210, 128, 2, 27, "Input"],
Cell[36744, 1214, 105, 2, 27, "Input"],
Cell[36852, 1218, 118, 2, 27, "Input"],
Cell[36973, 1222, 397, 7, 107, "Input"],
Cell[37373, 1231, 596, 11, 139, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[38030, 1249, 103, 2, 29, "Subsection",
  Evaluatable->False],
Cell[38136, 1253, 92, 2, 42, "Subsubsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[38253, 1259, 81, 2, 28, "Subsubsection",
  Evaluatable->False],
Cell[38337, 1263, 63, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[38425, 1268, 31, 0, 42, "Subsubsection"],
Cell[38459, 1270, 191, 3, 43, "Input"],
Cell[38653, 1275, 105, 2, 27, "Input"],
Cell[38761, 1279, 112, 2, 27, "Input"],
Cell[38876, 1283, 135, 2, 27, "Input"],
Cell[39014, 1287, 228, 4, 59, "Input"],
Cell[39245, 1293, 163, 4, 27, "Input"],
Cell[39411, 1299, 137, 3, 27, "Input"],
Cell[39551, 1304, 82, 1, 27, "Input"],
Cell[39636, 1307, 117, 2, 31, "Input"],
Cell[39756, 1311, 147, 3, 27, "Input"],
Cell[39906, 1316, 92, 1, 31, "Input"],
Cell[40001, 1319, 107, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[40145, 1326, 31, 0, 42, "Subsubsection"],
Cell[40179, 1328, 81, 1, 27, "Input"],
Cell[40263, 1331, 78, 1, 27, "Input"],
Cell[40344, 1334, 105, 2, 27, "Input"],
Cell[40452, 1338, 135, 3, 27, "Input"],
Cell[40590, 1343, 91, 1, 27, "Input"],
Cell[40684, 1346, 90, 1, 27, "Input"],
Cell[40777, 1349, 296, 4, 107, "Input"],
Cell[41076, 1355, 104, 2, 27, "Input"],
Cell[41183, 1359, 89, 1, 27, "Input"],
Cell[41275, 1362, 52, 1, 27, "Input"],
Cell[41330, 1365, 115, 2, 44, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[41482, 1372, 31, 0, 42, "Subsubsection"],
Cell[41516, 1374, 171, 3, 27, "Input"],
Cell[41690, 1379, 506, 9, 107, "Input"],
Cell[42199, 1390, 45, 1, 27, "Input"],
Cell[42247, 1393, 49, 1, 27, "Input"],
Cell[42299, 1396, 68, 1, 27, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],
Cell[42406, 1402, 97, 2, 40, "Section",
  Evaluatable->False],
Cell[42506, 1406, 112, 2, 45, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[42643, 1412, 96, 2, 45, "Subsection",
  Evaluatable->False],
Cell[42742, 1416, 44, 0, 42, "Subsubsection"],

Cell[CellGroupData[{
Cell[42811, 1420, 33, 0, 28, "Subsubsection"],
Cell[42847, 1422, 37, 0, 27, "Input"],

Cell[CellGroupData[{
Cell[42909, 1426, 31, 0, 42, "Subsubsection"],
Cell[42943, 1428, 67, 1, 49, "Input"],
Cell[43013, 1431, 70, 1, 27, "Input"],
Cell[43086, 1434, 39, 1, 44, "Input"],
Cell[43128, 1437, 103, 2, 44, "Input"],
Cell[43234, 1441, 53, 0, 27, "Input"],
Cell[43290, 1443, 85, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[43412, 1449, 31, 0, 42, "Subsubsection"],
Cell[43446, 1451, 77, 1, 27, "Input"]
}, Closed]]
}, Closed]],
Cell[43550, 1456, 87, 1, 46, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[43674, 1462, 106, 2, 29, "Subsection",
  Evaluatable->False],
Cell[43783, 1466, 92, 2, 42, "Subsubsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[43900, 1472, 81, 2, 28, "Subsubsection",
  Evaluatable->False],
Cell[43984, 1476, 63, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[44072, 1481, 31, 0, 42, "Subsubsection"],
Cell[44106, 1483, 251, 4, 67, "Input"],
Cell[44360, 1489, 180, 3, 84, "Input"],
Cell[44543, 1494, 81, 1, 27, "Input"],
Cell[44627, 1497, 237, 5, 27, "Input"],
Cell[44867, 1504, 78, 1, 31, "Input"],
Cell[44948, 1507, 256, 5, 43, "Input"],
Cell[45207, 1514, 437, 6, 171, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[45681, 1525, 31, 0, 42, "Subsubsection"],
Cell[45715, 1527, 109, 2, 27, "Input"],
Cell[45827, 1531, 123, 2, 27, "Input"],
Cell[45953, 1535, 187, 8, 24, "Special5",
  Evaluatable->False],
Cell[46143, 1545, 82, 1, 27, "Input"],
Cell[46228, 1548, 105, 2, 31, "Input"],
Cell[46336, 1552, 468, 7, 187, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[46841, 1564, 31, 0, 42, "Subsubsection"],
Cell[46875, 1566, 293, 6, 53, "Input"],
Cell[47171, 1574, 377, 8, 91, "Input"],
Cell[47551, 1584, 141, 5, 27, "Input"],
Cell[47695, 1591, 239, 4, 59, "Input"],
Cell[47937, 1597, 109, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[48083, 1604, 31, 0, 42, "Subsubsection"],
Cell[48117, 1606, 72, 1, 27, "Input"],
Cell[48192, 1609, 326, 5, 91, "Input"],
Cell[48521, 1616, 153, 2, 27, "Input"],
Cell[48677, 1620, 316, 5, 91, "Input"],
Cell[48996, 1627, 273, 5, 91, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[49330, 1639, 100, 2, 29, "Subsection",
  Evaluatable->False],
Cell[49433, 1643, 92, 2, 42, "Subsubsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[49550, 1649, 82, 2, 28, "Subsubsection",
  Evaluatable->False],
Cell[49635, 1653, 63, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[49723, 1658, 31, 0, 42, "Subsubsection"],
Cell[49757, 1660, 126, 2, 48, "Input"],
Cell[49886, 1664, 130, 2, 27, "Input"],
Cell[50019, 1668, 475, 9, 123, "Input"],
Cell[50497, 1679, 72, 1, 27, "Input"],
Cell[50572, 1682, 556, 9, 155, "Input"],
Cell[51131, 1693, 74, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[51242, 1699, 31, 0, 42, "Subsubsection"],
Cell[51276, 1701, 75, 1, 27, "Input"],
Cell[51354, 1704, 161, 4, 27, "Input"],
Cell[51518, 1710, 74, 1, 27, "Input"],
Cell[51595, 1713, 116, 2, 27, "Input"],
Cell[51714, 1717, 108, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[51859, 1724, 31, 0, 42, "Subsubsection"],
Cell[51893, 1726, 268, 5, 27, "Input"],
Cell[52164, 1733, 499, 8, 155, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[52724, 1748, 141, 5, 29, "Subsection",
  Evaluatable->False],
Cell[52868, 1755, 92, 2, 42, "Subsubsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[52985, 1761, 81, 2, 28, "Subsubsection",
  Evaluatable->False],
Cell[53069, 1765, 63, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[53157, 1770, 31, 0, 42, "Subsubsection"],
Cell[53191, 1772, 119, 2, 49, "Input"],
Cell[53313, 1776, 78, 1, 36, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[53428, 1782, 31, 0, 42, "Subsubsection"],
Cell[53462, 1784, 214, 4, 59, "Input"],
Cell[53679, 1790, 107, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[53823, 1797, 31, 0, 42, "Subsubsection"],
Cell[53857, 1799, 72, 1, 27, "Input"],
Cell[53932, 1802, 593, 10, 171, "Input"],
Cell[54528, 1814, 563, 10, 171, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[55128, 1829, 31, 0, 42, "Subsubsection"],
Cell[55162, 1831, 80, 1, 27, "Input"],
Cell[55245, 1834, 147, 3, 27, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[55453, 1844, 94, 3, 29, "Subsection"],

Cell[CellGroupData[{
Cell[55572, 1851, 33, 0, 42, "Subsubsection"],
Cell[55608, 1853, 63, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[55696, 1858, 31, 0, 42, "Subsubsection"],
Cell[55730, 1860, 264, 5, 59, "Input"],
Cell[55997, 1867, 148, 3, 27, "Input"],
Cell[56148, 1872, 73, 1, 27, "Input"],
Cell[56224, 1875, 267, 4, 75, "Input"],
Cell[56494, 1881, 137, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[56668, 1888, 31, 0, 42, "Subsubsection"],
Cell[56702, 1890, 157, 2, 27, "Input"],
Cell[56862, 1894, 271, 5, 59, "Input"],
Cell[57136, 1901, 426, 8, 123, "Input"],
Cell[57565, 1911, 66, 1, 27, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[57692, 1919, 118, 3, 29, "Subsection"],

Cell[CellGroupData[{
Cell[57835, 1926, 33, 0, 42, "Subsubsection"],
Cell[57871, 1928, 63, 1, 27, "Input"],
Cell[57937, 1931, 245, 4, 75, "Input"],
Cell[58185, 1937, 60, 1, 27, "Input"],
Cell[58248, 1940, 163, 4, 43, "Input"],
Cell[58414, 1946, 261, 4, 75, "Input"],
Cell[58678, 1952, 180, 4, 27, "Input"],
Cell[58861, 1958, 67, 1, 27, "Input"],
Cell[58931, 1961, 116, 2, 27, "Input"],
Cell[59050, 1965, 125, 2, 27, "Input"],
Cell[59178, 1969, 109, 2, 27, "Input"],
Cell[59290, 1973, 102, 2, 27, "Input"],
Cell[59395, 1977, 102, 2, 27, "Input"],
Cell[59500, 1981, 354, 7, 75, "Input"],
Cell[59857, 1990, 92, 1, 27, "Input"],
Cell[59952, 1993, 78, 1, 27, "Input"]
}, Closed]]
}, Closed]],
Cell[60057, 1998, 152, 6, 40, "Section",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[60234, 2008, 95, 2, 45, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[60354, 2014, 81, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[60438, 2018, 63, 1, 27, "Input"],
Cell[60504, 2021, 73, 1, 27, "Input"],
Cell[60580, 2024, 71, 1, 27, "Input"],
Cell[60654, 2027, 68, 1, 27, "Input"],
Cell[60725, 2030, 69, 1, 27, "Input"],
Cell[60797, 2033, 90, 1, 27, "Input"],
Cell[60890, 2036, 67, 1, 27, "Input"],
Cell[60960, 2039, 64, 1, 27, "Input"],
Cell[61027, 2042, 126, 3, 27, "Input"],
Cell[61156, 2047, 276, 5, 75, "Input"],
Cell[61435, 2054, 692, 13, 171, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[62176, 2073, 49, 0, 29, "Subsection"],

Cell[CellGroupData[{
Cell[62250, 2077, 33, 0, 42, "Subsubsection"],
Cell[62286, 2079, 63, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[62374, 2084, 31, 0, 42, "Subsubsection"],
Cell[62408, 2086, 77, 1, 27, "Input"],
Cell[62488, 2089, 55, 1, 27, "Input"],
Cell[62546, 2092, 132, 3, 27, "Input",
  Evaluatable->False],
Cell[62681, 2097, 87, 1, 27, "Input"],
Cell[62771, 2100, 51, 1, 27, "Input"],
Cell[62825, 2103, 49, 1, 27, "Input"],
Cell[62877, 2106, 56, 1, 27, "Input"],
Cell[62936, 2109, 58, 1, 27, "Input"],
Cell[62997, 2112, 249, 5, 43, "Input"],
Cell[63249, 2119, 170, 4, 59, "Input"],
Cell[63422, 2125, 303, 6, 91, "Input"],
Cell[63728, 2133, 128, 3, 27, "Input"],
Cell[63859, 2138, 504, 10, 139, "Input"],
Cell[64366, 2150, 89, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[64492, 2156, 31, 0, 42, "Subsubsection"],
Cell[64526, 2158, 104, 2, 27, "Input"],
Cell[64633, 2162, 116, 2, 27, "Input"],
Cell[64752, 2166, 118, 2, 27, "Input"],
Cell[64873, 2170, 118, 2, 27, "Input"],
Cell[64994, 2174, 116, 2, 27, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[65171, 2183, 95, 2, 29, "Subsection",
  Evaluatable->False],
Cell[65269, 2187, 92, 2, 42, "Subsubsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[65386, 2193, 81, 2, 28, "Subsubsection",
  Evaluatable->False],
Cell[65470, 2197, 63, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[65558, 2202, 31, 0, 42, "Subsubsection"],
Cell[65592, 2204, 216, 5, 135, "Input"],
Cell[65811, 2211, 67, 1, 27, "Input"],
Cell[65881, 2214, 77, 1, 27, "Input"],
Cell[65961, 2217, 79, 1, 27, "Input"],
Cell[66043, 2220, 204, 3, 100, "Input"],
Cell[66250, 2225, 85, 1, 27, "Input"],
Cell[66338, 2228, 87, 1, 27, "Input"],
Cell[66428, 2231, 411, 7, 123, "Input"],
Cell[66842, 2240, 71, 1, 27, "Input"],
Cell[66916, 2243, 100, 1, 27, "Input"],
Cell[67019, 2246, 68, 1, 27, "Input"],
Cell[67090, 2249, 262, 5, 96, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[67389, 2259, 31, 0, 42, "Subsubsection"],
Cell[67423, 2261, 93, 1, 27, "Input"],
Cell[67519, 2264, 82, 1, 27, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[67662, 2272, 104, 2, 29, "Subsection",
  Evaluatable->False],
Cell[67769, 2276, 92, 2, 42, "Subsubsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[67886, 2282, 82, 2, 28, "Subsubsection",
  Evaluatable->False],
Cell[67971, 2286, 63, 1, 27, "Input"],
Cell[68037, 2289, 139, 2, 43, "Input"],
Cell[68179, 2293, 77, 1, 27, "Input"],
Cell[68259, 2296, 68, 1, 27, "Input"],
Cell[68330, 2299, 224, 5, 47, "Input"],
Cell[68557, 2306, 72, 1, 27, "Input"],
Cell[68632, 2309, 161, 4, 27, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[68842, 2319, 81, 2, 40, "Section",
  Evaluatable->False],
Cell[68926, 2323, 106, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[69035, 2327, 131, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[69169, 2332, 117, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[69289, 2336, 102, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[69394, 2340, 68, 0, 42, "Subsubsection"],
Cell[69465, 2342, 74, 0, 42, "Subsubsection"],
Cell[69542, 2344, 118, 3, 42, "Subsubsection"],
Cell[69663, 2349, 77, 0, 42, "Subsubsection"],
Cell[69743, 2351, 96, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[69842, 2355, 66, 0, 42, "Subsubsection"],
Cell[69911, 2357, 185, 7, 44, "Subsubsection",
  Evaluatable->False]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

