(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     90623,       3066]*)
(*NotebookOutlinePosition[     91320,       3091]*)
(*  CellTagsIndexPosition[     91276,       3087]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Legal Notice, Disclaimer, and Book Ordering Information:", \
"Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "(* Legal Notice, Disclaimer, and Book Ordering Information:\n\nLast \
Modified: FIO June 8, 2002\n\n",
  StyleBox["Mathematica For Physics: 2nd Edition",
    FontColor->RGBColor[1, 0, 0]],
  "\n\nRobert L. Zimmerman and Fredrick I. Olness\n",
  "\nWebSite:  \n",
  StyleBox["  www.physics.smu.edu/~olness\n  darkwing.uoregon.edu/~phys600/\n\
\n",
    FontColor->RGBColor[1, 0, 0]],
  "MathSource Number: 0206-862",
  StyleBox["\n",
    FontColor->RGBColor[1, 0, 0]],
  "\nISBN 0-201-53796-6\nFor ordering information, call 1-800-282-0693\n\
Addison-Wesley Publishing Company\n",
  "\nCommunication with the authors:\nFredrick I. Olness:  \
olness@mail.physics.smu.edu\nRobert L. Zimmerman: bob@zim.uoregon.edu\n\n\
Copyright 2002, Addison-Wesley Publishing Company, Inc. The material in\nthis \
file may be distributed freely  so long as the content remains\nunchanged, \
and the copyright and  reference notices are included. The\npublisher grants \
permission for the noncommercial use of these programs\nand program segments. \
 All other uses require the prior written consent\nof the publisher.    \n\n\
All rights are reserved with regard to the  material in the\n\"Mathematica \
For Physics\" text, and may not be reproduced, stored in a\nretrieval system, \
or transmitted,  in any form or by any means,\nelectronic, mechanical, \
photocopying,  recording, or otherwise, without\nthe prior written permission \
 of the publisher. \n\nThe programs and applications presented in this book \
have been included\nfor  their instructional value. They have been tested \
with care but are\nnot  guaranteed for any particular purpose. The publisher \
does not\noffer any  warranties or representations, nor does it accept any\n\
liabilities with  respect to the programs or applications. \n\n *)\n"
}], "Input",
  Evaluatable->False,
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell["\<\
Contains correction on:  
    2nd Edition:Chpt.6,Problem 6.2.6 p.334:Spring Pendulm. 
    2nd Edition: Chpt.6, Problem 6.3.3 p.174: Sphere Rolling on a Fixed \
Sphere.
(FIO, 17 Jan 2003)  

Contains correction on:  
    2nd Edition:Chpt.6,Problem 6.4.2 p.351: Nonlinear Oscillator  (FIO, 19 \
Apr 2004)  \
\>", "SmallText",
  FontColor->RGBColor[1, 0, 0]],

Cell["6. Lagrangians and Hamiltonians", "Title",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["6.1 Introduction    ", "Section",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Off[General::spell];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Off[General::spell1];\)\)}], "Input",
  Hyphenation->False]
}, Closed]],

Cell["6.2 Lagrangian Problems without Lagrange Multipliers", "Section",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["\<\
Overview of  Lagrangian Problems without Lagrange Multipliers\
\>", \
"Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Initialization for Lagrangian Problems", "Subsection"],

Cell[BoxData[
    \(Needs["\<Calculus`VariationalMethods`\>"]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(?EulerEquations\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(L = m/2\ \ \(x'\)[t]^2\  - k/2\ \ \(\(x[t]^2\)\(\ \ \ \)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(EulerEquations[L, x[t], t] // ExpandAll\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(?FirstIntegrals\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(FirstIntegrals[L, x[t], t] // ExpandAll\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 1: Particle Sliding on a Movable Incline", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part a  ", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[{
    RowBox[{
      RowBox[{"T", "=", 
        RowBox[{
          RowBox[{\(1\/2\), " ", "M", " ", 
            SuperscriptBox[
              RowBox[{
                SuperscriptBox["x1", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
          RowBox[{\(1\/2\), " ", "m", " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                      MultilineFunction->None], "[", "t", "]"}], "2"], "+", 
                SuperscriptBox[
                  RowBox[{
                    SuperscriptBox["y", "\[Prime]",
                      MultilineFunction->None], "[", "t", "]"}], "2"]}], 
              ")"}]}]}]}], 
      ";"}], "\[IndentingNewLine]", \(V = m\ g\ y[t];\)}], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(change = {x \[Rule] \((\((x1[#] + \((L0 - s[#])\) 
                      Cos[\[Theta]])\) &)\), \ \ \ \[IndentingNewLine]\ \ \ \ \
\ \ \ \ \ \ \ \ \ y \[Rule] \((\((\((L0 - 
                        s[#])\)\ Sin[\[Theta]])\) &)\)};\)\)], "Input",
  Hyphenation->False],

Cell["  L=T-V /.change //Simplify ", "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eq1 = EulerEquations[L, {x1[t], s[t]}, t]\)], "Input",
  Hyphenation->False],

Cell[" eqMotion=Solve[eq1, {x1''[t],s''[t]}] //Flatten   ", "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(xmomentum = 
      M\ \(x1'\)[t] + m\ \(x'\)[t] /. change\  // Simplify\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(D[xmomentum, t]\  /. eqMotion // Simplify\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(energy = T + V /. change // Simplify\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(D[energy, t] /. change\) /. eqMotion // Simplify\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(\ \)\(FirstIntegrals[L, {x1[t], s[t]}, t]\)\(\ \)\)\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c ", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(Sol = \(DSolve[\[IndentingNewLine]{\((\ 
                  eqMotion /. Rule \[Rule] Equal)\), \[IndentingNewLine]s[
                    0] \[Equal] 0, \(s'\)[0] == 0, 
                x1[0] == 0, \(x1'\)[0] == 0} // Flatten, {x1[t], s[t]}, 
            t\ \ ] // Simplify\)\  // Flatten\)], "Input"],

Cell[BoxData[
    \(\((\(\((\(\((s[t]\  /. Sol)\)\ \  \[Equal] L0\  // 
                  Simplify\)\[IndentingNewLine] // 
                Solve[# /. t^2 \[Rule] x, x] &\[IndentingNewLine])\) /. 
            x \[Rule] t^2\  // Flatten\)\ \  // FullSimplify\ )\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 2: Bead Sliding on a Rotating Wire   ", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Remarks and outline", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part a ", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(x2rRule = {x, y, 
              z} \[Rule] {\((r[#]\ Sin[\[Theta]] 
                    Cos[\[Omega]\ #])\) &, \((r[#]\ Sin[\[Theta]] 
                    Sin[\[Omega]\ #])\) &, \((r[#]\ Cos[\[Theta]])\) &} // 
          Thread;\)\)], "Input"],

Cell[BoxData[
    \(\(\[Psi]Rule = \[Theta] \[Rule] \ \((\[Pi] - \[Psi])\)\ ;\)\)], "Input",\

  Hyphenation->False],

Cell[BoxData[{
    RowBox[{
      RowBox[{"T", "=", 
        RowBox[{\(1\/2\), " ", "m", " ", 
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                RowBox[{
                  SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"], "+", 
              SuperscriptBox[
                RowBox[{
                  SuperscriptBox["y", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"], "+", 
              SuperscriptBox[
                RowBox[{
                  SuperscriptBox["z", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], 
            ")"}]}]}], 
      ";"}], "\[IndentingNewLine]", \(V = 
        m\ g\ z[t];\), "\[IndentingNewLine]", \(L = \(T - V\  /. 
            x2rRule\)\  /. \[Psi]Rule\  // Simplify\)}], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eq1 = EulerEquations[L, r[t], t]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(rSol = \((\ \(Solve[eq1, \(r''\)[t]]\)[\([1, 1]\)] // ExpandAll\ )\) //. 
        Rule \[Rule] Equal\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eq2 = \ \(\(\(DSolve[\ {rSol, 
                  r[0] \[Equal] 0, \(r'\)[0] \[Equal] v0}\ , r[t], t]\)[\([1, 
                1]\)]\  // Simplify\)\  // PowerExpand\)\ \  // 
        ExpandAll\)], "Input"],

Cell[BoxData[
    \(\(\(rRule\)\(=\)\(\ \)\(MapAt[\ Collect[#, {Exp[\(-x_\)]\ \ }]\  &, \ 
        eq2, \ 2]\)\(\ \)\)\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(tRule = \((\ \(\(Solve[Len \[Equal] r[t] /. rRule\ , t\ , 
                InverseFunctions \[Rule] True]\)[\([2]\)]\  // 
            Simplify\)\[IndentingNewLine] // 
          PowerExpand\ \[IndentingNewLine])\)\)], "Input"],

Cell[BoxData[
    \(\(\(Series[t /. tRule, {\[Psi], 0, 0}\ ]\  // 
        Normal\)\(//\)\(Simplify\)\(\ \)\)\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(values = {\[Psi] \[Rule] \[Pi]/13, g \[Rule] 1, \[Omega] \[Rule] 2, 
          v0 \[Rule] 0};\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(position = \(\(\({x[t], y[t], z[t]} //. x2rRule\) //. 
              rRule\) /. \[Psi]Rule\) //. values;\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(p1 = 
        ParametricPlot3D[
          position // Evaluate, {t, 0, 6}, \[IndentingNewLine]Boxed \[Rule] 
            True, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]BoxRatios \[Rule] {1, 1, 
              1}, \[IndentingNewLine]DisplayFunction \[Rule] 
            Identity];\)\)], "Input"],

Cell[BoxData[{
    \(\(discretePoints = 
        Table[position, {t, 0, 6, 0.5}];\)\), "\[IndentingNewLine]", 
    \(\(discreteGraphics = 
        Graphics3D[{PointSize[0.03], Point /@ discretePoints}];\)\)}], "Input",\

  Hyphenation->False],

Cell[BoxData[
    \(\(Show[discreteGraphics, p1, BoxRatios \[Rule] {1, 1, 1}];\)\)], "Input",\

  Hyphenation->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 3: Bead on a Rotating Hoop  ", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Remarks and outline", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(x2rRule = {x, y, 
              z} \[Rule] {\((r\ Sin[\[Theta][#]] 
                    Cos[\[Omega]\ #])\) &, \((r\ Sin[\[Theta][#]] 
                    Sin[\[Omega]\ #])\) &, \((r\ Cos[\[Theta][#]])\) &} // 
          Thread;\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(\ \ \ \ \ \ \)\(\[Psi]Rule = {\[Theta] \[Rule] \((\[Pi] - \ \
\[Psi][#] &\ )\)};\)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{"T", "=", 
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{\(1\/2\), " ", "m", " ", 
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{
                      SuperscriptBox["x", "\[Prime]",
                        MultilineFunction->None], "[", "t", "]"}], "2"], "+", 
                  
                  SuperscriptBox[
                    RowBox[{
                      SuperscriptBox["y", "\[Prime]",
                        MultilineFunction->None], "[", "t", "]"}], "2"], "+", 
                  
                  SuperscriptBox[
                    RowBox[{
                      SuperscriptBox["z", "\[Prime]",
                        MultilineFunction->None], "[", "t", "]"}], "2"]}], 
                ")"}]}], "//.", "x2rRule"}], " ", "/.", "\[Psi]Rule"}], "//", 
        "Simplify"}]}]], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(V = \(m\ g\ z[t] //. x2rRule\)\  /. \[Psi]Rule // Simplify\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(\ \ \)\(\(L\)\(=\)\((T - V)\)\(\ \)\)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eq1 = EulerEquations[L, \ \[Psi][t], t]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\[Psi]Sol = \ \(\(\((Solve[eq1, \(\[Psi]''\)[t]] // 
              Flatten)\) /. {g \[Rule] \[Omega]c\^2\ \
r}\)\(//\)\(ExpandAll\)\(\ \)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(energy = \((\(\[Psi]'\)[t]\ D[L, \(\[Psi]'\)[t]] - 
              L)\) /. {g \[Rule] \[Omega]c\^2\ r} // Simplify\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(D[energy, t] /. \[Psi]Sol\) /. {g \[Rule] \[Omega]c^2\ r}\ \  // 
      Simplify\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(\ \ \)\(FirstIntegrals[L, \ \[Psi][t], 
          t] /. {g \[Rule] \[Omega]c\^2\ r} // Simplify\)\)\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Veff = energy //. {\(\[Psi]'\)[t] \[Rule] 0} // ExpandAll\)], "Input"],

Cell["dVeff= D[Veff,\[Psi][t]]  ", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(\(sol\)\(=\)\(Solve[dVeff\  \[Equal] 0, \[Psi][t], 
        InverseFunctions \[Rule] True\ ]\)\(\ \)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(eqRule\)\(=\)\(Join[{{\[Psi][t] \[Rule] \[Pi]}}, 
        sol]\)\(\ \)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(dVeff \[Equal] 0 //. eqRule\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(values1 = {r \[Rule] 1, \ \[Omega]c \[Rule] 1, \ 
          m \[Rule] 1};\)\)], "Input"],

Cell[BoxData[
    \(\(Plot3D[
        Veff /. values1 // 
          Evaluate, \[IndentingNewLine]{\[Psi][
            t], \(-\[Pi]\), \[Pi]}, {\[Omega], 1, 
          3}, \[IndentingNewLine]ColorFunction \[Rule] 
          Hue\ , \[IndentingNewLine]Ticks \[Rule] {\[Pi]\ Range[\(-1\), 1, 
                1/2], Automatic, \ Automatic\ }];\)\)], "Input"],

Cell[BoxData[
    \(\(Plot[\(\((\(Veff //. 
                    values1\) /. \[Omega] \[Rule] #)\) &\)\ \  /@ \ \ {2, 
              0.2} // Evaluate, \[IndentingNewLine]{\[Psi][
            t], \(-\[Pi]\), \[Pi]}, \[IndentingNewLine]Ticks \[Rule] {{\ \ \
\(-\[Pi]\)\ \ , 0, \ \[Pi]}, 
            Automatic}, \[IndentingNewLine]Epilog \[Rule] \
{\[IndentingNewLine]Hue[ .6], AbsolutePointSize[6], 
            Map[Point, \ \(\({\ \[Psi][t]\ , Veff} /. eqRule\)\  /. 
                  values1\) /. \[Omega] \[Rule] 
                  2]\ }\[IndentingNewLine]];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(\(pt1 = \(ContourPlot[\ \(\(energy /. values1\) /. {m \[Rule] 2, 
                      r \[Rule] 1\ }\) /. \((\[Omega] \[Rule] #)\)\ \  // 
                Evaluate, \ {\[Psi][t], \(-4\) \[Pi], \ 
                4\ \ \[Pi]}, {\(\[Psi]'\)[t], \(-3\), 
                3}\ , \ \[IndentingNewLine]FrameTicks \[Rule] {\[Pi]\ \
Range[\(-4\), 4, 2], Automatic}, \ \[IndentingNewLine]ColorFunction \[Rule] 
                Hue, \ \ \[IndentingNewLine]PlotPoints \[Rule] 
                100, \ \[IndentingNewLine]FrameLabel \[Rule] {"\<\[Psi]\>", "\
\<\[Psi]'\>"}\ , \[IndentingNewLine]DisplayFunction \[Rule] 
                Identity\ ] &\)\ \  /@ \ \ {2, 0.2\ };\)\)], "Input"],

Cell[BoxData[
    \(\(Show[GraphicsArray[\ pt1\ ]];\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(cylind = \ 
        ParametricPlot3D[{v, Sin[u], 
            Cos[u]}, \[IndentingNewLine]{u, \(-\[Pi]\), \[Pi]}, {v, \(-3\), 
            3}, \[IndentingNewLine]DisplayFunction \[Rule] 
            Identity\ ];\)\)], "Input"],

Cell[BoxData[
    \(\(\(Show[\ 
        cylind, \[IndentingNewLine]Graphics3D[\[IndentingNewLine]{\
AbsoluteThickness[
              3], \[IndentingNewLine]Cases[Graphics[pt1[\([1]\)]], _Line, 
                Infinity] /. \[IndentingNewLine]{x_\ , y_} :> {y, 
                  1.02\ \ Cos[x\ ], 
                  1.02  Sin[
                      x]\ }}\[IndentingNewLine]]\ , \
\[IndentingNewLine]ViewPoint \[Rule] {1, 1, 
            1}, \[IndentingNewLine]DisplayFunction \[Rule] $DisplayFunction];\
\)\(\ \)\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part d", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(values2 = {\[Omega] \[Rule] 2, \ \[Omega]c \[Rule] 1};\)\)], "Input"],

Cell[BoxData[
    \(eqRule /. values2 // N\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \({g \[RightArrow] \[Omega]c2\ r}\  // FullForm\)], "Input"],

Cell[BoxData[
    \(eq1 = \(\[Psi]Sol //. {g \[Rule] \ \(\[Omega]c\^2\) r}\) /. 
        Rule \[Rule] Equal\)], "Input"],

Cell[BoxData[
    \(eq2 = {eq1 /. {\(\[Psi]''\)[t] \[Rule] \(d\[Psi]'\)[t]}, \(\[Psi]'\)[
              t] \[Equal] d\[Psi][t]} // Flatten\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(ndsol1 = \(\(NDSolve[{eq2 //. values2, \[Psi][0] \[Equal] 1.1318, 
                  d\[Psi][0] \[Equal] #} // Flatten, {\[Psi][t], 
                d\[Psi][t]}, {t, 0, 10}]\)[\([1]\)] &\)\ \  /@ \ \ {\ \ 1, 
          2.5}\)], "Input"],

Cell["\<\
 \[Psi][1][t_]= \[Psi][t] /.ndsol1[[1,1]];
d\[Psi][1][t_]= d\[Psi][t]/.ndsol1[[1,2]];
 \[Psi][2][t_]= \[Psi][t] /.ndsol1[[2,1]];
d\[Psi][2][t_]= d\[Psi][t]/.ndsol1[[2,2]];\
\>", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(pt2 = \(Plot[\ \ {\(d\[Psi][#]\)[t], \(\[Psi][#]\)[t]}\  // 
                Evaluate, {t, 0, 
                10}, \[IndentingNewLine]PlotStyle \[Rule] {Dashing[{0.04}\ ], 
                  AbsoluteThickness[
                    2]\ }, \[IndentingNewLine]Ticks \[Rule] {\ \ Automatic, \
\[Pi]/2\ \ \ Range[1, 12, 3]\ }, \ \[IndentingNewLine]DisplayFunction \[Rule] 
                Identity\ \ ]\  &\)\  /@ \ \ Range[\ 2]\ ;\)\)], "Input"],

Cell[BoxData[
    \(\(Show[GraphicsArray[pt2]];\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(pt3 = \(ParametricPlot[\ \ {\ \(\[Psi][#]\)[t], \ \(d\[Psi][#]\)[
                    t]}\  // Evaluate, {t, 0, 
                10}, \[IndentingNewLine]PlotStyle \[Rule] \ 
                AbsoluteThickness[
                  2], \ \[IndentingNewLine]DisplayFunction \[Rule] 
                Identity\ ] &\)\ \  /@ \ \ {1, 2}\ \ \ ;\)\)], "Input"],

Cell[BoxData[
    \(\(Show[\ pt1[\([1]\)], pt3, \ 
        DisplayFunction \[Rule] $DisplayFunction];\)\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part e", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["\<\
bead[t_]:= 
  Graphics[
    { PointSize[0.03],
      Point[{Sin[\[Psi][1][t]],Cos[\[Psi][1][t]]} ]
    }];\
\>", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(frames = 2;\)\), "\n", 
    \(Do[\[IndentingNewLine]Show[{bead[t], 
          Graphics[{Hue[0.1], Circle[{0, 0}, 1]}, 
            PlotRange \[RightArrow] {{\(-2\), 2}, {\(-2\), 
                  2}}, \[IndentingNewLine]AspectRatio \[Rule] 
              1\[IndentingNewLine]]}\[IndentingNewLine]]\n, {t, 0, 10, 
        10/\((frames - 1)\)}]\)}], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 4: Springs Mounted on Top of a Carriage ", "Subsection",
  Hyphenation->False],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part a  ", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{
      RowBox[{"T", "=", 
        RowBox[{\(1\/2\), " ", "m", " ", 
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                RowBox[{
                  SuperscriptBox["xi", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"], "+", 
              SuperscriptBox[
                RowBox[{
                  SuperscriptBox["yi", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], 
            ")"}]}]}], ";"}]], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(\ \)\(V = 
        1\/2\ K\ \((\(-r0\) + xb[t])\)\^2 + 1\/2\ k\ yb[t]\^2;\)\)\)], "Input",\

  Hyphenation->False],

Cell[BoxData[
    \(\(change = {\[IndentingNewLine]xi \[Rule] \((\((\((xb[#])\) 
                      Cos[\[Omega]\ #] - yb[#]\ Sin[\[Omega]\ #])\) &)\), 
          yi \[Rule] \((\((\((xb[#])\) Sin[\[Omega]\ #] + 
                    yb[#]\ Cos[\[Omega]\ #])\) &)\)};\)\)], "Input",
  Hyphenation->False],

Cell["L =T-V  /.change  //FullSimplify", "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eqmotion\  = \ 
      EulerEquations[L, {xb[t], yb[t]}, t] // \ 
        Solve[#, \ {\(xb''\)[t], \(yb''\)[t]}] &\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(\(values = {K \[Rule] \ 1, k \[Rule] 1\ , m \[Rule] 1, 
          r0 \[Rule] 1};\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \({eq1, 
        eq2} = \((\(eqmotion[\([1]\)] /. values\) /. 
          Rules \[Rule] Equal)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eq3 = \(xb''\)[t] + 
          I\ \(yb''\)[t]\  \[Equal] \((\(\(xb''\)[t] + I\ \(yb''\)[t] /. 
              eq1\) /. eq2)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eq4 = 
      eq3 /. xb \[Rule] \((\((u[#] - I\ \ yb[#])\) &)\) // 
        Simplify\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(uSol = \(\(u[
                t] /. \(DSolve[{eq4, \ 
                    u[0] \[Equal] 1, \(u'\)[0] == 0\ }\ , \ u[t], 
                  t]\)[\([1]\)] // \ \ ExpToTrig\) // Simplify\) // 
        Expand\)], "Input"],

Cell[BoxData[
    \(xSol = \ \ \(\(uSol /. \ 
          Complex[a_, b_] \[Rule] 
            Complex[a, 0]\)\(//\)\(Simplify\)\(\ \)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(ySol = \((uSol - xSol\  // Together)\) /. I \[Rule] 1 // 
        Simplify\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(wvalues = {0.2, 0.4, 0.6, 0.8};\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(listb\  = \(ParametricPlot[\ {xSol, ySol} /. \[Omega] \[Rule] #\  // 
                Evaluate, {t, 0, 100}, 
              PlotPoints \[Rule] 100, \[IndentingNewLine]AspectRatio \[Rule] 
                1, \[IndentingNewLine]AxesLabel \[Rule] {"\<xb\>", "\<yb\>"}, \
\[IndentingNewLine]Ticks \[Rule] 
                False, \[IndentingNewLine]DisplayFunction \[Rule] 
                Identity] &\)\ \  /@ \ wvalues;\)\)], "Input"],

Cell[BoxData[
    \(\(Show[GraphicsArray[Partition[listb\ , 2]]];\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(change\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eq2 = \(\({xi[t], yi[t]} /. change\) /. xb[t] \[Rule] xSol\) /. 
          yb[t] \[Rule] ySol\  // Simplify\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(listi\  = \(ParametricPlot[
              eq2 /. \[Omega] \[Rule] # // Evaluate, {t, 0, 
                100}, \[IndentingNewLine]AxesLabel \[Rule] {"\<xi\>", \
"\<yi\>"}, \[IndentingNewLine]AspectRatio \[Rule] 
                1, \[IndentingNewLine]Ticks \[Rule] 
                False, \[IndentingNewLine]DisplayFunction \[Rule] 
                Identity] &\) /@ \ wvalues\ ;\)\)], "Input"],

Cell[BoxData[
    \(\(Show[GraphicsArray[Partition[listi\ , 2]]];\)\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(\(listpb\  = \(ParametricPlot[\ {ySol, 
                    D[ySol, t]}\ \  /. \[Omega] \[Rule] # // Evaluate, {t, 0, 
                100}, \[IndentingNewLine]AspectRatio \[Rule] 
                1, \[IndentingNewLine]AxesLabel \[Rule] {"\<yb\>", "\< \
yb'\>"}, \[IndentingNewLine]Ticks \[Rule] 
                False, \[IndentingNewLine]DisplayFunction \[Rule] 
                Identity] &\)\  /@ \ \ wvalues;\)\)], "Input"],

Cell[BoxData[
    \(\(Show[GraphicsArray[Partition[listpb\ , 2]]];\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(listpi\  = \(ParametricPlot[\ {eq2[\([2]\)], 
                    D[eq2[\([2]\)], t]}\ \  /. \[Omega] \[Rule] # // 
                Evaluate, {t, 0, 
                100}, \ \[IndentingNewLine]AspectRatio \[Rule] 
                1, \[IndentingNewLine]AxesLabel \[Rule] {"\<yb\>", "\< \
yb'\>"}, \[IndentingNewLine]Ticks \[Rule] 
                False, \[IndentingNewLine]DisplayFunction \[Rule] 
                Identity] &\)\  /@ \ \ wvalues;\)\)], "Input"],

Cell[BoxData[
    \(\(Show[GraphicsArray[Partition[listpi\ , 2]]];\)\)], "Input",
  Hyphenation->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 5: Mass Falling Through a Hole in a Table     ", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{"T1", "=", 
        RowBox[{\(1\/2\), " ", "m1", " ", 
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                RowBox[{
                  SuperscriptBox["r", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"], "+", 
              RowBox[{\(r[t]\^2\), " ", 
                SuperscriptBox[
                  RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                      MultilineFunction->None], "[", "t", "]"}], "2"]}]}], 
            ")"}]}]}], ";"}], "\n", \(V1 = 0;\)}], "Input"],

Cell[BoxData[
    \(\(zRule = {z \[Rule] \((\((len - r[#])\) &)\)};\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[{
    RowBox[{
      RowBox[{"T2", "=", 
        RowBox[{
          RowBox[{\(1\/2\), " ", "m2", " ", 
            SuperscriptBox[
              RowBox[{
                SuperscriptBox["z", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], "2"]}], "/.", 
          "zRule"}]}], 
      ";"}], "\n", \(V2 = \(-m2\)\ g\ z[t] /. zRule;\)}], "Input"],

Cell["L=(T1+T2)-(V1+V2) ", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(\(eq1\)\(=\)\(\ \)\(EulerEquations[L, {r[t], \[Phi][t]}, 
        t]\)\(\ \ \)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[{
    \(\(eq2 = \ 
        Solve[eq1, {\(\[Phi]''\)[t], \(r''\)[t]}] // 
          Flatten;\)\), "\[IndentingNewLine]", 
    \(eq2 // ColumnForm\)}], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(\ \)\(FirstIntegrals[L, {r[t], \[Phi][t]}, t] // 
      ColumnForm\)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{
      RowBox[{"eq\[Phi]", "=", " ", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              RowBox[{
                SuperscriptBox["\[Phi]", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Rule]", \(h\/r[t]\^2\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
              RowBox[{"-", 
                FractionBox[
                  RowBox[{"2", " ", "h", " ", 
                    RowBox[{
                      SuperscriptBox["r", "\[Prime]",
                        MultilineFunction->None], "[", "t", 
                      "]"}]}], \(r[t]\^3\)]}]}]}], "}"}]}], ";"}]], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eqR = \ \(eq2[\([1]\)] /. eq\[Phi] // Simplify\) // 
        ExpandAll\)], "Input",
  Hyphenation->False],

Cell[BoxData[{
    \(\(eqMotion = {eq\[Phi][\([1]\)], eqR} /. Rule \[Rule] Equal // 
          Flatten;\)\), "\[IndentingNewLine]", 
    \(eqMotion // ColumnForm\)}], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(energy = \(T1 + T2 + V1 + V2 /. eq\[Phi] // Simplify\) // 
        ExpandAll\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(Effpot\  = \((\(+g\)\ \ len\ \ m2 + energy)\) /. {\(r'\)[t] \[Rule] 0, 
            r[t] \[Rule] r} // Apart\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(min = 
      D[Effpot, r\ ] \[Equal] 0 // \(Solve[#, r\ ]\)[\([1]\)] &\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(values = {h \[Rule] 1, m1 \[Rule] 1, m2 \[Rule] 1, 
          g \[Rule] 1\ };\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(Plot[Effpot /. values // Evaluate, {r\ , 0.2, 3}];\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(ContourPlot[\ \(energy /. values\) /. len \[Rule] 10\  // 
          Evaluate, \[IndentingNewLine]{r[t], 0.2, 6}, {\(r'\)[t], \(-1\), 
          1}, \[IndentingNewLine]ContourShading \[Rule] 
          True, \[IndentingNewLine]ColorFunction \[Rule] 
          Hue\ \ ];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(values = {h \[Rule] 1, m1 \[Rule] 1, m2 \[Rule] 1, 
          g \[Rule] 1};\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(ndsol\  = \(NDSolve[{\ eqMotion /. values\ , \[Phi][0] \[Equal] 0, 
                r[0] \[Equal] \ 2, \(r'\)[0] \[Equal] 0} // 
              Flatten, {\[Phi][t], r[t]}, {t, 0, 
              70}]\)[\([1]\)]\ ;\)\)], "Input"],

Cell["\<\
\[Phi]1[t_]= \[Phi][t] /.ndsol; 
r1[t_]= r[t] /.ndsol; \
\>", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(ParametricPlot[\ 
        r1[t]\ {Cos[\[Phi]1[t]], Sin[\ \[Phi]1[t]]}\ \  // Evaluate, {t, 0, 
          70}, \[IndentingNewLine]AspectRatio \[Rule] 
          Automatic, \[IndentingNewLine]Epilog \[Rule] {AbsoluteThickness[3], 
            Circle[{0, 0}, 2], 
            Circle[{0, 0},  .55]}\[IndentingNewLine]];\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 6: Spring Pendulum  ", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  Hyphenation->False]
}, Open  ]],

Cell[CellGroupData[{

Cell["Part a ", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(\ \)\(lsrule = 
        lst \[Rule] \((\@\(x[#1]\^2 + y[#1]\^2\) &)\);\)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[{
    RowBox[{
      RowBox[{"T", "=", " ", 
        RowBox[{\(1\/2\), " ", "m", " ", 
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                RowBox[{
                  SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"], "+", 
              SuperscriptBox[
                RowBox[{
                  SuperscriptBox["y", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], 
            ")"}]}]}], 
      ";"}], "\[IndentingNewLine]", \(Vsp = \ 
        1\/2\ k\ \((\(-L0\) + lst[t])\)\^2;\), "\[IndentingNewLine]", \(Vgr = \
\(\(-\ m\)\(\ \)\(g\)\(\ \)\(x[t]\)\(\ \ \ \)\)\)}], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(polarrule = {x \[Rule] \((\((r[#]\ Cos[\[Theta][#]])\) &)\), 
          y \[Rule] \((\((r[#]\ Sin[\[Theta][#]])\) &)\)};\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(L = \(\(\(T - Vsp - Vgr /. lsrule\) /. polarrule // 
          Simplify\)\(//\)\(PowerExpand\)\(\ \)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[{
    \(\(eqMotion = \((\((\ \ EulerEquations[L, {r[t], \[Theta][t]}, 
                    t]\[IndentingNewLine] // \((\ \(Solve[#, {\(r''\)[
                              t], \(\[Theta]''\)[
                              t]}]\)[\([1]\)] &\ )\)\[IndentingNewLine])\) /. 
              Rule \[Rule] Equal\ \[IndentingNewLine] // 
            ExpandAll\[IndentingNewLine])\);\)\), "\[IndentingNewLine]", 
    \(eqMotion\  // ColumnForm\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Part b ", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(\(vertical = \ \ {\[Theta] \[Rule] \((0 &)\)};\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(vertMotion = \(\(eqMotion /. 
          Rule \[Rule] Equal\)\(/.\)\(vertical\)\(\ \)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(vertSol = \(DSolve[vertMotion[\([1]\)]\ , \ r[t], t] // Flatten\) // 
        ExpandAll\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(vertSol /. C[1] \[Rule] 0\) /. C[2] \[Rule] 0 // Flatten\) // 
      ExpandAll\)], "Input",
  Hyphenation->False]
}, Open  ]],

Cell[CellGroupData[{

Cell["Part c   ", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(\(valuesc = {L0 \[Rule] 40/9, n \[Rule] 1, k \[Rule] 4, \ g \[Rule] 1, 
          m \[Rule] 1};\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(initialc = {r[0] \[Equal] \((L0 + \ g\ m/k)\) + 1\ , \(r'\)[
                0] \[Equal]  .1, \[Theta][0] \[Equal] 
              1/2\ \ \ \[Pi], \(\[Theta]'\)[0] \[Equal] \  .0} /. 
          valuesc;\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(neqc = \({eqMotion, initialc} /. Rule \[Rule] Equal\)\  /. valuesc // 
          Flatten\ ;\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(nSolc = 
        NDSolve[neqc, {r[t], \[Theta][t]}, {t, 0, 110}, 
            MaxSteps \[Rule] 2000\ ] // Flatten;\)\)], "Input",
  Hyphenation->False],

Cell["\<\
rc[t_]= r[t]/.nSolc; 
\[Theta]c[t_]= \[Theta][t]/.nSolc; \
\>", "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(Plot[\ {rc[t], \[Theta]c[t]\ \ } // Evaluate, {t, 0, 
          110}, \[IndentingNewLine]PlotStyle \[Rule] {Hue[ .7], 
            Hue[ .9]}\ \ , \[IndentingNewLine]Ticks \[Rule] {Automatic, \ \
\[Pi]\ Range[\(-1\), 2, 1\ \ ]\ }\ , \[IndentingNewLine]Epilog \[Rule] 
          Map[Line, \ \({{0, #  \[Pi]}, {125, #  \[Pi]}\ } &\)\  /@ \ \ \
Range[\(-1\), 2]]\ \[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    \(\(\(ParametricPlot[\ 
        rc[t] {Sin[\[Theta]c[t]], \(-Cos[\[Theta]c[t]]\)}\  // Evaluate, {t, 
          0, 110}, \[IndentingNewLine]PlotStyle \[Rule] 
          Hue[0.9], \ \[IndentingNewLine]AspectRatio \[Rule] 
          1, \[IndentingNewLine]PlotRange \[Rule] {Automatic, {\(-8\), 
              8}}, \ \[IndentingNewLine]Epilog \[Rule] {\ \(Circle[{0, 
                    0}, #] &\) /@ {6, 4, 
                2}\ }\[IndentingNewLine]];\)\(\ \)\)\)], "Input"],

Cell[BoxData[{
    \(\(\(pt1 = \(ParametricPlot[\ {#[t], \(#'\)[t]\ \ } // Evaluate, {t, 0, 
                110}, \[IndentingNewLine]PlotStyle \[Rule] {Hue[ .7], 
                  Hue[ .9]}, \[IndentingNewLine]Ticks \[Rule] 
                False, \[IndentingNewLine]DisplayFunction \[Rule] 
                Identity\ \[IndentingNewLine]] &\)\  /@ \ \ {rc, \
\[Theta]c};\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[pt1]];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Part d   ", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(\(valuesd = {L0 \[Rule] 5, n \[Rule] 1, k \[Rule] 2, \ g \[Rule] 1, 
          m \[Rule] 1};\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(initiald = {r[0] \[Equal] \((L0 + \ g\ m/k +  .01)\)\ \ , \(r'\)[
                0] \[Equal] 
              0, \[Theta][0] \[Equal] \[Pi]\  -  .07, \(\[Theta]'\)[
                0] \[Equal] \ 0} /. valuesd\ ;\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(neqd = \({eqMotion, initiald} /. Rule \[Rule] Equal\)\  /. valuesd // 
          Flatten;\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(nSold = 
        NDSolve[neqd, {r[t], \[Theta][t]}, {t, 0, 110}, 
            MaxSteps \[Rule] 2000] // Flatten;\)\)], "Input"],

Cell["\<\
rd[t_]= r[t] /. nSold;
\[Theta]d[t_]= \[Theta][t] /. nSold; \
\>", "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(Plot[\ {rd[t], \[Theta]d[t]\ \ } // Evaluate, {t, 0, 
          110}, \[IndentingNewLine]PlotStyle \[Rule] {Hue[ .7], 
            Hue[ .9]}\ , \[IndentingNewLine]Ticks \[Rule] {Automatic, \ \[Pi]\
\ Range[\(-5\), 2, 1\ \ ]\ }\ , \[IndentingNewLine]Epilog \[Rule] 
          Map[Line, \({{0, #  \[Pi]}, {125, #  \[Pi]}\ } &\)\ \  /@ \ \ \
Range[\(-5\), 2]]\ \[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    \(\(ParametricPlot[\ 
        rd[t] {Sin[\[Theta]d[t]], \(-Cos[\[Theta]d[t]]\)} // Evaluate, {t, 0, 
          110}, \[IndentingNewLine]PlotStyle \[Rule] 
          Hue[ .9], \ \[IndentingNewLine]PlotRange \[Rule] 
          All, \[IndentingNewLine]AspectRatio \[Rule] 
          Automatic, \ \ \[IndentingNewLine]Epilog \[Rule] {\ \(Circle[{0, 
                    0}, #] &\) /@ {8, 6, 
                4}}\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[{
    \(\(\(pt1 = \[IndentingNewLine]\(ParametricPlot[\ {#[t], \(#'\)[t]\ \ } // 
                Evaluate, {t, 0, 
                110}, \[IndentingNewLine]PlotStyle \[Rule] {Hue[ .7], 
                  Hue[ .9]}\ , \[IndentingNewLine]Ticks \[Rule] 
                False, \[IndentingNewLine]DisplayFunction \[Rule] 
                Identity\ \[IndentingNewLine]] &\)\  /@ \ {rd, \
\[Theta]d};\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[pt1]];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Part e ", "Subsubsection",
  Hyphenation->False],

Cell["\<\
Contains correction on:  
    2nd Edition:Chpt.6,Problem 6.2.6 p.334:Spring Pendulm. 
(FIO, 17 Jan 2003)  

All values should be consistently either {rc,\[Theta]c} or \
{rd,\[Theta]d}\
\>", "Text",
  FontColor->RGBColor[1, 0, 0]],

Cell[BoxData[
    RowBox[{\(line[t_]\), ":=", "\[IndentingNewLine]", 
      RowBox[{"Show", "[", " ", "\[IndentingNewLine]", 
        RowBox[{"Graphics", "[", "\[IndentingNewLine]", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"{", 
                
                RowBox[{\(Line[{{0, 0}, 
                      rc[t] {Sin[\[Theta]c[t]], \(-Cos[\[Theta]c[t]]\)}}]\), 
                  ",", "\[IndentingNewLine]", 
                  RowBox[{"{", 
                    RowBox[{\(PointSize[0.1]\), ",", 
                      RowBox[{"Point", "[", " ", 
                        RowBox[{
                          RowBox[{
                            StyleBox["rc",
                              FontColor->RGBColor[1, 0, 0]], "[", "t", 
                            "]"}], \({Sin[\[Theta]c[
                                t]], \(-Cos[\[Theta]c[t]]\)}\)}], "]"}]}], 
                    "}"}]}], "}"}], "}"}], ",", 
            "\[IndentingNewLine]", \(PlotRange \[Rule] {{\(-10\), 
                  10}, {\(-13\), 13}}\)}], "\[IndentingNewLine]", "]"}], 
        "\[IndentingNewLine]", "]"}]}]], "Input"],

Cell[BoxData[{
    \(\(frames = 2;\)\), "\[IndentingNewLine]", 
    \(\(movie = \(line[#] &\)\  /@ \ 
          Range[0, 30, 30/\((\ frames - 1)\)];\)\ \)}], "Input",
  Hyphenation->False,
  AnimationDisplayTime->0.459482]
}, Open  ]]
}, Closed]],

Cell[TextData[{
  "6.3 Lagrangian Problems with Lagrange Multipliers",
  StyleBox[" ",
    FontColor->RGBColor[0, 0, 1]]
}], "Section",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
Overview of Nonholonomic Constraints and Lagrange Multipliers  \
\
\>", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["\<\
Lag[qi_,L_ ,Qi_,t_:t] := 
D[ D[L,(D[qi[t],t])],t]-D[L,qi[t]]==Qi;
  
Lag[qi_List,L_,Qi_List,t_:t] :=
(D[ D[L,(D[qi[[#]][t],t])],t]-D[L,qi[[#]][t]]==Qi[[#]]
)&  /@  Range[1,Length[qi]];\
\>", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Protect[Lag];", "Input",
  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Problem 1: Atwood Machine  ",
  StyleBox["  ",
    FontColor->RGBColor[0, 0, 1]]
}], "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Remarks and outline: ", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution    ", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  Hyphenation->False],

Cell[BoxData[{
    RowBox[{
      RowBox[{"T", "=", 
        RowBox[{\(1\/2\), " ", 
          RowBox[{"Sum", "[", 
            RowBox[{
              RowBox[{\(m[i]\), " ", 
                SuperscriptBox[
                  RowBox[{
                    SuperscriptBox[\(x[i]\), "\[Prime]",
                      MultilineFunction->None], "[", "t", "]"}], "2"]}], 
              ",", \({i, 1, 2}\)}], "]"}]}]}], 
      ";"}], "\n", \(V = \((\(-g\))\)\ Sum[
            m[i]\ \(x[i]\)[t], {i, 1, 2}];\)}], "Input"],

Cell["L= T-V", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["f[1]=x[1][t]+x[2][t]-Len;", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(\(Qeq = \(D[f[1], \(x[#]\)[t]]\ \[Lambda][1] &\)\  /@ \ {1, 
          2}\)\(\ \)\(\[IndentingNewLine]\)
    \(\ \)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(eq2\)\(=\)\(Lag[{x[1], x[2]}, L, Qeq]\)\(\ \)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(f[1] \[Equal] 0\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eq3 = D[f[1] \[Equal] 0, {t, 2}]\)], "Input",
  Hyphenation->False],

Cell[BoxData[{
    \(\(eq4 = \((\((\(Solve[{eq2, \ eq3} // 
                      Flatten\ , {\ \[Lambda][1], \(\((x[2])\)''\)[
                        t], \(\((x[1])\)''\)[t]\ }, t]\  // 
                  Simplify\)\[IndentingNewLine] // 
                Flatten\ \[IndentingNewLine])\) /. {Rule \[Rule] 
                Equal}\[IndentingNewLine])\);\)\), "\[IndentingNewLine]", 
    \(eq4 // ColumnForm\)}], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(initial = {\(x[1]\)[0] \[Equal] x0, \(\((x[1])\)'\)[0] \[Equal] 
            v0};\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(sol1 = \ \(\(DSolve[{eq4[\([{3}]\)], initial}\  // 
              Flatten, {\((x[1])\)[t]}, t] // 
          FullSimplify\)\(\ \)\(//\)\(Flatten\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(sol2 = {\(x[2]\)[t] \[Rule] Len - \(x[1]\)[t] /. sol1}\)], "Input",
  Hyphenation->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 2: Hoop Rolling on an Incline    ", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Remarks and outline", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{"T", "=", 
        RowBox[{\(1\/2\), " ", "m", " ", 
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                RowBox[{
                  SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"], "+", 
              RowBox[{\(r\^2\), " ", 
                SuperscriptBox[
                  RowBox[{
                    SuperscriptBox["\[Theta]", "\[Prime]",
                      MultilineFunction->None], "[", "t", "]"}], "2"]}]}], 
            ")"}]}]}], 
      ";"}], "\[IndentingNewLine]", \(V = 
        m\ g\ \((Len - x[t])\)\ Sin[\[Phi]];\), "\[IndentingNewLine]", \(L = 
      T - V\)}], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(eq1 = r\ \[Theta][t] - x[t] \[Equal] 0;\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(constraintForce = \[IndentingNewLine]{Q[
            1] \[Rule] \[Lambda]\ D[eq1[\([1]\)], x[t]], \[IndentingNewLine]Q[
            2] \[Rule] \[Lambda]\ D[eq1[\([1]\)], \[Theta][t]]}\)], "Input",
  Hyphenation->False],

Cell[BoxData[{
    \(\({eqX, eq\[Theta]} = 
        Lag[{x, \[Theta]}, L, {Q[1], Q[2]}] //. 
          constraintForce;\)\), "\[IndentingNewLine]", 
    \({eqX, eq\[Theta]} // ColumnForm\)}], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(initial = {x[0] \[Equal] x0, \(x'\)[0] \[Equal] 
            v0, \[Theta][0] \[Equal] x0/r, \(\[Theta]'\)[0] \[Equal] 
            v0/r};\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(\ \)\(xtSol = \(DSolve[{eqX, eq\[Theta], initial} // 
            Flatten, {x[t], \[Theta][t]}, t]\)[\([1]\)]\)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\[Lambda]Sol = Solve[eq1 /. xtSol, \[Lambda]]\)], "Input",
  Hyphenation->False],

Cell["\<\
xtSol2= xtSol /.\[Lambda]Sol //ExpandAll //Flatten\
\>", "Input",
  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(values = {x0 \[Rule] 0, v0 \[Rule] 0, 
          g \[Rule] \(-0.1\), \[Phi] \[Rule] \[Pi]/4, 
          r \[Rule] 2.0};\)\)], "Input"],

Cell["\<\
posx = ( x[t] Sin[\[Phi]]+ r Sin[\[Theta][t]]);
posy = ( x[t] Cos[\[Phi]]+ r Cos[\[Theta][t]]);\
\>", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["point={posx,posy} /.xtSol2 //.values;", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(ParametricPlot[point // Evaluate, {t, 0, 70}, 
        AspectRatio \[Rule] 1\ ];\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 3: Sphere Rolling on a Fixed Sphere   ", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["\<\
Contains correction on:  
    2nd Edition: Chpt.6, Problem 6.3.3 p.174: Sphere Rolling on a Fixed \
Sphere.
(FIO, 17 Jan 2003)  

The figure in the first edition was incorrect. This is fixed in the 2nd \
edition. The second angle (theta-2) is measured from the contact point of the \
two spheres. Although this definition may be less conventional, it simplifies \
our particular problem.\
\>", "Text",
  FontColor->RGBColor[1, 0, 0]],

Cell["Remarks and outline", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{
      RowBox[{"Tcm", "=", 
        RowBox[{\(1\/2\), " ", "m", " ", 
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                RowBox[{
                  SuperscriptBox["r", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"], "+", 
              RowBox[{\(r[t]\^2\), " ", 
                SuperscriptBox[
                  RowBox[{
                    SuperscriptBox["\[Theta]1", "\[Prime]",
                      MultilineFunction->None], "[", "t", "]"}], "2"]}]}], 
            ")"}]}]}], ";"}]], "Input",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{
      RowBox[{"Trot", "=", 
        RowBox[{\(1\/2\), " ", "I1", " ", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  SuperscriptBox["\[Theta]1", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "+", 
                RowBox[{
                  SuperscriptBox["\[Theta]2", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], ")"}], 
            "2"]}]}], ";"}]], "Input",
  Hyphenation->False],

Cell["T=Tcm+Trot; ", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["V= m g r[t] Cos[\[Theta]1[t]]; ", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["L=T-V", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["\<\
constraints= {b \[Theta]1[t] - a \[Theta]2[t]==0, r[t]-a-b==0 \
}\
\>", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(\(constraintRule\)\(=\)\(\ \)\(DSolve[constraints\ , {\[Theta]2, r}, 
        t]\)\(\ \)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(vars = {r[t], \[Theta]1[t], \[Theta]2[t]};\)\(\ \)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(Qeq = \(Sum[\[Lambda][j]*D[constraints[\([j, 1]\)], vars[\([#]\)]], {j, 
              1, 2}] &\)\  /@ \ {1, 2, 3}\)], "Input",
  Hyphenation->False],

Cell[BoxData[{
    \(\(eqMotion = \ 
        Lag[{r, \[Theta]1, \[Theta]2}, L, Qeq];\)\), "\[IndentingNewLine]", 
    \(eqMotion // ColumnForm\ \)}], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(\({\[Lambda]2Sol, \[Theta]Sol, \[Lambda]1Sol} = \((Solve[
                eqMotion //. constraintRule // 
                  Flatten, {\(\[Theta]1''\)[t], \[Lambda][1], \[Lambda][
                    2]}]\[IndentingNewLine] /. 
              Rule \[Rule] Equal\[IndentingNewLine] // 
            Flatten\[IndentingNewLine])\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \({\[Lambda]2Sol, \[Theta]Sol, \[Lambda]1Sol} // 
      ColumnForm\ \ \)}], "Input"],

Cell[BoxData[
    \(\(\(eq\[Theta]\)\(=\)\((\ \[Theta]Sol[\([1]\)] - \
\[Theta]Sol[\([2]\)])\)\(\ \)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(int\[Theta] = \(Integrate[
              eq\[Theta]\ \ \(\[Theta]1'\)[t], {t, 0, 
                t}]\  //. {\[Theta]1[0] \[Rule] 0, \(\[Theta]1'\)[0] \[Rule] 
                0} // Simplify\) // Apart\)], "Input"],

Cell[BoxData[
    \(sol\[Theta] = \(Solve[
            int\[Theta] \[Equal] 
              0, {\(\[Theta]1'\)[
                t]}]\)[\([1]\)]\  /. \@\(\(-1\) + Cos[x_]\) \[Rule] \
\[ImaginaryI]\ \@\(1 - Cos[x]\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(eq1 = \(\[Lambda]2Sol /. \[Lambda][2] \[Rule] 0\) //. 
        sol\[Theta]\)], "Input",
  Hyphenation->False],

Cell["\<\
sol2=Solve[eq1,Cos[\[Theta]1[t]]] //Flatten  \
\>", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(sol3 = \(\(Solve[sol2 //. {Rule \[Rule] Equal}, \[Theta]1[t], 
          InverseFunctions \[Rule] 
            True]\)\(//\)\(Flatten\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\((\[Theta]1[t]/Degree)\) //. 
          sol3[\([2]\)]\) //. {I1 \[Rule] \(2\ a\^2\ m\)\/5} // N\)], "Input"]
}, Closed]]
}, Closed]],

Cell[TextData[{
  "6.4 Hamiltonian Problems ",
  StyleBox["  ",
    FontColor->RGBColor[1, 0, 0]]
}], "Section",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Overview of Hamilton's Equations", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Hamilton[L_, xList_List, pList_List, 
        t_:  t] := \[IndentingNewLine]Module[{xx, vv, pp, sol, ham, eqp, eqx, 
          eqs}, \[IndentingNewLine]xx = 
          Through[xList[t]]; \[IndentingNewLine]vv = 
          D[xx, t]; \[IndentingNewLine]pp = 
          Through[pList[t]]; \[IndentingNewLine]sol = 
          Solve[\((\(D[L, #] &\) /@ vv)\) \[Equal] pp, vv] // 
            Flatten; \[IndentingNewLine]ham = \(pp . vv - L //. sol // 
              Simplify\) // Expand; \[IndentingNewLine]eqp = 
          D[pp, t] \[Equal] \(-Map[D[ham, #] &, xx]\) // 
            Thread; \[IndentingNewLine]eqx = 
          D[xx, t] \[Equal] \(+Map[D[ham, #] &, pp]\) // 
            Thread; \[IndentingNewLine]eqs = 
          Join[eqp, eqx]; \[IndentingNewLine]Return[{sol, ham, 
            eqs}]\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(Clear[L, x, V]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{
      RowBox[{"L", "=", 
        RowBox[{\(-V[x[t]]\), "+", 
          RowBox[{\(1\/2\), " ", "m", " ", 
            SuperscriptBox[
              RowBox[{
                SuperscriptBox["x", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], "2"]}]}]}], 
      ";"}]], "Input",
  Hyphenation->False],

Cell[BoxData[{
    \(\({pRule, hamiltonian, eqMotion} = 
        Hamilton[L, {x}, {px}];\)\), "\[IndentingNewLine]", 
    \(pRule\), "\[IndentingNewLine]", 
    \(hamiltonian\), "\[IndentingNewLine]", 
    \(eqMotion\)}], "Input"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"L", "=", 
        RowBox[{\(-V[x[t], y[t]]\), "+", 
          RowBox[{\(1\/2\), " ", "m", " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                      MultilineFunction->None], "[", "t", "]"}], "2"], "+", 
                SuperscriptBox[
                  RowBox[{
                    SuperscriptBox["y", "\[Prime]",
                      MultilineFunction->None], "[", "t", "]"}], "2"]}], 
              ")"}]}]}]}], ";"}], "\n", \(Hamilton[
      L, {x, y}, {px, py}]\)}], "Input"],

Cell["Protect[Hamilton];", "Input",
  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 1: Harmonic Oscillator", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Remarks and outline", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  Hyphenation->False],

Cell[BoxData[{
    RowBox[{
      RowBox[{"T", "=", 
        RowBox[{\(1\/2\), " ", "m", " ", 
          SuperscriptBox[
            RowBox[{
              SuperscriptBox["x", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "2"]}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{" ", \(V = 1\/2\ k\ x[t]\^2;\)}]}], "Input"],

Cell[BoxData[
    \(L = T - V\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eq1 = p[t] \[Equal] D[L, \(x'\)[t]]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(xpRule = \(Solve[eq1, \(x'\)[t]]\)[\([1]\)]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(H = \((p[t]\ \(x'\)[t] - L)\) //. xpRule\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eq2 = \[IndentingNewLine]{\(p'\)[
            t] \[Equal] \(-D[H, x[t]]\), \[IndentingNewLine]\(x'\)[
            t] \[Equal] \(+D[H, p[t]]\)}\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(Hamilton[L, {x}, {p}] // ColumnForm\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(initial = {p[0] \[Equal] p0, x[0] \[Equal] x0};\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(dsol = \(DSolve[eq2~Join~initial, {p[t], x[t]}, t] // Flatten\)\  // 
        FullSimplify\)], "Input",
  Hyphenation->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 2: Nonlinear Oscillator    ", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  Hyphenation->False],

Cell[CellGroupData[{

Cell["Remarks and Outline", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(firstDiffSeries[eqin_, {z_, p_}, initRule_List, order_, 
        t_:  t] := \[IndentingNewLine]Module[{eq, zSer, pSer, eSer, vars, 
          sol, zpsol}, \[IndentingNewLine]eq = 
          Table[eqin[\([i, 1]\)] - eqin[\([i, 2]\)] \[Equal] 0, {i, 
              2}]; \[IndentingNewLine]zSer = 
          Series[z[t], {t, 0, order}]; \[IndentingNewLine]pSer = 
          Series[p[t], {t, 0, order}]; \[IndentingNewLine]eSer = 
          eq //. \(({z[t] \[Rule] zSer, p[t] \[Rule] pSer})\) // 
            ExpandAll; \[IndentingNewLine]vars = \((Table[{D[z[t], {t, j}], 
                    D[p[t], {t, j}]}, {j, 1, order + 1}] /. t \[Rule] 0)\) // 
            Flatten; \ \ \ \ \ sol = 
          Solve[eSer, vars] // 
            Flatten; \[IndentingNewLine]zpSol = \({zSer, pSer} //. sol\) //. 
            initRule; \[IndentingNewLine]Return[
          zpSol]\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"eq1", "=", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              RowBox[{\(w\^2\ x[t]\), "+", 
                RowBox[{
                  SuperscriptBox["p", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "==", "0"}], 
            ",", 
            RowBox[{\(p[t]\), "==", 
              RowBox[{
                SuperscriptBox["x", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}]}], "}"}]}], 
      ";"}], "\[IndentingNewLine]", \(firstDiffSeries[
        eq1, {x, p}, {x[0] \[Rule] x0, p[0] \[Rule] p0}, 4, t] // 
      ColumnForm\)}], "Input"],

Cell[BoxData[
    \(firstOrderPert[eq1_, x_, {x0_, v0_}, eps_:  eps, 
        t_:  t] := \[IndentingNewLine]Module[{xRule, eq2, eqEps, initCon0, 
          initCon1, dsol1, 
          dsol2}, \[IndentingNewLine]xRule = {x \[Rule] \((\(x[0]\)[#] + 
                    eps\ \(x[1]\)[#] &)\)}; \[IndentingNewLine]eq2 = 
          eq1[\([1]\)] - eq1[\([2]\)] /. xRule; \[IndentingNewLine]eqEps = 
          CoefficientList[eq2, eps] \[Equal] 0 // 
            Thread; \[IndentingNewLine]initCon0 = {\(x[0]\)[0] \[Equal] 
              x0, \(\((x[0])\)'\)[0] \[Equal] 
              v0}; \[IndentingNewLine]initCon1 = {\(x[1]\)[0] \[Equal] 
              0, \(\((x[1])\)'\)[0] \[Equal] 
              0}; \[IndentingNewLine]dsol1 = \((DSolve[
                Join[{eqEps[\([1]\)]}, initCon0], {\(x[0]\)[t]}, t] // 
              Flatten)\); \[IndentingNewLine]dsol2 = \((DSolve[
                Join[{eqEps[\([2]\)]}, initCon1] //. dsol1, {\(x[1]\)[t]}, 
                t] // Flatten)\); \[IndentingNewLine]Return[\(x[t] /. 
              xRule\) //. Join[dsol1, dsol2]]\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"eq1", "=", 
        RowBox[{
          RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "==", \(\(-k\^2\)\ x[t] + eps\ x[t]\^2\)}]}], ";"}]], "Input"],

Cell[BoxData[
    \(\(firstOrderPert[eq1, x, {x0, 0}, eps, t] // Simplify\)\  // 
      Collect[#, eps] &\)], "Input",
  Hyphenation->False]
}, Open  ]],

Cell["Solution", "Subsubsection",
  Hyphenation->False],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[{
    RowBox[{
      RowBox[{"T", "=", 
        RowBox[{\(1\/2\), " ", "m", " ", 
          SuperscriptBox[
            RowBox[{
              SuperscriptBox["x", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "2"]}]}], 
      ";"}], "\n", \(V = 
        1\/2\ k\ x[t]\^2 - 1\/4\ \[Epsilon]\ x[t]\^4;\)}], "Input"],

Cell[BoxData[
    \(\(L\  = T - V;\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[{
    \(\({xprule, hamiltonian, eqMotion} = 
        Hamilton[L, {x}, {p}];\)\), "\[IndentingNewLine]", 
    \({xprule, hamiltonian, eqMotion} // ColumnForm\)}], "Input",
  Hyphenation->False]
}, Open  ]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(\(values = {k \[Rule] \ 1, \ \[Epsilon] \[Rule] 1/2, 
          m \[Rule] 1};\)\)], "Input"],

Cell[BoxData[
    \(\(pt1 = 
        Plot[V\  /. values // Evaluate, {x[t], \(-2\)\ , 2\ }, 
          DisplayFunction \[Rule] Identity];\)\)], "Input"],

Cell[BoxData[
    \(\(pt2 = \ 
        ContourPlot[
          hamiltonian\  /. values // Evaluate, {x[t], \(-2\), 
            2\ }, \[IndentingNewLine]{p[t], \(-1\), 
            1}, \[IndentingNewLine]ColorFunction \[Rule] 
            Hue, \[IndentingNewLine]Contours \[Rule] 
            15, \[IndentingNewLine]DisplayFunction \[Rule] 
            Identity]\ ;\)\)], "Input"],

Cell[BoxData[
    \(\(Show[GraphicsArray[{pt2, pt1}]];\)\)], "Input",
  Hyphenation->False]
}, Open  ]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(solt = \(firstDiffSeries[
            eqMotion, {x, p}, {x[0] \[Rule] x0, p[0] \[Rule] 0}, 6] // 
          Normal\)\  // Simplify\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eq1 = \((eqMotion // First)\) /. {\(p'\)[t] \[Rule] 
            m\ \(x''\)[t]}\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{
      StyleBox[\( (*\ 
          Incorrect\ \(version : \ \((\(4/19\)/
                      2004)\)\ \[IndentingNewLine]sol\[Epsilon]\)\  = \
\(firstOrderPert[eq1, x, {x0, 0}, \[Epsilon]] // 
                Collect[#, {x0, \[Epsilon], \ \ Cos[x_]\ }] &\)\  // 
              Short[#, 1] &\ \[IndentingNewLine]*) \),
        FontColor->RGBColor[0, 0, 1]], 
      StyleBox[" ",
        FontColor->RGBColor[1, 0, 0]]}]], "Input"],

Cell[BoxData[
    StyleBox[
      RowBox[{"sol\[Epsilon]", " ", "=", 
        RowBox[{
          RowBox[{
            StyleBox[\(firstOrderPert[eq1, x, {x0, 0}, \[Epsilon]]\),
              FontColor->RGBColor[1, 0, 0]], 
            "//", \(Collect[#, {x0, \[Epsilon], \ \ Cos[x_]\ }] &\)}], " ", 
          "//", \(Map[FullSimplify, #, 1] &\)}]}],
      FontColor->RGBColor[1, 0, 0]]], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(test1 = \(solt[\([1]\)] /. \[Epsilon]^n_ /; n > 1 \[Rule] 0 // Apart\) // 
        Collect[#, t] &\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(\ \)\(test2 = \ 
      Series[sol\[Epsilon], {t, 0, 6}] // Normal\)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(test1 \[Equal] test2\)], "Input"],

Cell[BoxData[
    \(\(values = {x0 \[Rule] 1.2\ , p0 \[Rule] 0, k \[Rule] 1, 
          m \[Rule] 1, \[Epsilon] \[Rule] 1/2};\)\)], "Input"],

Cell[BoxData[
    \(\(nsol = 
        NDSolve[{eqMotion /. values, p[0] \[Equal] 0, 
              x[0] \[Equal] 1.2\ \ }, {p[t], x[t]}, {t, 0\ , 30\ }] // 
          Flatten;\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(Plot[\({\ sol\[Epsilon]\ , solt[\([1]\)], x[t]} /. nsol\) /. 
            values\ \ \  // Evaluate, {t, 0, 
          30}, \[IndentingNewLine]PlotStyle \[Rule] {Dashing[{0.01}], 
            Dashing[{0.05}], \ 
            Thickness[0.005]}, \[IndentingNewLine]GridLines \[Rule] 
          Automatic]\ ;\)\)], "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 3: Cylindrical Coordinates  ", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  Hyphenation->False],

Cell[CellGroupData[{

Cell["Remarks and outline ", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(firstDiffSeries[eqin_, {z_, p_}, initRule_List, order_, 
        t_:  t] := \[IndentingNewLine]Module[{eq, zSer, pSer, eSer, vars, 
          sol, zpsol}, \[IndentingNewLine]eq = 
          Table[eqin[\([i, 1]\)] - eqin[\([i, 2]\)] \[Equal] 0, {i, 
              2}]; \[IndentingNewLine]zSer = 
          Series[z[t], {t, 0, order}]; \[IndentingNewLine]pSer = 
          Series[p[t], {t, 0, order}]; \[IndentingNewLine]eSer = 
          eq //. \(({z[t] \[Rule] zSer, p[t] \[Rule] pSer})\) // 
            ExpandAll; \[IndentingNewLine]vars = \((Table[{D[z[t], {t, j}], 
                    D[p[t], {t, j}]}, {j, 1, order + 1}] /. t \[Rule] 0)\) // 
            Flatten; \ \ \ \ \ sol = 
          Solve[eSer, vars] // 
            Flatten; \[IndentingNewLine]zpSol = \({zSer, pSer} //. sol\) //. 
            initRule; \[IndentingNewLine]Return[
          zpSol]\[IndentingNewLine]]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Required packages", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[" ",
    FontColor->RGBColor[1, 0, 0]],
  "Needs[\"Calculus`VectorAnalysis`\"]"
}], "Input",
  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]],

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(rRule = 
      rVector \[Rule] \((Evaluate[
              CoordinatesToCartesian[{r[#], \[Theta][#], z[#]}, 
                Cylindrical]] &)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[{
    \(T = \((1\/2\ m\ \(rVector'\)[t] . \(rVector'\)[t])\) //. rRule // 
        Simplify\), "\[IndentingNewLine]", 
    \(L = T - V[r[t], \[Theta][t], z[t]] // Simplify\)}], "Input"],

Cell[BoxData[
    \(\({pRule, hamiltonian, eqMotion} = 
        Hamilton[L, {r, \[Theta], z}, {pr, p\[Theta], pz}];\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(pRule\)], "Input"],

Cell[BoxData[
    \(hamiltonian\)], "Input"],

Cell[BoxData[
    \(eqMotion // ColumnForm\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[{
    \(\(vRule = {V \[Rule] \((\(-\(k\/\@\(#1\^2 + #3\^2\)\)\) &)\)};\)\), "\
\[IndentingNewLine]", 
    \(V[r[t], \[Theta][t], z[t]] //. vRule\)}], "Input"],

Cell[BoxData[
    \(\(zRule = {z \[Rule] \((0 &)\), pz \[Rule] \((0 &)\)};\)\)], "Input"],

Cell[BoxData[{
    \(\(eq1 = \(eqMotion //. vRule\) /. zRule // 
          PowerExpand;\)\), "\[IndentingNewLine]", 
    \(eq1 // ColumnForm\)}], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eq2 = eq1 //. p\[Theta] \[Rule] \((m\ h &)\)\)], "Input"],

Cell[BoxData[{
    \(\(rEq = eq2[\([{1, 4}]\)];\)\), "\[IndentingNewLine]", 
    \(rEq // ColumnForm\)}], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(\(initial = {r[0] \[Rule] r0, pr[0] \[Rule] 0};\)\)], "Input"],

Cell[BoxData[
    \(pert = \ \(\(firstDiffSeries[rEq, {r, pr}, initial, 4, 
          t]\)\(//\)\(Simplify\)\(\ \)\)\)], "Input",
  Hyphenation->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 4: Swinging Atwood Machine   ", "Subsection",
  Hyphenation->False],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[{
    \(\(T = \(m\/2\) {\(x1'\)[t], \(y1'\)[t]} . \ {\(x1'\)[t], \(y1'\)[
                  t]} + \ M\/2\ \(x2'\)[t]\^2;\)\), "\[IndentingNewLine]", 
    \(\ \(V = \(-g\)\ \ m\ x1[t] - g\ \ \ M\ x2[t];\)\)}], "Input"],

Cell[BoxData[
    \(\(change = \[IndentingNewLine]{x1 \[Rule] \((r[#]\ Cos[\[Theta][#]] \
&)\), \[IndentingNewLine]y1 \[Rule] \((r[#]\ Sin[\[Theta][#]] &)\)};\)\)], \
"Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(L0Rule = x2 \[Rule] \((L0 - r[#] &)\);\)\)], "Input"],

Cell["L=T-V /.L0Rule /.change //Simplify ", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\({xpRule, ham, eqMotion} = 
        Hamilton[L\ , {\[Theta], r}, {p\[Theta], pr}] // 
          Simplify;\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(xpRule\)], "Input"],

Cell[BoxData[
    \(ham\)], "Input"],

Cell[BoxData[
    \(eqMotion // ColumnForm\)], "Input"],

Cell[BoxData[
    \(\(eqMotion /. {p\[Theta][t] \[Rule] 0, \ \[Theta][t] \[Rule] 
            0}\) /. \(\(r\)\(\ \)\(\[Rule]\)\((x1[#] &\ )\)\(\ \)\)\)], \
"Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(\(values = {m \[Rule] 1, M \[Rule] 1.05, g \[Rule] 1};\)\)], "Input"],

Cell[BoxData[
    \(\(initial = {r[0] \[Equal] 10, 
          pr[0] \[Equal] 0, \[Theta][0] \[Equal] \[Pi]/12, 
          p\[Theta][0] \[Equal] 0};\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(eq1 = {eqMotion, initial} /. values // Flatten;\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(nSol = 
        NDSolve[eq1, {r\ , pr, \[Theta]\ , p\[Theta]}, {t, 0, 250\ }\ \ ] // 
          Flatten\ ;\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\({r1[t_], \[Theta]1[t_], pr1[t_], 
          p\[Theta]1[t_]} = {r[t], \[Theta][t], pr[t], \ p\[Theta][t]} /. 
          nSol;\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(\ \)\(Plot[{\ r1[t], \ \[Theta]1[t]} // Evaluate, {t, 0, 
          250}, \[IndentingNewLine]PlotStyle \[Rule] {Dashing[{0.01}], 
            Thickness[0.008]}\ ];\)\)\)], "Input"],

Cell[BoxData[
    \(\(ParametricPlot[{\ 
            r1[t]\ Sin[\[Theta]1[t]], \(-r1[t]\)\ Cos[\[Theta]1[t]]} // 
          Evaluate, {t, 0, 80}];\)\)], "Input"],

Cell[BoxData[
    \(\(pt1 = \[IndentingNewLine]\(ParametricPlot[# // Evaluate, {t, 0, 
                250}, \[IndentingNewLine]Ticks \[Rule] 
                False, \[IndentingNewLine]DisplayFunction \[Rule] 
                Identity\[IndentingNewLine]] &\)\  /@ \ \ {{\ r1[t]\ \ , \ 
              pr1[t]\ \ }, {\ \[Theta]1[t]\ \ , \ 
              p\[Theta]1[t]\ \ }};\)\)], "Input"],

Cell[BoxData[
    \(\(Show[GraphicsArray[pt1]];\)\)], "Input",
  Hyphenation->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Problem 5: Spherical Pendulum ",
  StyleBox[" ",
    FontColor->RGBColor[1, 0, 0]]
}], "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Required Packages  ", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Graphics`Shapes`\>"]\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Solution  ", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[{
    RowBox[{" ", 
      RowBox[{
        RowBox[{"T", "=", 
          RowBox[{\(1\/2\), " ", "m", " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                      MultilineFunction->None], "[", "t", "]"}], "2"], "+", 
                SuperscriptBox[
                  RowBox[{
                    SuperscriptBox["y", "\[Prime]",
                      MultilineFunction->None], "[", "t", "]"}], "2"], "+", 
                SuperscriptBox[
                  RowBox[{
                    SuperscriptBox["z", "\[Prime]",
                      MultilineFunction->None], "[", "t", "]"}], "2"]}], 
              ")"}]}]}], ";"}]}], "\[IndentingNewLine]", 
    RowBox[{\(V = m\ g\ z[t]\ ;\), " "}]}], "Input"],

Cell[BoxData[
    \(\(change = \[IndentingNewLine]{x\  \[Rule] \((L0\ \
Cos[\[Phi][#]]\ \ Sin[\ \[Theta][#]] &)\), \[IndentingNewLine]y\  \[Rule] \
\((L0\ Sin[\[Phi][#]]\ \ Sin[\ \[Theta][#]] &)\), \[IndentingNewLine]z\  \
\[Rule] \((L0\ Cos[\[Theta][#]] &)\)};\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\[Psi]Rule = \ \[Theta] \[Rule] \((\[Pi] - \[Psi][#] &)\);\)\)], \
"Input",
  Hyphenation->False],

Cell[BoxData[
    \(L = \(T - V /. change\) /. \[Psi]Rule // Simplify\)], "Input",
  Hyphenation->False],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\ \)\(eq1 = \ \({prule, ham, eqMotion} = 
          Hamilton[L, {\[Psi], \[Phi]}, {p\[Psi], p\[Phi]}, 
            t]\);\)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(prule\)], "Input"],

Cell[BoxData[
    \(ham\)], "Input"],

Cell[BoxData[
    \(eqMotion\  // ColumnForm\)], "Input"]
}, Closed]],

Cell[BoxData[
    \(eqMotion // ColumnForm\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(p\[Phi]Rule = {p\[Phi] \[Rule] \((m\ h &)\)};\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(\ \)\(eqMotion /. p\[Phi]Rule // ColumnForm\)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(\ \ \)\(\(\(eqMotion\  /. \ p\[Phi]Rule\) /. h \[Rule] 0 // 
        ExpandAll\)\(//\)\(Flatten\)\(\ \ \)\)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(\(\(Solve[{eqMotion[\([1]\)], \ 
                  D[eqMotion[\([3]\)], t]}\ , \(\[Psi]''\)[t]]\  /. 
              Rule \[Rule] Equal\) /. \ p\[Phi]Rule\) /. h \[Rule] 0 // 
        ExpandAll\)\(//\)\(Flatten\)\(\ \ \)\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(eqMotion\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(values = {L0 \[Rule] 1, g \[Rule] 1, m \[Rule] 1};\)\)], "Input"],

Cell[BoxData[
    \(\(initial = {\[Phi][0] == 0, 
          p\[Phi][0] \[Equal] 0.1, \[Psi][0] \[Equal] \[Pi]/2, 
          p\[Psi][0] \[Equal] 0};\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(\ \ \)\(nSol\  = \ 
        NDSolve[\ \ {eqMotion, initial} /. values // 
              Flatten\ , {\[Psi], \[Phi], p\[Psi], p\[Phi]}, \ {t, \ 0, \ 
              25}]\  // Flatten\ ;\)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\({\[Psi]1[t_]\ , \[Phi]1[t_]\ } = \ \ {\ \[Psi][t], \ \ \[Phi][t]\ } /. 
          nSol;\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(pt1 = \
\[IndentingNewLine]ParametricPlot3D[\[IndentingNewLine]\(\(\(\({x[t], y[t], 
                        z[t], Thickness[ .01]}\  /. change\) /. \[Psi]Rule\) /. 
                  values\) /. \[Psi] \[Rule] \[Psi]1\) /. \[Phi] \[Rule] \
\[Phi]1\  // Evaluate, \[IndentingNewLine]{t, 0, 
            25}, \[IndentingNewLine]DisplayFunction \[Rule] 
            Identity\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    \(Needs["\<Graphics`Shapes`\>"]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(sphere = \ Graphics3D[Sphere[0.96]]\ \ ;\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(pt1 = 
        Show[\ sphere, pt1, Boxed \[Rule] False\ , Shading \[Rule] False, 
          ViewPoint \[Rule] {1, 1, 0}];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[pt1 /. Polygon[x_] \[Rule] {Hue[0.8], Line[x]}, \ 
        ViewPoint \[Rule] {1, 0, 1/2}];\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell["6.5 Hamilton-Jacobi Problems  ", "Section",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Overview", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(HamiltonJacobi[L_, xList_List, pList__List, wList_List, a_, 
        t_:  t] := \[IndentingNewLine]Module[{xx, vv, pp, sol, ham, ww, 
          hamPrincFunc, pNewRule, HJeq}, \[IndentingNewLine]xx = 
          Map[#[t] &, xList]; \[IndentingNewLine]vv = 
          Map[\(#'\)[t] &, xList]; \[IndentingNewLine]pp = 
          Map[#[t] &, pList]; \[IndentingNewLine]sol = 
          Solve[\((\(D[L, #] &\) /@ vv)\) \[Equal] pp, vv] // 
            Flatten; \[IndentingNewLine]ham = \(\((pp . vv - L)\) //. sol // 
              Simplify\) // Expand; \[IndentingNewLine]ww = 
          Map[#[t] &, 
            wList, {2}]; \[IndentingNewLine]hamPrincFunc = \((Plus @@ ww)\) - 
            a\ t; \[IndentingNewLine]pNewRule = {pp \[Rule] \((\(D[
                          hamPrincFunc, #] &\) /@ xx)\) // Thread} // 
            Flatten; \[IndentingNewLine]HJeq = \((ham //. pNewRule)\) - 
              a \[Equal] 0; \ \ \ \ \ \ \ \[IndentingNewLine]Return[{sol, 
            hamPrincFunc, HJeq}]\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"L", "=", 
        RowBox[{
          RowBox[{\(+\(1\/2\)\), " ", "m", " ", 
            SuperscriptBox[
              RowBox[{
                SuperscriptBox["x", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], "2"]}], 
          "-", \(V[x[t]]\)}]}], 
      ";"}], "\[IndentingNewLine]", \({pRule, hamPrincFunc, eqHamJac} = 
        HamiltonJacobi[L, {x}, {p}, {W[x]}, a];\)}], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(pRule\)], "Input"],

Cell[BoxData[
    \(hamPrincFunc\)], "Input"],

Cell[BoxData[
    \(eqHamJac\  // ColumnForm\)], "Input"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"L", "=", 
        RowBox[{
          RowBox[{\(+\(1\/2\)\), " ", "m", " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                      MultilineFunction->None], "[", "t", "]"}], "2"], "+", 
                SuperscriptBox[
                  RowBox[{
                    SuperscriptBox["y", "\[Prime]",
                      MultilineFunction->None], "[", "t", "]"}], "2"]}], 
              ")"}]}], "-", \(V[x[t], y[t]]\)}]}], 
      ";"}], "\[IndentingNewLine]", \(HamiltonJacobi[
      L, {x, y}, {px, py}, {W1[x], W2[y]}, a]\)}], "Input",
  Hyphenation->False],

Cell["Protect[ HamiltonJacobi ];", "Input",
  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 1: Harmonic Oscillator   ", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[{
    RowBox[{
      RowBox[{"T", "=", 
        RowBox[{\(1\/2\), " ", "m", " ", 
          SuperscriptBox[
            RowBox[{
              SuperscriptBox["x", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "2"]}]}], 
      ";"}], "\[IndentingNewLine]", \(V = 
        1\/2\ k\ x[t]\^2;\), "\[IndentingNewLine]", \(L = T - V\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\({xpRule, ham, eqMotion} = 
        Hamilton[L, {x}, {p}] //. {x_[t] \[Rule] x};\)\)], "Input"],

Cell[BoxData[
    \(xpRule\)], "Input"],

Cell[BoxData[
    \(ham\)], "Input"],

Cell[BoxData[
    \(eqMotion\)], "Input"]
}, Closed]],

Cell[BoxData[
    \(\(pRule = {p \[Rule] D[S[x, t], x]};\)\)], "Input"],

Cell["eqHJ = (ham + D[S[x,t],t]) ==0  //. pRule", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(sRule = {S \[Rule] \((W[#1] - P\ #2 &)\)};\)\)], "Input"],

Cell["eqW= eqHJ //.sRule", "Input",
  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection",
  Hyphenation->False],

Cell["dWRule= Solve[eqW,W'[x]][[2]]", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(wRule = 
      W[x] \[Rule] \ \ \@\(2  m\ P\)\ \ Integrate[\@\(1 - x\^2\ \[Lambda]\), 
              x] /. \[Lambda] \[Rule] k\/\(2\ P\)\)], "Input"],

Cell["eq1= Q== D[S[x,t] /.sRule /.wRule,P] //Simplify ", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["\<\
xSol= Solve[eq1,x ] //Simplify //PowerExpand //Simplify //Flatten \
\
\>", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(eq2 = \(xpRule /. Rule \[Rule] Equal // Solve[#, p] &\)\  // 
        Flatten\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eq2 /. x' \[Rule] D[x /. xSol, t]\)], "Input",
  Hyphenation->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 2: Particle in a Constant Gravity Field  ", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Solution", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    StyleBox[\(Clear["\<Global`*\>"]\),
      FontFamily->"Courier",
      FontWeight->"Bold"]], "Input"],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[{
    RowBox[{
      RowBox[{"T", "=", 
        RowBox[{\(1\/2\), " ", "m", " ", 
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                RowBox[{
                  SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"], "+", 
              SuperscriptBox[
                RowBox[{
                  SuperscriptBox["z", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], 
            ")"}]}]}], ";"}], "\n", \(V = g\ m\ z[t];\), "\n", \(L = 
      T - V\)}], "Input"],

Cell[BoxData[
    \({prule, S, Chareq} = 
      HamiltonJacobi[L, {x, z}, {px, pz}, {Wx[x]\ , Wz[z]}, P] // 
        ExpandAll\)], "Input",
  Hyphenation->False],

Cell[BoxData[{
    \(eq1a = 
      Chareq[\([1, {1, 2, 4}]\)] \[Equal] A\  /. 
        z[t] \[Rule] z\), "\[IndentingNewLine]", 
    \(eq1b = 
      Chareq[\([1, 3]\)] \[Equal] \(-A\)\ \ \  /. x[t] \[Rule] x\)}], "Input",\

  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[{
    \(Wxsol = \(DSolve[eq1a, Wz[z], z]\)[\([2]\)]\), "\[IndentingNewLine]", 
    \(Wzsol = \(DSolve[eq1b, Wx[x], x]\)[\([2]\)]\)}], "Input"],

Cell[BoxData[
    \(Ssol = \(\(\(-P\)\ t + Wx[x] + Wz[z] /. \ 
          Wxsol\)\(/.\)\(Wzsol\)\(\ \)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(Qeq = \(\({Qx, 
              Qz} \[Equal] \((\ \(D[Ssol, #] &\) /@ {A, P} // Flatten)\) // 
          Thread\)\(\ \)\(//\)\(Simplify\)\(\ \)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(Sol = \(Solve[Qeq, {x, z}] /. {x \[Rule] x[t], z \[Rule] z[t]}\) /. 
          Rule \[Rule] Equal // Flatten\)], "Input"],

Cell[BoxData[
    \(\(\(\(Solve[{Sol, \((Sol /. t \[Rule] 0)\), \((D[Sol, t] /. 
                  t \[Rule] 0)\)} // Flatten, {x[t], z[t]}, {A, P, Qx, Qz}] // 
        Flatten\) // ExpandAll\)\(\n\)
    \)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 3:  Kepler's Problem and Hamilton-Jacobi Equations ", \
"Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Remarks and outline", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Required package", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Calculus`VectorAnalysis`\>"]\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(Needs["\<Calculus`VectorAnalysis`\>"]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(rRule = 
      rvector \[Rule] \((Evaluate[
              CoordinatesToCartesian[{r[#], \[Theta][#], z[#]}, 
                Cylindrical]] &)\)\)], "Input"],

Cell[BoxData[{
    \(\(T = \(m\/2\ \(rvector'\)[t] . \(rvector'\)[t] //. 
              rRule\)\  //. {\(z'\)[t] \[Rule] 0}\  // 
          Simplify;\)\), "\[IndentingNewLine]", 
    \(\(V = \(-\(k\/r[t]\)\);\)\)}], "Input"],

Cell[BoxData[
    \(\(\(\ \)\(L = T - V\)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[{
    \(\(\({momRule, hamPF, eqMotion} = 
        HamiltonJacobi[
          L, {r, \[Theta]}, {pr, p\[Theta]}, {Wr[r], W\[Theta][\[Theta]]}, 
          En];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \({momRule, hamPF, eqMotion} // ColumnForm\)}], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(w\[Theta]rule = \(DSolve[{\(W\[Theta]'\)[\[Theta]] \[Equal] \(+el\), 
            W\[Theta][0] \[Equal] 
              0}, {W\[Theta]}, \[Theta]]\)[\([1]\)]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eq1 = \((eqMotion //. 
                w\[Theta]rule // \(Solve[#, \(Wr'\)[
                      r[t]]]\)[\([1]\)] &)\) /. \ \ r[t] \[Rule] r\  // 
        PowerExpand\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eq2 = D[eq1[\([1, 2]\)], el]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eq3 = 
      Integrate[\ 1\/\(r\ \@\(\(-1\) + a\ r + b\ r\^2\)\), 
          r\ ] /. \ {a \[Rule] \(2\ k\ m\)\/el\^2, 
          b \[Rule] \(2\ En\ m\)\/el\^2}\)], "Input"],

Cell[BoxData[
    \(\(\(\ \ \)\(Qeq = \ 
      Q == \(\(\[Theta]\)\(\ \)\(+\)\(eq3\)\(\ \)\)\)\)\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(ueq = Qeq /. r \[Rule] 1\/u\)], "Input"],

Cell[BoxData[
    \(usol = \(\(\(u\  /. \(Solve[ueq, u]\)[\([2]\)]\)\  /. {Q \[Rule] \[Pi]/
                    2\ } // Simplify\) // PowerExpand\) // 
        Simplify\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eq4 = 
      usol \[Equal] \(1 + e\ Cos[\[Theta]]\)\/\(a\ \((1 - e\^2)\)\)\)], \
"Input"],

Cell[BoxData[
    \(eq5 = \ eq4 /. {\[Theta] \[Rule] {0, \[Pi]/2\ }}\  // Thread\)], "Input",\

  Hyphenation->False],

Cell[" Solve[eq5 ,{a,e}]", "Input",
  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["6.6 Exercises", "Section",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Exercise 1: Atwood Machine  ", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Exercise 2:  Double Atwood machine     ", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Exercise 3: Spherical Pendulum ",
  StyleBox[" ",
    FontColor->RGBColor[1, 0, 0]]
}], "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Exercise 4: Double Pendulum", "Subsubsection",
  Hyphenation->False],

Cell["Exercise 5:  Spring Pendulum  ", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Exercise 6:  Hamilton-Jacobi in parabolic coordinates", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Exercise 7:  How Hamilton Works",
  StyleBox["  ",
    FontColor->RGBColor[0, 0, 1]]
}], "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Exercise 8:  How HamiltonJacobi Works",
  StyleBox["  ",
    FontColor->RGBColor[0, 0, 1]]
}], "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Exercise 9:  How firstDiffSeries Works",
  StyleBox["  ",
    FontColor->RGBColor[0, 0, 1]]
}], "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Exercise 10: How firstOrderPert Works",
  StyleBox["  ",
    FontColor->RGBColor[0, 0, 1]]
}], "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]]
},
FrontEndVersion->"4.1 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
WindowToolbars->"EditBar",
CellGrouping->Manual,
WindowSize->{814, 903},
WindowMargins->{{70, Automatic}, {Automatic, 27}},
Magnification->1
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 116, 2, 42, "Subsubsection"],
Cell[1846, 56, 1886, 33, 657, "Input",
  Evaluatable->False]
}, Closed]],
Cell[3747, 92, 365, 11, 115, "SmallText"],
Cell[4115, 105, 118, 3, 114, "Title",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[4258, 112, 109, 3, 60, "Section",
  Evaluatable->False],
Cell[4370, 117, 144, 3, 43, "Input"]
}, Closed]],
Cell[4529, 123, 141, 3, 40, "Section",
  Evaluatable->False],
Cell[4673, 128, 163, 6, 45, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[4861, 138, 60, 0, 45, "Subsection"],
Cell[4924, 140, 96, 2, 27, "Input"],
Cell[5023, 144, 74, 2, 27, "Input"],
Cell[5100, 148, 113, 2, 24, "Input"],
Cell[5216, 152, 94, 2, 24, "Input"],
Cell[5313, 156, 74, 2, 24, "Input"],
Cell[5390, 160, 94, 2, 24, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[5521, 167, 140, 3, 29, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[5686, 174, 55, 1, 42, "Subsubsection"],
Cell[5744, 177, 76, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[5857, 184, 55, 1, 42, "Subsubsection"],
Cell[5915, 187, 872, 22, 62, "Input"],
Cell[6790, 211, 289, 5, 43, "Input"],
Cell[7082, 218, 67, 1, 27, "Input"],
Cell[7152, 221, 96, 2, 24, "Input"],
Cell[7251, 225, 90, 1, 24, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[7378, 231, 53, 1, 42, "Subsubsection"],
Cell[7434, 234, 126, 3, 27, "Input"],
Cell[7563, 239, 96, 2, 24, "Input"],
Cell[7662, 243, 91, 2, 24, "Input"],
Cell[7756, 247, 105, 2, 24, "Input"],
Cell[7864, 251, 110, 2, 24, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[8011, 258, 54, 1, 42, "Subsubsection"],
Cell[8068, 261, 319, 5, 59, "Input"],
Cell[8390, 268, 275, 4, 56, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[8714, 278, 137, 3, 29, "Subsection",
  Evaluatable->False],
Cell[8854, 283, 114, 3, 42, "Subsubsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[8993, 290, 103, 3, 28, "Subsubsection",
  Evaluatable->False],
Cell[9099, 295, 76, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[9212, 302, 102, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[9317, 307, 265, 5, 27, "Input"],
Cell[9585, 314, 116, 3, 27, "Input"],
Cell[9704, 319, 897, 22, 78, "Input"],
Cell[10604, 343, 87, 2, 24, "Input"],
Cell[10694, 347, 155, 3, 24, "Input"],
Cell[10852, 352, 225, 4, 24, "Input"],
Cell[11080, 358, 153, 3, 24, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[11270, 366, 101, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[11374, 371, 247, 4, 59, "Input"],
Cell[11624, 377, 144, 3, 24, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[11805, 385, 101, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[11909, 390, 152, 3, 27, "Input"],
Cell[12064, 395, 163, 3, 27, "Input"],
Cell[12230, 400, 345, 7, 91, "Input"],
Cell[12578, 409, 242, 6, 43, "Input"],
Cell[12823, 417, 117, 3, 27, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[12989, 426, 128, 3, 29, "Subsection",
  Evaluatable->False],
Cell[13120, 431, 114, 3, 42, "Subsubsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[13259, 438, 103, 3, 28, "Subsubsection",
  Evaluatable->False],
Cell[13365, 443, 76, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[13478, 450, 101, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[13582, 455, 287, 6, 27, "Input"],
Cell[13872, 463, 143, 3, 27, "Input"],
Cell[14018, 468, 944, 24, 44, "Input"],
Cell[14965, 494, 113, 2, 24, "Input"],
Cell[15081, 498, 98, 2, 27, "Input"],
Cell[15182, 502, 94, 2, 24, "Input"],
Cell[15279, 506, 194, 4, 28, "Input"],
Cell[15476, 512, 168, 3, 28, "Input"],
Cell[15647, 517, 137, 3, 24, "Input"],
Cell[15787, 522, 158, 3, 28, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[15982, 530, 101, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[16086, 535, 90, 1, 27, "Input"],
Cell[16179, 538, 91, 2, 24, "Input"],
Cell[16273, 542, 159, 3, 24, "Input"],
Cell[16435, 547, 131, 3, 24, "Input"],
Cell[16569, 552, 82, 2, 24, "Input"],
Cell[16654, 556, 110, 2, 24, "Input"],
Cell[16767, 560, 353, 7, 75, "Input"],
Cell[17123, 569, 576, 10, 104, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[17736, 584, 53, 1, 42, "Subsubsection"],
Cell[17792, 587, 695, 10, 107, "Input"],
Cell[18490, 599, 88, 2, 27, "Input"],
Cell[18581, 603, 248, 5, 56, "Input"],
Cell[18832, 610, 528, 11, 139, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[19397, 626, 101, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[19501, 631, 91, 1, 27, "Input"],
Cell[19595, 634, 77, 2, 27, "Input"],
Cell[19675, 638, 78, 1, 24, "Input"],
Cell[19756, 641, 120, 2, 28, "Input"],
Cell[19879, 645, 173, 3, 24, "Input"],
Cell[20055, 650, 256, 4, 24, "Input"],
Cell[20314, 656, 244, 7, 69, "Input"],
Cell[20561, 665, 463, 7, 75, "Input"],
Cell[21027, 674, 84, 2, 27, "Input"],
Cell[21114, 678, 370, 6, 56, "Input"],
Cell[21487, 686, 138, 3, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[21662, 694, 101, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[21766, 699, 179, 8, 87, "Input"],
Cell[21948, 709, 380, 7, 123, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[22377, 722, 92, 1, 29, "Subsection"],

Cell[CellGroupData[{
Cell[22494, 727, 55, 1, 42, "Subsubsection"],
Cell[22552, 730, 76, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[22665, 737, 55, 1, 42, "Subsubsection"],
Cell[22723, 740, 559, 15, 44, "Input"],
Cell[23285, 757, 138, 4, 44, "Input"],
Cell[23426, 763, 305, 5, 43, "Input"],
Cell[23734, 770, 71, 1, 27, "Input"],
Cell[23808, 773, 168, 4, 24, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[24013, 782, 53, 1, 42, "Subsubsection"],
Cell[24069, 785, 137, 3, 27, "Input"],
Cell[24209, 790, 148, 4, 27, "Input"],
Cell[24360, 796, 179, 4, 24, "Input"],
Cell[24542, 802, 138, 4, 24, "Input"],
Cell[24683, 808, 237, 5, 24, "Input"],
Cell[24923, 815, 169, 4, 24, "Input"],
Cell[25095, 821, 129, 3, 24, "Input"],
Cell[25227, 826, 90, 2, 24, "Input"],
Cell[25320, 830, 453, 7, 91, "Input"],
Cell[25776, 839, 102, 2, 27, "Input"],
Cell[25881, 843, 61, 2, 24, "Input"],
Cell[25945, 847, 162, 3, 24, "Input"],
Cell[26110, 852, 414, 7, 88, "Input"],
Cell[26527, 861, 102, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[26666, 868, 53, 1, 42, "Subsubsection"],
Cell[26722, 871, 446, 7, 91, "Input"],
Cell[27171, 880, 103, 2, 27, "Input"],
Cell[27277, 884, 481, 8, 88, "Input"],
Cell[27761, 894, 103, 2, 27, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[27913, 902, 146, 3, 29, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[28084, 909, 103, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[28190, 914, 76, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[28303, 921, 101, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[28407, 926, 614, 15, 62, "Input"],
Cell[29024, 943, 104, 2, 27, "Input"],
Cell[29131, 947, 381, 10, 62, "Input"],
Cell[29515, 959, 83, 2, 27, "Input"],
Cell[29601, 963, 137, 3, 24, "Input"],
Cell[29741, 968, 193, 5, 40, "Input"],
Cell[29937, 975, 129, 3, 24, "Input"],
Cell[30069, 980, 837, 21, 43, "Input"],
Cell[30909, 1003, 125, 3, 27, "Input"],
Cell[31037, 1008, 197, 4, 40, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[31271, 1017, 101, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[31375, 1022, 131, 3, 27, "Input"],
Cell[31509, 1027, 163, 3, 24, "Input"],
Cell[31675, 1032, 125, 3, 24, "Input"],
Cell[31803, 1037, 136, 3, 24, "Input"],
Cell[31942, 1042, 109, 2, 27, "Input"],
Cell[32054, 1046, 306, 5, 72, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[32397, 1056, 101, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[32501, 1061, 134, 3, 27, "Input"],
Cell[32638, 1066, 248, 4, 27, "Input"],
Cell[32889, 1072, 128, 5, 42, "Input"],
Cell[33020, 1079, 352, 6, 75, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[33421, 1091, 120, 3, 29, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[33566, 1098, 55, 1, 42, "Subsubsection"],
Cell[33624, 1101, 76, 2, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[33737, 1108, 54, 1, 42, "Subsubsection"],
Cell[33794, 1111, 133, 3, 43, "Input"],
Cell[33930, 1116, 736, 18, 98, "Input"],
Cell[34669, 1136, 179, 3, 27, "Input"],
Cell[34851, 1141, 157, 3, 27, "Input"],
Cell[35011, 1146, 460, 7, 107, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[35508, 1158, 54, 1, 42, "Subsubsection"],
Cell[35565, 1161, 103, 2, 27, "Input"],
Cell[35671, 1165, 141, 3, 27, "Input"],
Cell[35815, 1170, 142, 3, 27, "Input"],
Cell[35960, 1175, 137, 3, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[36134, 1183, 56, 1, 42, "Subsubsection"],
Cell[36193, 1186, 152, 3, 27, "Input"],
Cell[36348, 1191, 260, 5, 27, "Input"],
Cell[36611, 1198, 150, 3, 27, "Input"],
Cell[36764, 1203, 173, 4, 27, "Input"],
Cell[36940, 1209, 104, 4, 42, "Input"],
Cell[37047, 1215, 418, 6, 91, "Input"],
Cell[37468, 1223, 490, 8, 107, "Input"],
Cell[37961, 1233, 481, 8, 123, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[38479, 1246, 56, 1, 42, "Subsubsection"],
Cell[38538, 1249, 149, 3, 27, "Input"],
Cell[38690, 1254, 269, 5, 27, "Input"],
Cell[38962, 1261, 148, 3, 27, "Input"],
Cell[39113, 1266, 149, 3, 27, "Input"],
Cell[39265, 1271, 107, 4, 42, "Input"],
Cell[39375, 1277, 416, 6, 91, "Input"],
Cell[39794, 1285, 461, 8, 107, "Input"],
Cell[40258, 1295, 517, 9, 139, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[40812, 1309, 54, 1, 42, "Subsubsection"],
Cell[40869, 1312, 239, 8, 104, "Text"],
Cell[41111, 1322, 1126, 23, 139, "Input"],
Cell[42240, 1347, 222, 5, 43, "Input"]
}, Open  ]]
}, Closed]],
Cell[42489, 1356, 205, 7, 40, "Section",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[42719, 1367, 165, 6, 45, "Subsection",
  Evaluatable->False],
Cell[42887, 1375, 257, 9, 102, "Input"],
Cell[43147, 1386, 78, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[43262, 1393, 187, 7, 29, "Subsection",
  Evaluatable->False],
Cell[43452, 1402, 116, 3, 42, "Subsubsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[43593, 1409, 107, 3, 28, "Subsubsection",
  Evaluatable->False],
Cell[43703, 1414, 76, 2, 27, "Input"],
Cell[43782, 1418, 513, 13, 62, "Input"],
Cell[44298, 1433, 71, 2, 27, "Input"],
Cell[44372, 1437, 90, 2, 24, "Input"],
Cell[44465, 1441, 174, 4, 43, "Input"],
Cell[44642, 1447, 106, 2, 24, "Input"],
Cell[44751, 1451, 70, 2, 24, "Input"],
Cell[44824, 1455, 87, 2, 24, "Input"],
Cell[44914, 1459, 441, 8, 88, "Input"],
Cell[45358, 1469, 140, 3, 24, "Input"],
Cell[45501, 1474, 187, 3, 27, "Input"],
Cell[45691, 1479, 109, 2, 24, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[45849, 1487, 133, 3, 29, "Subsection",
  Evaluatable->False],
Cell[45985, 1492, 114, 3, 42, "Subsubsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[46124, 1499, 103, 3, 28, "Subsubsection",
  Evaluatable->False],
Cell[46230, 1504, 76, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[46343, 1511, 101, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[46447, 1516, 744, 19, 78, "Input"],
Cell[47194, 1537, 98, 2, 24, "Input"],
Cell[47295, 1541, 238, 4, 59, "Input"],
Cell[47536, 1547, 222, 5, 40, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[47795, 1557, 101, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[47899, 1562, 196, 4, 27, "Input"],
Cell[48098, 1568, 172, 3, 27, "Input"],
Cell[48273, 1573, 100, 2, 24, "Input"],
Cell[48376, 1577, 123, 4, 24, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[48536, 1586, 101, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[48640, 1591, 156, 3, 27, "Input"],
Cell[48799, 1596, 168, 5, 42, "Input"],
Cell[48970, 1603, 102, 2, 27, "Input"],
Cell[49075, 1607, 117, 2, 27, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[49241, 1615, 138, 3, 29, "Subsection",
  Evaluatable->False],
Cell[49382, 1620, 443, 11, 122, "Text"],
Cell[49828, 1633, 114, 3, 42, "Subsubsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[49967, 1640, 103, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[50073, 1645, 76, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[50186, 1652, 101, 3, 28, "Subsubsection",
  Evaluatable->False],
Cell[50290, 1657, 618, 16, 44, "Input"],
Cell[50911, 1675, 541, 14, 44, "Input"],
Cell[51455, 1691, 77, 2, 27, "Input"],
Cell[51535, 1695, 96, 2, 27, "Input"],
Cell[51634, 1699, 70, 2, 27, "Input"],
Cell[51707, 1703, 138, 5, 24, "Input"],
Cell[51848, 1710, 147, 3, 24, "Input"],
Cell[51998, 1715, 111, 2, 24, "Input"],
Cell[52112, 1719, 169, 3, 27, "Input"],
Cell[52284, 1724, 180, 4, 40, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[52501, 1733, 101, 3, 28, "Subsubsection",
  Evaluatable->False],
Cell[52605, 1738, 496, 9, 107, "Input"],
Cell[53104, 1749, 137, 3, 24, "Input"],
Cell[53244, 1754, 234, 4, 24, "Input"],
Cell[53481, 1760, 225, 5, 28, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[53743, 1770, 101, 3, 28, "Subsubsection",
  Evaluatable->False],
Cell[53847, 1775, 129, 3, 27, "Input"],
Cell[53979, 1780, 118, 4, 24, "Input"],
Cell[54100, 1786, 176, 3, 24, "Input"],
Cell[54279, 1791, 131, 2, 43, "Input"]
}, Closed]]
}, Closed]],
Cell[54437, 1797, 182, 7, 40, "Section",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[54644, 1808, 124, 3, 45, "Subsection",
  Evaluatable->False],
Cell[54771, 1813, 851, 15, 203, "Input"],
Cell[55625, 1830, 69, 2, 27, "Input"],
Cell[55697, 1834, 349, 10, 44, "Input"],
Cell[56049, 1846, 230, 5, 75, "Input"],
Cell[56282, 1853, 653, 16, 62, "Input"],
Cell[56938, 1871, 83, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[57058, 1878, 122, 3, 29, "Subsection",
  Evaluatable->False],
Cell[57183, 1883, 114, 3, 42, "Subsubsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[57322, 1890, 103, 3, 28, "Subsubsection",
  Evaluatable->False],
Cell[57428, 1895, 76, 2, 27, "Input"],
Cell[57507, 1899, 351, 9, 80, "Input"],
Cell[57861, 1910, 64, 2, 27, "Input"],
Cell[57928, 1914, 90, 2, 24, "Input"],
Cell[58021, 1918, 98, 2, 24, "Input"],
Cell[58122, 1922, 95, 2, 24, "Input"],
Cell[58220, 1926, 197, 4, 56, "Input"],
Cell[58420, 1932, 90, 2, 24, "Input"],
Cell[58513, 1936, 106, 2, 24, "Input"],
Cell[58622, 1940, 145, 3, 27, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[58816, 1949, 127, 3, 29, "Subsection",
  Evaluatable->False],
Cell[58946, 1954, 76, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[59047, 1960, 66, 1, 42, "Subsubsection"],
Cell[59116, 1963, 915, 15, 187, "Input"],
Cell[60034, 1980, 668, 17, 48, "Input"],
Cell[60705, 1999, 1100, 17, 187, "Input"],
Cell[61808, 2018, 272, 7, 29, "Input"],
Cell[62083, 2027, 140, 3, 27, "Input"]
}, Open  ]],
Cell[62238, 2033, 55, 1, 42, "Subsubsection"],

Cell[CellGroupData[{
Cell[62318, 2038, 53, 1, 42, "Subsubsection"],
Cell[62374, 2041, 351, 9, 80, "Input"],
Cell[62728, 2052, 71, 2, 27, "Input"],
Cell[62802, 2056, 205, 4, 43, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[63044, 2065, 53, 1, 42, "Subsubsection"],
Cell[63100, 2068, 112, 2, 27, "Input"],
Cell[63215, 2072, 152, 3, 27, "Input"],
Cell[63370, 2077, 379, 8, 91, "Input"],
Cell[63752, 2087, 91, 2, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[63880, 2094, 53, 1, 42, "Subsubsection"],
Cell[63936, 2097, 185, 4, 27, "Input"],
Cell[64124, 2103, 134, 3, 27, "Input"],
Cell[64261, 2108, 455, 10, 59, "Input"],
Cell[64719, 2120, 418, 10, 27, "Input"],
Cell[65140, 2132, 153, 3, 27, "Input"],
Cell[65296, 2137, 128, 3, 27, "Input"],
Cell[65427, 2142, 53, 1, 27, "Input"],
Cell[65483, 2145, 140, 2, 27, "Input"],
Cell[65626, 2149, 212, 5, 27, "Input"],
Cell[65841, 2156, 340, 6, 59, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[66230, 2168, 128, 3, 29, "Subsection",
  Evaluatable->False],
Cell[66361, 2173, 76, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[66462, 2179, 115, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[66580, 2184, 915, 15, 171, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[67532, 2204, 112, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[67647, 2209, 167, 6, 27, "Input"]
}, Closed]],
Cell[67829, 2218, 103, 3, 42, "Subsubsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[67957, 2225, 53, 1, 42, "Subsubsection"],
Cell[68013, 2228, 198, 5, 27, "Input"],
Cell[68214, 2235, 198, 3, 62, "Input"],
Cell[68415, 2240, 152, 3, 27, "Input"],
Cell[68570, 2245, 38, 1, 27, "Input"],
Cell[68611, 2248, 44, 1, 27, "Input"],
Cell[68658, 2251, 77, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[68772, 2258, 53, 1, 42, "Subsubsection"],
Cell[68828, 2261, 171, 3, 69, "Input"],
Cell[69002, 2266, 89, 1, 27, "Input"],
Cell[69094, 2269, 176, 4, 43, "Input"],
Cell[69273, 2275, 77, 1, 27, "Input"],
Cell[69353, 2278, 136, 3, 43, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[69526, 2286, 53, 1, 42, "Subsubsection"],
Cell[69582, 2289, 82, 1, 27, "Input"],
Cell[69667, 2292, 151, 3, 27, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[69867, 2301, 81, 1, 29, "Subsection"],

Cell[CellGroupData[{
Cell[69973, 2306, 55, 1, 42, "Subsubsection"],
Cell[70031, 2309, 76, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[70144, 2316, 53, 1, 42, "Subsubsection"],
Cell[70200, 2319, 230, 3, 61, "Input"],
Cell[70433, 2324, 197, 4, 59, "Input"],
Cell[70633, 2330, 75, 1, 27, "Input"],
Cell[70711, 2333, 100, 2, 27, "Input"],
Cell[70814, 2337, 163, 4, 27, "Input"],
Cell[70980, 2343, 39, 1, 27, "Input"],
Cell[71022, 2346, 36, 1, 27, "Input"],
Cell[71061, 2349, 55, 1, 27, "Input"],
Cell[71119, 2352, 186, 4, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[71342, 2361, 53, 1, 42, "Subsubsection"],
Cell[71398, 2364, 89, 1, 27, "Input"],
Cell[71490, 2367, 184, 4, 27, "Input"],
Cell[71677, 2373, 106, 2, 27, "Input"],
Cell[71786, 2377, 165, 4, 27, "Input"],
Cell[71954, 2383, 183, 4, 27, "Input"],
Cell[72140, 2389, 204, 3, 43, "Input"],
Cell[72347, 2394, 161, 3, 27, "Input"],
Cell[72511, 2399, 386, 6, 91, "Input"],
Cell[72900, 2407, 84, 2, 27, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[73033, 2415, 189, 7, 29, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[73247, 2426, 114, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[73364, 2431, 84, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[73485, 2438, 105, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[73593, 2443, 76, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[73706, 2450, 53, 1, 42, "Subsubsection"],
Cell[73762, 2453, 839, 20, 62, "Input"],
Cell[74604, 2475, 298, 5, 75, "Input"],
Cell[74905, 2482, 119, 3, 27, "Input"],
Cell[75027, 2487, 104, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[75156, 2493, 183, 4, 27, "Input"],
Cell[75342, 2499, 38, 1, 27, "Input"],
Cell[75383, 2502, 36, 1, 27, "Input"],
Cell[75422, 2505, 57, 1, 27, "Input"]
}, Closed]],
Cell[75494, 2509, 77, 2, 27, "Input"],
Cell[75574, 2513, 104, 2, 27, "Input"],
Cell[75681, 2517, 106, 2, 27, "Input"],
Cell[75790, 2521, 168, 3, 27, "Input"],
Cell[75961, 2526, 258, 4, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[76256, 2535, 53, 1, 42, "Subsubsection"],
Cell[76312, 2538, 63, 2, 27, "Input"],
Cell[76378, 2542, 87, 1, 27, "Input"],
Cell[76468, 2545, 184, 4, 27, "Input"],
Cell[76655, 2551, 246, 5, 27, "Input"],
Cell[76904, 2558, 146, 3, 27, "Input"],
Cell[77053, 2563, 430, 7, 107, "Input"],
Cell[77486, 2572, 84, 2, 27, "Input"],
Cell[77573, 2576, 99, 2, 27, "Input"],
Cell[77675, 2580, 158, 3, 27, "Input"],
Cell[77836, 2585, 132, 2, 27, "Input"]
}, Closed]]
}, Closed]],
Cell[77995, 2591, 119, 3, 40, "Section",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[78139, 2598, 100, 3, 45, "Subsection",
  Evaluatable->False],
Cell[78242, 2603, 76, 2, 27, "Input"],
Cell[78321, 2607, 1047, 16, 219, "Input"],
Cell[79371, 2625, 477, 12, 62, "Input"],
Cell[79851, 2639, 38, 1, 27, "Input"],
Cell[79892, 2642, 45, 1, 27, "Input"],
Cell[79940, 2645, 57, 1, 27, "Input"],
Cell[80000, 2648, 728, 18, 62, "Input"],
Cell[80731, 2668, 91, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[80859, 2675, 125, 3, 29, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[81009, 2682, 103, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[81115, 2687, 76, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[81228, 2694, 53, 1, 42, "Subsubsection"],
Cell[81284, 2697, 378, 9, 98, "Input"],

Cell[CellGroupData[{
Cell[81687, 2710, 116, 2, 27, "Input"],
Cell[81806, 2714, 39, 1, 27, "Input"],
Cell[81848, 2717, 36, 1, 27, "Input"],
Cell[81887, 2720, 41, 1, 27, "Input"]
}, Closed]],
Cell[81943, 2724, 71, 1, 27, "Input"],
Cell[82017, 2727, 106, 2, 27, "Input"],
Cell[82126, 2731, 79, 1, 27, "Input"],
Cell[82208, 2734, 83, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[82328, 2741, 53, 1, 42, "Subsubsection"],
Cell[82384, 2744, 94, 2, 27, "Input"],
Cell[82481, 2748, 169, 3, 44, "Input"],
Cell[82653, 2753, 113, 2, 27, "Input"],
Cell[82769, 2757, 141, 5, 27, "Input"],
Cell[82913, 2764, 132, 3, 27, "Input"],
Cell[83048, 2769, 88, 2, 27, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[83185, 2777, 141, 3, 29, "Subsection",
  Evaluatable->False],
Cell[83329, 2782, 55, 1, 42, "Subsubsection"],
Cell[83387, 2785, 119, 3, 27, "Input"],

Cell[CellGroupData[{
Cell[83531, 2792, 53, 1, 42, "Subsubsection"],
Cell[83587, 2795, 592, 15, 78, "Input"],
Cell[84182, 2812, 161, 4, 24, "Input"],
Cell[84346, 2818, 245, 7, 40, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[84628, 2830, 53, 1, 42, "Subsubsection"],
Cell[84684, 2833, 155, 2, 43, "Input"],
Cell[84842, 2837, 138, 3, 24, "Input"],
Cell[84983, 2842, 198, 4, 24, "Input"],
Cell[85184, 2848, 141, 2, 24, "Input"],
Cell[85328, 2852, 219, 4, 40, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[85596, 2862, 153, 4, 29, "Subsection",
  Evaluatable->False],
Cell[85752, 2868, 114, 3, 42, "Subsubsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[85891, 2875, 111, 3, 28, "Subsubsection",
  Evaluatable->False],
Cell[86005, 2880, 92, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[86134, 2887, 103, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[86240, 2892, 76, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[86353, 2899, 53, 1, 42, "Subsubsection"],
Cell[86409, 2902, 92, 2, 27, "Input"],
Cell[86504, 2906, 176, 4, 27, "Input"],
Cell[86683, 2912, 224, 4, 76, "Input"],
Cell[86910, 2918, 78, 2, 27, "Input"],
Cell[86991, 2922, 311, 7, 56, "Input"],
Cell[87305, 2931, 211, 4, 24, "Input"],
Cell[87519, 2937, 223, 5, 24, "Input"],
Cell[87745, 2944, 83, 2, 24, "Input"],
Cell[87831, 2948, 192, 4, 46, "Input"],
Cell[88026, 2954, 131, 3, 24, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[88194, 2962, 53, 1, 42, "Subsubsection"],
Cell[88250, 2965, 60, 1, 44, "Input"],
Cell[88313, 2968, 203, 4, 24, "Input"],
Cell[88519, 2974, 109, 3, 43, "Input"],
Cell[88631, 2979, 117, 3, 24, "Input"],
Cell[88751, 2984, 83, 2, 24, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[88883, 2992, 102, 3, 40, "Section",
  Evaluatable->False],
Cell[88988, 2997, 123, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[89114, 3002, 134, 3, 28, "Subsubsection",
  Evaluatable->False],
Cell[89251, 3007, 193, 7, 28, "Subsubsection",
  Evaluatable->False],
Cell[89447, 3016, 74, 1, 28, "Subsubsection"],
Cell[89524, 3019, 125, 3, 28, "Subsubsection",
  Evaluatable->False],
Cell[89652, 3024, 148, 3, 28, "Subsubsection",
  Evaluatable->False],
Cell[89803, 3029, 194, 7, 28, "Subsubsection",
  Evaluatable->False],
Cell[90000, 3038, 200, 7, 28, "Subsubsection",
  Evaluatable->False],
Cell[90203, 3047, 201, 7, 28, "Subsubsection",
  Evaluatable->False],
Cell[90407, 3056, 200, 7, 28, "Subsubsection",
  Evaluatable->False]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

