(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     64376,       2054]*)
(*NotebookOutlinePosition[     65073,       2079]*)
(*  CellTagsIndexPosition[     65029,       2075]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Legal Notice, Disclaimer, and Book Ordering Information:", \
"Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "(* Legal Notice, Disclaimer, and Book Ordering Information:\n\nLast \
Modified: FIO June 8, 2002\n\n",
  StyleBox["Mathematica For Physics: 2nd Edition",
    FontColor->RGBColor[1, 0, 0]],
  "\n\nRobert L. Zimmerman and Fredrick I. Olness\n",
  "\nWebSite:  \n",
  StyleBox["  www.physics.smu.edu/~olness\n  darkwing.uoregon.edu/~phys600/\n\
\n",
    FontColor->RGBColor[1, 0, 0]],
  "MathSource Number: 0206-862",
  StyleBox["\n",
    FontColor->RGBColor[1, 0, 0]],
  "\nISBN 0-201-53796-6\nFor ordering information, call 1-800-282-0693\n\
Addison-Wesley Publishing Company\n",
  "\nCommunication with the authors:\nFredrick I. Olness:  \
olness@mail.physics.smu.edu\nRobert L. Zimmerman: bob@zim.uoregon.edu\n\n\
Copyright 2002, Addison-Wesley Publishing Company, Inc. The material in\nthis \
file may be distributed freely  so long as the content remains\nunchanged, \
and the copyright and  reference notices are included. The\npublisher grants \
permission for the noncommercial use of these programs\nand program segments. \
 All other uses require the prior written consent\nof the publisher.    \n\n\
All rights are reserved with regard to the  material in the\n\"Mathematica \
For Physics\" text, and may not be reproduced, stored in a\nretrieval system, \
or transmitted,  in any form or by any means,\nelectronic, mechanical, \
photocopying,  recording, or otherwise, without\nthe prior written permission \
 of the publisher. \n\nThe programs and applications presented in this book \
have been included\nfor  their instructional value. They have been tested \
with care but are\nnot  guaranteed for any particular purpose. The publisher \
does not\noffer any  warranties or representations, nor does it accept any\n\
liabilities with  respect to the programs or applications. \n\n *)\n"
}], "Input",
  Evaluatable->False,
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell["\<\
Contains correction on:  
    2nd Edition:Chpt.9,Problem 9.1.5 p.547: The One-Dimensional Harmonic \
Oscillator  (FIO, 19 Apr 2004)  
      Part b. Definition of Table was previoiusly missing. 
      
2nd Edition:Chpt.9,Problem 9.3.4 p.569: Particle in a Finite, Spherical Well  \
(FIO, 19 Apr 2004)  
     Part b. Mathematica Version 5 has difficult with the \"\[ScriptL]\" \
character. Replace with \"ell\"\
\>", "SmallText",
  FontColor->RGBColor[1, 0, 0]],

Cell[" 9. Quantum Mechanics", "Title",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["9.1  Introduction", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\ \(Off[General::"\<spell\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Off[General::"\<spell1\>"];\)\)}], "Input"]
}, Closed]],

Cell["9.2 One-Dimensional Schroedinger's Equation ", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Problem 1: Particle bound in an Infinite Potential Well", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Required Packages", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[" Needs[\"Graphics`Legend`\"]", "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Solution: ", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Clear[\"Global`*\"];", "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{"eq1", "=", " ", 
        FormBox[
          RowBox[{"0", "==", 
            RowBox[{\(\((V - En)\)\ \[Psi][x]\), "-", 
              FractionBox[
                RowBox[{\(\[HBar]\^2\), " ", 
                  RowBox[{
                    SuperscriptBox["\[Psi]", "\[Prime]\[Prime]",
                      MultilineFunction->None], "[", "x", 
                    "]"}]}], \(2\ m\)]}]}],
          "TraditionalForm"]}], ";"}]], "Input"],

Cell[BoxData[
    \(eq2 = eq1 /. V \[Rule] 0\)], "Input"],

Cell[BoxData[
    \(\(krule = \ En \[Rule] \(\[HBar]\^2\ k\^2\)\/\(2\ m\);\)\)], "Input"],

Cell[BoxData[
    \(schrod = \(Solve[eq2 /. krule, \(\[Psi]''\)[x]\ ]\)[\([1, 1]\)] /. 
        Rule \[Rule] Equal\)], "Input"],

Cell["\<\
dsol= DSolve[schrod,\[Psi],x][[1,1]]\
\>", "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection"],

Cell[BoxData[
    \(sol1 = 
      Reduce[{\[Psi][0] \[Equal] 0, \[Psi][a] \[Equal] 0} /. dsol]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"En", "\[Equal]", 
        FormBox[\(\(k\^2\ \[HBar]\^2\)\/\(2\ m\)\),
          "TraditionalForm"]}], "/.", 
      FormBox[\(k \[Rule] \(n\ \[Pi]\)\/a\),
        "TraditionalForm"]}]], "Input"],

Cell[BoxData[
    RowBox[{\(\[Psi][x_, n_]\), " ", "=", 
      RowBox[{\(\[Psi][x\ ]\  /. dsol\), "/.", 
        RowBox[{"{", 
          RowBox[{\(C[1] \[Rule] 0\), ",", " ", 
            FormBox[\(k \[Rule] \(n\ \[Pi]\)\/a\),
              "TraditionalForm"]}], "}"}]}]}]], "Input"],

Cell[BoxData[
    \(normEq = \ \(1\  \[Equal] \ Integrate[\[Psi][x, n]\^2, {x, 0, a}] // 
          Simplify[#, Element[n, Integers]] &\) // \(Solve[#, C[2]]\)[\([2, 
              1\ ]\)] &\)], "Input"],

Cell[BoxData[
    \(\[Psi][x_, n_]\  = \[Psi][x, n] /. normEq // Simplify\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection"],

Cell["\<\
table= \
Table[Integrate[\[Psi][x,i]\[Psi][x,j],{x,0,a}],{i,4},{j,4}];\
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(TableForm[table, 
      TableHeadings \[Rule] {Table[\[Psi][i], {i, 4}], 
          Table[\[Psi][j], {j, 4}]}]\)], "Input"],

Cell[BoxData[
    \(\(Plot[\ 
        Table[\[Psi][n, x], {n, 4}] /. {a \[Rule] 1} // 
          Evaluate, \[IndentingNewLine]{x, 0, 1}, 
        PlotStyle \[Rule] {{}, Dashing[{ .05}], Dashing[{ .03}], 
            Dashing[{ .01}]}, \[IndentingNewLine]PlotLabel \[Rule] 
          StyleForm[\[Psi], FontSize \[Rule] 14, 
            FontWeight \[Rule] 
              Bold], \[IndentingNewLine]PlotLegend \[Rule] {"\<n=1\>", "\<n=2\
\>", "\<n=3\>", "\<n=4\>"\ }, 
        LegendPosition \[Rule] {1, \(-1\)/2}];\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 2: Particle bound in a Finite Potential Well", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Clear[\"Global`*\"];", "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{"schrodeq", "=", 
        FormBox[
          RowBox[{"0", "==", 
            RowBox[{\(\((V - En)\)\ \[Psi][x]\), "-", 
              FractionBox[
                RowBox[{\(\[HBar]\^2\), " ", 
                  RowBox[{
                    SuperscriptBox["\[Psi]", "\[Prime]\[Prime]",
                      MultilineFunction->None], "[", "x", 
                    "]"}]}], \(2\ m\)]}]}],
          "TraditionalForm"]}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"EWrule", "=", 
        FormBox[\({En \[Rule] \(kW\^2\ \[HBar]\^2\)\/\(2\ m\) + V}\),
          "TraditionalForm"]}], ";"}]], "Input"],

Cell[BoxData[
    \(\(\(\(\[Psi][x] /. \(DSolve[schrodeq, \[Psi][x], x]\)[\([1, 1]\)]\) /. 
            EWrule // ExpToTrig\)\  // Simplify\)\  // PowerExpand\)], "Input"],

Cell[BoxData[
    RowBox[{"kWrule", "=", " ", 
      RowBox[{
        RowBox[{
          FormBox[\(kW \[Rule] \(\@2\ \@\(m\ \((En - V)\)\)\)\/\[HBar]\),
            "TraditionalForm"], "/.", \(V \[Rule] \(-V0\)\)}], 
        "/.", \(En \[Rule] \(-Wn\)\)}]}]], "Input"],

Cell[BoxData[
    \(\(\[Psi]W[x_] = cSym\ Cos[kW\ x] + cAsym\ Sin[kW\ x];\)\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ELRrule", "=", 
        FormBox[\({En \[Rule] \(kLR\^2\ \[HBar]\^2\)\/\(2\ m\)}\),
          "TraditionalForm"]}], ";"}]], "Input"],

Cell[BoxData[
    \(\(\(\(\(\[Psi][x] /. \(DSolve[schrodeq, \[Psi][x], x]\)[\([1, 1]\)]\) /. 
            V \[Rule] 0\) /. ELRrule\  // 
        Simplify\)\(//\)\(\ \)\(PowerExpand\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    RowBox[{"kLRrule", "=", " ", 
      RowBox[{
        RowBox[{
          FormBox[\(kLR \[Rule] \(\@2\ \@\(En\ m\)\)\/\[HBar]\),
            "TraditionalForm"], " ", "/.", \(En \[Rule] \(-Wn\)\)}], " ", "//",
         "PowerExpand"}]}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"qLRrule", "=", " ", 
        FormBox[\(qLR \[Rule] \(\@2\ \@\(m\ Wn\)\)\/\[HBar]\),
          "TraditionalForm"]}], ";"}]], "Input"],

Cell[BoxData[
    \(\(\(\(\(\(\[Psi][
                  x] /. \(DSolve[schrodeq, \[Psi][x], x]\)[\([1, 1]\)]\) /. 
              V \[Rule] 0\) /. ELRrule\)\  /. kLR \[Rule] I\ qLR // 
        Simplify\)\(//\)\(\ \)\(PowerExpand\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(\[Psi]R[x_] = \ 
        cR\ E\^\(\(-qLR\)\ x\)\ \ \ ;\)\(\ \ \ \ \ \ \ \ \ \ \ \)\( (*x > 
        a*) \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(\[Psi]L[x_] = \ 
        cL\ E\^\(\(+qLR\)\ x\)\ ;\)\(\ \ \ \ \ \ \)\( (*x < \(-a\)*) \)\)\)], \
"Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection"],

Cell["\<\
eq1= {  (\[Psi]L[ x]-\[Psi]W[ x]==0)  /. {x-> -a}, 
        (\[Psi]W[ x]-\[Psi]R[ x]==0)  /. {x-> +a},
        (\[Psi]L'[x]-\[Psi]W'[x]==0)  /. {x-> -a},
        (\[Psi]W'[x]-\[Psi]R'[x]==0)  /. {x-> +a}  } \
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\((eq2 = eq1 /. cAsym \[Rule] 0\ )\) // ColumnForm\)], "Input"],

Cell[BoxData[
    \(eq3 = 
      Reduce[{\ eq2\ , \ cL \[NotEqual] 0, cR \[NotEqual] 0, 
            kW \[NotEqual] 0, qLR\  \[NotEqual] 0, \ cSym \[NotEqual] 0, 
            Cos[\ a\ kW] \[NotEqual] 0\ } // Flatten\ \ , {cL, 
          cR}\ ]\ ; \(\(eq3\)\(\ \)\(//\)\(ColumnForm\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(\ \)\(symSol = \ \(\(Solve[eq3\ \ , {cL, cR}\ ]\  // 
          Simplify\)\(//\)\(Flatten\)\(\ \ \)\)\)\)\)], "Input"],

Cell[BoxData[
    \(\(\(\ \)\(symEn = Tan[a\ kW] \[Equal] \ \ qLR/kW;\)\)\)], "Input"],

Cell[BoxData[{
    \(\(eq4 = 
        Reduce[{\ eq1 /. cSym \[Rule] 0\ , \ cL \[NotEqual] 0, 
              cR \[NotEqual] 0, kW \[NotEqual] 0, qLR \[NotEqual] 0, 
              cAsym \[NotEqual] 0, Cos[\ a\ kW] \[NotEqual] 0\ } // 
            Flatten\ \ , {cL, cR}\ ]\ ;\)\), "\[IndentingNewLine]", 
    \(eq4 // ColumnForm\)}], "Input"],

Cell[BoxData[
    \(\(\(\ \)\(asymSol = \ \(\(Solve[eq4\ , {cL, cR}\ ]\  // 
          Simplify\)\(//\)\(Flatten\)\(\ \)\)\)\)\)], "Input"],

Cell[BoxData[
    \(\(asymEn = Tan[a\ kW] \[Equal] \ \(-\ kW\)/qLR;\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c ", "Subsubsection"],

Cell[BoxData[
    \(\(values = {a \[Rule] 1, m \[Rule] 1, \[HBar] \[Rule] 1, 
          V0\  \[Rule] {\ 100, \ 200, \ 500, \[Infinity]}}\ ;\)\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"nRule", "=", 
        FormBox[\(Wn \[Rule] 
            V0 - \(n\^2\ \[Pi]\^2\ \[HBar]\^2\)\/\(8\ a\^2\ m\)\),
          "TraditionalForm"]}], ";"}]], "Input"],

Cell[BoxData[
    \(\(kRules = {kW \[Rule] \(\(\ \)\(\@\(2\ m\ \((V0 - Wn\ )\)\)\)\)\/\
\[HBar], qLR \[Rule] \(\(\ \)\(\@\(2\ \((Wn)\)\ m\)\)\)\/\[HBar]};\)\)], \
"Input"],

Cell["eq5 =symEn/.kRules /.nRule//PowerExpand ", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(pt1 = 
        Plot[{ArcTan[eq5[\([1]\)]], ArcTan[eq5[\([2]\)]]} /. values // 
            Evaluate, \[IndentingNewLine]{n, 0, 
            9\ }, \[IndentingNewLine]Frame \[Rule] True, 
          FrameTicks \[Rule] {{{1, "\<n=1\>"}, {3, "\<n=3\>"}, {5, \
"\<n=5\>"}, {7, "\<n=7\>"}, {9, "\<n=9\>"}}, {0, 0.5, 1, 
                1.5}}, \[IndentingNewLine]PlotRange \[Rule] { .4, 
              1.6}, \[IndentingNewLine]DisplayFunction \[Rule] 
            Identity];\)\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"text", "=", 
        RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
            RowBox[{"Text", "[", " ", 
              RowBox[{"\"\<V0=\!\(
\*InterpretationBox[\(\[Infinity]\),
DirectedInfinity[ 1]]\)\>\"", ",", "  ", \({6, 1.5}\)}], "]"}], ",", 
            "\[IndentingNewLine]", \(Text[\ "\<V0=500\>", \ {6, 1.3}]\), ",", 
            "\[IndentingNewLine]", \(Text[\ "\<V0=200\>", \ {6, 1.1}]\), ",", 
            "\[IndentingNewLine]", \(Text[\ "\<V0=100\>", \ {6, 0.8}]\)}], 
          "}"}]}], ";"}]], "Input"],

Cell[BoxData[
    \(\(Show[pt1, Graphics[text]\ , GridLines \[Rule] Automatic, 
        DisplayFunction \[Rule] $DisplayFunction];\)\)], "Input"],

Cell["eq6 =asymEn/.kRules /.nRule//PowerExpand ", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{
      RowBox[{"text", "=", 
        RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
            RowBox[{"Text", "[", " ", 
              RowBox[{"\"\<V0=\!\(
\*InterpretationBox[\(\[Infinity]\),
DirectedInfinity[ 1]]\)\>\"", ",", "  ", \({7, 0}\)}], "]"}], ",", 
            "\[IndentingNewLine]", \(Text[\ "\<V0=500\>", \ {7, \(- .4\)}]\), 
            ",", "\[IndentingNewLine]", \(Text[\ "\<V0=200\>", \ {7, \(- \
.7\)}]\), ",", \(Text[\ "\<V0=100\>", \ {7, \(- .9\)\ }]\)}], "}"}]}], 
      ";"}]], "Input"],

Cell[BoxData[
    \(\(Plot[{ArcTan[eq6[\([1]\)]], ArcTan[\ eq6[\([2]\)]]}\  /. values // 
          Evaluate, \[IndentingNewLine]{n, 0.0\ , 
          9}, \[IndentingNewLine]Frame \[Rule] True, \ 
        FrameTicks \[Rule] {{{2, "\<n=2\>"}, {4, "\<n=4\>"}, {6, "\<n=6\>"}, \
{8, "\<n=8\>"}}, {\(-1.5\), \(-1\), 0, 0.5, 1, 
              1.5}}, \[IndentingNewLine]PlotRange \[Rule] {\(-1\)\ , \  .1}, \
\ \[IndentingNewLine]GridLines \[Rule] 
          Automatic, \[IndentingNewLine]Epilog \[Rule] \ 
          text\ \ ];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part d", "Subsubsection"],

Cell[BoxData[
    \(nValues[eq_, potential_, 
        guess_] := \((n /. \(FindRoot[
              eq /. {m \[Rule] 1, a \[Rule] 1, \[HBar] \[Rule] 1, 
                    V0 \[Rule] potential} // Evaluate, {n, 
                guess}]\)[\([1]\)])\)\)], "Input"],

Cell["symGuess= {0.9, 2.9, 4.9, 6.9, 8.9};", "Input",
  AspectRatioFixed->True],

Cell["\<\
symValues= {nValues[eq5,100,#]
           ,nValues[eq5,200,#]
           ,nValues[eq5,500,#]}&  /@  symGuess;  \
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(asymGuess = {1.9\ , 3.9\ , 5.9, 7.9\ };\)\)], "Input"],

Cell["\<\
asymValues={nValues[eq6,100,#]
           ,nValues[eq6,200,#]
           ,nValues[eq6,500,#]}& /@  asymGuess;   \
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\((Partition[Sort[{symValues, asymValues} // Flatten], 3] // 
        TableForm[#, TableSpacing \[Rule] {0, 2}, 
            TableHeadings \[Rule] {{"\<n=1\>", "\<n=2\>", "\<n=3\>", \
"\<n=4\>", "\<n=5\>", "\<n=6\>", "\<n=7\>", "\<n=8\>", "\<n=9\>"}, {"\<V0=100\
\>", "\<V0=200\>", "\<V0=500\>"}}] &)\)\)], "Input"],

Cell[BoxData[
    \(Partition[Sort[{symValues, asymValues} // Flatten], 3] // \ 
      TableForm[#, \[IndentingNewLine]TableSpacing \[Rule] {0, 2}, 
          TableHeadings \[Rule] {{"\<n=1\>", "\<n=2\>", "\<n=3\>", "\<n=4\>", \
"\<n=5\>", "\<n=6\>", "\<n=7\>", "\<n=8\>", "\<n=9\>"}, {"\<V0=100\>", \
"\<V0=200\>", "\<V0=500\>"}}\[IndentingNewLine]] &\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part e", "Subsubsection"],

Cell[BoxData[
    \(\(\(symRules = {kRules, nRule, symSol, a \[Rule] 1, \[HBar] \[Rule] 1, 
          m \[Rule] 1, V0 \[Rule] 100, cSym \[Rule] 100, cAsym \[Rule] 0} // 
        Flatten\)\(\n\)
    \)\)], "Input"],

Cell["\<\
Clear[s\[Psi],a\[Psi]];
(* Symmetric*) 
s\[Psi][x_ /;x<-1,n0_]:= (\[Psi]L[x]//.symRules//.{n->n0});
s\[Psi][x_ /;-1<=x<1,n0_]:= (\[Psi]W[x]//.symRules//.{n->n0});
s\[Psi][x_ /;x>=1,n0_]:= (\[Psi]R[x]//.symRules//.{n->n0});\
\>", "Input",
  AspectRatioFixed->True],

Cell["symEnergy= nValues[eq5, 100,#]&/@symGuess;  ", "Input",
  AspectRatioFixed->True],

Cell["\<\
plotsym= 
Plot[ s\[Psi][x,#] //.symRules //Evaluate
        ,{x,-2,2}
        ,PlotLabel->  NumberForm[#,2]
        ,Axes->None
        ,DisplayFunction->Identity ]&  /@  symEnergy;\
\>", "Input",
  AspectRatioFixed->True],

Cell["Show[GraphicsArray[{plotsym[[{1,2,3}]],plotsym[[{4,5}]]}]];", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(asymRules = {kRules, nRule, asymSol, a \[Rule] 1, \[HBar] \[Rule] 1, 
          m \[Rule] 1, V0 \[Rule] 100, cAsym \[Rule] 100, cSym \[Rule] 0} // 
        Flatten\)], "Input"],

Cell["\<\
 (* Asymmetric*) 
a\[Psi][x_ /;x<-1,n0_]:= (\[Psi]L[x]//.asymRules//.{n->n0});
a\[Psi][x_ /; -1<=x<1,n0_]:= (\[Psi]W[x]//.asymRules//.{n->n0});
a\[Psi][x_ /;x>=1,n0_]:= (\[Psi]R[x]//.asymRules//.{n->n0});\
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(asymEnergy = \(nValues[eq6, 100, #] &\) /@ asymGuess\ ;\)\)], "Input"],

Cell["\<\
 plotasym= 
  Plot[ a\[Psi][x,#] //.asymRules //Evaluate
          ,{x,-2,2}
          ,PlotLabel->NumberForm[#,2]
          ,Axes->None
          ,DisplayFunction->Identity]& /@ asymEnergy;              
              \
\>", "Input",
  AspectRatioFixed->True],

Cell["Show[GraphicsArray[{plotasym[[{1,2}]],plotasym[[{3,4}]]}]];", "Input",
  AspectRatioFixed->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 3: Particle Hitting a Finite Step Potential", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Required Packages", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[" Needs[\"Graphics`Legend`\"]", "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Clear[\"Global`*\"];", "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection"],

Cell[BoxData[
    \(\(\[Psi]L[
          x_] = \[ExponentialE]\^\(\[ImaginaryI]\ kL\ x\) + \[ExponentialE]\^\
\(\(-\[ImaginaryI]\)\ kL\ x\)\ R;\)\)], "Input"],

Cell[BoxData[
    RowBox[{" ", 
      RowBox[{
        RowBox[{"kLRule", "=", 
          FormBox[\(kL \[Rule] \@2\ \@\(En\ m\)\/\[HBar]\),
            "TraditionalForm"]}], ";"}]}]], "Input"],

Cell[BoxData[
    \(\(\(\ \ \ \ \ \)\(\[Psi]R[
          x_] = \[ExponentialE]\^\(\[ImaginaryI]\ kR\ x\)\ T;\)\)\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"kRRule", "=", 
        RowBox[{"kR", "\[Rule]", 
          FractionBox[
            FormBox[\(\@2\ \@\(m\ \((En - V0)\)\)\),
              "TraditionalForm"], 
            StyleBox["\[HBar]",
              FontFamily->"Courier"]]}]}], ";"}]], "Input"],

Cell[BoxData[
    \(boundary = {\[Psi]L[x] \[Equal] \[Psi]R[x], \(\[Psi]L'\)[
              x] \[Equal] \(\[Psi]R'\)[x]} //. x \[Rule] 0\)], "Input"],

Cell[BoxData[
    \(RTrule = \(Solve[boundary, {R, T}] // Flatten\) // Simplify\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection"],

Cell[BoxData[
    \(\(\(\ \ \)\(\(exp_\^*\) := \(\(exp\)\(\ \)\(/.\)\({Complex[a_, 
              b_] \[RuleDelayed] Complex[a, \(-b\)]}\)\(\ \)\)\)\)\)], "Input"],

Cell[BoxData[
    \(\(\(\((a - \[ImaginaryI]\ b + \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \
\[Theta]\))\)\^*\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(Conjugate[
      a - \[ImaginaryI]\ b + \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \
\[Theta]\)]\)], "Input"],

Cell[BoxData[
    \(\[Del]f_ := \(\(\(D[f, #\ ] &\)\ \  /@ \ \ {x, y, 
          z}\)\(\ \ \)\)\)], "Input"],

Cell[BoxData[
    \(\[Del]\[Psi][x\ \ ]\)], "Input"],

Cell[BoxData[
    \(flux[\[Psi]_] := \(\[HBar]\/\(2  \[ImaginaryI]\ m\)\) \((\(\[Psi]\^*\)\ \
\[Del]\[Psi]\  - \ \[Del]\(\[Psi]\^*\)\ \[Psi])\)\  // Simplify\)], "Input"],

Cell[BoxData[
    \(\(\(\[Psi]L[x] // flux\)\(//\)\(Simplify\)\(\ \ \)\)\)], "Input"],

Cell[BoxData[
    \(incFlux = \(\(flux[\[Psi]L[x]]\)\(\ \)\(/.\)\({R \[Rule] 
            0}\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(Rflux = \((incFlux - flux[\[Psi]L[x]])\) // Simplify\)], "Input"],

Cell[BoxData[
    \(Tflux = flux[\[Psi]R[x]]\)], "Input"],

Cell["\<\
{RR,TT}= { Rflux[[1]] /incFlux[[1]],
           Tflux[[1]] /incFlux[[1]] }\
\>", "Input",
  AspectRatioFixed->True],

Cell["{RR,TT}={RR,TT}/. RTrule", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(RR + TT\  // Simplify\)], "Input"],

Cell[BoxData[
    \(\(values = {m \[Rule] 1, \[HBar] \[Rule] 1, V0 \[Rule] 1};\)\)], "Input"],

Cell[BoxData[
    \(\(Plot[\(\(\({RR, TT, TT + RR} /. RTrule\) /. kLRule\) /. kRRule\) /. 
            values // Evaluate, \[IndentingNewLine]{En, 1, 
          2}, \[IndentingNewLine]AxesLabel \[Rule] {"\<E\>", \
"\<Coefficient\>"}, \[IndentingNewLine]PlotStyle \[Rule] {Dashing[{0.06, 
                0.02}], 
            Dashing[{0.02}], {}}, \[IndentingNewLine]PlotLegend \[Rule] \
{"\<RR\>", "\<TT\>", "\<TT+RR\>"}, \[IndentingNewLine]LegendPosition \[Rule] \
{1, \(-1\)/2}, \[IndentingNewLine]PlotRange \[Rule] {0, 1}];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection"],

Cell[BoxData[
    \(\(kRule = {kLRule, kRRule};\)\)], "Input"],

Cell[BoxData[
    \(\(\(wave[x_, 
          En_] = \(\({\[Psi]L[x], \[Psi]R[x]} /. RTrule\) /. kRule\) /. 
            values\  // Simplify\ ;\)\(\ \ \)\)\)], "Input"],

Cell[BoxData[
    \(\[Psi][x_, En_] := 
      Which[\ x \[LessEqual] 0, \(wave[x, En]\)[\([1]\)], 
        x > 0, \(wave[x, En]\)[\([2]\)]]\)], "Input"],

Cell[BoxData[
    \(\(waveplot2D[Energy_] := 
        Plot[{\[Psi][x, Energy] // Re, \[Psi][x, Energy] // 
              Im}, \[IndentingNewLine]{x, \(-10\), 
            10}, \[IndentingNewLine]PlotStyle \[Rule] {{}, Dashing[{0.02}]}, 
          AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\)], "Input"],

Cell[BoxData[
    \(\(waveplot2D[1.1];\)\)], "Input"],

Cell[BoxData[
    \(\(waveplot2D[0.9];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part d", "Subsubsection"],

Cell[BoxData[
    \(\(Plot3D[\[Psi][x, Energy] // Re, {x, \(-10\), 10}, {Energy,  .5, 1.5}, 
        PlotPoints \[Rule] 50, 
        AxesLabel \[Rule] {"\<x\>", "\<Energy\>", "\<\[Psi]\>"}];\)\)], \
"Input"],

Cell[BoxData[
    \(\(Plot3D[\[Psi][x, Energy] // Im, {x, \(-10\), 10}, {Energy,  .5, 1.5}, 
        PlotPoints \[Rule] 50, 
        AxesLabel \[Rule] {"\<x\>", "\<Energy\>", "\<\[Psi]\>"}];\)\)], \
"Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part e", "Subsubsection"],

Cell[BoxData[
    \(\(timePlot[time_, En_] := 
        Plot[{Exp[\(-I\)\ En\ time] \[Psi][x, En] // Re, 
            Exp[\(-I\)\ En\ time] \[Psi][x, En] // 
              Im}, \[IndentingNewLine]{x, \(-10\), 
            10}, \[IndentingNewLine]PlotStyle \[Rule] {{}, {Thickness[
                  0.008]}}, \[IndentingNewLine]PlotRange \[Rule] {\(-2\), 
              2}];\)\)], "Input"],

Cell[BoxData[
    \(\(\(timePlot[1. , 0.9];\)\(\[IndentingNewLine]\)
    \)\)], "Input"],

Cell[BoxData[{
    \(\(frames = 1;\)\ \), "\[IndentingNewLine]", 
    \(\(Energy = 0.9;\)\), "\n", 
    \(\(timestep = \(2  \[Pi]\)\/\(\((frames)\) Energy\);\)\), "\n", 
    \(Do[\[IndentingNewLine]\(timePlot[n\ timestep\ , 
          Energy];\)\[IndentingNewLine], {n, 1, 
        frames}\n]\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(frames = 1;\)\), "\n", 
    \(\(Energy = 1.1;\)\), "\n", 
    \(\(timestep = \(2  \[Pi]\)\/\(\((frames)\) Energy\);\)\), "\n", 
    \(Do[\[IndentingNewLine]\(timePlot[n\ timestep\ , 
          Energy];\)\[IndentingNewLine], {n, 1, 
        frames}\n]\), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Problem 4: Particle Propagating Towards a Rectangular \
Potential\
\>", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Clear[\"Global`*\"];", "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection"],

Cell[BoxData[
    \(\(\[Psi]L[
          x_] = \[ExponentialE]\^\(\[ImaginaryI]\ kLR\ x\) + \
\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ kLR\ x\)\ R;\)\)], "Input"],

Cell[BoxData[
    \(\(\[Psi]R[
          x_] = \[ExponentialE]\^\(\[ImaginaryI]\ kLR\ x\)\ T;\)\)], "Input"],

Cell[BoxData[
    \(\(\[Psi]W[x_] = 
        B\ \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ kW\ x\) + 
          A\ \[ExponentialE]\^\(\[ImaginaryI]\ kW\ x\);\)\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"kRules", "=", 
        FormBox[
          RowBox[{"{", 
            
            RowBox[{\(kW \[Rule] \@2\ \@\(m\ \((En - V0)\)\)\/\[HBar]\), ",", 
              
              RowBox[{"kLR", "\[Rule]", 
                RowBox[{\(\@2\), " ", 
                  FractionBox[\(\@\(En\ m\)\), 
                    StyleBox["\[HBar]",
                      FontFamily->"Courier"]]}]}]}], "}"}],
          "TraditionalForm"]}], ";"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection"],

Cell[BoxData[
    \(\(eq1 = {\((\[Psi]L[x] - \[Psi]W[x] \[Equal] 
                  0)\) /. {x \[Rule] \(-a\)}, \[IndentingNewLine]\ \ \ \ \ \
\((\[Psi]W[x] - \[Psi]R[x] \[Equal] 
                  0)\) /. {x \[Rule] \(+a\)}, \[IndentingNewLine]\ \ \ \ \ \
\((\(\[Psi]L'\)[x] - \(\[Psi]W'\)[x] \[Equal] 
                  0)\) /. {x \[Rule] \(-a\)}, \[IndentingNewLine]\ \ \ \ \ \
\((\(\[Psi]W'\)[x] - \(\[Psi]R'\)[x] \[Equal] 0)\) /. {x \[Rule] \(+a\)}} // 
          Simplify\ ;\)\)], "Input"],

Cell[BoxData[{
    \(\(ABRTrule = \(Solve[eq1, {A, B, R, T}] // FullSimplify\) // 
          Flatten;\)\), "\[IndentingNewLine]", 
    \(ABRTrule // ColumnForm\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection"],

Cell[BoxData[
    \(\(\(\ \ \)\(\(exp_\^*\) := \(\(exp\)\(\ \)\(/.\)\({Complex[a_, 
              b_] \[RuleDelayed] Complex[a, \(-b\)]}\)\(\ \)\)\)\)\)], "Input"],

Cell[BoxData[
    \(\[Del]f_ := \(\(\(D[f, #\ ] &\)\  /@ \ {x, y, z}\)\(\ \ \)\)\)], "Input"],

Cell[BoxData[
    \(flux[\[Psi]_] := \(\[HBar]\/\(2  \[ImaginaryI]\ m\)\) \((\(\[Psi]\^*\)\ \
\[Del]\[Psi]\  - \ \[Del]\(\[Psi]\^*\)\ \[Psi])\)\  // Simplify\)], "Input"],

Cell[BoxData[
    \(\(\(incFlux\)\(=\)\(flux[\(\[Psi]L[x] /. R \[Rule] 0\) /. 
          ABRTrule\ ]\)\(\ \ \)\)\)], "Input"],

Cell["\<\
Rflux=  (incFlux-flux[\[Psi]L[x]/.ABRTrule]) //ExpToTrig //Simplify \
 \
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Tflux = \(\(flux[\[Psi]R[x] /. ABRTrule] // 
          ExpToTrig\)\(\ \)\(//\)\(Simplify\)\(\ \ \)\)\)], "Input"],

Cell[BoxData[{
    \(\({RR, TT} = {Rflux[\([1]\)]/incFlux[\([1]\)], 
          Tflux[\([1]\)]/incFlux[\([1]\)]};\)\), "\[IndentingNewLine]", 
    \({RR, TT} // ColumnForm\)}], "Input"],

Cell[BoxData[
    \(TT + RR == 1\ \  // Simplify\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part d", "Subsubsection"],

Cell[BoxData[
    \(\(values = {\[HBar] \[Rule] 1, m \[Rule] 1, 
          a \[Rule] 1\ };\)\)], "Input"],

Cell[BoxData[
    \(\(Plot[\(\({RR, TT} /. kRules\) /. {V0 \[Rule] \(-100\)}\) /. values // 
          Evaluate, \ {En, 1, 
          200}, \ \[IndentingNewLine]AxesLabel \[Rule] {"\<En\>", "\<RR, \
TT\>"}, PlotStyle \[Rule] {{}, Dashing[{0.02, 0.02}]}];\)\)], "Input"],

Cell[BoxData[
    \(\(Plot[\(\({RR, TT} /. kRules\) /. {V0 \[Rule] \(+1\)}\) /. values // 
          Evaluate, \ {En, 0, 
          5}, \ \[IndentingNewLine]AxesLabel \[Rule] {"\<En\>", "\<RR, \
TT\>"}, PlotStyle \[Rule] {{}, 
            Dashing[{0.02, 0.02}]}, \[IndentingNewLine]PlotPoints \[Rule] 
          50\[IndentingNewLine]];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part e", "Subsubsection"],

Cell[BoxData[
    \(\(Plot3D[\(\(TT /. kRules\)\  /. values\) /. a \[Rule] 1 // 
          Evaluate, {En, 0, 10}, {V0, \(-20\), 
          0}, \ \[IndentingNewLine]PlotPoints \[Rule] 
          40, \[IndentingNewLine]\ 
        Ticks \[Rule] {Range[0, 10, 5], 
            Range[\(-20\), 0, 10], {0, 1/2, 
              1}\ \ }, \[IndentingNewLine]AxesLabel \[Rule] {"\<Energy\>", \
"\<Potential\>", "\<TT\>"}];\)\)], "Input"],

Cell[BoxData[
    \(\(Plot3D[\(\(\(RR /. kRules\) /. ABRTrule\) /. values\) /. a \[Rule] 1 // 
          Evaluate, {En, 0, 10}, {V0, \(-20\), 
          0}, \[IndentingNewLine]PlotPoints \[Rule] 40, \[IndentingNewLine]\ 
        Ticks \[Rule] {Range[0, 10, 5], 
            Range[\(-20\), 0, 10], {0, 1/2, 
              1}}, \[IndentingNewLine]AxesLabel \[Rule] {"\<Energy\>", \
"\<Potential\>", "\<RR\>"}];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part f", "Subsubsection"],

Cell[BoxData[
    \(\({\[Psi]L[x_, aa_], \[Psi]W[x_, aa_], \[Psi]R[x_, 
            aa_]} = \ \(\({\[Psi]L[x], \[Psi]W[x], \[Psi]R[x]}\  /. 
                ABRTrule\) /. kRules\) //. {\[HBar] \[Rule] 1, \ m \[Rule] 1, 
              a \[Rule] aa}\  // Simplify;\)\)], "Input"],

Cell[BoxData[
    \(\(\(\[Psi][x_, a_]\)\(:=\)\(Which[
        x\  \[LessEqual] \ \(-a\), \ \[Psi]L[x, a], \(-a\) < x \[LessEqual] \ 
          a, \ \[Psi]W[x, a], a < x, \ \[Psi]R[x, a]]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(\ \)\(Plot[\ \ \[Psi][x, 2]\  /. {\ En \[Rule] 1, \ 
              V0 \[Rule] \(-12\)} // Re, {x, \(-15\), 15}, 
        Epilog \[Rule] {Thickness[0.02], 
            Line[{{\(-2\), 0}, {2, 0}}]}];\)\)\)], "Input"],

Cell[BoxData[
    \(\(\(\ \)\(Plot[\ \[Psi][x, 2] \(\[Psi][x, 2]\^*\)\  //. {\ 
            En \[Rule] 1, \ V0 \[Rule] \(-12\)}\ , {x, \(-15\), 15}, 
        Epilog \[Rule] {Thickness[0.02], 
            Line[{{\(-2\), 0}, {2, 0}}]}]\ ;\)\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part g", "Subsubsection"],

Cell[BoxData[
    \(\(timePlot[t_, En_, 
          V0_] := \[IndentingNewLine]Plot[\ {\[ExponentialE]\^\(\(-\
\[ImaginaryI]\)\ En\ t/\[HBar]\)\ \[Psi][x, 2\ ]\  // 
                  Re, \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ En\ t/\[HBar]\)\ \
\[Psi][x, 2] // Im} //. {\ \[HBar] \[Rule] 1}\  // 
            Evaluate, \[IndentingNewLine]{x, \(-15\), 15}, 
          PlotStyle \[Rule] {{}, {Dashing[{0.02}], 
                Thickness[
                  0.008]}}, \[IndentingNewLine]PlotRange \[Rule] {\(-2\), 
              2}, \[IndentingNewLine]Epilog \[Rule] {Thickness[0.02], 
              Line[{{\(-2\), 0}, {2, 0}}]}];\)\)], "Input"],

Cell["\<\
 frames=1;
 V0=1.1;
 En=1;
 timestep=2 \[Pi]/(frames En);
 Do[timePlot[n timestep ,En,V0],{n,1,frames}]\
\>", "Input",
  AspectRatioFixed->True,
  AnimationDisplayTime->0.13]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 5: The One-Dimensional Harmonic Oscillator  ", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Clear[\"Global`*\"];", "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection"],

Cell[BoxData[
    RowBox[{"eq1", "=", 
      RowBox[{
        FormBox[
          RowBox[{"0", "==", 
            RowBox[{\(\((V - En)\)\ \(\[Psi](x)\)\), "-", 
              FractionBox[
                RowBox[{\(\[HBar]\^2\), " ", 
                  RowBox[{
                    SuperscriptBox["\[Psi]", "\[Prime]\[Prime]",
                      MultilineFunction->None], "(", "x", 
                    ")"}]}], \(2\ m\)]}]}],
          "TraditionalForm"], " ", "/.", 
        RowBox[{"V", "\[Rule]", 
          FormBox[\(\(k\ x\^2\)\/2\),
            "TraditionalForm"]}]}]}]], "Input"],

Cell[BoxData[
    \(eq2 = \(\(DSolve[eq1, \[Psi][x], x]\)[\([1]\)]\  // PowerExpand\)\  // 
        Simplify\)], "Input"],

Cell[BoxData[
    \(\(notation = {k \[Rule] \(\[Omega]\^2\) m, \ 
          En\ \  \[Rule] \ \((1\/2 + 
                  n)\)\ \[HBar]\ \[Omega], \ \[Omega] \[Rule] \[HBar]\/\(m\ \
\[Alpha]\^2\)};\)\)], "Input"],

Cell[BoxData[
    \(dsol\  = \(eq2[\([1]\)]\  //. notation // PowerExpand\) // 
        Simplify\)], "Input"],

Cell[BoxData[
    \(\[Psi]0[x_, n_] = \(\(\[Psi][x] /. dsol\)\  /. C[2] \[Rule] 0\) /. 
        C[1] \[Rule] 1\)], "Input"],

Cell[BoxData[
    RowBox[{"energylevels", "=", 
      RowBox[{\(En /. notation\), "/.", 
        RowBox[{"{", 
          RowBox[{"\[Omega]", "\[Rule]", 
            FormBox[\(\@\(k\/m\)\),
              "TraditionalForm"]}], "}"}]}]}]], "Input"],

Cell[BoxData[
    \(energylevels /. n \[Rule] Range[0, 3, 1]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection"],

Cell[BoxData[
    \(norm[n_]\ \  := 
      Integrate[\[Psi]0[x\ , n] \[Psi]0[x\ , 
              n]\ , {x, \(-\[Infinity]\), \[Infinity]}, 
          Assumptions \[Rule] {\ \[Alpha] > 0\ , Element[n, Integers]}\ ] // 
        Sqrt\)], "Input"],

Cell[BoxData[
    \(Table[
      norm[n] == \ \ \ \ Sqrt[\ \ 2^
              n\ \ \ \(n!\)\ \ \[Alpha]\ Sqrt[\[Pi]]\ \ ]\ , {n, 0, 
        5}]\)], "Input"],

Cell[BoxData[
    RowBox[{\(\[Psi][x_, n_]\), "=", "  ", 
      FractionBox[\(\[Psi]0[x, n]\), 
        FormBox[\(\@\[Pi]\%4\ \@\(2\^n\ \[Alpha]\ \(n!\)\)\),
          "TraditionalForm"]]}]], "Input"],

Cell[BoxData[
    \(Table[
        Integrate[\[Psi][x, n]\^2\ , {x, \(-\[Infinity]\), \[Infinity]}, \ 
          Assumptions \[Rule] {\ \[Alpha] > 0}], {n, 0, 3}]\  // 
      PowerExpand\)], "Input"],

Cell[BoxData[
    \(table = \(\[Psi][x, #] &\) /@ Range[0, 3] // Simplify\)], "Input"],

Cell[BoxData[
    \(TableForm[
      table, \[IndentingNewLine]TableHeadings \[Rule] {{\ "\<\[Psi][x,0]\>", \
"\<\[Psi][x,1]\>", "\<\[Psi][x,2]\>", "\<\[Psi][x,3]\>"\ \ \ }}]\)], "Input"],

Cell[BoxData[
    \(\(Plot[\ \ Table[\[Psi][x, n]/2\  + \ \ n, {n, 0, 
                7}]\ \  /. {\[Alpha] \[Rule] 1}\  // 
          Evaluate\ , \[IndentingNewLine]{x, \(-6\), 
          6}\ , \[IndentingNewLine]Epilog \[Rule] \(Plot[
              0.6\ \ z^2, {z, \(-6\), 
                6}, \[IndentingNewLine]PlotStyle \[Rule] 
                Thickness[ .01], \[IndentingNewLine]DisplayFunction \[Rule] 
                Identity\[IndentingNewLine]]\)[\([1]\)]\ \ \
\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    \(\(Plot[\ \ Table[\[Psi][x, n]\^2 + \ n, {n, 0, 
                7}]\ \  /. {\[Alpha] \[Rule] 1}\  // Evaluate\ , {x, \(-5\), 
          5}, \[IndentingNewLine]Epilog \[Rule] \(Plot[
              0.6\ \ z^2, {z, \(-6\), 
                6}, \[IndentingNewLine]PlotStyle \[Rule] 
                Thickness[ .01], \[IndentingNewLine]DisplayFunction \[Rule] 
                Identity\[IndentingNewLine]]\)[\([1]\)]\ \
\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]]
}, Closed]],

Cell["9.3 Three-Dimensional Schroedinger's Equation  ", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
Problem 1:  Three-Dimensional Harmonic Oscillator in Cartesian \
Coordinates \
\>", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Required Packages", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Needs[\"Calculus`VectorAnalysis`\"]", "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Clear[\"Global`*\"];", "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection"],

Cell[BoxData[
    \(\(SetCoordinates[Cartesian[x, y, z]];\)\)], "Input"],

Cell["\[Psi][x_,y_,z_] = X[x] Y[y] Z[z]; ", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(eq1 = \ \(-\[HBar]\^2\)\/\(2  m\)\ Laplacian[\[Psi][x, y, 
              z]] + \ \((Vx[x] + Vy[y] + Vz[z]\  - \ En)\) \[Psi][x, y, 
            z]\)], "Input"],

Cell[BoxData[
    \(eq2 = eq1/\[Psi][x, y, z] // ExpandAll\)], "Input"],

Cell[BoxData[
    \(\(Enrule = {En -> Ex + Ey + Ez}\ ;\)\)], "Input"],

Cell["\<\
select[eq_,Ei_,var_]:= Select[eq,(!FreeQ[#,var]|| !FreeQ[#,Ei \
])&]\
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(fieldEq = \[IndentingNewLine]0 \[Equal] {\ 
            select[eq2 /. Enrule, Ex, x], \ \ select[eq2 /. Enrule, Ey, y], 
            select[eq2 /. Enrule, Ez, z]} // Thread; 
    fieldEq\  // ColumnForm\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{"potential", "=", 
        FormBox[\({Vx(x) \[Rule] \(kx\ x\^2\)\/2, 
            Vy(y) \[Rule] \(ky\ y\^2\)\/2, Vz(z) \[Rule] \(kz\ z\^2\)\/2}\),
          "TraditionalForm"]}], ";"}]], "Input"],

Cell[BoxData[{
    \(\({xEq, yEq, zEq} = fieldEq /. potential;\)\), "\[IndentingNewLine]", 
    \({xEq, yEq, zEq} // ColumnForm\)}], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"notation", "=", 
        FormBox[\({kx \[Rule] m\ \[Omega]x\^2, 
            Ex \[Rule] \((nx + 
                    1\/2)\)\ \[Omega]x\ \[HBar], \[Omega]x \[Rule] \
\[HBar]\/\(m\ \[Alpha]x\^2\)}\),
          "TraditionalForm"]}], ";"}]], "Input"],

Cell[BoxData[
    \(xSol = \ \(DSolve[xEq //. notation, X[x], x]\)[\([1]\)] // 
        Simplify\)], "Input"],

Cell[BoxData[
    RowBox[{\(X[x_, nx_]\), " ", "=", 
      RowBox[{\(X[x]\ \  /. xSol\), "//.", 
        FormBox[
          RowBox[{"{", 
            RowBox[{
              RowBox[{
                SubscriptBox[
                  TagBox["c",
                    C], "2"], "\[Rule]", "0"}], ",", 
              RowBox[{
                SubscriptBox[
                  TagBox["c",
                    C], "1"], 
                "\[Rule]", \(1\/\(\@\[Pi]\%4\ \@\(2\^nx\ \[Alpha]x\ \(nx!\)\)\
\)\)}]}], "}"}],
          "TraditionalForm"]}]}]], "Input"],

Cell[BoxData[
    \(\(\(Table[\ 
        Integrate[X[x, nx]\^2\ \ , {x, \(-\[Infinity]\), \[Infinity]}, 
          GenerateConditions \[Rule] False]\ , {nx, 0, 
          5}]\)\(//\)\(PowerExpand\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(Y[y_, ny_] = X[y, ny]\  /. {\[Alpha]x \[Rule] \[Alpha]y}\)], "Input"],

Cell[BoxData[
    \(Z[z_, nz_] = X[z, nz] /. {\[Alpha]x \[Rule] \[Alpha]z}\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection"],

Cell[BoxData[
    \(\(\[Alpha]Rule = \ {\[Alpha]x \[Rule] 1, \ \[Alpha]y \[Rule] 
            1};\)\)], "Input"],

Cell[BoxData[
    \(\(wavePlot = 
        Plot3D[X[x, 3]\ Y[y, 
                2] /. \[Alpha]Rule, \[IndentingNewLine]{x, \(-4\), 
            4}, {y, \(-4\), 4}, \[IndentingNewLine]PlotPoints \[Rule] 
            35, \[IndentingNewLine]DisplayFunction \[Rule] 
            Identity];\)\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"vPlot", "=", 
        RowBox[{"Plot3D", "[", 
          RowBox[{
            RowBox[{
              RowBox[{"0.15", " ", 
                RowBox[{"(", 
                  FormBox[\(x\^2 + y\^2\),
                    "TraditionalForm"], ")"}]}], "-", "2"}], ",", 
            "\[IndentingNewLine]", \({x, \(-4\), 4}\), 
            ",", \({y, \(-4\), 4}\), ",", 
            "\[IndentingNewLine]", \(PlotPoints \[Rule] 35\), ",", 
            "\[IndentingNewLine]", \(DisplayFunction \[Rule] Identity\)}], 
          "]"}]}], ";"}]], "Input"],

Cell[BoxData[
    \(\(Show[{vPlot, wavePlot}, 
        DisplayFunction \[Rule] $DisplayFunction\ ];\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Problem 2:  Schroedinger's Equation for Spherically Symmetric \
Potentials \
\>", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Required Packages", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Needs[\"Calculus`VectorAnalysis`\"] ", "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Clear[\"Global`*\"];", "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Part a ",
  StyleBox[" ",
    FontColor->RGBColor[0, 1, 0]]
}], "Subsubsection"],

Cell[BoxData[
    \(\(SetCoordinates[Spherical[r, \[Theta], \[Phi]]];\)\)], "Input"],

Cell["\[Psi][r,\[Theta],\[Phi]] =R[r] \[CapitalTheta][\[Theta]] \
\[CapitalPhi][\[Phi]];", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"eq1", "=", " ", 
      RowBox[{
        RowBox[{
          FormBox[\(-\(\[HBar]\^2\/\(2\ m\)\)\),
            "TraditionalForm"], 
          "  ", \(Laplacian[\[Psi][r, \[Theta], \[Phi]]]\)}], "+", 
        " ", \(\((V\  - \ En)\) \[Psi][r, \[Theta], \[Phi]]\)}]}]], "Input"],

Cell[BoxData[
    RowBox[{"eq2", "=", 
      RowBox[{
        RowBox[{"eq1", " ", 
          
          FormBox[\(\(r\^2\ \(\(sin\^2\)(\[Theta])\)\)\/\[Psi][
                  r, \[Theta], \[Phi]]\),
            "TraditionalForm"]}], "//", "ExpandAll"}]}]], "Input"],

Cell["select[eq_,var_]:= Select[eq,(!FreeQ[#,var])&]", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"eq3", "=", 
      RowBox[{\(select[eq2, \[Phi]]\), "\[Equal]", 
        FormBox[\(\(\(\ \)\(\(\[HBar]\^2\) m\[Phi]\^2\)\)\/\(2\ m\)\),
          "TraditionalForm"]}]}]], "Input"],

Cell["\<\
\[Phi]Eq=Solve[eq3,\[CapitalPhi]''[\[Phi]] ][[1,1]] /.Rule->Equal\
\
\>", "Input",
  AspectRatioFixed->True],

Cell["eq4=DSolve[\[Phi]Eq,\[CapitalPhi][\[Phi]],\[Phi]][[1]] ", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(\(\ \)\(\(\(eq4 /. {C[1] \[Rule] 1, \ C[2] \[Rule] {I, \(-I\)}} // 
          MapAll[TrigToExp, #] &\)\  // Map[Thread, #, 2] &\)\  // 
      Flatten\)\)\)], "Input"],

Cell[BoxData[
    RowBox[{"       ", 
      RowBox[{
        RowBox[{"\[Phi]Rule", "=", 
          RowBox[{\(\[CapitalPhi][\[Phi]]\), "\[Rule]", 
            FormBox[\(\[ExponentialE]\^\(\[ImaginaryI]\ m\[Phi]\ \[Phi]\)\),
              "TraditionalForm"]}]}], ";"}]}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Part b",
  StyleBox[" ",
    FontColor->RGBColor[0, 1, 0]]
}], "Subsubsection"],

Cell[BoxData[
    \(eq5 = \ \(\(\((eq2 /. \((\[Phi]Eq /. Equal \[Rule] Rule\ )\))\)/
          Sin[\[Theta]]\^2\)\(//\)\(Expand\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    RowBox[{"eq6", "=", 
      RowBox[{\(select[eq5, r]\), "\[Equal]", 
        FormBox[\(-\(\(\[ScriptL]\ \((\[ScriptL] + 
                      1)\)\ \[HBar]\^2\)\/\(2\ m\)\)\),
          "TraditionalForm"]}]}]], "Input"],

Cell["\<\
rEq= Solve[eq6,R''[r] ][[1,1]] /. Rule->Equal // ExpandAll    \
\
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"eq7", "=", " ", 
      RowBox[{\(select[eq5, \[Theta]]\), "\[Equal]", " ", 
        FormBox[\(\(\[ScriptL]\ \((\[ScriptL] + 
                    1)\)\ \[HBar]\^2\)\/\(2\ m\)\),
          "TraditionalForm"]}]}]], "Input"],

Cell[BoxData[
    \(\[Theta]Eq = \ \(\(\(Solve[
              eq7, \(\[CapitalTheta]''\)[\[Theta]]]\)[\([1, 1]\)]\  /. 
          Rule \[Rule] Equal\)\(//\)\(ExpandAll\)\(\ \)\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Part c",
  StyleBox[" ",
    FontColor->RGBColor[0, 1, 0]]
}], "Subsubsection"],

Cell[BoxData[
    \(vChange[\ Eq_, \[Psi]_, x_, z_, f_] := \ 
      Eq /. {D[\[Psi][x], {x, 
                n_}] \[RuleDelayed] \[IndentingNewLine]Nest[\((\ \((1/
                        D[f, z])\)\ \ D[#, z])\) &, \[Psi][z], n], \[Psi][
              x] \[RuleDelayed] \[Psi][z], x \[RuleDelayed] f}\)], "Input"],

Cell[BoxData[
    \(eq8 = \ \(\(vChange[\[Theta]Eq, \[CapitalTheta], \[Theta], z, 
            ArcCos[z]]\  // 
          ExpandAll\)\(//\)\(\ \)\(Simplify\)\(\ \ \)\)\)], "Input"],

Cell[BoxData[
    \(eq9 = DSolve[eq8\ , \[CapitalTheta][z]\ , z] // Flatten\)], "Input"],

Cell[BoxData[
    \(\(\(\ \)\(LegendreQ[2\ , 1, z]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(\[Theta]Rule = 
      eq9 /. {C[1] \[Rule] 1, \ C[2] \[Rule] 0}\  // Simplify\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part d", "Subsubsection"],

Cell[BoxData[
    \(\(\(\(norm[\[ScriptL], m]\ \ \[CapitalTheta][
                z]\ \[CapitalPhi][\[Phi]]\  /. \[Theta]Rule\) /. \[Phi]Rule\) \
/. \ z \[Rule] 
          Cos[\[Theta]]\) /. \(\(m\[Phi]\)\(\[Rule]\)\(m\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(norm[\[ScriptL]_, m_]\), "=", 
        FormBox[\(1\/\(2\ \@\[Pi]\)\ \@\(\(\((2\ \[ScriptL] + 1)\)\ \(\((\
\[ScriptL] - m)\)!\)\)\/\(\((m + \[ScriptL])\)!\)\)\),
          "TraditionalForm"]}], ";"}]], "Input"],

Cell[BoxData[
    \(Y[\[ScriptL]_, 
        m_, \[Theta]_, \[Phi]_] = \(\(\(norm[\[ScriptL], m]\ \[CapitalTheta][
                  z]\ \[CapitalPhi][\[Phi]]\  /. \[Theta]Rule\) /. \[Phi]Rule\
\) /. \ z \[Rule] 
            Cos[\[Theta]]\) /. \(\(m\[Phi]\)\(\[Rule]\)\(m\)\(\ \)\)\)], \
"Input"],

Cell[BoxData[
    \(\(\(Table[\ 
          SphericalHarmonicY[\[ScriptL], m, \[Theta], \[Phi]] == 
            Y[\[ScriptL], m, \[Theta], \[Phi]], {\[ScriptL], 0, 
            4}, {m, \(-\[ScriptL]\), \[ScriptL]}] // 
        Simplify\)\(//\)\(PowerExpand\)\(\ \ \)\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 3: Particle in an Infinite, Spherical Well ", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Required Packages", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
 Needs[\"NumericalMath`BesselZeros`\"]
 Needs[\"Graphics`Legend`\"]\
\>", "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Clear[\"Global`*\"];", "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection"],

Cell[BoxData[
    RowBox[{"rEq", "=", 
      RowBox[{
        RowBox[{"0", "==", 
          FormBox[
            
            RowBox[{\(\(2\ m\ \(R(r)\)\ \((En - V(r))\)\ r\^2\)\/\[HBar]\^2\),
               "+", 
              RowBox[{
                RowBox[{
                  SuperscriptBox["R", "\[Prime]\[Prime]",
                    MultilineFunction->None], "(", "r", ")"}], 
                " ", \(r\^2\)}], "+", 
              RowBox[{"2", " ", 
                RowBox[{
                  SuperscriptBox["R", "\[Prime]",
                    MultilineFunction->None], "(", "r", ")"}], " ", "r"}], 
              "-", \(\[ScriptL]\ \((\[ScriptL] + 1)\)\ \(R(r)\)\)}],
            "TraditionalForm"]}], " ", "/.", 
        FormBox[\({V(r) \[Rule] 0, 
            En \[Rule] \(k\^2\ \[HBar]\^2\)\/\(2\ m\)}\),
          "TraditionalForm"]}]}]], "Input"],

Cell[BoxData[
    \(dsol = \ \(DSolve[rEq\ , R[r], r] // Flatten\) // Simplify\)], "Input"],

Cell[BoxData[
    \(R[r_, \[ScriptL]_, 
        k_:  1]\  = \ \(R[r]\  /. 
          dsol\)\  /. {C[1] \[Rule] \@\(1 + 2  \[ScriptL]\), \ 
          C[2] \[Rule] 0}\)], "Input"],

Cell[BoxData[
    \(Integrate[\ R[r, \[ScriptL], k]^2\ , {r, 0, \[Infinity]}\ , 
      Assumptions \[Rule] {\ k > 0, \[ScriptL] > \(-1\)/2}]\)], "Input"],

Cell[BoxData[
    \(\(TableForm[\ \(R[r, #, k] &\) /@ 
            Range[0, 
              3], \[IndentingNewLine]TableHeadings \[Rule] {\ {\ \
"\<\[ScriptL]=0\>", "\<\[ScriptL]=1\>", "\<\[ScriptL]=2\>", \
"\<\[ScriptL]=3\>"\ \ }}\ ]\  // Simplify\) // PowerExpand\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection"],

Cell[BoxData[
    \(\(?BesselJZeros\)\)], "Input"],

Cell[BoxData[
    \(zeros = \(\(\(BesselJZeros[1/2 + #, 5] &\)\  /@ \ \ Range[0, 
          4]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(TableForm[zeros, \ 
      TableSpacing \[Rule] \ 
        1\ , \ \ \ TableHeadings \[Rule] {{"\<S-Wave\>", "\<P-Wave\>", \
"\<D-Wave\>", "\<F-Wave\>", "\<G-Wave\>"}, \[IndentingNewLine]{"\<First\>", "\
\<Second\>", "\<Third\>", "\<Fourth\>", "\<Fifth\>"}}]\)], "Input"],

Cell[BoxData[
    \(\(levels = 
        Table[\[IndentingNewLine]{{i - 0.4, zeros[\([i, j]\)]}, {i + 0.4, 
              zeros[\([i, j]\)]}}, \[IndentingNewLine]{i, 1, 
            Length[zeros]}, {j, 1, Length[zeros[\([1]\)]]}]\ ;\)\)], "Input"],

Cell[BoxData[
    \(\(Show[\[IndentingNewLine]{Graphics[{Thickness[0.01], 
              Map[Line, levels, {2}]}], \[IndentingNewLine]Graphics[
            Text["\<S\>", {1, 1}]], Graphics[Text["\<P\>", {2, 1}]], 
          Graphics[Text["\<D\>", {3, 1}]], \[IndentingNewLine]Graphics[
            Text["\<F\>", {4, 1}]], 
          Graphics[
            Text["\<G\>", {5, 
                1}]]\[IndentingNewLine]}, \[IndentingNewLine]Frame \[Rule] 
          True, \[IndentingNewLine]PlotRange \[Rule] {{0, 5.9}, {\(-1\), 
              25}}];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection"],

Cell[BoxData[
    \(\(\(\ \)\(Plot[
        R[r, 0, k] /. {k \[Rule] \((zeros[\([0 + 
                        1]\)])\)}\[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \  // Evaluate, \[IndentingNewLine]{r, \ 0\ , 
          1}, \ \ PlotStyle \[Rule] {{}, Dashing[{0.01}], Dashing[{0.02}], 
            Dashing[{ .03}], 
            Dashing[{ .05}]}\ , \[IndentingNewLine]PlotLabel \[Rule] 
          StyleForm["\<\[Psi]\>", 
            FontSize \[Rule] 
              14], \[IndentingNewLine]PlotLegend \[Rule] \ \ {k1, k2, k3, k4, 
            k5}\ \ , \[IndentingNewLine]LegendPosition \[Rule] {1, \(-1\)/
              2}, \[IndentingNewLine]Epilog \[Rule] 
          Text[StyleForm["\<S(\[ScriptL]=0)-State\>", 
              FontSize \[Rule] 14], {0.6, 
              2}]\ \[IndentingNewLine]];\)\)\)], "Input"],

Cell[BoxData[
    \(\(rPlots = \[IndentingNewLine]Table[\[IndentingNewLine]Plot[\ 
            R[r, \[ScriptL], zeros[\([\(+1\) + \[ScriptL], n]\)]] // 
              Evaluate, {r, 0.01, 1}, \ Ticks \[Rule] None, \ 
            PlotRange \[Rule] 
              All, \[IndentingNewLine]PlotLabel \[Rule] {n, \[ScriptL]}, \
\[IndentingNewLine]DisplayFunction \[Rule] 
              Identity\[IndentingNewLine]], \ {n, 1, 5}, {\[ScriptL], 0, 
            4}];\)\)], "Input"],

Cell[BoxData[
    \(\(\(rPlots // GraphicsArray\)\  // Show;\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 4: Particle in a Finite, Spherical Well  ", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Required Packages", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[" Needs[\"Graphics`Legend`\"]", "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Clear[\"Global`*\"];", "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection"],

Cell[BoxData[
    RowBox[{"rEq", "=", 
      RowBox[{
        RowBox[{
          RowBox[{"0", "\[Equal]", 
            FormBox[
              RowBox[{\(k\^2\ \(R(r)\)\ r\^2\), "+", 
                RowBox[{
                  RowBox[{
                    SuperscriptBox["R", "\[Prime]\[Prime]",
                      MultilineFunction->None], "(", "r", ")"}], 
                  " ", \(r\^2\)}], "+", 
                RowBox[{"2", " ", 
                  RowBox[{
                    SuperscriptBox["R", "\[Prime]",
                      MultilineFunction->None], "(", "r", ")"}], " ", "r"}], 
                "-", \(\[ScriptL]\ \((\[ScriptL] + 1)\)\ \(R(r)\)\)}],
              "TraditionalForm"]}], " ", "/.", \(En \[Rule] \(-Wn\)\)}], 
        "/.", \(V \[Rule] \(-V0\)\)}]}]], "Input"],

Cell[BoxData[
    \(rRule = \ \(DSolve[rEq\ , R[r], r]\  // Flatten\) // 
        ExpandAll\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"kRule", "=", 
        FormBox[\({kIn \[Rule] \(\@2\ \@m\ \@\(V0 - Wn\)\)\/\[HBar], 
            kOut \[Rule] \(\[ImaginaryI]\ \@2\ \@m\ \@Wn\)\/\[HBar]}\),
          "TraditionalForm"]}], ";"}]], "Input"],

Cell[BoxData[
    \(\(Series[\ \(R[r] /. rRule\) /. \[ScriptL] \[Rule] #\ , {r, 0, 
              1}] &\)\ \  /@ \ \ Range[0, 3] // ColumnForm\)], "Input"],

Cell[BoxData[
    \(waveIn[kIn_, \[ScriptL]_, 
        r_] = \(\(R[r] /. rRule\) /. {C[1] \[Rule] cIn, C[2] \[Rule] 0, 
              k \[Rule] kIn} // Simplify\) // PowerExpand\)], "Input"],

Cell[BoxData[
    \(\(TableForm[\(waveIn[kIn\ , #, r\ ] &\) /@ 
            Range[0, 
              3], \[IndentingNewLine]TableHeadings \[Rule] {\ {\ \
"\<\[ScriptL]=0\>", "\<\[ScriptL]=1\>", "\<\[ScriptL]=2\>", \
"\<\[ScriptL]=3\>"\ \ }}\ ]\  // Simplify\) // PowerExpand\)], "Input"],

Cell[BoxData[
    \(eq1 = \(R[r] /. rRule\) /. k\  \[Rule] I\ qOut // 
        PowerExpand\)], "Input"],

Cell[BoxData[
    \(\(\(\(\(eq1 /. \[ScriptL] \[Rule] 0 // TrigToExp\) // Simplify\) // 
        PowerExpand\)\(//\)\(Collect[#, {\ 
            Exp[a_]\ \ }] &\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(eq2 = eq1 /. C[2] \[Rule] \(\(1\)\(\ \)\(C[1]\)\(\ \)\)\)], "Input"],

Cell["\<\
waveOut[qOut_,\[ScriptL]_,r_]= eq1 /.rRule /.{C[1]\[Rule] cOut,C[2]\
\[Rule] +I cOut} \
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(\(TableForm[\(\((\(\(waveOut[qOut\ , #, r\ ] // TrigToExp\)\  // 
                Simplify\) // PowerExpand\ \ )\) &\) /@ 
        Range[0, 
          3], \[IndentingNewLine]TableHeadings \[Rule] {\ {\ \
"\<\[ScriptL]=0\>", "\<\[ScriptL]=1\>", "\<\[ScriptL]=2\>", \
"\<\[ScriptL]=3\>"\ \ }}\ ]\)\(\ \ \)\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection"],

Cell[BoxData[
    \(bc1 = \(\((waveIn[kIn, \[ScriptL], r] \[Equal] 
            waveOut[qOut, \[ScriptL], r])\)\(//.\)\({r \[Rule] 
            a}\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(cOutRule = \ \(Solve[bc1, cOut] /. cIn \[Rule] 1\  // Flatten\) // 
        Simplify\)], "Input"],

Cell["\<\
bc2= (D[waveIn[kIn,\[ScriptL],r],r] == \
D[waveOut[qOut,\[ScriptL],r],r]) //.{r->a}//Simplify;\
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(allRules = {kIn \[Rule] \(\@2\ \@\(m\ \((V0 - Wn)\)\)\)\/\[HBar], 
            qOut \[Rule] \@2\ \@\(\(m\ Wn\)\/\[HBar]\^2\), \ \ cOutRule, \ \
\[HBar] \[Rule] 1, a \[Rule] 1, m \[Rule] 1, V0 \[Rule] 110, cIn \[Rule] 1} // 
          Flatten\ ;\)\)], "Input"],

Cell[BoxData[
    \(\(bc2Sol[\[ScriptL]_] = \ \(\(\(bc2 //. cOutRule\) /. cIn \[Rule] 1\) //. 
              allRules\)\  //. allRules\  // Simplify;\)\)], "Input"],

Cell[BoxData[
    \(eq3 = bc2Sol[0] // Simplify\)], "Input"],

Cell[BoxData[
    \(\(Plot[eq3[\([1]\)]\  // Evaluate, {Wn, 0, 110}];\)\)], "Input"],

Cell[BoxData[
    \(sValues = \ \(FindRoot[\ eq3\ , {Wn, #}] &\)\ \  /@ \ \ {10, 40, 70, 
          90}\)], "Input"],

Cell[BoxData[
    \(\(\(\ \)\(eq4\  = \ bc2Sol[1]\  // Simplify\ \ ;\)\)\)], "Input"],

Cell[BoxData[
    \(\(eq5 = \ bc2Sol[2]\  // Simplify\ ;\)\)], "Input"],

Cell[BoxData[
    \(\(Plot[{eq4[\([1]\)], eq5[\([1]\)]} // 
          Evaluate, \[IndentingNewLine]{Wn, 0, 
          110}, \[IndentingNewLine]PlotStyle \[Rule] {{}, 
            Dashing[{0.01}]}\ ];\)\)], "Input"],

Cell[BoxData[
    \(pValues = \ \ \(FindRoot[\ eq4\ , {Wn, #}] &\)\ \  /@ \ \ {20, 60, 80, 
          100}\)], "Input"],

Cell[BoxData[
    \(dValues = \ \ \(FindRoot[\ eq5, {Wn, #}] &\)\ \  /@ \ \ {10, 40, 70, 
          90}\)], "Input"],

Cell[BoxData[
    \(TableForm[{sValues, pValues, dValues}, \ 
      TableSpacing \[Rule] \ 
        1\ , \ \ \ TableHeadings \[Rule] {{"\<S-Wave\>", "\<P-Wave\>", \
"\<D-Wave\>"\ \ }, {"\<First\>", "\<Second\>", "\<Third\>", "\<Fourth\>"\ }}]\
\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection"],

Cell[BoxData[
    \(\({in[r_, \[ScriptL]_, Wn_], 
          out[r_, \[ScriptL]_, Wn_]} = {waveIn[kIn, \[ScriptL], r], 
            waveOut[qOut, \[ScriptL], r]} //. allRules;\)\)], "Input"],

Cell[BoxData[
    \(\(\(\ \)\(wave[r_, \[ScriptL]_, Wn_] = 
        Which[r \[LessEqual] 1\ , in[r, \[ScriptL], Wn], r > 1\ , 
          out[r, \[ScriptL], Wn]];\)\)\)], "Input"],

Cell[BoxData[
    \(\(Plot[\ \(wave[r, 0, Wn]\  /. sValues\  // Re\) // 
          Evaluate\ , \[IndentingNewLine]{r, 0, 1.3}, \ 
        PlotStyle \[Rule] {{}, Dashing[{0.01}], Dashing[{0.02}], 
            Dashing[{ .03}]}, \ \[IndentingNewLine]PlotLegend \[Rule] \ 
          Evaluate[\ \(Wn /. sValues[\([#]\)] &\) /@ 
              Range[4]]\ , \[IndentingNewLine]LegendPosition \[Rule] {1, \(-1\
\)/2}, \[IndentingNewLine]Epilog \[Rule] 
          Line[{{1, \(-3\)}, {1, 3}}]]\ ;\)\)], "Input"],

Cell[BoxData[
    \(\(\(\ \)\(Plot[\ \(wave[r, 1, Wn]\  /. pValues // Re\) // 
          Evaluate\ \ \ \ , \[IndentingNewLine]{r, 0, 1.3}, \ 
        PlotStyle \[Rule] {{}, Dashing[{0.01}], Dashing[{0.02}], 
            Dashing[{ .03}]}, \[IndentingNewLine]PlotLegend \[Rule] \ 
          Evaluate[\ \(Wn /. pValues[\([#]\)] &\) /@ 
              Range[4]]\ , \[IndentingNewLine]LegendPosition \[Rule] {1, \(-1\
\)/2}, \[IndentingNewLine]Epilog \[Rule] 
          Line[{{1, \(-3\)}, {1, 3}}]\[IndentingNewLine]];\)\)\)], "Input"],

Cell[BoxData[
    \(\(\(\ \)\(Plot[\ \(wave[r, 2, Wn]\  /. dValues // Re\) // 
          Evaluate\ \ \ \ , \[IndentingNewLine]{r, 0, 1.3}, \ 
        PlotStyle \[Rule] {{}, Dashing[{0.01}], Dashing[{0.02}], 
            Dashing[{0.03}]}, \[IndentingNewLine]PlotLegend \[Rule] \ 
          Evaluate[\ \(Wn /. dValues[\([#]\)] &\) /@ 
              Range[3]]\ , \[IndentingNewLine]LegendPosition \[Rule] {1, \(-1\
\)/2}, \[IndentingNewLine]Epilog \[Rule] 
          Line[{{1, \(-3\)}, {1, 3}}]\[IndentingNewLine]];\)\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Problem 5: The Hydrogen Atom in Spherical Coordinates",
  StyleBox[" ",
    FontColor->RGBColor[1, 0, 0]]
}], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Required Packages", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[" Needs[\"Graphics`ParametricPlot3D`\"]", "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Clear[\"Global`*\"];", "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection"],

Cell[BoxData[
    RowBox[{"eq1", "=", 
      RowBox[{
        RowBox[{
          RowBox[{"0", "\[Equal]", 
            FormBox[
              
              RowBox[{\(\(2\ m\ \(R(
                        r)\)\ \((En - V(r))\)\ r\^2\)\/\[HBar]\^2\), "+", 
                RowBox[{
                  RowBox[{
                    SuperscriptBox["R", "\[Prime]\[Prime]",
                      MultilineFunction->None], "(", "r", ")"}], 
                  " ", \(r\^2\)}], "+", 
                RowBox[{"2", " ", 
                  RowBox[{
                    SuperscriptBox["R", "\[Prime]",
                      MultilineFunction->None], "(", "r", ")"}], " ", "r"}], 
                "-", \(\[ScriptL]\ \((\[ScriptL] + 1)\)\ \(R(r)\)\)}],
              "TraditionalForm"]}], "/.", 
          RowBox[{\(V[r]\), "\[Rule]", 
            FormBox[\(-\(e\^2\/\(4\ \[Pi]\ r\ \[Epsilon]0\)\)\),
              "TraditionalForm"]}]}], 
        "/.", \(En \[Rule] \(-Wn\)\)}]}]], "Input"],

Cell["eq2=DSolve[eq1,{R[r]},r][[1]] ", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{
      RowBox[{"substitutions", "=", 
        FormBox[\({m \[Rule] \(4\ \[Pi]\ \[Epsilon]0\ \[HBar]\^2\)\/\(a0\ \
e\^2\), Wn \[Rule] \(e\^4\ m\)\/\(32\ n\^2\ \[Pi]\^2\ \[Epsilon]0\^2\ \[HBar]\
\^2\)}\),
          "TraditionalForm"]}], ";"}]], "Input"],

Cell[BoxData[
    \(eq3 = \(eq2 //. substitutions\ \  // PowerExpand\) // 
        Simplify\)], "Input"],

Cell[BoxData[
    \(eq4 = eq3 /. {C[1] \[Rule] 0\ }\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"rNorm", "=", 
        FormBox[\(2\^\(\[ScriptL] + 1\)\ \((1\/\(a0\ n\))\)\^\[ScriptL]\ \@\(\
\(\((n - \[ScriptL] - 1)\)!\)\/\(a0\^3\ n\^4\ \(\((n + \[ScriptL])\)!\)\)\)\),
          
          "TraditionalForm"]}], ";"}]], "Input"],

Cell[BoxData[
    \(rwave[n_, \[ScriptL]_, 
        r_]\  = \(\(R[r] /. eq4[\([1]\)]\) /. C[2] \[Rule] rNorm // 
          PowerExpand\) // Simplify\)], "Input"],

Cell[BoxData[
    \(Integrate[\ \(r\^2\) {\ \ rwave[1, 0, r\ ], rwave[2, 0, r\ ], rwave[2, \
1, r\ ]}\^2, {r, 0, \[Infinity]}, 
      Assumptions \[Rule] {Re[a0] > 0}]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection"],

Cell[BoxData[
    \(eq5 = \(\(Table[
          rwave[n, \[ScriptL], r], \ {n, 1, 3}, {\[ScriptL], 0, 
            n - 1}\ ]\)\(//\)\(\ \)\(TableForm[#, \ 
            TableHeadings \[Rule] {{"\<n=1\>", "\<n=2\>", "\<n=3\>"}, {"\<\
\[ScriptL]=0\>", "\<\[ScriptL]=1\>", "\<\[ScriptL]=2\>"}}] &\)\(\ \)\)\)], \
"Input"],

Cell[BoxData[
    \(\(plot[n_, \[ScriptL]_, rmax_] := \[IndentingNewLine]Plot[
          r\^2\ rwave[n, \[ScriptL], r]\^2 /. a0 \[Rule] 1 // 
            Evaluate, \[IndentingNewLine]{r, 0.01, 
            rmax}, \[IndentingNewLine]Ticks \[Rule] {{1, 4, 8, 14, 20}, {0.1, 
                0.3, 0.5}}, \[IndentingNewLine]DisplayFunction \[Rule] 
            Identity];\)\)], "Input"],

Cell["\<\
Show[GraphicsArray[ \
Table[plot[n,\[ScriptL],n*7],{n,1,3},{\[ScriptL],0,n-1}]]];\
\>", "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection"],

Cell[BoxData[
    \(\(plot[\[ScriptL]_, 
          m_] := \[IndentingNewLine]SphericalPlot3D[\[IndentingNewLine]\(\
SphericalHarmonicY[\[ScriptL], m, \[Theta], \[Phi]]\  // Abs\) // 
            Evaluate, \[IndentingNewLine]{\[Theta], 0, \[Pi]}, {\[Phi], 0, 
            2\ \[Pi]}, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]DisplayFunction \[Rule] 
            Identity];\)\)], "Input"],

Cell["\<\
pt1=Table[plot[\[ScriptL],m] ,{\[ScriptL],0,2} ,{m,-\[ScriptL],\
\[ScriptL]}];
Show[GraphicsArray[pt1]];
 \
\>", "Input",
  AspectRatioFixed->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["9.4 Exercises", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Exercise 1:  Infinite Potential Well with Rectangular \
Perturbation\
\>", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Exercise 2:  Tilted Square Well", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Exercise 3: The Wentzel-Kramers-Brillouin Approximation", \
"Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Exercise 4: Plot of the Electron Probability Density", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Exercise 5: Perturbed Harmonic Oscillator", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Exercise 6: Perturbation Theory", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Exercise 7:  Separation of variables in Cylindrical \
Coordinates\
\>", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]]
},
FrontEndVersion->"4.1 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
WindowToolbars->"EditBar",
CellGrouping->Manual,
WindowSize->{742, 790},
WindowMargins->{{98, Automatic}, {Automatic, 61}},
Magnification->1
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 116, 2, 42, "Subsubsection"],
Cell[1846, 56, 1886, 33, 657, "Input",
  Evaluatable->False]
}, Closed]],
Cell[3747, 92, 469, 11, 100, "SmallText"],
Cell[4219, 105, 86, 2, 114, "Title",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[4330, 111, 84, 2, 60, "Section",
  Evaluatable->False],
Cell[4417, 115, 134, 2, 43, "Input"]
}, Closed]],
Cell[4566, 120, 111, 2, 40, "Section",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[4702, 126, 125, 2, 45, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[4852, 132, 90, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[4945, 136, 71, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[5053, 142, 83, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[5139, 146, 63, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[5239, 152, 31, 0, 42, "Subsubsection"],
Cell[5273, 154, 477, 12, 46, "Input"],
Cell[5753, 168, 57, 1, 27, "Input"],
Cell[5813, 171, 89, 1, 46, "Input"],
Cell[5905, 174, 127, 2, 27, "Input"],
Cell[6035, 178, 87, 3, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[6159, 186, 31, 0, 42, "Subsubsection"],
Cell[6193, 188, 107, 2, 27, "Input"],
Cell[6303, 192, 235, 6, 46, "Input"],
Cell[6541, 200, 283, 6, 41, "Input"],
Cell[6827, 208, 203, 3, 31, "Input"],
Cell[7033, 213, 86, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[7156, 219, 31, 0, 42, "Subsubsection"],
Cell[7190, 221, 121, 4, 27, "Input"],
Cell[7314, 227, 143, 3, 27, "Input"],
Cell[7460, 232, 525, 10, 75, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[8034, 248, 122, 2, 29, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[8181, 254, 81, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[8265, 258, 63, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[8365, 264, 31, 0, 42, "Subsubsection"],
Cell[8399, 266, 477, 12, 46, "Input"],
Cell[8879, 280, 175, 4, 46, "Input"],
Cell[9057, 286, 171, 2, 27, "Input"],
Cell[9231, 290, 268, 6, 48, "Input"],
Cell[9502, 298, 88, 1, 27, "Input"],
Cell[9593, 301, 173, 4, 46, "Input"],
Cell[9769, 307, 203, 3, 27, "Input"],
Cell[9975, 312, 262, 6, 48, "Input"],
Cell[10240, 320, 174, 4, 48, "Input"],
Cell[10417, 326, 250, 4, 27, "Input"],
Cell[10670, 332, 145, 3, 28, "Input"],
Cell[10818, 337, 129, 3, 28, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[10984, 345, 31, 0, 42, "Subsubsection"],
Cell[11018, 347, 258, 6, 72, "Input"],
Cell[11279, 355, 83, 1, 27, "Input"],
Cell[11365, 358, 303, 5, 27, "Input"],
Cell[11671, 365, 142, 2, 27, "Input"],
Cell[11816, 369, 86, 1, 27, "Input"],
Cell[11905, 372, 339, 6, 43, "Input"],
Cell[12247, 380, 139, 2, 27, "Input"],
Cell[12389, 384, 82, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[12508, 390, 32, 0, 42, "Subsubsection"],
Cell[12543, 392, 154, 2, 27, "Input"],
Cell[12700, 396, 201, 5, 46, "Input"],
Cell[12904, 403, 171, 3, 48, "Input"],
Cell[13078, 408, 83, 1, 27, "Input"],
Cell[13164, 411, 503, 9, 91, "Input"],
Cell[13670, 422, 569, 12, 91, "Input"],
Cell[14242, 436, 145, 2, 27, "Input"],
Cell[14390, 440, 84, 1, 27, "Input"],
Cell[14477, 443, 546, 12, 75, "Input"],
Cell[15026, 457, 536, 9, 107, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[15599, 471, 31, 0, 42, "Subsubsection"],
Cell[15633, 473, 262, 5, 27, "Input"],
Cell[15898, 480, 79, 1, 27, "Input"],
Cell[15980, 483, 162, 5, 57, "Input"],
Cell[16145, 490, 76, 1, 27, "Input"],
Cell[16224, 493, 163, 5, 57, "Input"],
Cell[16390, 500, 335, 5, 59, "Input"],
Cell[16728, 507, 365, 5, 75, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[17130, 517, 31, 0, 42, "Subsubsection"],
Cell[17164, 519, 213, 4, 43, "Input"],
Cell[17380, 525, 273, 7, 87, "Input"],
Cell[17656, 534, 87, 1, 27, "Input"],
Cell[17746, 537, 232, 8, 102, "Input"],
Cell[17981, 547, 102, 1, 27, "Input"],
Cell[18086, 550, 196, 3, 27, "Input"],
Cell[18285, 555, 255, 6, 72, "Input"],
Cell[18543, 563, 92, 1, 27, "Input"],
Cell[18638, 566, 270, 9, 117, "Input"],
Cell[18911, 577, 102, 1, 27, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[19062, 584, 121, 2, 29, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[19208, 590, 90, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[19301, 594, 71, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[19409, 600, 81, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[19493, 604, 63, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[19593, 610, 31, 0, 42, "Subsubsection"],
Cell[19627, 612, 158, 3, 30, "Input"],
Cell[19788, 617, 191, 5, 48, "Input"],
Cell[19982, 624, 125, 2, 30, "Input"],
Cell[20110, 628, 293, 8, 48, "Input"],
Cell[20406, 638, 149, 2, 27, "Input"],
Cell[20558, 642, 92, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[20687, 648, 31, 0, 42, "Subsubsection"],
Cell[20721, 650, 163, 2, 27, "Input"],
Cell[20887, 654, 130, 2, 32, "Input"],
Cell[21020, 658, 125, 3, 32, "Input"],
Cell[21148, 663, 108, 2, 27, "Input"],
Cell[21259, 667, 52, 1, 27, "Input"],
Cell[21314, 670, 170, 2, 43, "Input"],
Cell[21487, 674, 85, 1, 27, "Input"],
Cell[21575, 677, 115, 2, 27, "Input"],
Cell[21693, 681, 85, 1, 27, "Input"],
Cell[21781, 684, 57, 1, 27, "Input"],
Cell[21841, 687, 125, 4, 42, "Input"],
Cell[21969, 693, 67, 1, 27, "Input"],
Cell[22039, 696, 54, 1, 27, "Input"],
Cell[22096, 699, 93, 1, 27, "Input"],
Cell[22192, 702, 541, 8, 123, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[22770, 715, 31, 0, 42, "Subsubsection"],
Cell[22804, 717, 62, 1, 27, "Input"],
Cell[22869, 720, 167, 3, 27, "Input"],
Cell[23039, 725, 152, 3, 27, "Input"],
Cell[23194, 730, 300, 5, 59, "Input"],
Cell[23497, 737, 53, 1, 27, "Input"],
Cell[23553, 740, 53, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[23643, 746, 31, 0, 42, "Subsubsection"],
Cell[23677, 748, 207, 4, 27, "Input"],
Cell[23887, 754, 207, 4, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[24131, 763, 31, 0, 42, "Subsubsection"],
Cell[24165, 765, 388, 7, 75, "Input"],
Cell[24556, 774, 88, 2, 43, "Input"],
Cell[24647, 778, 340, 7, 163, "Input"],
Cell[24990, 787, 321, 7, 163, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[25360, 800, 143, 5, 29, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[25528, 809, 81, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[25612, 813, 63, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[25712, 819, 31, 0, 42, "Subsubsection"],
Cell[25746, 821, 160, 3, 30, "Input"],
Cell[25909, 826, 108, 2, 30, "Input"],
Cell[26020, 830, 168, 3, 30, "Input"],
Cell[26191, 835, 481, 13, 48, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[26709, 853, 31, 0, 42, "Subsubsection"],
Cell[26743, 855, 495, 8, 75, "Input"],
Cell[27241, 865, 173, 3, 43, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[27451, 873, 31, 0, 42, "Subsubsection"],
Cell[27485, 875, 163, 2, 27, "Input"],
Cell[27651, 879, 93, 1, 27, "Input"],
Cell[27747, 882, 170, 2, 43, "Input"],
Cell[27920, 886, 125, 2, 27, "Input"],
Cell[28048, 890, 122, 4, 27, "Input"],
Cell[28173, 896, 133, 2, 27, "Input"],
Cell[28309, 900, 184, 3, 43, "Input"],
Cell[28496, 905, 61, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[28594, 911, 31, 0, 42, "Subsubsection"],
Cell[28628, 913, 105, 2, 27, "Input"],
Cell[28736, 917, 269, 4, 43, "Input"],
Cell[29008, 923, 350, 6, 75, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[29395, 934, 31, 0, 42, "Subsubsection"],
Cell[29429, 936, 426, 8, 75, "Input"],
Cell[29858, 946, 423, 7, 75, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[30318, 958, 31, 0, 42, "Subsubsection"],
Cell[30352, 960, 277, 4, 27, "Input"],
Cell[30632, 966, 210, 3, 27, "Input"],
Cell[30845, 971, 238, 4, 27, "Input"],
Cell[31086, 977, 253, 4, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[31376, 986, 31, 0, 42, "Subsubsection"],
Cell[31410, 988, 641, 11, 100, "Input"],
Cell[32054, 1001, 184, 8, 87, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[32287, 1015, 122, 2, 29, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[32434, 1021, 81, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[32518, 1025, 63, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[32618, 1031, 31, 0, 28, "Subsubsection"],
Cell[32652, 1033, 588, 15, 46, "Input"],
Cell[33243, 1050, 121, 2, 27, "Input"],
Cell[33367, 1054, 212, 4, 44, "Input"],
Cell[33582, 1060, 109, 2, 27, "Input"],
Cell[33694, 1064, 123, 2, 27, "Input"],
Cell[33820, 1068, 245, 6, 50, "Input"],
Cell[34068, 1076, 73, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[34178, 1082, 31, 0, 42, "Subsubsection"],
Cell[34212, 1084, 243, 5, 43, "Input"],
Cell[34458, 1091, 157, 4, 27, "Input"],
Cell[34618, 1097, 200, 4, 52, "Input"],
Cell[34821, 1103, 199, 4, 31, "Input"],
Cell[35023, 1109, 86, 1, 27, "Input"],
Cell[35112, 1112, 187, 3, 43, "Input"],
Cell[35302, 1117, 508, 9, 123, "Input"],
Cell[35813, 1128, 471, 8, 115, "Input"]
}, Open  ]]
}, Closed]],
Cell[36311, 1140, 114, 2, 40, "Section",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[36450, 1146, 155, 5, 45, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[36630, 1155, 90, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[36723, 1159, 78, 1, 27, "Input"]
}, Closed]],
Cell[36816, 1163, 81, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[36900, 1167, 63, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[36988, 1172, 31, 0, 42, "Subsubsection"],
Cell[37022, 1174, 72, 1, 27, "Input"],
Cell[37097, 1177, 78, 1, 27, "Input"],
Cell[37178, 1180, 179, 3, 46, "Input"],
Cell[37360, 1185, 71, 1, 27, "Input"],
Cell[37434, 1188, 69, 1, 27, "Input"],
Cell[37506, 1191, 119, 4, 27, "Input"],
Cell[37628, 1197, 235, 4, 59, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[37900, 1206, 31, 0, 42, "Subsubsection"],
Cell[37934, 1208, 236, 5, 46, "Input"],
Cell[38173, 1215, 141, 2, 43, "Input"],
Cell[38317, 1219, 289, 7, 44, "Input"],
Cell[38609, 1228, 109, 2, 27, "Input"],
Cell[38721, 1232, 549, 16, 52, "Input"],
Cell[39273, 1250, 218, 4, 31, "Input"],
Cell[39494, 1256, 89, 1, 27, "Input"],
Cell[39586, 1259, 87, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[39710, 1265, 31, 0, 42, "Subsubsection"],
Cell[39744, 1267, 112, 2, 27, "Input"],
Cell[39859, 1271, 300, 6, 75, "Input"],
Cell[40162, 1279, 582, 14, 83, "Input"],
Cell[40747, 1295, 114, 2, 27, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[40910, 1303, 153, 5, 29, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[41088, 1312, 90, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[41181, 1316, 79, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[41297, 1322, 81, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[41381, 1326, 63, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[41481, 1332, 99, 4, 42, "Subsubsection"],
Cell[41583, 1338, 84, 1, 27, "Input"],
Cell[41670, 1341, 125, 2, 27, "Input"],
Cell[41798, 1345, 302, 7, 46, "Input"],
Cell[42103, 1354, 266, 7, 48, "Input"],
Cell[42372, 1363, 89, 1, 27, "Input"],
Cell[42464, 1366, 205, 4, 46, "Input"],
Cell[42672, 1372, 118, 4, 27, "Input"],
Cell[42793, 1378, 98, 1, 27, "Input"],
Cell[42894, 1381, 188, 3, 27, "Input"],
Cell[43085, 1386, 279, 6, 30, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[43401, 1397, 98, 4, 42, "Subsubsection"],
Cell[43502, 1403, 150, 2, 29, "Input"],
Cell[43655, 1407, 237, 5, 46, "Input"],
Cell[43895, 1414, 115, 4, 27, "Input"],
Cell[44013, 1420, 247, 5, 46, "Input"],
Cell[44263, 1427, 190, 3, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[44490, 1435, 98, 4, 42, "Subsubsection"],
Cell[44591, 1441, 314, 5, 43, "Input"],
Cell[44908, 1448, 180, 3, 27, "Input"],
Cell[45091, 1453, 88, 1, 27, "Input"],
Cell[45182, 1456, 73, 1, 27, "Input"],
Cell[45258, 1459, 110, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[45405, 1466, 31, 0, 42, "Subsubsection"],
Cell[45439, 1468, 241, 4, 27, "Input"],
Cell[45683, 1474, 252, 5, 62, "Input"],
Cell[45938, 1481, 295, 6, 27, "Input"],
Cell[46236, 1489, 280, 5, 27, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[46565, 1500, 121, 2, 29, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[46711, 1506, 90, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[46804, 1510, 118, 4, 42, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[46959, 1519, 81, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[47043, 1523, 63, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[47143, 1529, 31, 0, 42, "Subsubsection"],
Cell[47177, 1531, 859, 21, 46, "Input"],
Cell[48039, 1554, 91, 1, 27, "Input"],
Cell[48133, 1557, 177, 4, 33, "Input"],
Cell[48313, 1563, 153, 2, 27, "Input"],
Cell[48469, 1567, 277, 5, 43, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[48783, 1577, 31, 0, 42, "Subsubsection"],
Cell[48817, 1579, 50, 1, 27, "Input"],
Cell[48870, 1582, 117, 2, 27, "Input"],
Cell[48990, 1586, 289, 5, 43, "Input"],
Cell[49282, 1593, 246, 4, 59, "Input"],
Cell[49531, 1599, 559, 10, 123, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[50127, 1614, 31, 0, 42, "Subsubsection"],
Cell[50161, 1616, 820, 15, 139, "Input"],
Cell[50984, 1633, 471, 8, 107, "Input"],
Cell[51458, 1643, 75, 1, 27, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[51582, 1650, 119, 2, 29, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[51726, 1656, 90, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[51819, 1660, 71, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[51927, 1666, 81, 2, 28, "Subsubsection",
  Evaluatable->False],
Cell[52011, 1670, 63, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[52111, 1676, 31, 0, 28, "Subsubsection"],
Cell[52145, 1678, 788, 18, 29, "Input"],
Cell[52936, 1698, 104, 2, 27, "Input"],
Cell[53043, 1702, 246, 5, 48, "Input"],
Cell[53292, 1709, 155, 2, 27, "Input"],
Cell[53450, 1713, 190, 3, 27, "Input"],
Cell[53643, 1718, 286, 5, 43, "Input"],
Cell[53932, 1725, 103, 2, 27, "Input"],
Cell[54038, 1729, 183, 3, 27, "Input"],
Cell[54224, 1734, 88, 1, 27, "Input"],
Cell[54315, 1737, 137, 4, 27, "Input"],
Cell[54455, 1743, 340, 6, 43, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[54832, 1754, 31, 0, 28, "Subsubsection"],
Cell[54866, 1756, 169, 3, 27, "Input"],
Cell[55038, 1761, 117, 2, 27, "Input"],
Cell[55158, 1765, 145, 4, 27, "Input"],
Cell[55306, 1771, 281, 4, 71, "Input"],
Cell[55590, 1777, 164, 2, 27, "Input"],
Cell[55757, 1781, 60, 1, 27, "Input"],
Cell[55820, 1784, 84, 1, 27, "Input"],
Cell[55907, 1787, 116, 2, 27, "Input"],
Cell[56026, 1791, 85, 1, 27, "Input"],
Cell[56114, 1794, 71, 1, 27, "Input"],
Cell[56188, 1797, 214, 4, 59, "Input"],
Cell[56405, 1803, 119, 2, 27, "Input"],
Cell[56527, 1807, 116, 2, 27, "Input"],
Cell[56646, 1811, 257, 5, 43, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[56940, 1821, 31, 0, 28, "Subsubsection"],
Cell[56974, 1823, 189, 3, 27, "Input"],
Cell[57166, 1828, 178, 3, 27, "Input"],
Cell[57347, 1833, 500, 8, 91, "Input"],
Cell[57850, 1843, 529, 8, 107, "Input"],
Cell[58382, 1853, 529, 8, 107, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[58960, 1867, 190, 6, 29, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[59175, 1877, 90, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[59268, 1881, 81, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[59386, 1887, 81, 2, 28, "Subsubsection",
  Evaluatable->False],
Cell[59470, 1891, 63, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[59570, 1897, 31, 0, 28, "Subsubsection"],
Cell[59604, 1899, 975, 23, 46, "Input"],
Cell[60582, 1924, 73, 1, 27, "Input"],
Cell[60658, 1927, 277, 6, 47, "Input"],
Cell[60938, 1935, 104, 2, 27, "Input"],
Cell[61045, 1939, 64, 1, 27, "Input"],
Cell[61112, 1942, 273, 6, 62, "Input"],
Cell[61388, 1950, 161, 3, 27, "Input"],
Cell[61552, 1955, 180, 3, 31, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[61769, 1963, 31, 0, 28, "Subsubsection"],
Cell[61803, 1965, 316, 6, 43, "Input"],
Cell[62122, 1973, 382, 6, 99, "Input"],
Cell[62507, 1981, 132, 4, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[62676, 1990, 31, 0, 28, "Subsubsection"],
Cell[62710, 1992, 468, 8, 123, "Input"],
Cell[63181, 2002, 157, 6, 57, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[63387, 2014, 80, 2, 40, "Section",
  Evaluatable->False],
Cell[63470, 2018, 149, 5, 42, "Subsubsection",
  Evaluatable->False],
Cell[63622, 2025, 104, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[63729, 2029, 130, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[63862, 2034, 125, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[63990, 2038, 114, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[64107, 2042, 104, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[64214, 2046, 146, 5, 42, "Subsubsection",
  Evaluatable->False]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

